package com.google.android.exoplayer2.extractor.mkv;

import android.util.Log;
import android.util.Pair;
import android.util.SparseArray;
import androidx.annotation.Nullable;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.audio.Ac3Util;
import com.google.android.exoplayer2.drm.DrmInitData;
import com.google.android.exoplayer2.g0.e;
import com.google.android.exoplayer2.g0.f;
import com.google.android.exoplayer2.g0.g;
import com.google.android.exoplayer2.g0.h;
import com.google.android.exoplayer2.g0.m;
import com.google.android.exoplayer2.g0.o;
import com.google.android.exoplayer2.util.b0;
import com.google.android.exoplayer2.util.l;
import com.google.android.exoplayer2.util.n;
import com.google.android.exoplayer2.util.q;
import com.google.android.exoplayer2.video.ColorInfo;
import java.io.IOException;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Locale;
import java.util.UUID;

public final class MatroskaExtractor implements e {
    private static final String A = "A_MPEG/L3";
    private static final int A0 = 186;
    private static final byte[] A1 = {49, 10, 48, 48, 58, 48, 48, 58, 48, 48, 44, 48, 48, 48, 32, 45, 45, 62, 32, 48, 48, 58, 48, 48, 58, 48, 48, 44, 48, 48, 48, 10};
    private static final String B = "A_AC3";
    private static final int B0 = 21680;
    private static final int B1 = 19;
    private static final String C = "A_EAC3";
    private static final int C0 = 21690;
    private static final byte[] C1 = {32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32};
    private static final String D = "A_TRUEHD";
    private static final int D0 = 21682;
    private static final long D1 = 1000;
    private static final String E = "A_DTS";
    private static final int E0 = 225;
    private static final String E1 = "%02d:%02d:%02d,%03d";
    private static final String F = "A_DTS/EXPRESS";
    private static final int F0 = 159;
    private static final byte[] F1 = b0.S("Format: Start, End, ReadOrder, Layer, Style, Name, MarginL, MarginR, MarginV, Effect, Text");
    private static final String G = "A_DTS/LOSSLESS";
    private static final int G0 = 25188;
    private static final byte[] G1 = {68, 105, 97, 108, 111, 103, 117, 101, 58, 32, 48, 58, 48, 48, 58, 48, 48, 58, 48, 48, 44, 48, 58, 48, 48, 58, 48, 48, 58, 48, 48, 44};
    private static final String H = "A_FLAC";
    private static final int H0 = 181;
    private static final int H1 = 21;
    private static final String I = "A_MS/ACM";
    private static final int I0 = 28032;
    private static final long I1 = 10000;
    private static final String J = "A_PCM/INT/LIT";
    private static final int J0 = 25152;
    private static final byte[] J1 = {32, 32, 32, 32, 32, 32, 32, 32, 32, 32};
    private static final String K = "S_TEXT/UTF8";
    private static final int K0 = 20529;
    private static final String K1 = "%01d:%02d:%02d:%02d";
    private static final String L = "S_TEXT/ASS";
    private static final int L0 = 20530;
    private static final int L1 = 18;
    private static final String M = "S_VOBSUB";
    private static final int M0 = 20532;
    private static final int M1 = 65534;
    private static final String N = "S_HDMV/PGS";
    private static final int N0 = 16980;
    private static final int N1 = 1;
    private static final String O = "S_DVBSUB";
    private static final int O0 = 16981;
    private static final UUID O1 = new UUID(72057594037932032L, -9223371306706625679L);
    private static final int P = 8192;
    private static final int P0 = 20533;
    private static final int Q = 5760;
    private static final int Q0 = 18401;
    private static final int R = 8;
    private static final int R0 = 18402;
    private static final int S = 2;
    private static final int S0 = 18407;
    private static final int T = 440786851;
    private static final int T0 = 18408;
    private static final int U = 17143;
    private static final int U0 = 475249515;
    private static final int V = 17026;
    private static final int V0 = 187;
    private static final int W = 17029;
    private static final int W0 = 179;
    private static final int X = 408125543;
    private static final int X0 = 183;
    private static final int Y = 357149030;
    private static final int Y0 = 241;
    private static final int Z = 290298740;
    private static final int Z0 = 2274716;
    private static final int a0 = 19899;
    private static final int a1 = 30320;
    private static final int b0 = 21419;
    private static final int b1 = 30322;
    private static final int c0 = 21420;
    private static final int c1 = 21432;

    /* renamed from: d  reason: collision with root package name */
    public static final h f8132d = new a();
    private static final int d0 = 357149030;
    private static final int d1 = 21936;

    /* renamed from: e  reason: collision with root package name */
    public static final int f8133e = 1;
    private static final int e0 = 2807729;
    private static final int e1 = 21945;
    private static final String f = "MatroskaExtractor";
    private static final int f0 = 17545;
    private static final int f1 = 21946;
    private static final int g = -1;
    private static final int g0 = 524531317;
    private static final int g1 = 21947;
    private static final int h = 0;
    private static final int h0 = 231;
    private static final int h1 = 21948;
    private static final int i = 1;
    private static final int i0 = 163;
    private static final int i1 = 21949;
    private static final int j = 2;
    private static final int j0 = 160;
    private static final int j1 = 21968;
    private static final String k = "matroska";
    private static final int k0 = 161;
    private static final int k1 = 21969;
    private static final String l = "webm";
    private static final int l0 = 155;
    private static final int l1 = 21970;
    private static final String m = "V_VP8";
    private static final int m0 = 251;
    private static final int m1 = 21971;
    private static final String n = "V_VP9";
    private static final int n0 = 374648427;
    private static final int n1 = 21972;
    private static final String o = "V_MPEG2";
    private static final int o0 = 174;
    private static final int o1 = 21973;
    private static final String p = "V_MPEG4/ISO/SP";
    private static final int p0 = 215;
    private static final int p1 = 21974;
    private static final String q = "V_MPEG4/ISO/ASP";
    private static final int q0 = 131;
    private static final int q1 = 21975;
    private static final String r = "V_MPEG4/ISO/AP";
    private static final int r0 = 136;
    private static final int r1 = 21976;
    private static final String s = "V_MPEG4/ISO/AVC";
    private static final int s0 = 21930;
    private static final int s1 = 21977;
    private static final String t = "V_MPEGH/ISO/HEVC";
    private static final int t0 = 2352003;
    private static final int t1 = 21978;
    private static final String u = "V_MS/VFW/FOURCC";
    private static final int u0 = 134;
    private static final int u1 = 0;
    private static final String v = "V_THEORA";
    private static final int v0 = 25506;
    private static final int v1 = 1;
    private static final String w = "A_VORBIS";
    private static final int w0 = 22186;
    private static final int w1 = 2;
    private static final String x = "A_OPUS";
    private static final int x0 = 22203;
    private static final int x1 = 3;
    private static final String y = "A_AAC";
    private static final int y0 = 224;
    private static final int y1 = 826496599;
    private static final String z = "A_MPEG/L2";
    private static final int z0 = 176;
    private static final int z1 = 1482049860;
    private int A2;
    private int B2;
    private int C2;
    private boolean D2;
    private boolean E2;
    private boolean F2;
    private boolean G2;
    private byte H2;
    private int I2;
    private int J2;
    private int K2;
    private boolean L2;
    private boolean M2;
    private g N2;
    private final b P1;
    private final d Q1;
    private final SparseArray<c> R1;
    private final boolean S1;
    private final q T1;
    private final q U1;
    private final q V1;
    private final q W1;
    private final q X1;
    private final q Y1;
    private final q Z1;
    private final q a2;
    private final q b2;
    private ByteBuffer c2;
    private long d2;
    private long e2;
    private long f2;
    private long g2;
    private long h2;
    private c i2;
    private boolean j2;
    private int k2;
    private long l2;
    private boolean m2;
    private long n2;
    private long o2;
    private long p2;
    private l q2;
    private l r2;
    private boolean s2;
    private int t2;
    private long u2;
    private long v2;
    private int w2;
    private int x2;
    private int[] y2;
    private int z2;

    @Retention(RetentionPolicy.SOURCE)
    public @interface Flags {
    }

    /* access modifiers changed from: package-private */
    public static class a implements h {
        a() {
        }

        @Override // com.google.android.exoplayer2.g0.h
        public e[] a() {
            return new e[]{new MatroskaExtractor()};
        }
    }

    private final class b implements EbmlReaderOutput {
        private b() {
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public void a(int i) throws ParserException {
            MatroskaExtractor.this.k(i);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public int b(int i) {
            switch (i) {
                case 131:
                case 136:
                case 155:
                case 159:
                case 176:
                case 179:
                case 186:
                case 215:
                case 231:
                case 241:
                case 251:
                case MatroskaExtractor.N0 /*{ENCODED_INT: 16980}*/:
                case MatroskaExtractor.W /*{ENCODED_INT: 17029}*/:
                case MatroskaExtractor.U /*{ENCODED_INT: 17143}*/:
                case MatroskaExtractor.Q0 /*{ENCODED_INT: 18401}*/:
                case MatroskaExtractor.T0 /*{ENCODED_INT: 18408}*/:
                case MatroskaExtractor.K0 /*{ENCODED_INT: 20529}*/:
                case MatroskaExtractor.L0 /*{ENCODED_INT: 20530}*/:
                case MatroskaExtractor.c0 /*{ENCODED_INT: 21420}*/:
                case MatroskaExtractor.c1 /*{ENCODED_INT: 21432}*/:
                case MatroskaExtractor.B0 /*{ENCODED_INT: 21680}*/:
                case MatroskaExtractor.D0 /*{ENCODED_INT: 21682}*/:
                case MatroskaExtractor.C0 /*{ENCODED_INT: 21690}*/:
                case MatroskaExtractor.s0 /*{ENCODED_INT: 21930}*/:
                case MatroskaExtractor.e1 /*{ENCODED_INT: 21945}*/:
                case MatroskaExtractor.f1 /*{ENCODED_INT: 21946}*/:
                case MatroskaExtractor.g1 /*{ENCODED_INT: 21947}*/:
                case MatroskaExtractor.h1 /*{ENCODED_INT: 21948}*/:
                case MatroskaExtractor.i1 /*{ENCODED_INT: 21949}*/:
                case MatroskaExtractor.w0 /*{ENCODED_INT: 22186}*/:
                case MatroskaExtractor.x0 /*{ENCODED_INT: 22203}*/:
                case MatroskaExtractor.G0 /*{ENCODED_INT: 25188}*/:
                case MatroskaExtractor.t0 /*{ENCODED_INT: 2352003}*/:
                case MatroskaExtractor.e0 /*{ENCODED_INT: 2807729}*/:
                    return 2;
                case 134:
                case 17026:
                case MatroskaExtractor.Z0 /*{ENCODED_INT: 2274716}*/:
                    return 3;
                case 160:
                case 174:
                case 183:
                case 187:
                case 224:
                case 225:
                case MatroskaExtractor.S0 /*{ENCODED_INT: 18407}*/:
                case MatroskaExtractor.a0 /*{ENCODED_INT: 19899}*/:
                case MatroskaExtractor.M0 /*{ENCODED_INT: 20532}*/:
                case MatroskaExtractor.P0 /*{ENCODED_INT: 20533}*/:
                case MatroskaExtractor.d1 /*{ENCODED_INT: 21936}*/:
                case MatroskaExtractor.j1 /*{ENCODED_INT: 21968}*/:
                case MatroskaExtractor.J0 /*{ENCODED_INT: 25152}*/:
                case MatroskaExtractor.I0 /*{ENCODED_INT: 28032}*/:
                case MatroskaExtractor.a1 /*{ENCODED_INT: 30320}*/:
                case MatroskaExtractor.Z /*{ENCODED_INT: 290298740}*/:
                case 357149030:
                case MatroskaExtractor.n0 /*{ENCODED_INT: 374648427}*/:
                case MatroskaExtractor.X /*{ENCODED_INT: 408125543}*/:
                case MatroskaExtractor.T /*{ENCODED_INT: 440786851}*/:
                case MatroskaExtractor.U0 /*{ENCODED_INT: 475249515}*/:
                case MatroskaExtractor.g0 /*{ENCODED_INT: 524531317}*/:
                    return 1;
                case 161:
                case 163:
                case MatroskaExtractor.O0 /*{ENCODED_INT: 16981}*/:
                case MatroskaExtractor.R0 /*{ENCODED_INT: 18402}*/:
                case MatroskaExtractor.b0 /*{ENCODED_INT: 21419}*/:
                case MatroskaExtractor.v0 /*{ENCODED_INT: 25506}*/:
                case MatroskaExtractor.b1 /*{ENCODED_INT: 30322}*/:
                    return 4;
                case 181:
                case MatroskaExtractor.f0 /*{ENCODED_INT: 17545}*/:
                case MatroskaExtractor.k1 /*{ENCODED_INT: 21969}*/:
                case MatroskaExtractor.l1 /*{ENCODED_INT: 21970}*/:
                case MatroskaExtractor.m1 /*{ENCODED_INT: 21971}*/:
                case MatroskaExtractor.n1 /*{ENCODED_INT: 21972}*/:
                case MatroskaExtractor.o1 /*{ENCODED_INT: 21973}*/:
                case MatroskaExtractor.p1 /*{ENCODED_INT: 21974}*/:
                case MatroskaExtractor.q1 /*{ENCODED_INT: 21975}*/:
                case MatroskaExtractor.r1 /*{ENCODED_INT: 21976}*/:
                case MatroskaExtractor.s1 /*{ENCODED_INT: 21977}*/:
                case MatroskaExtractor.t1 /*{ENCODED_INT: 21978}*/:
                    return 5;
                default:
                    return 0;
            }
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public boolean c(int i) {
            return i == 357149030 || i == MatroskaExtractor.g0 || i == MatroskaExtractor.U0 || i == MatroskaExtractor.n0;
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public void d(int i, int i2, f fVar) throws IOException, InterruptedException {
            MatroskaExtractor.this.g(i, i2, fVar);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public void e(int i, String str) throws ParserException {
            MatroskaExtractor.this.x(i, str);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public void f(int i, double d2) throws ParserException {
            MatroskaExtractor.this.m(i, d2);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public void g(int i, long j, long j2) throws ParserException {
            MatroskaExtractor.this.w(i, j, j2);
        }

        @Override // com.google.android.exoplayer2.extractor.mkv.EbmlReaderOutput
        public void h(int i, long j) throws ParserException {
            MatroskaExtractor.this.n(i, j);
        }

        /* synthetic */ b(MatroskaExtractor matroskaExtractor, a aVar) {
            this();
        }
    }

    /* access modifiers changed from: private */
    public static final class d {

        /* renamed from: a  reason: collision with root package name */
        private final byte[] f8139a = new byte[10];

        /* renamed from: b  reason: collision with root package name */
        private boolean f8140b;

        /* renamed from: c  reason: collision with root package name */
        private int f8141c;

        /* renamed from: d  reason: collision with root package name */
        private int f8142d;

        /* renamed from: e  reason: collision with root package name */
        private long f8143e;
        private int f;

        public void a(c cVar) {
            if (this.f8140b && this.f8141c > 0) {
                cVar.T.c(this.f8143e, this.f, this.f8142d, 0, cVar.k);
                this.f8141c = 0;
            }
        }

        public void b() {
            this.f8140b = false;
        }

        public void c(c cVar, long j) {
            if (this.f8140b) {
                int i = this.f8141c;
                int i2 = i + 1;
                this.f8141c = i2;
                if (i == 0) {
                    this.f8143e = j;
                }
                if (i2 >= 16) {
                    cVar.T.c(this.f8143e, this.f, this.f8142d, 0, cVar.k);
                    this.f8141c = 0;
                }
            }
        }

        public void d(f fVar, int i, int i2) throws IOException, InterruptedException {
            if (!this.f8140b) {
                fVar.l(this.f8139a, 0, 10);
                fVar.i();
                if (Ac3Util.j(this.f8139a) != -1) {
                    this.f8140b = true;
                    this.f8141c = 0;
                } else {
                    return;
                }
            }
            if (this.f8141c == 0) {
                this.f = i;
                this.f8142d = 0;
            }
            this.f8142d += i2;
        }
    }

    public MatroskaExtractor() {
        this(0);
    }

    private m h() {
        l lVar;
        l lVar2;
        if (this.e2 == -1 || this.h2 == C.f7870b || (lVar = this.q2) == null || lVar.c() == 0 || (lVar2 = this.r2) == null || lVar2.c() != this.q2.c()) {
            this.q2 = null;
            this.r2 = null;
            return new m.b(this.h2);
        }
        int c3 = this.q2.c();
        int[] iArr = new int[c3];
        long[] jArr = new long[c3];
        long[] jArr2 = new long[c3];
        long[] jArr3 = new long[c3];
        int i3 = 0;
        for (int i4 = 0; i4 < c3; i4++) {
            jArr3[i4] = this.q2.b(i4);
            jArr[i4] = this.e2 + this.r2.b(i4);
        }
        while (true) {
            int i5 = c3 - 1;
            if (i3 < i5) {
                int i6 = i3 + 1;
                iArr[i3] = (int) (jArr[i6] - jArr[i3]);
                jArr2[i3] = jArr3[i6] - jArr3[i3];
                i3 = i6;
            } else {
                iArr[i5] = (int) ((this.e2 + this.d2) - jArr[i5]);
                jArr2[i5] = this.h2 - jArr3[i5];
                this.q2 = null;
                this.r2 = null;
                return new com.google.android.exoplayer2.g0.a(iArr, jArr, jArr2, jArr3);
            }
        }
    }

    private void i(c cVar, long j3) {
        d dVar = cVar.P;
        if (dVar != null) {
            dVar.c(cVar, j3);
        } else {
            if (K.equals(cVar.f8138e)) {
                j(cVar, E1, 19, 1000, C1);
            } else if (L.equals(cVar.f8138e)) {
                j(cVar, K1, 21, 10000, J1);
            }
            cVar.T.c(j3, this.B2, this.K2, 0, cVar.k);
        }
        this.L2 = true;
        t();
    }

    private void j(c cVar, String str, int i3, long j3, byte[] bArr) {
        v(this.Z1.f9627a, this.v2, str, i3, j3, bArr);
        o oVar = cVar.T;
        q qVar = this.Z1;
        oVar.b(qVar, qVar.d());
        this.K2 += this.Z1.d();
    }

    private static int[] l(int[] iArr, int i3) {
        if (iArr == null) {
            return new int[i3];
        }
        if (iArr.length >= i3) {
            return iArr;
        }
        return new int[Math.max(iArr.length * 2, i3)];
    }

    private static boolean o(String str) {
        return m.equals(str) || n.equals(str) || o.equals(str) || p.equals(str) || q.equals(str) || r.equals(str) || s.equals(str) || t.equals(str) || u.equals(str) || v.equals(str) || x.equals(str) || w.equals(str) || y.equals(str) || z.equals(str) || A.equals(str) || B.equals(str) || C.equals(str) || D.equals(str) || E.equals(str) || F.equals(str) || G.equals(str) || H.equals(str) || I.equals(str) || J.equals(str) || K.equals(str) || L.equals(str) || M.equals(str) || N.equals(str) || O.equals(str);
    }

    private boolean p(com.google.android.exoplayer2.g0.l lVar, long j3) {
        if (this.m2) {
            this.o2 = j3;
            lVar.f8429a = this.n2;
            this.m2 = false;
            return true;
        }
        if (this.j2) {
            long j4 = this.o2;
            if (j4 != -1) {
                lVar.f8429a = j4;
                this.o2 = -1;
                return true;
            }
        }
        return false;
    }

    private void q(f fVar, int i3) throws IOException, InterruptedException {
        if (this.V1.d() < i3) {
            if (this.V1.b() < i3) {
                q qVar = this.V1;
                byte[] bArr = qVar.f9627a;
                qVar.N(Arrays.copyOf(bArr, Math.max(bArr.length * 2, i3)), this.V1.d());
            }
            q qVar2 = this.V1;
            fVar.readFully(qVar2.f9627a, qVar2.d(), i3 - this.V1.d());
            this.V1.O(i3);
        }
    }

    private int r(f fVar, o oVar, int i3) throws IOException, InterruptedException {
        int i4;
        int a3 = this.Y1.a();
        if (a3 > 0) {
            i4 = Math.min(i3, a3);
            oVar.b(this.Y1, i4);
        } else {
            i4 = oVar.a(fVar, i3, false);
        }
        this.C2 += i4;
        this.K2 += i4;
        return i4;
    }

    private void s(f fVar, byte[] bArr, int i3, int i4) throws IOException, InterruptedException {
        int min = Math.min(i4, this.Y1.a());
        fVar.readFully(bArr, i3 + min, i4 - min);
        if (min > 0) {
            this.Y1.i(bArr, i3, min);
        }
        this.C2 += i4;
    }

    private void t() {
        this.C2 = 0;
        this.K2 = 0;
        this.J2 = 0;
        this.D2 = false;
        this.E2 = false;
        this.G2 = false;
        this.I2 = 0;
        this.H2 = 0;
        this.F2 = false;
        this.Y1.L();
    }

    private long u(long j3) throws ParserException {
        long j4 = this.f2;
        if (j4 != C.f7870b) {
            return b0.k0(j3, j4, 1000);
        }
        throw new ParserException("Can't scale timecode prior to timecodeScale being set.");
    }

    private static void v(byte[] bArr, long j3, String str, int i3, long j4, byte[] bArr2) {
        byte[] bArr3;
        byte[] bArr4;
        if (j3 == C.f7870b) {
            bArr4 = bArr2;
            bArr3 = bArr4;
        } else {
            int i4 = (int) (j3 / 3600000000L);
            long j5 = j3 - (((long) (i4 * com.blankj.utilcode.constant.a.f6461c)) * 1000000);
            int i5 = (int) (j5 / 60000000);
            long j6 = j5 - (((long) (i5 * 60)) * 1000000);
            int i6 = (int) (j6 / 1000000);
            int i7 = (int) ((j6 - (((long) i6) * 1000000)) / j4);
            bArr4 = b0.S(String.format(Locale.US, str, Integer.valueOf(i4), Integer.valueOf(i5), Integer.valueOf(i6), Integer.valueOf(i7)));
            bArr3 = bArr2;
        }
        System.arraycopy(bArr4, 0, bArr, i3, bArr3.length);
    }

    private void y(f fVar, c cVar, int i3) throws IOException, InterruptedException {
        int i4;
        if (K.equals(cVar.f8138e)) {
            z(fVar, A1, i3);
        } else if (L.equals(cVar.f8138e)) {
            z(fVar, G1, i3);
        } else {
            o oVar = cVar.T;
            boolean z3 = true;
            if (!this.D2) {
                if (cVar.i) {
                    this.B2 &= -1073741825;
                    int i5 = 128;
                    if (!this.E2) {
                        fVar.readFully(this.V1.f9627a, 0, 1);
                        this.C2++;
                        byte[] bArr = this.V1.f9627a;
                        if ((bArr[0] & 128) != 128) {
                            this.H2 = bArr[0];
                            this.E2 = true;
                        } else {
                            throw new ParserException("Extension bit is set in signal byte");
                        }
                    }
                    byte b3 = this.H2;
                    if ((b3 & 1) == 1) {
                        boolean z4 = (b3 & 2) == 2;
                        this.B2 |= 1073741824;
                        if (!this.F2) {
                            fVar.readFully(this.a2.f9627a, 0, 8);
                            this.C2 += 8;
                            this.F2 = true;
                            q qVar = this.V1;
                            byte[] bArr2 = qVar.f9627a;
                            if (!z4) {
                                i5 = 0;
                            }
                            bArr2[0] = (byte) (i5 | 8);
                            qVar.P(0);
                            oVar.b(this.V1, 1);
                            this.K2++;
                            this.a2.P(0);
                            oVar.b(this.a2, 8);
                            this.K2 += 8;
                        }
                        if (z4) {
                            if (!this.G2) {
                                fVar.readFully(this.V1.f9627a, 0, 1);
                                this.C2++;
                                this.V1.P(0);
                                this.I2 = this.V1.D();
                                this.G2 = true;
                            }
                            int i6 = this.I2 * 4;
                            this.V1.M(i6);
                            fVar.readFully(this.V1.f9627a, 0, i6);
                            this.C2 += i6;
                            short s3 = (short) ((this.I2 / 2) + 1);
                            int i7 = (s3 * 6) + 2;
                            ByteBuffer byteBuffer = this.c2;
                            if (byteBuffer == null || byteBuffer.capacity() < i7) {
                                this.c2 = ByteBuffer.allocate(i7);
                            }
                            this.c2.position(0);
                            this.c2.putShort(s3);
                            int i8 = 0;
                            int i9 = 0;
                            while (true) {
                                i4 = this.I2;
                                if (i8 >= i4) {
                                    break;
                                }
                                int H3 = this.V1.H();
                                if (i8 % 2 == 0) {
                                    this.c2.putShort((short) (H3 - i9));
                                } else {
                                    this.c2.putInt(H3 - i9);
                                }
                                i8++;
                                i9 = H3;
                            }
                            int i10 = (i3 - this.C2) - i9;
                            if (i4 % 2 == 1) {
                                this.c2.putInt(i10);
                            } else {
                                this.c2.putShort((short) i10);
                                this.c2.putInt(0);
                            }
                            this.b2.N(this.c2.array(), i7);
                            oVar.b(this.b2, i7);
                            this.K2 += i7;
                        }
                    }
                } else {
                    byte[] bArr3 = cVar.j;
                    if (bArr3 != null) {
                        this.Y1.N(bArr3, bArr3.length);
                    }
                }
                this.D2 = true;
            }
            int d3 = i3 + this.Y1.d();
            if (!s.equals(cVar.f8138e) && !t.equals(cVar.f8138e)) {
                if (cVar.P != null) {
                    if (this.Y1.d() != 0) {
                        z3 = false;
                    }
                    com.google.android.exoplayer2.util.a.i(z3);
                    cVar.P.d(fVar, this.B2, d3);
                }
                while (true) {
                    int i11 = this.C2;
                    if (i11 >= d3) {
                        break;
                    }
                    r(fVar, oVar, d3 - i11);
                }
            } else {
                byte[] bArr4 = this.U1.f9627a;
                bArr4[0] = 0;
                bArr4[1] = 0;
                bArr4[2] = 0;
                int i12 = cVar.U;
                int i13 = 4 - i12;
                while (this.C2 < d3) {
                    int i14 = this.J2;
                    if (i14 == 0) {
                        s(fVar, bArr4, i13, i12);
                        this.U1.P(0);
                        this.J2 = this.U1.H();
                        this.T1.P(0);
                        oVar.b(this.T1, 4);
                        this.K2 += 4;
                    } else {
                        this.J2 = i14 - r(fVar, oVar, i14);
                    }
                }
            }
            if (w.equals(cVar.f8138e)) {
                this.W1.P(0);
                oVar.b(this.W1, 4);
                this.K2 += 4;
            }
        }
    }

    private void z(f fVar, byte[] bArr, int i3) throws IOException, InterruptedException {
        int length = bArr.length + i3;
        if (this.Z1.b() < length) {
            this.Z1.f9627a = Arrays.copyOf(bArr, length + i3);
        } else {
            System.arraycopy(bArr, 0, this.Z1.f9627a, 0, bArr.length);
        }
        fVar.readFully(this.Z1.f9627a, bArr.length, i3);
        this.Z1.M(length);
    }

    @Override // com.google.android.exoplayer2.g0.e
    public boolean b(f fVar) throws IOException, InterruptedException {
        return new c().b(fVar);
    }

    @Override // com.google.android.exoplayer2.g0.e
    public int d(f fVar, com.google.android.exoplayer2.g0.l lVar) throws IOException, InterruptedException {
        this.L2 = false;
        boolean z3 = true;
        while (z3 && !this.L2) {
            z3 = this.P1.b(fVar);
            if (z3 && p(lVar, fVar.getPosition())) {
                return 1;
            }
        }
        if (z3) {
            return 0;
        }
        for (int i3 = 0; i3 < this.R1.size(); i3++) {
            this.R1.valueAt(i3).d();
        }
        return -1;
    }

    @Override // com.google.android.exoplayer2.g0.e
    public void e(g gVar) {
        this.N2 = gVar;
    }

    @Override // com.google.android.exoplayer2.g0.e
    public void f(long j3, long j4) {
        this.p2 = C.f7870b;
        this.t2 = 0;
        this.P1.a();
        this.Q1.e();
        t();
        for (int i3 = 0; i3 < this.R1.size(); i3++) {
            this.R1.valueAt(i3).h();
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Code restructure failed: missing block: B:71:0x01f3, code lost:
        throw new com.google.android.exoplayer2.ParserException("EBML lacing sample size out of range.");
     */
    /* JADX WARNING: Removed duplicated region for block: B:77:0x022a  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x022c  */
    /* JADX WARNING: Removed duplicated region for block: B:88:0x0242  */
    /* JADX WARNING: Removed duplicated region for block: B:89:0x0245  */
    public void g(int i3, int i4, f fVar) throws IOException, InterruptedException {
        char c3;
        int i5;
        int i6;
        int[] iArr;
        int i7 = 0;
        int i8 = 1;
        if (i3 == 161 || i3 == 163) {
            if (this.t2 == 0) {
                this.z2 = (int) this.Q1.d(fVar, false, true, 8);
                this.A2 = this.Q1.b();
                this.v2 = C.f7870b;
                this.t2 = 1;
                this.V1.L();
            }
            c cVar = this.R1.get(this.z2);
            if (cVar == null) {
                fVar.j(i4 - this.A2);
                this.t2 = 0;
                return;
            }
            if (this.t2 == 1) {
                q(fVar, 3);
                int i9 = (this.V1.f9627a[2] & 6) >> 1;
                byte b3 = 255;
                if (i9 == 0) {
                    this.x2 = 1;
                    int[] l3 = l(this.y2, 1);
                    this.y2 = l3;
                    l3[0] = (i4 - this.A2) - 3;
                } else if (i3 == 163) {
                    int i10 = 4;
                    q(fVar, 4);
                    int i11 = (this.V1.f9627a[3] & 255) + 1;
                    this.x2 = i11;
                    int[] l4 = l(this.y2, i11);
                    this.y2 = l4;
                    if (i9 == 2) {
                        int i12 = this.x2;
                        Arrays.fill(l4, 0, i12, ((i4 - this.A2) - 4) / i12);
                    } else if (i9 == 1) {
                        int i13 = 0;
                        int i14 = 0;
                        while (true) {
                            i5 = this.x2;
                            if (i13 >= i5 - 1) {
                                break;
                            }
                            this.y2[i13] = 0;
                            do {
                                i10++;
                                q(fVar, i10);
                                i6 = this.V1.f9627a[i10 - 1] & 255;
                                iArr = this.y2;
                                iArr[i13] = iArr[i13] + i6;
                            } while (i6 == 255);
                            i14 += iArr[i13];
                            i13++;
                        }
                        this.y2[i5 - 1] = ((i4 - this.A2) - i10) - i14;
                    } else if (i9 == 3) {
                        int i15 = 0;
                        int i16 = 0;
                        while (true) {
                            int i17 = this.x2;
                            if (i15 >= i17 - 1) {
                                c3 = 1;
                                this.y2[i17 - 1] = ((i4 - this.A2) - i10) - i16;
                                break;
                            }
                            this.y2[i15] = i7;
                            i10++;
                            q(fVar, i10);
                            int i18 = i10 - 1;
                            if (this.V1.f9627a[i18] != 0) {
                                long j3 = 0;
                                int i19 = 0;
                                while (true) {
                                    if (i19 >= 8) {
                                        break;
                                    }
                                    int i20 = i8 << (7 - i19);
                                    if ((this.V1.f9627a[i18] & i20) != 0) {
                                        i10 += i19;
                                        q(fVar, i10);
                                        long j4 = (long) ((~i20) & this.V1.f9627a[i18] & b3);
                                        int i21 = i18 + 1;
                                        j3 = j4;
                                        while (i21 < i10) {
                                            b3 = 255;
                                            i21++;
                                            j3 = (j3 << 8) | ((long) (this.V1.f9627a[i21] & b3));
                                        }
                                        if (i15 > 0) {
                                            j3 -= (1 << ((i19 * 7) + 6)) - 1;
                                        }
                                    } else {
                                        i19++;
                                        i8 = 1;
                                        b3 = 255;
                                    }
                                }
                                if (j3 >= -2147483648L && j3 <= 2147483647L) {
                                    int i22 = (int) j3;
                                    int[] iArr2 = this.y2;
                                    if (i15 != 0) {
                                        i22 += iArr2[i15 - 1];
                                    }
                                    iArr2[i15] = i22;
                                    i16 += iArr2[i15];
                                    i15++;
                                    i7 = 0;
                                    i8 = 1;
                                    b3 = 255;
                                }
                            } else {
                                throw new ParserException("No valid varint length mask found");
                            }
                        }
                        byte[] bArr = this.V1.f9627a;
                        this.u2 = this.p2 + u((long) ((bArr[c3] & 255) | (bArr[0] << 8)));
                        byte[] bArr2 = this.V1.f9627a;
                        this.B2 = ((cVar.g != 2 || (i3 == 163 && (bArr2[2] & 128) == 128)) ? 1 : 0) | (!((bArr2[2] & 8) != 8) ? Integer.MIN_VALUE : 0);
                        this.t2 = 2;
                        this.w2 = 0;
                    } else {
                        throw new ParserException("Unexpected lacing value: " + i9);
                    }
                } else {
                    throw new ParserException("Lacing only supported in SimpleBlocks.");
                }
                c3 = 1;
                byte[] bArr3 = this.V1.f9627a;
                this.u2 = this.p2 + u((long) ((bArr3[c3] & 255) | (bArr3[0] << 8)));
                byte[] bArr22 = this.V1.f9627a;
                if ((bArr22[2] & 8) != 8) {
                }
                this.B2 = ((cVar.g != 2 || (i3 == 163 && (bArr22[2] & 128) == 128)) ? 1 : 0) | (!((bArr22[2] & 8) != 8) ? Integer.MIN_VALUE : 0);
                this.t2 = 2;
                this.w2 = 0;
            }
            if (i3 == 163) {
                while (true) {
                    int i23 = this.w2;
                    if (i23 < this.x2) {
                        y(fVar, cVar, this.y2[i23]);
                        i(cVar, this.u2 + ((long) ((this.w2 * cVar.h) / 1000)));
                        this.w2++;
                    } else {
                        this.t2 = 0;
                        return;
                    }
                }
            } else {
                y(fVar, cVar, this.y2[0]);
            }
        } else if (i3 == O0) {
            byte[] bArr4 = new byte[i4];
            this.i2.j = bArr4;
            fVar.readFully(bArr4, 0, i4);
        } else if (i3 == R0) {
            byte[] bArr5 = new byte[i4];
            fVar.readFully(bArr5, 0, i4);
            this.i2.k = new o.a(1, bArr5, 0, 0);
        } else if (i3 == b0) {
            Arrays.fill(this.X1.f9627a, (byte) 0);
            fVar.readFully(this.X1.f9627a, 4 - i4, i4);
            this.X1.P(0);
            this.k2 = (int) this.X1.F();
        } else if (i3 == v0) {
            byte[] bArr6 = new byte[i4];
            this.i2.l = bArr6;
            fVar.readFully(bArr6, 0, i4);
        } else if (i3 == b1) {
            byte[] bArr7 = new byte[i4];
            this.i2.s = bArr7;
            fVar.readFully(bArr7, 0, i4);
        } else {
            throw new ParserException("Unexpected id: " + i3);
        }
    }

    /* access modifiers changed from: package-private */
    public void k(int i3) throws ParserException {
        if (i3 != 160) {
            if (i3 == 174) {
                if (o(this.i2.f8138e)) {
                    c cVar = this.i2;
                    cVar.c(this.N2, cVar.f);
                    SparseArray<c> sparseArray = this.R1;
                    c cVar2 = this.i2;
                    sparseArray.put(cVar2.f, cVar2);
                }
                this.i2 = null;
            } else if (i3 == a0) {
                int i4 = this.k2;
                if (i4 != -1) {
                    long j3 = this.l2;
                    if (j3 != -1) {
                        if (i4 == U0) {
                            this.n2 = j3;
                            return;
                        }
                        return;
                    }
                }
                throw new ParserException("Mandatory element SeekID or SeekPosition not found");
            } else if (i3 == J0) {
                c cVar3 = this.i2;
                if (!cVar3.i) {
                    return;
                }
                if (cVar3.k != null) {
                    cVar3.m = new DrmInitData(new DrmInitData.SchemeData(C.h1, n.f, this.i2.k.f8438b));
                    return;
                }
                throw new ParserException("Encrypted Track found but ContentEncKeyID was not found");
            } else if (i3 == I0) {
                c cVar4 = this.i2;
                if (cVar4.i && cVar4.j != null) {
                    throw new ParserException("Combining encryption and compression is not supported");
                }
            } else if (i3 == 357149030) {
                if (this.f2 == C.f7870b) {
                    this.f2 = 1000000;
                }
                long j4 = this.g2;
                if (j4 != C.f7870b) {
                    this.h2 = u(j4);
                }
            } else if (i3 != n0) {
                if (i3 == U0 && !this.j2) {
                    this.N2.g(h());
                    this.j2 = true;
                }
            } else if (this.R1.size() != 0) {
                this.N2.o();
            } else {
                throw new ParserException("No valid tracks were found");
            }
        } else if (this.t2 == 2) {
            if (!this.M2) {
                this.B2 |= 1;
            }
            i(this.R1.get(this.z2), this.u2);
            this.t2 = 0;
        }
    }

    /* access modifiers changed from: package-private */
    public void m(int i3, double d3) {
        if (i3 == 181) {
            this.i2.M = (int) d3;
        } else if (i3 != f0) {
            switch (i3) {
                case k1 /*{ENCODED_INT: 21969}*/:
                    this.i2.A = (float) d3;
                    return;
                case l1 /*{ENCODED_INT: 21970}*/:
                    this.i2.B = (float) d3;
                    return;
                case m1 /*{ENCODED_INT: 21971}*/:
                    this.i2.C = (float) d3;
                    return;
                case n1 /*{ENCODED_INT: 21972}*/:
                    this.i2.D = (float) d3;
                    return;
                case o1 /*{ENCODED_INT: 21973}*/:
                    this.i2.E = (float) d3;
                    return;
                case p1 /*{ENCODED_INT: 21974}*/:
                    this.i2.F = (float) d3;
                    return;
                case q1 /*{ENCODED_INT: 21975}*/:
                    this.i2.G = (float) d3;
                    return;
                case r1 /*{ENCODED_INT: 21976}*/:
                    this.i2.H = (float) d3;
                    return;
                case s1 /*{ENCODED_INT: 21977}*/:
                    this.i2.I = (float) d3;
                    return;
                case t1 /*{ENCODED_INT: 21978}*/:
                    this.i2.J = (float) d3;
                    return;
                default:
                    return;
            }
        } else {
            this.g2 = (long) d3;
        }
    }

    /* access modifiers changed from: package-private */
    public void n(int i3, long j3) throws ParserException {
        if (i3 != K0) {
            if (i3 != L0) {
                boolean z3 = false;
                switch (i3) {
                    case 131:
                        this.i2.g = (int) j3;
                        return;
                    case 136:
                        c cVar = this.i2;
                        if (j3 == 1) {
                            z3 = true;
                        }
                        cVar.R = z3;
                        return;
                    case 155:
                        this.v2 = u(j3);
                        return;
                    case 159:
                        this.i2.K = (int) j3;
                        return;
                    case 176:
                        this.i2.n = (int) j3;
                        return;
                    case 179:
                        this.q2.a(u(j3));
                        return;
                    case 186:
                        this.i2.o = (int) j3;
                        return;
                    case 215:
                        this.i2.f = (int) j3;
                        return;
                    case 231:
                        this.p2 = u(j3);
                        return;
                    case 241:
                        if (!this.s2) {
                            this.r2.a(j3);
                            this.s2 = true;
                            return;
                        }
                        return;
                    case 251:
                        this.M2 = true;
                        return;
                    case N0 /*{ENCODED_INT: 16980}*/:
                        if (j3 != 3) {
                            throw new ParserException("ContentCompAlgo " + j3 + " not supported");
                        }
                        return;
                    case W /*{ENCODED_INT: 17029}*/:
                        if (j3 < 1 || j3 > 2) {
                            throw new ParserException("DocTypeReadVersion " + j3 + " not supported");
                        }
                        return;
                    case U /*{ENCODED_INT: 17143}*/:
                        if (j3 != 1) {
                            throw new ParserException("EBMLReadVersion " + j3 + " not supported");
                        }
                        return;
                    case Q0 /*{ENCODED_INT: 18401}*/:
                        if (j3 != 5) {
                            throw new ParserException("ContentEncAlgo " + j3 + " not supported");
                        }
                        return;
                    case T0 /*{ENCODED_INT: 18408}*/:
                        if (j3 != 1) {
                            throw new ParserException("AESSettingsCipherMode " + j3 + " not supported");
                        }
                        return;
                    case c0 /*{ENCODED_INT: 21420}*/:
                        this.l2 = j3 + this.e2;
                        return;
                    case c1 /*{ENCODED_INT: 21432}*/:
                        int i4 = (int) j3;
                        if (i4 == 0) {
                            this.i2.t = 0;
                            return;
                        } else if (i4 == 1) {
                            this.i2.t = 2;
                            return;
                        } else if (i4 == 3) {
                            this.i2.t = 1;
                            return;
                        } else if (i4 == 15) {
                            this.i2.t = 3;
                            return;
                        } else {
                            return;
                        }
                    case B0 /*{ENCODED_INT: 21680}*/:
                        this.i2.p = (int) j3;
                        return;
                    case D0 /*{ENCODED_INT: 21682}*/:
                        this.i2.r = (int) j3;
                        return;
                    case C0 /*{ENCODED_INT: 21690}*/:
                        this.i2.q = (int) j3;
                        return;
                    case s0 /*{ENCODED_INT: 21930}*/:
                        c cVar2 = this.i2;
                        if (j3 == 1) {
                            z3 = true;
                        }
                        cVar2.Q = z3;
                        return;
                    case w0 /*{ENCODED_INT: 22186}*/:
                        this.i2.N = j3;
                        return;
                    case x0 /*{ENCODED_INT: 22203}*/:
                        this.i2.O = j3;
                        return;
                    case G0 /*{ENCODED_INT: 25188}*/:
                        this.i2.L = (int) j3;
                        return;
                    case t0 /*{ENCODED_INT: 2352003}*/:
                        this.i2.h = (int) j3;
                        return;
                    case e0 /*{ENCODED_INT: 2807729}*/:
                        this.f2 = j3;
                        return;
                    default:
                        switch (i3) {
                            case e1 /*{ENCODED_INT: 21945}*/:
                                int i5 = (int) j3;
                                if (i5 == 1) {
                                    this.i2.x = 2;
                                    return;
                                } else if (i5 == 2) {
                                    this.i2.x = 1;
                                    return;
                                } else {
                                    return;
                                }
                            case f1 /*{ENCODED_INT: 21946}*/:
                                int i6 = (int) j3;
                                if (i6 != 1) {
                                    if (i6 == 16) {
                                        this.i2.w = 6;
                                        return;
                                    } else if (i6 == 18) {
                                        this.i2.w = 7;
                                        return;
                                    } else if (!(i6 == 6 || i6 == 7)) {
                                        return;
                                    }
                                }
                                this.i2.w = 3;
                                return;
                            case g1 /*{ENCODED_INT: 21947}*/:
                                c cVar3 = this.i2;
                                cVar3.u = true;
                                int i7 = (int) j3;
                                if (i7 == 1) {
                                    cVar3.v = 1;
                                    return;
                                } else if (i7 == 9) {
                                    cVar3.v = 6;
                                    return;
                                } else if (i7 == 4 || i7 == 5 || i7 == 6 || i7 == 7) {
                                    cVar3.v = 2;
                                    return;
                                } else {
                                    return;
                                }
                            case h1 /*{ENCODED_INT: 21948}*/:
                                this.i2.y = (int) j3;
                                return;
                            case i1 /*{ENCODED_INT: 21949}*/:
                                this.i2.z = (int) j3;
                                return;
                            default:
                                return;
                        }
                }
            } else if (j3 != 1) {
                throw new ParserException("ContentEncodingScope " + j3 + " not supported");
            }
        } else if (j3 != 0) {
            throw new ParserException("ContentEncodingOrder " + j3 + " not supported");
        }
    }

    @Override // com.google.android.exoplayer2.g0.e
    public void release() {
    }

    /* access modifiers changed from: package-private */
    public void w(int i3, long j3, long j4) throws ParserException {
        if (i3 == 160) {
            this.M2 = false;
        } else if (i3 == 174) {
            this.i2 = new c(null);
        } else if (i3 == 187) {
            this.s2 = false;
        } else if (i3 == a0) {
            this.k2 = -1;
            this.l2 = -1;
        } else if (i3 == P0) {
            this.i2.i = true;
        } else if (i3 == j1) {
            this.i2.u = true;
        } else if (i3 == X) {
            long j5 = this.e2;
            if (j5 == -1 || j5 == j3) {
                this.e2 = j3;
                this.d2 = j4;
                return;
            }
            throw new ParserException("Multiple Segment elements not supported");
        } else if (i3 == U0) {
            this.q2 = new l();
            this.r2 = new l();
        } else if (i3 != g0 || this.j2) {
        } else {
            if (!this.S1 || this.n2 == -1) {
                this.N2.g(new m.b(this.h2));
                this.j2 = true;
                return;
            }
            this.m2 = true;
        }
    }

    /* access modifiers changed from: package-private */
    public void x(int i3, String str) throws ParserException {
        if (i3 == 134) {
            this.i2.f8138e = str;
        } else if (i3 != 17026) {
            if (i3 == Z0) {
                this.i2.S = str;
            }
        } else if (!l.equals(str) && !k.equals(str)) {
            throw new ParserException("DocType " + str + " not supported");
        }
    }

    public MatroskaExtractor(int i3) {
        this(new a(), i3);
    }

    MatroskaExtractor(b bVar, int i3) {
        this.e2 = -1;
        this.f2 = C.f7870b;
        this.g2 = C.f7870b;
        this.h2 = C.f7870b;
        this.n2 = -1;
        this.o2 = -1;
        this.p2 = C.f7870b;
        this.P1 = bVar;
        bVar.c(new b(this, null));
        this.S1 = (i3 & 1) != 0 ? false : true;
        this.Q1 = new d();
        this.R1 = new SparseArray<>();
        this.V1 = new q(4);
        this.W1 = new q(ByteBuffer.allocate(4).putInt(-1).array());
        this.X1 = new q(4);
        this.T1 = new q(com.google.android.exoplayer2.util.o.f9611b);
        this.U1 = new q(4);
        this.Y1 = new q();
        this.Z1 = new q();
        this.a2 = new q(8);
        this.b2 = new q();
    }

    /* access modifiers changed from: private */
    public static final class c {

        /* renamed from: a  reason: collision with root package name */
        private static final int f8134a = 0;

        /* renamed from: b  reason: collision with root package name */
        private static final int f8135b = 50000;

        /* renamed from: c  reason: collision with root package name */
        private static final int f8136c = 1000;

        /* renamed from: d  reason: collision with root package name */
        private static final int f8137d = 200;
        public float A;
        public float B;
        public float C;
        public float D;
        public float E;
        public float F;
        public float G;
        public float H;
        public float I;
        public float J;
        public int K;
        public int L;
        public int M;
        public long N;
        public long O;
        @Nullable
        public d P;
        public boolean Q;
        public boolean R;
        private String S;
        public o T;
        public int U;

        /* renamed from: e  reason: collision with root package name */
        public String f8138e;
        public int f;
        public int g;
        public int h;
        public boolean i;
        public byte[] j;
        public o.a k;
        public byte[] l;
        public DrmInitData m;
        public int n;
        public int o;
        public int p;
        public int q;
        public int r;
        public byte[] s;
        public int t;
        public boolean u;
        public int v;
        public int w;
        public int x;
        public int y;
        public int z;

        private c() {
            this.n = -1;
            this.o = -1;
            this.p = -1;
            this.q = -1;
            this.r = 0;
            this.s = null;
            this.t = -1;
            this.u = false;
            this.v = -1;
            this.w = -1;
            this.x = -1;
            this.y = 1000;
            this.z = 200;
            this.A = -1.0f;
            this.B = -1.0f;
            this.C = -1.0f;
            this.D = -1.0f;
            this.E = -1.0f;
            this.F = -1.0f;
            this.G = -1.0f;
            this.H = -1.0f;
            this.I = -1.0f;
            this.J = -1.0f;
            this.K = 1;
            this.L = -1;
            this.M = 8000;
            this.N = 0;
            this.O = 0;
            this.R = true;
            this.S = "eng";
        }

        private byte[] b() {
            if (this.A == -1.0f || this.B == -1.0f || this.C == -1.0f || this.D == -1.0f || this.E == -1.0f || this.F == -1.0f || this.G == -1.0f || this.H == -1.0f || this.I == -1.0f || this.J == -1.0f) {
                return null;
            }
            byte[] bArr = new byte[25];
            ByteBuffer wrap = ByteBuffer.wrap(bArr);
            wrap.put((byte) 0);
            wrap.putShort((short) ((int) ((this.A * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.B * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.C * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.D * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.E * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.F * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.G * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) ((this.H * 50000.0f) + 0.5f)));
            wrap.putShort((short) ((int) (this.I + 0.5f)));
            wrap.putShort((short) ((int) (this.J + 0.5f)));
            wrap.putShort((short) this.y);
            wrap.putShort((short) this.z);
            return bArr;
        }

        private static Pair<String, List<byte[]>> e(q qVar) throws ParserException {
            try {
                qVar.Q(16);
                long s2 = qVar.s();
                if (s2 == 1482049860) {
                    return new Pair<>(n.g, null);
                }
                if (s2 == 826496599) {
                    byte[] bArr = qVar.f9627a;
                    for (int c2 = qVar.c() + 20; c2 < bArr.length - 4; c2++) {
                        if (bArr[c2] == 0 && bArr[c2 + 1] == 0 && bArr[c2 + 2] == 1 && bArr[c2 + 3] == 15) {
                            return new Pair<>(n.o, Collections.singletonList(Arrays.copyOfRange(bArr, c2, bArr.length)));
                        }
                    }
                    throw new ParserException("Failed to find FourCC VC1 initialization data");
                }
                Log.w(MatroskaExtractor.f, "Unknown FourCC. Setting mimeType to video/x-unknown");
                return new Pair<>(n.p, null);
            } catch (ArrayIndexOutOfBoundsException unused) {
                throw new ParserException("Error parsing FourCC private data");
            }
        }

        private static boolean f(q qVar) throws ParserException {
            try {
                int v2 = qVar.v();
                if (v2 == 1) {
                    return true;
                }
                if (v2 != MatroskaExtractor.M1) {
                    return false;
                }
                qVar.P(24);
                if (qVar.w() == MatroskaExtractor.O1.getMostSignificantBits() && qVar.w() == MatroskaExtractor.O1.getLeastSignificantBits()) {
                    return true;
                }
                return false;
            } catch (ArrayIndexOutOfBoundsException unused) {
                throw new ParserException("Error parsing MS/ACM codec private");
            }
        }

        private static List<byte[]> g(byte[] bArr) throws ParserException {
            try {
                if (bArr[0] == 2) {
                    int i2 = 1;
                    int i3 = 0;
                    while (bArr[i2] == -1) {
                        i3 += 255;
                        i2++;
                    }
                    int i4 = i2 + 1;
                    int i5 = i3 + bArr[i2];
                    int i6 = 0;
                    while (bArr[i4] == -1) {
                        i6 += 255;
                        i4++;
                    }
                    int i7 = i4 + 1;
                    int i8 = i6 + bArr[i4];
                    if (bArr[i7] == 1) {
                        byte[] bArr2 = new byte[i5];
                        System.arraycopy(bArr, i7, bArr2, 0, i5);
                        int i9 = i7 + i5;
                        if (bArr[i9] == 3) {
                            int i10 = i9 + i8;
                            if (bArr[i10] == 5) {
                                byte[] bArr3 = new byte[(bArr.length - i10)];
                                System.arraycopy(bArr, i10, bArr3, 0, bArr.length - i10);
                                ArrayList arrayList = new ArrayList(2);
                                arrayList.add(bArr2);
                                arrayList.add(bArr3);
                                return arrayList;
                            }
                            throw new ParserException("Error parsing vorbis codec private");
                        }
                        throw new ParserException("Error parsing vorbis codec private");
                    }
                    throw new ParserException("Error parsing vorbis codec private");
                }
                throw new ParserException("Error parsing vorbis codec private");
            } catch (ArrayIndexOutOfBoundsException unused) {
                throw new ParserException("Error parsing vorbis codec private");
            }
        }

        /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
        public void c(g gVar, int i2) throws ParserException {
            char c2;
            int i3;
            int i4;
            List<byte[]> list;
            Format format;
            int i5;
            int i6;
            String str;
            int K2;
            String str2;
            String str3;
            List<byte[]> list2;
            String str4 = this.f8138e;
            str4.hashCode();
            int i7 = 1;
            int i8 = 0;
            switch (str4.hashCode()) {
                case -2095576542:
                    if (str4.equals(MatroskaExtractor.r)) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -2095575984:
                    if (str4.equals(MatroskaExtractor.p)) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1985379776:
                    if (str4.equals(MatroskaExtractor.I)) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1784763192:
                    if (str4.equals(MatroskaExtractor.D)) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1730367663:
                    if (str4.equals(MatroskaExtractor.w)) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1482641358:
                    if (str4.equals(MatroskaExtractor.z)) {
                        c2 = 5;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1482641357:
                    if (str4.equals(MatroskaExtractor.A)) {
                        c2 = 6;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1373388978:
                    if (str4.equals(MatroskaExtractor.u)) {
                        c2 = 7;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -933872740:
                    if (str4.equals(MatroskaExtractor.O)) {
                        c2 = '\b';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -538363189:
                    if (str4.equals(MatroskaExtractor.q)) {
                        c2 = '\t';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -538363109:
                    if (str4.equals(MatroskaExtractor.s)) {
                        c2 = '\n';
                        break;
                    }
                    c2 = 65535;
                    break;
                case -425012669:
                    if (str4.equals(MatroskaExtractor.M)) {
                        c2 = 11;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -356037306:
                    if (str4.equals(MatroskaExtractor.G)) {
                        c2 = '\f';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 62923557:
                    if (str4.equals(MatroskaExtractor.y)) {
                        c2 = '\r';
                        break;
                    }
                    c2 = 65535;
                    break;
                case 62923603:
                    if (str4.equals(MatroskaExtractor.B)) {
                        c2 = 14;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 62927045:
                    if (str4.equals(MatroskaExtractor.E)) {
                        c2 = 15;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 82338133:
                    if (str4.equals(MatroskaExtractor.m)) {
                        c2 = 16;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 82338134:
                    if (str4.equals(MatroskaExtractor.n)) {
                        c2 = 17;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 99146302:
                    if (str4.equals(MatroskaExtractor.N)) {
                        c2 = 18;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 444813526:
                    if (str4.equals(MatroskaExtractor.v)) {
                        c2 = 19;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 542569478:
                    if (str4.equals(MatroskaExtractor.F)) {
                        c2 = 20;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 725957860:
                    if (str4.equals(MatroskaExtractor.J)) {
                        c2 = 21;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 738597099:
                    if (str4.equals(MatroskaExtractor.L)) {
                        c2 = 22;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 855502857:
                    if (str4.equals(MatroskaExtractor.t)) {
                        c2 = 23;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1422270023:
                    if (str4.equals(MatroskaExtractor.K)) {
                        c2 = 24;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1809237540:
                    if (str4.equals(MatroskaExtractor.o)) {
                        c2 = 25;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1950749482:
                    if (str4.equals(MatroskaExtractor.C)) {
                        c2 = com.alibaba.fastjson.parser.c.f5609e;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1950789798:
                    if (str4.equals(MatroskaExtractor.H)) {
                        c2 = 27;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1951062397:
                    if (str4.equals(MatroskaExtractor.x)) {
                        c2 = 28;
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            String str5 = n.N;
            switch (c2) {
                case 0:
                case 1:
                case '\t':
                    byte[] bArr = this.l;
                    if (bArr == null) {
                        list = null;
                    } else {
                        list = Collections.singletonList(bArr);
                    }
                    str = n.l;
                    str5 = str;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 2:
                    if (f(new q(this.l))) {
                        K2 = b0.K(this.L);
                        if (K2 == 0) {
                            Log.w(MatroskaExtractor.f, "Unsupported PCM bit depth: " + this.L + ". Setting mimeType to " + str5);
                        }
                        i4 = K2;
                        str5 = n.w;
                        list = null;
                        i3 = -1;
                        break;
                    } else {
                        Log.w(MatroskaExtractor.f, "Non-PCM MS/ACM is unsupported. Setting mimeType to " + str5);
                    }
                    list = null;
                    i4 = -1;
                    i3 = -1;
                case 3:
                    this.P = new d();
                    str2 = n.C;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 4:
                    list = g(this.l);
                    str5 = n.G;
                    i4 = -1;
                    i3 = 8192;
                    break;
                case 5:
                    str3 = n.v;
                    str5 = str3;
                    list = null;
                    i4 = -1;
                    i3 = 4096;
                    break;
                case 6:
                    str3 = "audio/mpeg";
                    str5 = str3;
                    list = null;
                    i4 = -1;
                    i3 = 4096;
                    break;
                case 7:
                    Pair<String, List<byte[]>> e2 = e(new q(this.l));
                    str = (String) e2.first;
                    list = (List) e2.second;
                    str5 = str;
                    i4 = -1;
                    i3 = -1;
                    break;
                case '\b':
                    byte[] bArr2 = this.l;
                    list = Collections.singletonList(new byte[]{bArr2[0], bArr2[1], bArr2[2], bArr2[3]});
                    str5 = n.j0;
                    i4 = -1;
                    i3 = -1;
                    break;
                case '\n':
                    com.google.android.exoplayer2.video.a b2 = com.google.android.exoplayer2.video.a.b(new q(this.l));
                    list2 = b2.f9657a;
                    this.U = b2.f9658b;
                    str = n.h;
                    list = list2;
                    str5 = str;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 11:
                    list = Collections.singletonList(this.l);
                    str5 = n.e0;
                    i4 = -1;
                    i3 = -1;
                    break;
                case '\f':
                    str2 = n.E;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case '\r':
                    list = Collections.singletonList(this.l);
                    str = n.r;
                    str5 = str;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 14:
                    str2 = n.z;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 15:
                case 20:
                    str2 = n.D;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 16:
                    str2 = n.j;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 17:
                    str2 = n.k;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 18:
                    str5 = n.f0;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 19:
                    str2 = n.p;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 21:
                    K2 = b0.K(this.L);
                    if (K2 == 0) {
                        Log.w(MatroskaExtractor.f, "Unsupported PCM bit depth: " + this.L + ". Setting mimeType to " + str5);
                        list = null;
                        i4 = -1;
                        i3 = -1;
                        break;
                    }
                    i4 = K2;
                    str5 = n.w;
                    list = null;
                    i3 = -1;
                case 22:
                    str5 = n.P;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 23:
                    com.google.android.exoplayer2.video.b a2 = com.google.android.exoplayer2.video.b.a(new q(this.l));
                    list2 = a2.f9662a;
                    this.U = a2.f9663b;
                    str = n.i;
                    list = list2;
                    str5 = str;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 24:
                    str5 = n.Y;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 25:
                    str2 = n.n;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 26:
                    str2 = n.A;
                    str5 = str2;
                    list = null;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 27:
                    list = Collections.singletonList(this.l);
                    str = n.K;
                    str5 = str;
                    i4 = -1;
                    i3 = -1;
                    break;
                case 28:
                    list = new ArrayList<>(3);
                    list.add(this.l);
                    list.add(ByteBuffer.allocate(8).order(ByteOrder.nativeOrder()).putLong(this.N).array());
                    list.add(ByteBuffer.allocate(8).order(ByteOrder.nativeOrder()).putLong(this.O).array());
                    str5 = n.H;
                    i4 = -1;
                    i3 = MatroskaExtractor.Q;
                    break;
                default:
                    throw new ParserException("Unrecognized codec identifier.");
            }
            int i9 = (this.R ? 1 : 0) | 0;
            if (this.Q) {
                i8 = 2;
            }
            int i10 = i9 | i8;
            if (n.l(str5)) {
                format = Format.k(Integer.toString(i2), str5, null, -1, i3, this.K, this.M, i4, list, this.m, i10, this.S);
            } else if (n.n(str5)) {
                if (this.r == 0) {
                    int i11 = this.p;
                    i5 = -1;
                    if (i11 == -1) {
                        i11 = this.n;
                    }
                    this.p = i11;
                    int i12 = this.q;
                    if (i12 == -1) {
                        i12 = this.o;
                    }
                    this.q = i12;
                } else {
                    i5 = -1;
                }
                int i13 = this.p;
                format = Format.z(Integer.toString(i2), str5, null, -1, i3, this.n, this.o, -1.0f, list, -1, (i13 == i5 || (i6 = this.q) == i5) ? -1.0f : ((float) (this.o * i13)) / ((float) (this.n * i6)), this.s, this.t, this.u ? new ColorInfo(this.v, this.x, this.w, b()) : null, this.m);
                i7 = 2;
            } else {
                if (n.Y.equals(str5)) {
                    format = Format.t(Integer.toString(i2), str5, i10, this.S, this.m);
                } else if (n.P.equals(str5)) {
                    ArrayList arrayList = new ArrayList(2);
                    arrayList.add(MatroskaExtractor.F1);
                    arrayList.add(this.l);
                    format = Format.v(Integer.toString(i2), str5, null, -1, i10, this.S, -1, this.m, Long.MAX_VALUE, arrayList);
                } else if (n.e0.equals(str5) || n.f0.equals(str5) || n.j0.equals(str5)) {
                    format = Format.n(Integer.toString(i2), str5, null, -1, i10, list, this.S, this.m);
                } else {
                    throw new ParserException("Unexpected MIME type.");
                }
                i7 = 3;
            }
            o a3 = gVar.a(this.f, i7);
            this.T = a3;
            a3.d(format);
        }

        public void d() {
            d dVar = this.P;
            if (dVar != null) {
                dVar.a(this);
            }
        }

        public void h() {
            d dVar = this.P;
            if (dVar != null) {
                dVar.b();
            }
        }

        /* synthetic */ c(a aVar) {
            this();
        }
    }
}
