package com.google.android.material.card;

import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.TypedArray;
import android.graphics.RectF;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.util.AttributeSet;
import android.util.Log;
import android.view.accessibility.AccessibilityEvent;
import android.view.accessibility.AccessibilityNodeInfo;
import android.widget.Checkable;
import android.widget.FrameLayout;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.DimenRes;
import androidx.annotation.Dimension;
import androidx.annotation.DrawableRes;
import androidx.annotation.FloatRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.cardview.widget.CardView;
import com.google.android.material.R;
import com.google.android.material.shape.i;
import com.google.android.material.shape.m;
import com.google.android.material.shape.q;

public class MaterialCardView extends CardView implements Checkable, q {
    private static final int[] P0 = {16842911};
    private static final int[] Q0 = {16842912};
    private static final int[] R0 = {R.attr.state_dragged};
    private static final int S0 = R.style.Widget_MaterialComponents_CardView;
    private static final String T0 = "MaterialCardView";
    private static final String U0 = "androidx.cardview.widget.CardView";
    @NonNull
    private final a V0;
    private boolean W0;
    private boolean X0;
    private boolean Y0;
    private a Z0;

    public interface a {
        void a(MaterialCardView materialCardView, boolean z);
    }

    public MaterialCardView(Context context) {
        this(context, null);
    }

    @NonNull
    private RectF getBoundsAsRectF() {
        RectF rectF = new RectF();
        rectF.set(this.V0.k().getBounds());
        return rectF;
    }

    private void j() {
        if (Build.VERSION.SDK_INT > 26) {
            this.V0.j();
        }
    }

    @Override // androidx.cardview.widget.CardView
    @NonNull
    public ColorStateList getCardBackgroundColor() {
        return this.V0.l();
    }

    @NonNull
    public ColorStateList getCardForegroundColor() {
        return this.V0.m();
    }

    /* access modifiers changed from: package-private */
    public float getCardViewRadius() {
        return super.getRadius();
    }

    @Nullable
    public Drawable getCheckedIcon() {
        return this.V0.n();
    }

    @Dimension
    public int getCheckedIconMargin() {
        return this.V0.o();
    }

    @Dimension
    public int getCheckedIconSize() {
        return this.V0.p();
    }

    @Nullable
    public ColorStateList getCheckedIconTint() {
        return this.V0.q();
    }

    @Override // androidx.cardview.widget.CardView
    public int getContentPaddingBottom() {
        return this.V0.A().bottom;
    }

    @Override // androidx.cardview.widget.CardView
    public int getContentPaddingLeft() {
        return this.V0.A().left;
    }

    @Override // androidx.cardview.widget.CardView
    public int getContentPaddingRight() {
        return this.V0.A().right;
    }

    @Override // androidx.cardview.widget.CardView
    public int getContentPaddingTop() {
        return this.V0.A().top;
    }

    @FloatRange(from = 0.0d, to = 1.0d)
    public float getProgress() {
        return this.V0.u();
    }

    @Override // androidx.cardview.widget.CardView
    public float getRadius() {
        return this.V0.s();
    }

    public ColorStateList getRippleColor() {
        return this.V0.v();
    }

    @Override // com.google.android.material.shape.q
    @NonNull
    public m getShapeAppearanceModel() {
        return this.V0.w();
    }

    @ColorInt
    @Deprecated
    public int getStrokeColor() {
        return this.V0.x();
    }

    @Nullable
    public ColorStateList getStrokeColorStateList() {
        return this.V0.y();
    }

    @Dimension
    public int getStrokeWidth() {
        return this.V0.z();
    }

    @Override // androidx.cardview.widget.CardView
    public void h(int i, int i2, int i3, int i4) {
        this.V0.U(i, i2, i3, i4);
    }

    public boolean isChecked() {
        return this.X0;
    }

    public boolean k() {
        a aVar = this.V0;
        return aVar != null && aVar.D();
    }

    public boolean l() {
        return this.Y0;
    }

    /* access modifiers changed from: package-private */
    public void m(int i, int i2, int i3, int i4) {
        super.h(i, i2, i3, i4);
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        i.f(this, this.V0.k());
    }

    /* access modifiers changed from: protected */
    public int[] onCreateDrawableState(int i) {
        int[] onCreateDrawableState = super.onCreateDrawableState(i + 3);
        if (k()) {
            FrameLayout.mergeDrawableStates(onCreateDrawableState, P0);
        }
        if (isChecked()) {
            FrameLayout.mergeDrawableStates(onCreateDrawableState, Q0);
        }
        if (l()) {
            FrameLayout.mergeDrawableStates(onCreateDrawableState, R0);
        }
        return onCreateDrawableState;
    }

    public void onInitializeAccessibilityEvent(@NonNull AccessibilityEvent accessibilityEvent) {
        super.onInitializeAccessibilityEvent(accessibilityEvent);
        accessibilityEvent.setClassName(U0);
        accessibilityEvent.setChecked(isChecked());
    }

    public void onInitializeAccessibilityNodeInfo(@NonNull AccessibilityNodeInfo accessibilityNodeInfo) {
        super.onInitializeAccessibilityNodeInfo(accessibilityNodeInfo);
        accessibilityNodeInfo.setClassName(U0);
        accessibilityNodeInfo.setCheckable(k());
        accessibilityNodeInfo.setClickable(isClickable());
        accessibilityNodeInfo.setChecked(isChecked());
    }

    /* access modifiers changed from: protected */
    @Override // androidx.cardview.widget.CardView
    public void onMeasure(int i, int i2) {
        super.onMeasure(i, i2);
        this.V0.F(getMeasuredWidth(), getMeasuredHeight());
    }

    public void setBackground(Drawable drawable) {
        setBackgroundDrawable(drawable);
    }

    public void setBackgroundDrawable(Drawable drawable) {
        if (this.W0) {
            if (!this.V0.C()) {
                Log.i(T0, "Setting a custom background is not supported.");
                this.V0.G(true);
            }
            super.setBackgroundDrawable(drawable);
        }
    }

    /* access modifiers changed from: package-private */
    public void setBackgroundInternal(Drawable drawable) {
        super.setBackgroundDrawable(drawable);
    }

    @Override // androidx.cardview.widget.CardView
    public void setCardBackgroundColor(@ColorInt int i) {
        this.V0.H(ColorStateList.valueOf(i));
    }

    @Override // androidx.cardview.widget.CardView
    public void setCardElevation(float f) {
        super.setCardElevation(f);
        this.V0.Z();
    }

    public void setCardForegroundColor(@Nullable ColorStateList colorStateList) {
        this.V0.I(colorStateList);
    }

    public void setCheckable(boolean z) {
        this.V0.J(z);
    }

    public void setChecked(boolean z) {
        if (this.X0 != z) {
            toggle();
        }
    }

    public void setCheckedIcon(@Nullable Drawable drawable) {
        this.V0.K(drawable);
    }

    public void setCheckedIconMargin(@Dimension int i) {
        this.V0.L(i);
    }

    public void setCheckedIconMarginResource(@DimenRes int i) {
        if (i != -1) {
            this.V0.L(getResources().getDimensionPixelSize(i));
        }
    }

    public void setCheckedIconResource(@DrawableRes int i) {
        this.V0.K(androidx.appcompat.a.a.a.d(getContext(), i));
    }

    public void setCheckedIconSize(@Dimension int i) {
        this.V0.M(i);
    }

    public void setCheckedIconSizeResource(@DimenRes int i) {
        if (i != 0) {
            this.V0.M(getResources().getDimensionPixelSize(i));
        }
    }

    public void setCheckedIconTint(@Nullable ColorStateList colorStateList) {
        this.V0.N(colorStateList);
    }

    public void setClickable(boolean z) {
        super.setClickable(z);
        a aVar = this.V0;
        if (aVar != null) {
            aVar.X();
        }
    }

    public void setDragged(boolean z) {
        if (this.Y0 != z) {
            this.Y0 = z;
            refreshDrawableState();
            j();
            invalidate();
        }
    }

    @Override // androidx.cardview.widget.CardView
    public void setMaxCardElevation(float f) {
        super.setMaxCardElevation(f);
        this.V0.b0();
    }

    public void setOnCheckedChangeListener(@Nullable a aVar) {
        this.Z0 = aVar;
    }

    @Override // androidx.cardview.widget.CardView
    public void setPreventCornerOverlap(boolean z) {
        super.setPreventCornerOverlap(z);
        this.V0.b0();
        this.V0.Y();
    }

    public void setProgress(@FloatRange(from = 0.0d, to = 1.0d) float f) {
        this.V0.P(f);
    }

    @Override // androidx.cardview.widget.CardView
    public void setRadius(float f) {
        super.setRadius(f);
        this.V0.O(f);
    }

    public void setRippleColor(@Nullable ColorStateList colorStateList) {
        this.V0.Q(colorStateList);
    }

    public void setRippleColorResource(@ColorRes int i) {
        this.V0.Q(androidx.appcompat.a.a.a.c(getContext(), i));
    }

    @Override // com.google.android.material.shape.q
    public void setShapeAppearanceModel(@NonNull m mVar) {
        if (Build.VERSION.SDK_INT >= 21) {
            setClipToOutline(mVar.u(getBoundsAsRectF()));
        }
        this.V0.R(mVar);
    }

    public void setStrokeColor(@ColorInt int i) {
        this.V0.S(ColorStateList.valueOf(i));
    }

    public void setStrokeWidth(@Dimension int i) {
        this.V0.T(i);
    }

    @Override // androidx.cardview.widget.CardView
    public void setUseCompatPadding(boolean z) {
        super.setUseCompatPadding(z);
        this.V0.b0();
        this.V0.Y();
    }

    public void toggle() {
        if (k() && isEnabled()) {
            this.X0 = !this.X0;
            refreshDrawableState();
            j();
            a aVar = this.Z0;
            if (aVar != null) {
                aVar.a(this, this.X0);
            }
        }
    }

    public MaterialCardView(Context context, AttributeSet attributeSet) {
        this(context, attributeSet, R.attr.materialCardViewStyle);
    }

    @Override // androidx.cardview.widget.CardView
    public void setCardBackgroundColor(@Nullable ColorStateList colorStateList) {
        this.V0.H(colorStateList);
    }

    public void setStrokeColor(ColorStateList colorStateList) {
        this.V0.S(colorStateList);
    }

    /* JADX WARNING: Illegal instructions before constructor call */
    public MaterialCardView(Context context, AttributeSet attributeSet, int i) {
        super(com.google.android.material.theme.a.a.c(context, attributeSet, i, r6), attributeSet, i);
        int i2 = S0;
        this.X0 = false;
        this.Y0 = false;
        this.W0 = true;
        TypedArray j = com.google.android.material.internal.m.j(getContext(), attributeSet, R.styleable.MaterialCardView, i, i2, new int[0]);
        a aVar = new a(this, attributeSet, i, i2);
        this.V0 = aVar;
        aVar.H(super.getCardBackgroundColor());
        aVar.U(super.getContentPaddingLeft(), super.getContentPaddingTop(), super.getContentPaddingRight(), super.getContentPaddingBottom());
        aVar.E(j);
        j.recycle();
    }
}
