package com.ibm.icu.impl;

import com.ibm.icu.impl.locale.f;
import com.ibm.icu.lang.c;
import com.ibm.icu.text.NumberFormat;
import com.ibm.icu.util.ULocale;
import com.ibm.icu.util.h0;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.math.BigDecimal;
import java.math.BigInteger;
import java.text.FieldPosition;
import java.text.ParsePosition;
import java.util.Arrays;
import java.util.MissingResourceException;

public final class DateNumberFormat extends NumberFormat {
    private static final int L0 = 20;
    private static j1<ULocale, char[]> M0 = new j1<>();
    private static final long N0 = 922337203685477579L;
    private static final long serialVersionUID = -6315692826916346953L;
    private transient char[] O0;
    private char[] digits;
    private int maxIntDigits;
    private int minIntDigits;
    private char minusSign;
    private boolean positiveOnly;
    private char zeroDigit;

    public DateNumberFormat(ULocale uLocale, String str, String str2) {
        this.positiveOnly = false;
        this.O0 = new char[20];
        if (str.length() <= 10) {
            h(uLocale, str, str2);
            return;
        }
        throw new UnsupportedOperationException("DateNumberFormat does not support digits out of BMP.");
    }

    private void h(ULocale uLocale, String str, String str2) {
        String str3 = f.f14027b;
        char[] cArr = M0.get(uLocale);
        if (cArr == null) {
            ICUResourceBundle iCUResourceBundle = (ICUResourceBundle) h0.j(a0.f13490d, uLocale);
            try {
                str3 = iCUResourceBundle.W0("NumberElements/" + str2 + "/symbols/minusSign");
            } catch (MissingResourceException unused) {
                if (!str2.equals("latn")) {
                    try {
                        str3 = iCUResourceBundle.W0("NumberElements/latn/symbols/minusSign");
                    } catch (MissingResourceException unused2) {
                    }
                }
            }
            cArr = new char[11];
            for (int i = 0; i < 10; i++) {
                cArr[i] = str.charAt(i);
            }
            cArr[10] = str3.charAt(0);
            M0.put(uLocale, cArr);
        }
        char[] cArr2 = new char[10];
        this.digits = cArr2;
        System.arraycopy(cArr, 0, cArr2, 0, 10);
        this.zeroDigit = this.digits[0];
        this.minusSign = cArr[10];
    }

    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        if (this.digits == null) {
            setZeroDigit(this.zeroDigit);
        }
        this.O0 = new char[20];
    }

    @Override // com.ibm.icu.text.NumberFormat, java.lang.Object
    public Object clone() {
        DateNumberFormat dateNumberFormat = (DateNumberFormat) super.clone();
        dateNumberFormat.digits = (char[]) this.digits.clone();
        dateNumberFormat.O0 = new char[20];
        return dateNumberFormat;
    }

    @Override // com.ibm.icu.text.NumberFormat
    public boolean equals(Object obj) {
        if (obj == null || !super.equals(obj) || !(obj instanceof DateNumberFormat)) {
            return false;
        }
        DateNumberFormat dateNumberFormat = (DateNumberFormat) obj;
        if (this.maxIntDigits == dateNumberFormat.maxIntDigits && this.minIntDigits == dateNumberFormat.minIntDigits && this.minusSign == dateNumberFormat.minusSign && this.positiveOnly == dateNumberFormat.positiveOnly && Arrays.equals(this.digits, dateNumberFormat.digits)) {
            return true;
        }
        return false;
    }

    @Override // com.ibm.icu.text.NumberFormat
    public StringBuffer format(double d2, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        throw new UnsupportedOperationException("StringBuffer format(double, StringBuffer, FieldPosition) is not implemented");
    }

    public char[] getDigits() {
        return (char[]) this.digits.clone();
    }

    @Override // com.ibm.icu.text.NumberFormat
    public int getMaximumIntegerDigits() {
        return this.maxIntDigits;
    }

    @Override // com.ibm.icu.text.NumberFormat
    public int getMinimumIntegerDigits() {
        return this.minIntDigits;
    }

    public char getZeroDigit() {
        return this.zeroDigit;
    }

    @Override // com.ibm.icu.text.NumberFormat
    public int hashCode() {
        return super.hashCode();
    }

    @Override // com.ibm.icu.text.NumberFormat
    public Number parse(String str, ParsePosition parsePosition) {
        int i;
        int index = parsePosition.getIndex();
        long j = 0;
        int i2 = 0;
        boolean z = false;
        boolean z2 = false;
        while (true) {
            i = index + i2;
            if (i >= str.length()) {
                break;
            }
            char charAt = str.charAt(i);
            if (i2 != 0 || charAt != this.minusSign) {
                int i3 = charAt - this.digits[0];
                if (i3 < 0 || 9 < i3) {
                    i3 = c.j(charAt);
                }
                if (i3 < 0 || 9 < i3) {
                    i3 = 0;
                    while (i3 < 10 && charAt != this.digits[i3]) {
                        i3++;
                    }
                }
                if (i3 < 0 || i3 > 9 || j >= N0) {
                    break;
                }
                j = (j * 10) + ((long) i3);
                z = true;
            } else if (this.positiveOnly) {
                break;
            } else {
                z2 = true;
            }
            i2++;
        }
        if (!z) {
            return null;
        }
        if (z2) {
            j *= -1;
        }
        Long valueOf = Long.valueOf(j);
        parsePosition.setIndex(i);
        return valueOf;
    }

    @Override // com.ibm.icu.text.NumberFormat
    public void setMaximumIntegerDigits(int i) {
        this.maxIntDigits = i;
    }

    @Override // com.ibm.icu.text.NumberFormat
    public void setMinimumIntegerDigits(int i) {
        this.minIntDigits = i;
    }

    public void setParsePositiveOnly(boolean z) {
        this.positiveOnly = z;
    }

    public void setZeroDigit(char c2) {
        this.zeroDigit = c2;
        if (this.digits == null) {
            this.digits = new char[10];
        }
        this.digits[0] = c2;
        for (int i = 1; i < 10; i++) {
            this.digits[i] = (char) (c2 + i);
        }
    }

    @Override // com.ibm.icu.text.NumberFormat
    public StringBuffer format(long j, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        if (j < 0) {
            stringBuffer.append(this.minusSign);
            j = -j;
        }
        int i = (int) j;
        char[] cArr = this.O0;
        int length = cArr.length;
        int i2 = this.maxIntDigits;
        if (length < i2) {
            i2 = cArr.length;
        }
        int i3 = i2 - 1;
        while (true) {
            this.O0[i3] = this.digits[i % 10];
            i /= 10;
            if (i3 != 0 && i != 0) {
                i3--;
            }
        }
        for (int i4 = this.minIntDigits - (i2 - i3); i4 > 0; i4--) {
            i3--;
            this.O0[i3] = this.digits[0];
        }
        int i5 = i2 - i3;
        stringBuffer.append(this.O0, i3, i5);
        fieldPosition.setBeginIndex(0);
        if (fieldPosition.getField() == 0) {
            fieldPosition.setEndIndex(i5);
        } else {
            fieldPosition.setEndIndex(0);
        }
        return stringBuffer;
    }

    public DateNumberFormat(ULocale uLocale, char c2, String str) {
        this.positiveOnly = false;
        this.O0 = new char[20];
        StringBuffer stringBuffer = new StringBuffer();
        for (int i = 0; i < 10; i++) {
            stringBuffer.append((char) (c2 + i));
        }
        h(uLocale, stringBuffer.toString(), str);
    }

    @Override // com.ibm.icu.text.NumberFormat
    public StringBuffer format(BigInteger bigInteger, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        throw new UnsupportedOperationException("StringBuffer format(BigInteger, StringBuffer, FieldPosition) is not implemented");
    }

    @Override // com.ibm.icu.text.NumberFormat
    public StringBuffer format(BigDecimal bigDecimal, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        throw new UnsupportedOperationException("StringBuffer format(BigDecimal, StringBuffer, FieldPosition) is not implemented");
    }

    @Override // com.ibm.icu.text.NumberFormat
    public StringBuffer format(com.ibm.icu.math.BigDecimal bigDecimal, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        throw new UnsupportedOperationException("StringBuffer format(BigDecimal, StringBuffer, FieldPosition) is not implemented");
    }
}
