package com.ibm.icu.impl;

import com.ibm.icu.util.TimeZone;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.TreeSet;

public class JavaTimeZone extends TimeZone {
    private static final TreeSet<String> O0 = new TreeSet<>();
    private static Method P0 = null;
    private static final long serialVersionUID = 6977448185543929364L;
    private transient Calendar Q0;
    private volatile transient boolean R0;
    private java.util.TimeZone javatz;

    static {
        String[] availableIDs;
        for (String str : java.util.TimeZone.getAvailableIDs()) {
            O0.add(str);
        }
        try {
            P0 = java.util.TimeZone.class.getMethod("observesDaylightTime", null);
        } catch (NoSuchMethodException | SecurityException unused) {
        }
    }

    public JavaTimeZone() {
        this(java.util.TimeZone.getDefault(), null);
    }

    public static JavaTimeZone createTimeZone(String str) {
        TreeSet<String> treeSet = O0;
        java.util.TimeZone timeZone = treeSet.contains(str) ? java.util.TimeZone.getTimeZone(str) : null;
        if (timeZone == null) {
            boolean[] zArr = new boolean[1];
            String canonicalID = TimeZone.getCanonicalID(str, zArr);
            if (zArr[0] && treeSet.contains(canonicalID)) {
                timeZone = java.util.TimeZone.getTimeZone(canonicalID);
            }
        }
        if (timeZone == null) {
            return null;
        }
        return new JavaTimeZone(timeZone, str);
    }

    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        objectInputStream.defaultReadObject();
        this.Q0 = new GregorianCalendar(this.javatz);
    }

    @Override // com.ibm.icu.util.TimeZone, java.lang.Object
    public Object clone() {
        if (isFrozen()) {
            return this;
        }
        return cloneAsThawed();
    }

    @Override // com.ibm.icu.util.TimeZone
    public int getDSTSavings() {
        return this.javatz.getDSTSavings();
    }

    @Override // com.ibm.icu.util.TimeZone
    public int getOffset(int i, int i2, int i3, int i4, int i5, int i6) {
        return this.javatz.getOffset(i, i2, i3, i4, i5, i6);
    }

    @Override // com.ibm.icu.util.TimeZone
    public int getRawOffset() {
        return this.javatz.getRawOffset();
    }

    @Override // com.ibm.icu.util.TimeZone
    public int hashCode() {
        return super.hashCode() + this.javatz.hashCode();
    }

    @Override // com.ibm.icu.util.TimeZone
    public boolean inDaylightTime(Date date) {
        return this.javatz.inDaylightTime(date);
    }

    @Override // com.ibm.icu.util.TimeZone, com.ibm.icu.util.n
    public boolean isFrozen() {
        return this.R0;
    }

    @Override // com.ibm.icu.util.TimeZone
    public boolean observesDaylightTime() {
        Method method = P0;
        if (method != null) {
            try {
                return ((Boolean) method.invoke(this.javatz, null)).booleanValue();
            } catch (IllegalAccessException | IllegalArgumentException | InvocationTargetException unused) {
            }
        }
        return super.observesDaylightTime();
    }

    @Override // com.ibm.icu.util.TimeZone
    public void setRawOffset(int i) {
        if (!isFrozen()) {
            this.javatz.setRawOffset(i);
            return;
        }
        throw new UnsupportedOperationException("Attempt to modify a frozen JavaTimeZone instance.");
    }

    public java.util.TimeZone unwrap() {
        return this.javatz;
    }

    @Override // com.ibm.icu.util.TimeZone
    public boolean useDaylightTime() {
        return this.javatz.useDaylightTime();
    }

    public JavaTimeZone(java.util.TimeZone timeZone, String str) {
        this.R0 = false;
        str = str == null ? timeZone.getID() : str;
        this.javatz = timeZone;
        setID(str);
        this.Q0 = new GregorianCalendar(this.javatz);
    }

    @Override // com.ibm.icu.util.TimeZone, com.ibm.icu.util.TimeZone, com.ibm.icu.util.n
    public TimeZone cloneAsThawed() {
        JavaTimeZone javaTimeZone = (JavaTimeZone) super.cloneAsThawed();
        javaTimeZone.javatz = (java.util.TimeZone) this.javatz.clone();
        javaTimeZone.Q0 = new GregorianCalendar(this.javatz);
        javaTimeZone.R0 = false;
        return javaTimeZone;
    }

    @Override // com.ibm.icu.util.TimeZone, com.ibm.icu.util.TimeZone, com.ibm.icu.util.n
    public TimeZone freeze() {
        this.R0 = true;
        return this;
    }

    @Override // com.ibm.icu.util.TimeZone
    public void getOffset(long j, boolean z, int[] iArr) {
        synchronized (this.Q0) {
            if (z) {
                int[] iArr2 = new int[6];
                u.j(j, iArr2);
                int i = iArr2[5];
                int i2 = i % 1000;
                int i3 = i / 1000;
                int i4 = i3 % 60;
                int i5 = i3 / 60;
                int i6 = i5 % 60;
                int i7 = i5 / 60;
                this.Q0.clear();
                this.Q0.set(iArr2[0], iArr2[1], iArr2[2], i7, i6, i4);
                this.Q0.set(14, i2);
                int i8 = this.Q0.get(6);
                int i9 = this.Q0.get(11);
                int i10 = this.Q0.get(12);
                int i11 = this.Q0.get(13);
                int i12 = this.Q0.get(14);
                if (!(iArr2[4] == i8 && i7 == i9 && i6 == i10 && i4 == i11 && i2 == i12)) {
                    int i13 = Math.abs(i8 - iArr2[4]) > 1 ? 1 : i8 - iArr2[4];
                    Calendar calendar = this.Q0;
                    calendar.setTimeInMillis((calendar.getTimeInMillis() - ((long) ((((((((((((i13 * 24) + i9) - i7) * 60) + i10) - i6) * 60) + i11) - i4) * 1000) + i12) - i2))) - 1);
                }
            } else {
                this.Q0.setTimeInMillis(j);
            }
            iArr[0] = this.Q0.get(15);
            iArr[1] = this.Q0.get(16);
        }
    }
}
