package com.ibm.icu.impl;

import com.ibm.icu.text.PluralRules;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public enum StandardPlural {
    ZERO(PluralRules.KEYWORD_ZERO),
    ONE(PluralRules.KEYWORD_ONE),
    TWO(PluralRules.KEYWORD_TWO),
    FEW(PluralRules.KEYWORD_FEW),
    MANY(PluralRules.KEYWORD_MANY),
    OTHER(PluralRules.KEYWORD_OTHER),
    EQ_0("=0"),
    EQ_1("=1");
    
    public static final int COUNT;
    public static final int OTHER_INDEX;
    public static final List<StandardPlural> VALUES;
    private final String keyword;

    static {
        StandardPlural standardPlural;
        OTHER_INDEX = standardPlural.ordinal();
        List<StandardPlural> unmodifiableList = Collections.unmodifiableList(Arrays.asList(values()));
        VALUES = unmodifiableList;
        COUNT = unmodifiableList.size();
    }

    private StandardPlural(String str) {
        this.keyword = str;
    }

    public static final StandardPlural fromString(CharSequence charSequence) {
        StandardPlural orNullFromString = orNullFromString(charSequence);
        if (orNullFromString != null) {
            return orNullFromString;
        }
        throw new IllegalArgumentException(charSequence.toString());
    }

    public static final int indexFromString(CharSequence charSequence) {
        StandardPlural orNullFromString = orNullFromString(charSequence);
        if (orNullFromString != null) {
            return orNullFromString.ordinal();
        }
        throw new IllegalArgumentException(charSequence.toString());
    }

    public static final int indexOrNegativeFromString(CharSequence charSequence) {
        StandardPlural orNullFromString = orNullFromString(charSequence);
        if (orNullFromString != null) {
            return orNullFromString.ordinal();
        }
        return -1;
    }

    public static final int indexOrOtherIndexFromString(CharSequence charSequence) {
        StandardPlural orNullFromString = orNullFromString(charSequence);
        if (orNullFromString == null) {
            orNullFromString = OTHER;
        }
        return orNullFromString.ordinal();
    }

    public static final StandardPlural orNullFromString(CharSequence charSequence) {
        int length = charSequence.length();
        if (length != 1) {
            if (length != 2) {
                if (length != 3) {
                    if (length != 4) {
                        if (length == 5 && PluralRules.KEYWORD_OTHER.contentEquals(charSequence)) {
                            return OTHER;
                        }
                        return null;
                    } else if (PluralRules.KEYWORD_MANY.contentEquals(charSequence)) {
                        return MANY;
                    } else {
                        if (PluralRules.KEYWORD_ZERO.contentEquals(charSequence)) {
                            return ZERO;
                        }
                        return null;
                    }
                } else if (PluralRules.KEYWORD_ONE.contentEquals(charSequence)) {
                    return ONE;
                } else {
                    if (PluralRules.KEYWORD_TWO.contentEquals(charSequence)) {
                        return TWO;
                    }
                    if (PluralRules.KEYWORD_FEW.contentEquals(charSequence)) {
                        return FEW;
                    }
                    return null;
                }
            } else if ("=0".contentEquals(charSequence)) {
                return EQ_0;
            } else {
                if ("=1".contentEquals(charSequence)) {
                    return EQ_1;
                }
                return null;
            }
        } else if (charSequence.charAt(0) == '0') {
            return EQ_0;
        } else {
            if (charSequence.charAt(0) == '1') {
                return EQ_1;
            }
            return null;
        }
    }

    public static final StandardPlural orOtherFromString(CharSequence charSequence) {
        StandardPlural orNullFromString = orNullFromString(charSequence);
        return orNullFromString != null ? orNullFromString : OTHER;
    }

    public final String getKeyword() {
        return this.keyword;
    }
}
