package com.ibm.icu.text;

import androidx.constraintlayout.core.motion.h.w;
import androidx.exifinterface.media.ExifInterface;
import com.google.android.exoplayer2.C;
import com.ibm.icu.impl.ICUResourceBundle;
import com.ibm.icu.impl.a0;
import com.ibm.icu.impl.j1;
import com.ibm.icu.impl.l1;
import com.ibm.icu.impl.l2;
import com.ibm.icu.impl.number.Padder;
import com.ibm.icu.impl.units.e;
import com.ibm.icu.impl.z0;
import com.ibm.icu.lang.c;
import com.ibm.icu.text.DateFormat;
import com.ibm.icu.util.Calendar;
import com.ibm.icu.util.ICUCloneNotSupportedException;
import com.ibm.icu.util.Region;
import com.ibm.icu.util.ULocale;
import com.ibm.icu.util.h0;
import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.BitSet;
import java.util.Collection;
import java.util.Collections;
import java.util.EnumSet;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.MissingResourceException;
import java.util.Set;
import java.util.TreeMap;
import java.util.TreeSet;

public class DateTimePatternGenerator implements com.ibm.icu.util.n<DateTimePatternGenerator>, Cloneable {
    private static final int A1 = 4096;
    private static final int[][] B1 = {new int[]{71, 0, x1, 1, 3}, new int[]{71, 0, y1, 4}, new int[]{71, 0, v1, 5}, new int[]{121, 1, 256, 1, 20}, new int[]{89, 1, c.p.o4, 1, 20}, new int[]{117, 1, c.p.E4, 1, 20}, new int[]{114, 1, 304, 1, 20}, new int[]{85, 1, x1, 1, 3}, new int[]{85, 1, y1, 4}, new int[]{85, 1, v1, 5}, new int[]{81, 2, 256, 1, 2}, new int[]{81, 2, x1, 3}, new int[]{81, 2, y1, 4}, new int[]{81, 2, v1, 5}, new int[]{113, 2, c.p.o4, 1, 2}, new int[]{113, 2, -275, 3}, new int[]{113, 2, -276, 4}, new int[]{113, 2, -273, 5}, new int[]{77, 3, 256, 1, 2}, new int[]{77, 3, x1, 3}, new int[]{77, 3, y1, 4}, new int[]{77, 3, v1, 5}, new int[]{76, 3, c.p.o4, 1, 2}, new int[]{76, 3, -275, 3}, new int[]{76, 3, -276, 4}, new int[]{76, 3, -273, 5}, new int[]{108, 3, c.p.o4, 1, 1}, new int[]{119, 4, 256, 1, 2}, new int[]{87, 5, 256, 1}, new int[]{69, 6, x1, 1, 3}, new int[]{69, 6, y1, 4}, new int[]{69, 6, v1, 5}, new int[]{69, 6, w1, 6}, new int[]{99, 6, c.p.E4, 1, 2}, new int[]{99, 6, -291, 3}, new int[]{99, 6, -292, 4}, new int[]{99, 6, -289, 5}, new int[]{99, 6, -290, 6}, new int[]{101, 6, c.p.o4, 1, 2}, new int[]{101, 6, -275, 3}, new int[]{101, 6, -276, 4}, new int[]{101, 6, -273, 5}, new int[]{101, 6, -274, 6}, new int[]{100, 7, 256, 1, 2}, new int[]{103, 7, c.p.o4, 1, 20}, new int[]{68, 8, 256, 1, 3}, new int[]{70, 9, 256, 1}, new int[]{97, 10, x1, 1, 3}, new int[]{97, 10, y1, 4}, new int[]{97, 10, v1, 5}, new int[]{98, 10, -275, 1, 3}, new int[]{98, 10, -276, 4}, new int[]{98, 10, -273, 5}, new int[]{66, 10, -307, 1, 3}, new int[]{66, 10, -308, 4}, new int[]{66, 10, -305, 5}, new int[]{72, 11, w.c.q, 1, 2}, new int[]{107, 11, 432, 1, 2}, new int[]{104, 11, 256, 1, 2}, new int[]{75, 11, c.p.o4, 1, 2}, new int[]{109, 12, 256, 1, 2}, new int[]{115, 13, 256, 1, 2}, new int[]{65, 13, c.p.o4, 1, 1000}, new int[]{83, 14, 256, 1, 1000}, new int[]{118, 15, -291, 1}, new int[]{118, 15, -292, 4}, new int[]{122, 15, x1, 1, 3}, new int[]{122, 15, y1, 4}, new int[]{90, 15, -273, 1, 3}, new int[]{90, 15, -276, 4}, new int[]{90, 15, -275, 5}, new int[]{79, 15, -275, 1}, new int[]{79, 15, -276, 4}, new int[]{86, 15, -275, 1}, new int[]{86, 15, -276, 2}, new int[]{86, 15, -277, 3}, new int[]{86, 15, -278, 4}, new int[]{88, 15, -273, 1}, new int[]{88, 15, -275, 2}, new int[]{88, 15, -276, 4}, new int[]{120, 15, -273, 1}, new int[]{120, 15, -275, 2}, new int[]{120, 15, -276, 4}};
    static final Map<String, String[]> I0;
    public static final int J0 = 0;
    public static final int K0 = 1;
    public static final int L0 = 2;
    public static final int M0 = 3;
    public static final int N0 = 4;
    public static final int O0 = 5;
    public static final int P0 = 6;
    public static final int Q0 = 7;
    public static final int R0 = 8;
    public static final int S0 = 9;
    public static final int T0 = 10;
    public static final int U0 = 11;
    public static final int V0 = 12;
    public static final int W0 = 13;
    public static final int X0 = 14;
    public static final int Y0 = 15;
    @Deprecated
    public static final int Z0 = 16;

    /* renamed from: a  reason: collision with root package name */
    private static final boolean f15137a = false;
    private static final DisplayWidth a1;

    /* renamed from: b  reason: collision with root package name */
    private static final String[] f15138b = {DateFormat.HOUR24};
    private static final int b1;
    private static final DisplayWidth[] c1 = DisplayWidth.values();
    public static final int d1 = 0;
    public static final int e1 = 2048;
    @Deprecated
    public static final int f1 = 4096;
    @Deprecated
    public static final int g1 = 8192;
    public static final int h1 = 65535;
    private static final int i1 = 16384;
    private static final int j1 = 24576;
    private static com.ibm.icu.impl.w<String, DateTimePatternGenerator> k1 = new j1();
    private static final String[] l1 = {"Era", "Year", "Quarter", "Month", "Week", "*", "Day-Of-Week", "Day", "*", "*", "*", "Hour", "Minute", "Second", "*", "Timezone"};
    private static final String[] m1 = {"era", "year", "quarter", "month", "week", "weekOfMonth", "weekday", "day", "dayOfYear", "weekdayOfMonth", "dayperiod", "hour", "minute", "second", "*", "zone"};
    private static final String[] n1 = {"Era", "Year", "Quarter", "Month", "Week_in_Year", "Week_in_Month", "Weekday", "Day", "Day_Of_Year", "Day_of_Week_in_Month", "Dayperiod", "Hour", "Minute", "Second", "Fractional_Second", "Zone"};
    private static final String[] o1;
    private static final Set<String> p1;
    private static final int q1 = 1023;
    private static final int r1 = 64512;
    private static final int s1 = 16;
    private static final int t1 = 256;
    private static final int u1 = 0;
    private static final int v1 = -257;
    private static final int w1 = -258;
    private static final int x1 = -259;
    private static final int y1 = -260;
    private static final int z1 = 65536;
    private TreeMap<f, l> C1 = new TreeMap<>();
    private TreeMap<String, l> D1 = new TreeMap<>();
    private String E1 = "?";
    private String[] F1 = {"{1} {0}", "{1} {0}", "{1} {0}", "{1} {0}"};
    private String[] G1 = new String[16];
    private String[][] H1;
    private char I1;
    private volatile boolean J1;
    private transient f K1;
    private transient i L1;
    private transient h M1;
    private String[] N1;
    private Set<String> O1;

    public enum DisplayWidth {
        WIDE(""),
        ABBREVIATED("-short"),
        NARROW("-narrow");
        
        @Deprecated

        /* renamed from: a  reason: collision with root package name */
        private static int f15139a = values().length;
        private final String cldrKey;

        private DisplayWidth(String str) {
            this.cldrKey = str;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String g() {
            return this.cldrKey;
        }
    }

    /* access modifiers changed from: private */
    public class b extends l2.c {
        private b() {
        }

        @Override // com.ibm.icu.impl.l2.c
        public void a(l2.b bVar, l2.e eVar, boolean z) {
            int F = DateTimePatternGenerator.F(bVar);
            if (F >= 0 && DateTimePatternGenerator.this.H(F) == null) {
                DateTimePatternGenerator.this.C0(F, eVar.toString());
            }
        }
    }

    /* access modifiers changed from: private */
    public class c extends l2.c {
        private c() {
        }

        @Override // com.ibm.icu.impl.l2.c
        public void a(l2.b bVar, l2.e eVar, boolean z) {
            int S = DateTimePatternGenerator.S(bVar);
            if (S != -1) {
                int i = S / DisplayWidth.f15139a;
                DisplayWidth displayWidth = DateTimePatternGenerator.c1[S % DisplayWidth.f15139a];
                if (eVar.j().c("dn", eVar) && DateTimePatternGenerator.this.d0(i, displayWidth) == null) {
                    DateTimePatternGenerator.this.L0(i, displayWidth, eVar.toString());
                }
            }
        }
    }

    /* access modifiers changed from: private */
    public class d extends l2.c {

        /* renamed from: a  reason: collision with root package name */
        j f15143a;

        public d(j jVar) {
            this.f15143a = jVar;
        }

        @Override // com.ibm.icu.impl.l2.c
        public void a(l2.b bVar, l2.e eVar, boolean z) {
            String bVar2 = bVar.toString();
            if (!DateTimePatternGenerator.this.w0(bVar2)) {
                DateTimePatternGenerator.this.E0(bVar2);
                DateTimePatternGenerator.this.v(eVar.toString(), bVar2, !z, this.f15143a);
            }
        }
    }

    /* access modifiers changed from: private */
    public enum e {
        FIX_FRACTIONAL_SECONDS,
        SKELETON_USES_CAP_J
    }

    /* access modifiers changed from: private */
    public static class f implements Comparable<f> {
        private m I0;
        private boolean J0;

        /* renamed from: a  reason: collision with root package name */
        private int[] f15147a;

        /* renamed from: b  reason: collision with root package name */
        private m f15148b;

        private f() {
            this.f15147a = new int[16];
            this.f15148b = new m();
            this.I0 = new m();
            this.J0 = false;
        }

        public boolean equals(Object obj) {
            return this == obj || (obj != null && (obj instanceof f) && this.f15148b.equals(((f) obj).f15148b));
        }

        /* renamed from: g */
        public int compareTo(f fVar) {
            int g = this.f15148b.g(fVar.f15148b);
            if (g > 0) {
                return -1;
            }
            return g < 0 ? 1 : 0;
        }

        /* access modifiers changed from: package-private */
        public void h(f fVar, int i) {
            int i2 = 0;
            while (true) {
                int[] iArr = this.f15147a;
                if (i2 < iArr.length) {
                    if (((1 << i2) & i) != 0) {
                        iArr[i2] = fVar.f15147a[i2];
                        this.f15148b.h(fVar.f15148b, i2);
                    } else {
                        iArr[i2] = 0;
                        this.f15148b.f(i2);
                    }
                    i2++;
                } else {
                    return;
                }
            }
        }

        public int hashCode() {
            return this.f15148b.hashCode();
        }

        public boolean i(int i) {
            return this.f15147a[i] > 0;
        }

        /* access modifiers changed from: package-private */
        public String j() {
            return this.I0.p(this.J0);
        }

        /* access modifiers changed from: package-private */
        public int k(f fVar, int i, h hVar) {
            int i2;
            hVar.c();
            int i3 = 0;
            for (int i4 = 0; i4 < 16; i4++) {
                if (((1 << i4) & i) == 0) {
                    i2 = 0;
                } else {
                    i2 = this.f15147a[i4];
                }
                int i5 = fVar.f15147a[i4];
                if (i2 != i5) {
                    if (i2 == 0) {
                        i3 += 65536;
                        hVar.a(i4);
                    } else if (i5 == 0) {
                        i3 += 4096;
                        hVar.b(i4);
                    } else {
                        i3 += Math.abs(i2 - i5);
                    }
                }
            }
            return i3;
        }

        /* access modifiers changed from: package-private */
        public int l() {
            int i = 0;
            int i2 = 0;
            while (true) {
                int[] iArr = this.f15147a;
                if (i >= iArr.length) {
                    return i2;
                }
                if (iArr[i] != 0) {
                    i2 |= 1 << i;
                }
                i++;
            }
        }

        /* access modifiers changed from: package-private */
        public f n(String str, i iVar, boolean z) {
            String nVar;
            char i;
            Arrays.fill(this.f15147a, 0);
            this.f15148b.e();
            this.I0.e();
            this.J0 = false;
            iVar.f(str);
            Iterator<Object> it = iVar.c().iterator();
            while (true) {
                int i2 = 1;
                if (it.hasNext()) {
                    Object next = it.next();
                    if (next instanceof n) {
                        n nVar2 = (n) next;
                        nVar = nVar2.toString();
                        int[] iArr = DateTimePatternGenerator.B1[nVar2.c()];
                        int i3 = iArr[1];
                        if (!this.f15148b.k(i3)) {
                            i = this.f15148b.i(i3);
                            char charAt = nVar.charAt(0);
                            if (!z && !(i == 'r' && (charAt == 'U' || charAt == 'y'))) {
                                if ((i == 'U' || i == 'y') && charAt == 'r') {
                                }
                            }
                        } else {
                            this.f15148b.m(i3, nVar);
                            char c2 = (char) iArr[0];
                            int i4 = iArr[3];
                            if ("GEzvQ".indexOf(c2) < 0) {
                                i2 = i4;
                            }
                            this.I0.l(i3, c2, i2);
                            int i5 = iArr[2];
                            if (i5 > 0) {
                                i5 += nVar.length();
                            }
                            this.f15147a[i3] = i5;
                        }
                    }
                } else {
                    if (!this.f15148b.k(12) && !this.f15148b.k(14) && this.f15148b.k(13)) {
                        int i6 = 0;
                        while (true) {
                            if (i6 >= DateTimePatternGenerator.B1.length) {
                                break;
                            }
                            int[] iArr2 = DateTimePatternGenerator.B1[i6];
                            if (iArr2[1] == 13) {
                                this.f15148b.l(13, (char) iArr2[0], iArr2[3]);
                                this.I0.l(13, (char) iArr2[0], iArr2[3]);
                                int i7 = iArr2[2];
                                int[] iArr3 = this.f15147a;
                                if (i7 > 0) {
                                    i7++;
                                }
                                iArr3[13] = i7;
                            } else {
                                i6++;
                            }
                        }
                    }
                    if (!this.f15148b.k(11)) {
                        if (this.f15148b.i(11) == 'h' || this.f15148b.i(11) == 'K') {
                            if (this.f15148b.k(10)) {
                                int i8 = 0;
                                while (true) {
                                    if (i8 >= DateTimePatternGenerator.B1.length) {
                                        break;
                                    }
                                    int[] iArr4 = DateTimePatternGenerator.B1[i8];
                                    if (iArr4[1] == 10) {
                                        this.f15148b.l(10, (char) iArr4[0], iArr4[3]);
                                        this.I0.l(10, (char) iArr4[0], iArr4[3]);
                                        this.f15147a[10] = iArr4[2];
                                        this.J0 = true;
                                        break;
                                    }
                                    i8++;
                                }
                            }
                        } else if (!this.f15148b.k(10)) {
                            this.f15148b.f(10);
                            this.I0.f(10);
                            this.f15147a[10] = 0;
                        }
                    }
                    return this;
                }
            }
            throw new IllegalArgumentException("Conflicting fields:\t" + i + ", " + nVar + "\t in " + str);
        }

        public String o() {
            return this.f15148b.o(this.J0);
        }

        public String toString() {
            return this.f15148b.p(this.J0);
        }
    }

    private static class g extends l2.c {

        /* renamed from: a  reason: collision with root package name */
        HashMap<String, String[]> f15149a;

        @Override // com.ibm.icu.impl.l2.c
        public void a(l2.b bVar, l2.e eVar, boolean z) {
            String[] strArr;
            l2.d j = eVar.j();
            for (int i = 0; j.d(i, bVar, eVar); i++) {
                String bVar2 = bVar.toString();
                l2.d j2 = eVar.j();
                String[] strArr2 = null;
                String str = null;
                for (int i2 = 0; j2.d(i2, bVar, eVar); i2++) {
                    if (bVar.r("allowed")) {
                        strArr2 = eVar.h();
                    } else if (bVar.r("preferred")) {
                        str = eVar.f();
                    }
                }
                if (strArr2 == null || strArr2.length <= 0) {
                    strArr = new String[2];
                    if (str == null) {
                        str = DateTimePatternGenerator.f15138b[0];
                    }
                    strArr[0] = str;
                    strArr[1] = strArr[0];
                } else {
                    strArr = new String[(strArr2.length + 1)];
                    if (str == null) {
                        str = strArr2[0];
                    }
                    strArr[0] = str;
                    System.arraycopy(strArr2, 0, strArr, 1, strArr2.length);
                }
                this.f15149a.put(bVar2, strArr);
            }
        }

        private g(HashMap<String, String[]> hashMap) {
            this.f15149a = hashMap;
        }
    }

    /* access modifiers changed from: private */
    public static class h {

        /* renamed from: a  reason: collision with root package name */
        int f15150a;

        /* renamed from: b  reason: collision with root package name */
        int f15151b;

        private h() {
        }

        /* access modifiers changed from: package-private */
        public void a(int i) {
            this.f15151b = (1 << i) | this.f15151b;
        }

        /* access modifiers changed from: package-private */
        public void b(int i) {
            this.f15150a = (1 << i) | this.f15150a;
        }

        /* access modifiers changed from: package-private */
        public void c() {
            this.f15151b = 0;
            this.f15150a = 0;
        }

        /* access modifiers changed from: package-private */
        public void d(h hVar) {
            this.f15150a = hVar.f15150a;
            this.f15151b = hVar.f15151b;
        }

        public String toString() {
            return "missingFieldMask: " + DateTimePatternGenerator.M0(this.f15150a) + ", extraFieldMask: " + DateTimePatternGenerator.M0(this.f15151b);
        }
    }

    @Deprecated
    public static class i {

        /* renamed from: a  reason: collision with root package name */
        private static final UnicodeSet f15152a = new UnicodeSet("[a-zA-Z]").freeze();

        /* renamed from: b  reason: collision with root package name */
        private static final UnicodeSet f15153b = new UnicodeSet("[[[:script=Latn:][:script=Cyrl:]]&[[:L:][:M:]]]").freeze();

        /* renamed from: c  reason: collision with root package name */
        private transient z0 f15154c = new z0().u(f15152a).o(f15153b).v(true);

        /* renamed from: d  reason: collision with root package name */
        private List<Object> f15155d = new ArrayList();

        private void b(StringBuffer stringBuffer, boolean z) {
            if (stringBuffer.length() != 0) {
                this.f15155d.add(new n(stringBuffer.toString(), z));
                stringBuffer.setLength(0);
            }
        }

        @Deprecated
        public List<Object> c() {
            return this.f15155d;
        }

        @Deprecated
        public boolean d() {
            int i = 0;
            for (Object obj : this.f15155d) {
                if (obj instanceof n) {
                    i |= 1 << ((n) obj).d();
                }
            }
            boolean z = (i & 1023) != 0;
            boolean z2 = (i & 64512) != 0;
            if (!z || !z2) {
                return false;
            }
            return true;
        }

        @Deprecated
        public Object e(String str) {
            return this.f15154c.m(str);
        }

        @Deprecated
        public final i f(String str) {
            return g(str, false);
        }

        @Deprecated
        public i g(String str, boolean z) {
            this.f15155d.clear();
            if (str.length() == 0) {
                return this;
            }
            this.f15154c.s(str);
            StringBuffer stringBuffer = new StringBuffer();
            StringBuffer stringBuffer2 = new StringBuffer();
            while (true) {
                stringBuffer.setLength(0);
                int j = this.f15154c.j(stringBuffer);
                if (j == 0) {
                    b(stringBuffer2, false);
                    return this;
                } else if (j == 1) {
                    if (!(stringBuffer2.length() == 0 || stringBuffer.charAt(0) == stringBuffer2.charAt(0))) {
                        b(stringBuffer2, false);
                    }
                    stringBuffer2.append(stringBuffer);
                } else {
                    b(stringBuffer2, false);
                    this.f15155d.add(stringBuffer.toString());
                }
            }
        }

        @Deprecated
        public String h(int i, int i2) {
            StringBuilder sb = new StringBuilder();
            while (i < i2) {
                Object obj = this.f15155d.get(i);
                if (obj instanceof String) {
                    sb.append(this.f15154c.m((String) obj));
                } else {
                    sb.append(this.f15155d.get(i).toString());
                }
                i++;
            }
            return sb.toString();
        }

        @Deprecated
        public String toString() {
            return h(0, this.f15155d.size());
        }
    }

    public static final class j {

        /* renamed from: a  reason: collision with root package name */
        public static final int f15156a = 0;

        /* renamed from: b  reason: collision with root package name */
        public static final int f15157b = 1;

        /* renamed from: c  reason: collision with root package name */
        public static final int f15158c = 2;

        /* renamed from: d  reason: collision with root package name */
        public int f15159d;

        /* renamed from: e  reason: collision with root package name */
        public String f15160e;
    }

    /* access modifiers changed from: private */
    public static class k {

        /* renamed from: a  reason: collision with root package name */
        public String f15161a;

        /* renamed from: b  reason: collision with root package name */
        public f f15162b;

        public k(String str, f fVar) {
            this.f15161a = str;
            this.f15162b = fVar;
        }
    }

    /* access modifiers changed from: private */
    public static class l {

        /* renamed from: a  reason: collision with root package name */
        public String f15163a;

        /* renamed from: b  reason: collision with root package name */
        public boolean f15164b;

        public l(String str, boolean z) {
            this.f15163a = str;
            this.f15164b = z;
        }

        public String toString() {
            return this.f15163a + "," + this.f15164b;
        }
    }

    /* access modifiers changed from: private */
    public static class m {

        /* renamed from: a  reason: collision with root package name */
        private static final byte f15165a = 0;

        /* renamed from: b  reason: collision with root package name */
        private static final byte f15166b = 0;

        /* renamed from: c  reason: collision with root package name */
        static final /* synthetic */ boolean f15167c = false;

        /* renamed from: d  reason: collision with root package name */
        private byte[] f15168d;

        /* renamed from: e  reason: collision with root package name */
        private byte[] f15169e;

        private m() {
            this.f15168d = new byte[16];
            this.f15169e = new byte[16];
        }

        private StringBuilder b(int i, StringBuilder sb, boolean z) {
            char c2 = (char) this.f15168d[i];
            byte b2 = this.f15169e[i];
            if (z) {
                c2 = DateTimePatternGenerator.U(i, c2);
            }
            for (int i2 = 0; i2 < b2; i2++) {
                sb.append(c2);
            }
            return sb;
        }

        private StringBuilder d(StringBuilder sb, boolean z, boolean z2) {
            for (int i = 0; i < 16; i++) {
                if (!z2 || i != 10) {
                    b(i, sb, z);
                }
            }
            return sb;
        }

        public StringBuilder a(int i, StringBuilder sb) {
            return b(i, sb, false);
        }

        public StringBuilder c(StringBuilder sb) {
            return d(sb, false, false);
        }

        public void e() {
            Arrays.fill(this.f15168d, (byte) 0);
            Arrays.fill(this.f15169e, (byte) 0);
        }

        public boolean equals(Object obj) {
            return this == obj || (obj != null && (obj instanceof m) && g((m) obj) == 0);
        }

        /* access modifiers changed from: package-private */
        public void f(int i) {
            this.f15168d[i] = 0;
            this.f15169e[i] = 0;
        }

        public int g(m mVar) {
            for (int i = 0; i < 16; i++) {
                int i2 = this.f15168d[i] - mVar.f15168d[i];
                if (i2 != 0) {
                    return i2;
                }
                int i3 = this.f15169e[i] - mVar.f15169e[i];
                if (i3 != 0) {
                    return i3;
                }
            }
            return 0;
        }

        /* access modifiers changed from: package-private */
        public void h(m mVar, int i) {
            this.f15168d[i] = mVar.f15168d[i];
            this.f15169e[i] = mVar.f15169e[i];
        }

        public int hashCode() {
            return Arrays.hashCode(this.f15168d) ^ Arrays.hashCode(this.f15169e);
        }

        /* access modifiers changed from: package-private */
        public char i(int i) {
            return (char) this.f15168d[i];
        }

        /* access modifiers changed from: package-private */
        public int j(int i) {
            return this.f15169e[i];
        }

        public boolean k(int i) {
            return this.f15169e[i] == 0;
        }

        /* access modifiers changed from: package-private */
        public void l(int i, char c2, int i2) {
            this.f15168d[i] = (byte) c2;
            this.f15169e[i] = (byte) i2;
        }

        /* access modifiers changed from: package-private */
        public void m(int i, String str) {
            char[] charArray = str.toCharArray();
            for (char c2 : charArray) {
            }
            l(i, str.charAt(0), str.length());
        }

        public String n() {
            return d(new StringBuilder(), true, false).toString();
        }

        public String o(boolean z) {
            return d(new StringBuilder(), true, z).toString();
        }

        public String p(boolean z) {
            return d(new StringBuilder(), false, z).toString();
        }

        public String toString() {
            return d(new StringBuilder(), false, false).toString();
        }
    }

    @Deprecated
    public static class n {

        /* renamed from: a  reason: collision with root package name */
        private final String f15170a;

        /* renamed from: b  reason: collision with root package name */
        private final int f15171b;

        @Deprecated
        public n(String str) {
            this(str, false);
        }

        @Deprecated
        public static String b(int i) {
            try {
                return DateTimePatternGenerator.o1[i];
            } catch (Exception unused) {
                return String.valueOf(i);
            }
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private int c() {
            return this.f15171b;
        }

        @Deprecated
        public int d() {
            return DateTimePatternGenerator.B1[this.f15171b][1];
        }

        @Deprecated
        public boolean e() {
            return DateTimePatternGenerator.B1[this.f15171b][2] > 0;
        }

        @Deprecated
        public String toString() {
            return this.f15170a;
        }

        @Deprecated
        public n(String str, boolean z) {
            int V = DateTimePatternGenerator.V(str, z);
            this.f15171b = V;
            if (V >= 0) {
                this.f15170a = str;
                return;
            }
            throw new IllegalArgumentException("Illegal datetime field:\t" + str);
        }
    }

    static {
        HashMap hashMap = new HashMap();
        ((ICUResourceBundle) h0.m(a0.f13490d, "supplementalData", ICUResourceBundle.j)).s0("timeData", new g(hashMap));
        I0 = Collections.unmodifiableMap(hashMap);
        DisplayWidth displayWidth = DisplayWidth.WIDE;
        a1 = displayWidth;
        b1 = displayWidth.ordinal();
        String[] strArr = {"G", DateFormat.YEAR, "Q", "M", "w", ExifInterface.y4, "E", DateFormat.DAY, "D", "F", "a", DateFormat.HOUR24, DateFormat.MINUTE, DateFormat.SECOND, ExifInterface.w4, "v"};
        o1 = strArr;
        p1 = new HashSet(Arrays.asList(strArr));
    }

    protected DateTimePatternGenerator() {
        int[] iArr = new int[2];
        iArr[1] = DisplayWidth.f15139a;
        iArr[0] = 16;
        this.H1 = (String[][]) Array.newInstance(String.class, iArr);
        this.I1 = 'H';
        this.J1 = false;
        this.K1 = new f();
        this.L1 = new i();
        this.M1 = new h();
        this.O1 = new HashSet(20);
    }

    private void A() {
        for (int i2 = 0; i2 < 16; i2++) {
            if (H(i2) == null) {
                C0(i2, "{0} ├{2}: {1}┤");
            }
            DisplayWidth displayWidth = DisplayWidth.WIDE;
            if (d0(i2, displayWidth) == null) {
                L0(i2, displayWidth, "F" + i2);
            }
            DisplayWidth displayWidth2 = DisplayWidth.ABBREVIATED;
            if (d0(i2, displayWidth2) == null) {
                L0(i2, displayWidth2, d0(i2, displayWidth));
            }
            DisplayWidth displayWidth3 = DisplayWidth.NARROW;
            if (d0(i2, displayWidth3) == null) {
                L0(i2, displayWidth3, d0(i2, displayWidth2));
            }
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0078, code lost:
        if (r11.equals("h23") == false) goto L_0x0065;
     */
    private void C(ULocale uLocale) {
        String language = uLocale.getLanguage();
        String country = uLocale.getCountry();
        if (language.isEmpty() || country.isEmpty()) {
            ULocale addLikelySubtags = ULocale.addLikelySubtags(uLocale);
            String language2 = addLikelySubtags.getLanguage();
            country = addLikelySubtags.getCountry();
            language = language2;
        }
        String keywordValue = uLocale.getKeywordValue("rg");
        char c2 = 2;
        if (keywordValue != null && !keywordValue.isEmpty()) {
            country = keywordValue.length() > 2 ? keywordValue.substring(0, 2) : keywordValue;
        }
        if (language.isEmpty()) {
            language = C.r0;
        }
        if (country.isEmpty()) {
            country = e.c.i;
        }
        String[] D = D(language, country);
        Character ch = null;
        String keywordValue2 = uLocale.getKeywordValue("hours");
        if (keywordValue2 != null) {
            switch (keywordValue2.hashCode()) {
                case 101512:
                    if (keywordValue2.equals("h11")) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 101513:
                    if (keywordValue2.equals("h12")) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 101545:
                    break;
                case 101546:
                    if (keywordValue2.equals("h24")) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    ch = 'K';
                    break;
                case 1:
                    ch = 'h';
                    break;
                case 2:
                    ch = 'H';
                    break;
                case 3:
                    ch = 'k';
                    break;
            }
        }
        if (D == null) {
            try {
                D = D(language, Region.n(country).toString());
            } catch (IllegalArgumentException unused) {
            }
        }
        if (D != null) {
            this.I1 = ch != null ? ch.charValue() : D[0].charAt(0);
            this.N1 = (String[]) Arrays.copyOfRange(D, 1, D.length - 1);
            return;
        }
        String[] strArr = f15138b;
        this.N1 = strArr;
        this.I1 = ch != null ? ch.charValue() : strArr[0].charAt(0);
    }

    private String[] D(String str, String str2) {
        Map<String, String[]> map = I0;
        String[] strArr = map.get(str + com.ibm.icu.impl.locale.b.f14006b + str2);
        return strArr == null ? map.get(str2) : strArr;
    }

    private String E(int i2) {
        return this.G1[i2];
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void E0(String str) {
        x();
        this.O1.add(str);
    }

    @Deprecated
    public static int F(l2.b bVar) {
        int i2 = 0;
        while (true) {
            String[] strArr = l1;
            if (i2 >= strArr.length) {
                return -1;
            }
            if (bVar.r(strArr[i2])) {
                return i2;
            }
            i2++;
        }
    }

    @Deprecated
    public static int G(String str) {
        int i2 = 0;
        while (true) {
            String[] strArr = l1;
            if (i2 >= strArr.length) {
                return -1;
            }
            if (strArr[i2].equals(str)) {
                return i2;
            }
            i2++;
        }
    }

    private void H0(ULocale uLocale) {
        Calendar instance = Calendar.getInstance(uLocale);
        for (int i2 = 0; i2 <= 3; i2++) {
            F0(i2, Calendar.getDateAtTimePattern(instance, uLocale, i2));
        }
    }

    private String J(int i2) {
        return "'" + this.H1[i2][b1] + "'";
    }

    private void J0(ULocale uLocale) {
        I0(String.valueOf(new DecimalFormatSymbols(uLocale).getDecimalSeparator()));
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    @Deprecated
    private void L0(int i2, DisplayWidth displayWidth, String str) {
        x();
        if (i2 < 16 && i2 >= 0) {
            this.H1[i2][displayWidth.ordinal()] = str;
        }
    }

    private String M(f fVar, int i2, h hVar, f fVar2, EnumSet<e> enumSet, int i3) {
        if (i2 == 0) {
            return null;
        }
        k R = R(fVar, i2, hVar, fVar2);
        String w = w(R, fVar, enumSet, i3);
        while (true) {
            int i4 = hVar.f15150a;
            if (i4 == 0) {
                return w;
            }
            if ((i4 & j1) == 16384 && (i2 & j1) == j1) {
                R.f15161a = w;
                enumSet = EnumSet.copyOf((EnumSet) enumSet);
                enumSet.add(e.FIX_FRACTIONAL_SECONDS);
                w = w(R, fVar, enumSet, i3);
                hVar.f15150a &= -16385;
            } else {
                String w2 = w(R(fVar, i4, hVar, fVar2), fVar, enumSet, i3);
                int t0 = t0(i4 & (~hVar.f15150a));
                w = l1.g(E(t0), 2, 3, w, w2, J(t0));
            }
        }
    }

    /* access modifiers changed from: private */
    public static String M0(int i2) {
        StringBuilder sb = new StringBuilder();
        for (int i3 = 0; i3 < 16; i3++) {
            if (((1 << i3) & i2) != 0) {
                if (sb.length() != 0) {
                    sb.append(" | ");
                }
                sb.append(n1[i3]);
                sb.append(Padder.f14124a);
            }
        }
        return sb.toString();
    }

    /* JADX WARNING: Code restructure failed: missing block: B:12:0x0054, code lost:
        if (r9 != null) goto L_0x005b;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:13:0x0056, code lost:
        if (r11 != null) goto L_?;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:14:0x0058, code lost:
        return "";
     */
    /* JADX WARNING: Code restructure failed: missing block: B:15:0x005b, code lost:
        if (r11 != null) goto L_0x005e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x005d, code lost:
        return r9;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:17:0x005e, code lost:
        r12 = r10.K1.o();
        r0 = r12.indexOf(77);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:18:0x006b, code lost:
        if (r0 < 0) goto L_0x0074;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:19:0x006d, code lost:
        r13 = (r12.lastIndexOf(77) + 1) - r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:20:0x0074, code lost:
        r13 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x0075, code lost:
        r2 = 3;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:22:0x0078, code lost:
        if (r13 != 4) goto L_0x0086;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:24:0x0080, code lost:
        if (r12.indexOf(69) < 0) goto L_0x0084;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:25:0x0082, code lost:
        r2 = 0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:26:0x0084, code lost:
        r2 = 1;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0086, code lost:
        if (r13 != 3) goto L_0x0089;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:28:0x0088, code lost:
        r2 = 2;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x0097, code lost:
        return com.ibm.icu.impl.l1.g(Y(r2), 2, 2, r11, r9);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:34:?, code lost:
        return r11;
     */
    private String P(String str, f fVar, int i2) {
        EnumSet<e> noneOf = EnumSet.noneOf(e.class);
        String z0 = z0(str, noneOf);
        synchronized (this) {
            this.K1.n(z0, this.L1, false);
            k R = R(this.K1, -1, this.M1, fVar);
            h hVar = this.M1;
            if (hVar.f15150a == 0 && hVar.f15151b == 0) {
                return w(R, this.K1, noneOf, i2);
            }
            int l2 = this.K1.l();
            String M = M(this.K1, l2 & 1023, this.M1, fVar, noneOf, i2);
            String M2 = M(this.K1, l2 & 64512, this.M1, fVar, noneOf, i2);
        }
    }

    private k R(f fVar, int i2, h hVar, f fVar2) {
        int k2;
        k kVar = new k("", null);
        h hVar2 = new h();
        int i3 = Integer.MAX_VALUE;
        int i4 = Integer.MIN_VALUE;
        for (f fVar3 : this.C1.keySet()) {
            if (!fVar3.equals(fVar2) && ((k2 = fVar.k(fVar3, i2, hVar2)) < i3 || (k2 == i3 && i4 < hVar2.f15150a))) {
                int i5 = hVar2.f15150a;
                l lVar = this.C1.get(fVar3);
                kVar.f15161a = lVar.f15163a;
                if (lVar.f15164b) {
                    kVar.f15162b = fVar3;
                } else {
                    kVar.f15162b = null;
                }
                hVar.d(hVar2);
                if (k2 == 0) {
                    break;
                }
                i4 = i5;
                i3 = k2;
            }
        }
        return kVar;
    }

    /* access modifiers changed from: private */
    public static int S(l2.b bVar) {
        for (int i2 = 0; i2 < m1.length; i2++) {
            for (int i3 = 0; i3 < DisplayWidth.f15139a; i3++) {
                if (bVar.r(m1[i2].concat(c1[i3].g()))) {
                    return (i2 * DisplayWidth.f15139a) + i3;
                }
            }
        }
        return -1;
    }

    private String T(ULocale uLocale) {
        String keywordValue = uLocale.getKeywordValue("calendar");
        if (keywordValue == null) {
            keywordValue = Calendar.getKeywordValuesForLocale("calendar", uLocale, true)[0];
        }
        return keywordValue == null ? "gregorian" : keywordValue;
    }

    /* access modifiers changed from: private */
    public static char U(int i2, char c2) {
        if (c2 == 'h' || c2 == 'K') {
            return 'h';
        }
        int i3 = 0;
        while (true) {
            int[][] iArr = B1;
            if (i3 < iArr.length) {
                int[] iArr2 = iArr[i3];
                if (iArr2[1] == i2) {
                    return (char) iArr2[0];
                }
                i3++;
            } else {
                throw new IllegalArgumentException("Could not find field " + i2);
            }
        }
    }

    /* access modifiers changed from: private */
    public static int V(String str, boolean z) {
        int length = str.length();
        if (length == 0) {
            return -1;
        }
        char charAt = str.charAt(0);
        for (int i2 = 1; i2 < length; i2++) {
            if (str.charAt(i2) != charAt) {
                return -1;
            }
        }
        int i3 = 0;
        int i4 = -1;
        while (true) {
            int[][] iArr = B1;
            if (i3 < iArr.length) {
                int[] iArr2 = iArr[i3];
                if (iArr2[0] == charAt) {
                    if (iArr2[3] <= length && iArr2[iArr2.length - 1] >= length) {
                        return i3;
                    }
                    i4 = i3;
                }
                i3++;
            } else if (z) {
                return -1;
            } else {
                return i4;
            }
        }
    }

    public static DateTimePatternGenerator c0() {
        DateTimePatternGenerator dateTimePatternGenerator = new DateTimePatternGenerator();
        dateTimePatternGenerator.s();
        dateTimePatternGenerator.A();
        return dateTimePatternGenerator;
    }

    private static String g0(i iVar, BitSet bitSet) {
        StringBuilder sb = new StringBuilder();
        for (int i2 = 0; i2 < iVar.f15155d.size(); i2++) {
            if (!bitSet.get(i2)) {
                Object obj = iVar.f15155d.get(i2);
                if (obj instanceof String) {
                    sb.append(iVar.e(obj.toString()));
                } else {
                    sb.append(obj.toString());
                }
            }
        }
        return sb.toString();
    }

    @Deprecated
    public static DateTimePatternGenerator h0(ULocale uLocale) {
        String uLocale2 = uLocale.toString();
        DateTimePatternGenerator dateTimePatternGenerator = k1.get(uLocale2);
        if (dateTimePatternGenerator != null) {
            return dateTimePatternGenerator;
        }
        DateTimePatternGenerator dateTimePatternGenerator2 = new DateTimePatternGenerator();
        dateTimePatternGenerator2.v0(uLocale, false);
        dateTimePatternGenerator2.freeze();
        k1.put(uLocale2, dateTimePatternGenerator2);
        return dateTimePatternGenerator2;
    }

    public static DateTimePatternGenerator i0() {
        return j0(ULocale.getDefault(ULocale.Category.FORMAT));
    }

    public static DateTimePatternGenerator j0(ULocale uLocale) {
        return h0(uLocale).cloneAsThawed();
    }

    public static DateTimePatternGenerator k0(Locale locale) {
        return j0(ULocale.forLocale(locale));
    }

    @Deprecated
    public static DateTimePatternGenerator l0(ULocale uLocale) {
        DateTimePatternGenerator dateTimePatternGenerator = new DateTimePatternGenerator();
        dateTimePatternGenerator.v0(uLocale, true);
        return dateTimePatternGenerator;
    }

    private static String m0(String str) {
        int V = V(str, true);
        String[] strArr = n1;
        int[][] iArr = B1;
        String str2 = strArr[iArr[V][1]];
        if (iArr[V][2] < 0) {
            return str2 + ":S";
        }
        return str2 + ":N";
    }

    private TreeSet<String> p0(String str) {
        List<Object> c2 = this.L1.f(str).c();
        TreeSet<String> treeSet = new TreeSet<>();
        for (Object obj : c2) {
            String obj2 = obj.toString();
            if (!obj2.startsWith("G") && !obj2.startsWith("a")) {
                treeSet.add(obj2);
            }
        }
        return treeSet;
    }

    private void r(j jVar, ULocale uLocale) {
        ICUResourceBundle iCUResourceBundle = (ICUResourceBundle) h0.j(a0.f13490d, uLocale);
        String T = T(uLocale);
        b bVar = new b();
        try {
            iCUResourceBundle.q0("calendar/" + T + "/appendItems", bVar);
        } catch (MissingResourceException unused) {
        }
        try {
            iCUResourceBundle.q0("fields", new c());
        } catch (MissingResourceException unused2) {
        }
        d dVar = new d(jVar);
        try {
            iCUResourceBundle.q0("calendar/" + T + "/availableFormats", dVar);
        } catch (MissingResourceException unused3) {
        }
    }

    private void s() {
        j jVar = new j();
        int i2 = 0;
        while (true) {
            String[] strArr = o1;
            if (i2 < strArr.length) {
                u(String.valueOf(strArr[i2]), false, jVar);
                i2++;
            } else {
                return;
            }
        }
    }

    private void t(j jVar, ULocale uLocale) {
        for (int i2 = 0; i2 <= 3; i2++) {
            u(((SimpleDateFormat) DateFormat.getDateInstance(i2, uLocale)).toPattern(), false, jVar);
            SimpleDateFormat simpleDateFormat = (SimpleDateFormat) DateFormat.getTimeInstance(i2, uLocale);
            u(simpleDateFormat.toPattern(), false, jVar);
            if (i2 == 3) {
                z(simpleDateFormat.toPattern(), jVar);
            }
        }
    }

    private int t0(int i2) {
        int i3 = 0;
        while (i2 != 0) {
            i2 >>>= 1;
            i3++;
        }
        return i3 - 1;
    }

    private void u0(j jVar, String str) {
        this.L1.f(str);
        StringBuilder sb = new StringBuilder();
        int i2 = 0;
        boolean z = false;
        while (true) {
            if (i2 >= this.L1.f15155d.size()) {
                break;
            }
            Object obj = this.L1.f15155d.get(i2);
            if (!(obj instanceof String)) {
                char charAt = obj.toString().charAt(0);
                if (charAt == 'm') {
                    sb.append(obj);
                    z = true;
                } else if (charAt != 's') {
                    if (z || charAt == 'z' || charAt == 'Z' || charAt == 'v' || charAt == 'V') {
                        break;
                    }
                } else if (z) {
                    sb.append(obj);
                    u(sb.toString(), false, jVar);
                }
            } else if (z) {
                sb.append(this.L1.e(obj.toString()));
            }
            i2++;
        }
        BitSet bitSet = new BitSet();
        BitSet bitSet2 = new BitSet();
        for (int i3 = 0; i3 < this.L1.f15155d.size(); i3++) {
            Object obj2 = this.L1.f15155d.get(i3);
            if (obj2 instanceof n) {
                bitSet.set(i3);
                char charAt2 = obj2.toString().charAt(0);
                if (charAt2 == 's' || charAt2 == 'S') {
                    bitSet2.set(i3);
                    int i4 = i3 - 1;
                    while (i4 >= 0 && !bitSet.get(i4)) {
                        bitSet2.set(i3);
                        i4++;
                    }
                }
            }
        }
        u(g0(this.L1, bitSet2), false, jVar);
    }

    private void v0(ULocale uLocale, boolean z) {
        j jVar = new j();
        s();
        if (!z) {
            t(jVar, uLocale);
        }
        r(jVar, uLocale);
        if (!z) {
            H0(uLocale);
        } else {
            G0("{1} {0}");
        }
        J0(uLocale);
        C(uLocale);
        A();
    }

    private String w(k kVar, f fVar, EnumSet<e> enumSet, int i2) {
        char c2;
        char c3;
        this.L1.f(kVar.f15161a);
        StringBuilder sb = new StringBuilder();
        for (Object obj : this.L1.c()) {
            if (obj instanceof String) {
                sb.append(this.L1.e((String) obj));
            } else {
                n nVar = (n) obj;
                StringBuilder sb2 = new StringBuilder(nVar.toString());
                int d2 = nVar.d();
                if (enumSet.contains(e.FIX_FRACTIONAL_SECONDS) && d2 == 13) {
                    sb2.append(this.E1);
                    fVar.f15148b.a(14, sb2);
                } else if (fVar.f15147a[d2] != 0) {
                    char i3 = fVar.f15148b.i(d2);
                    int j2 = fVar.f15148b.j(d2);
                    if (i3 == 'E' && j2 < 3) {
                        j2 = 3;
                    }
                    f fVar2 = kVar.f15162b;
                    char c4 = 'e';
                    if ((d2 == 11 && (i2 & 2048) == 0) || ((d2 == 12 && (i2 & 4096) == 0) || (d2 == 13 && (i2 & 8192) == 0))) {
                        j2 = sb2.length();
                    } else if (!(fVar2 == null || i3 == 'c' || i3 == 'e')) {
                        int j3 = fVar2.f15148b.j(d2);
                        boolean e2 = nVar.e();
                        boolean i4 = fVar2.i(d2);
                        if (j3 == j2 || ((e2 && !i4) || (i4 && !e2))) {
                            j2 = sb2.length();
                        }
                    }
                    if (d2 == 11 || d2 == 3 || d2 == 6 || (d2 == 1 && i3 != 'Y')) {
                        c2 = sb2.charAt(0);
                    } else {
                        c2 = i3;
                    }
                    if (c2 != 'E' || j2 >= 3) {
                        c4 = c2;
                    }
                    if (d2 == 11) {
                        if (enumSet.contains(e.SKELETON_USES_CAP_J) || i3 == (c3 = this.I1)) {
                            c4 = this.I1;
                        } else if (i3 == 'h' && c3 == 'K') {
                            c4 = 'K';
                        } else if (i3 == 'H' && c3 == 'k') {
                            c4 = 'k';
                        } else if (i3 == 'k' && c3 == 'H') {
                            c4 = 'H';
                        } else if (i3 == 'K' && c3 == 'h') {
                            c4 = 'h';
                        }
                    }
                    sb2 = new StringBuilder();
                    while (j2 > 0) {
                        sb2.append(c4);
                        j2--;
                    }
                }
                sb.append((CharSequence) sb2);
            }
        }
        return sb.toString();
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean w0(String str) {
        return this.O1.contains(str);
    }

    private void x() {
        if (isFrozen()) {
            throw new UnsupportedOperationException("Attempt to modify frozen object");
        }
    }

    @Deprecated
    public static boolean y0(String str) {
        char charAt = str.charAt(0);
        for (int i2 = 1; i2 < str.length(); i2++) {
            if (str.charAt(i2) != charAt) {
                return false;
            }
        }
        return true;
    }

    private void z(String str, j jVar) {
        u0(jVar, str);
    }

    private String z0(String str, EnumSet<e> enumSet) {
        char c2;
        StringBuilder sb = new StringBuilder();
        int i2 = 0;
        boolean z = false;
        while (i2 < str.length()) {
            char charAt = str.charAt(i2);
            if (charAt == '\'') {
                z = !z;
            } else if (!z) {
                if (charAt == 'j' || charAt == 'C') {
                    int i3 = 0;
                    while (true) {
                        int i4 = i2 + 1;
                        if (i4 >= str.length() || str.charAt(i4) != charAt) {
                            int i5 = (i3 & 1) + 1;
                        } else {
                            i3++;
                            i2 = i4;
                        }
                    }
                    int i52 = (i3 & 1) + 1;
                    int i6 = i3 < 2 ? 1 : (i3 >> 1) + 3;
                    char c3 = 'a';
                    if (charAt == 'j') {
                        c2 = this.I1;
                    } else {
                        String str2 = this.N1[0];
                        char charAt2 = str2.charAt(0);
                        char charAt3 = str2.charAt(str2.length() - 1);
                        if (charAt3 == 'b' || charAt3 == 'B') {
                            c3 = charAt3;
                        }
                        c2 = charAt2;
                    }
                    if (c2 == 'H' || c2 == 'k') {
                        i6 = 0;
                    }
                    while (true) {
                        int i7 = i6 - 1;
                        if (i6 <= 0) {
                            break;
                        }
                        sb.append(c3);
                        i6 = i7;
                    }
                    while (true) {
                        int i8 = i52 - 1;
                        if (i52 <= 0) {
                            break;
                        }
                        sb.append(c2);
                        i52 = i8;
                    }
                } else if (charAt == 'J') {
                    sb.append('H');
                    enumSet.add(e.SKELETON_USES_CAP_J);
                } else {
                    sb.append(charAt);
                }
            }
            i2++;
        }
        return sb.toString();
    }

    public String A0(String str, String str2) {
        return B0(str, str2, 0);
    }

    /* renamed from: B */
    public DateTimePatternGenerator freeze() {
        this.J1 = true;
        return this;
    }

    public String B0(String str, String str2, int i2) {
        String w;
        synchronized (this) {
            w = w(new k(str, null), this.K1.n(str2, this.L1, false), EnumSet.noneOf(e.class), i2);
        }
        return w;
    }

    public void C0(int i2, String str) {
        x();
        this.G1[i2] = str;
    }

    public void D0(int i2, String str) {
        L0(i2, a1, str);
    }

    public void F0(int i2, String str) {
        if (i2 < 0 || i2 > 3) {
            throw new IllegalArgumentException("Illegal style here: " + i2);
        }
        x();
        this.F1[i2] = str;
    }

    public void G0(String str) {
        x();
        for (int i2 = 0; i2 <= 3; i2++) {
            F0(i2, str);
        }
    }

    public String H(int i2) {
        return this.G1[i2];
    }

    public String I(int i2) {
        return d0(i2, a1);
    }

    public void I0(String str) {
        x();
        this.E1 = str;
    }

    public String K(String str) {
        String j2;
        synchronized (this) {
            this.K1.n(str, this.L1, false);
            j2 = this.K1.j();
        }
        return j2;
    }

    @Deprecated
    public void K0(char c2) {
        this.I1 = c2;
    }

    public Set<String> L(Set<String> set) {
        if (set == null) {
            set = new HashSet<>();
        }
        set.addAll(this.D1.keySet());
        return set;
    }

    public String N(String str) {
        return P(str, null, 0);
    }

    @Deprecated
    public boolean N0(String str, String str2) {
        if (str.equals(str2)) {
            return true;
        }
        TreeSet<String> p0 = p0(str);
        TreeSet<String> p02 = p0(str2);
        if (p0.size() != p02.size()) {
            return false;
        }
        Iterator<String> it = p02.iterator();
        Iterator<String> it2 = p0.iterator();
        while (it2.hasNext()) {
            int V = V(it2.next(), false);
            int V2 = V(it.next(), false);
            int[][] iArr = B1;
            if (iArr[V][1] != iArr[V2][1]) {
                return false;
            }
        }
        return true;
    }

    public String O(String str, int i2) {
        return P(str, null, i2);
    }

    @Deprecated
    public String W(String str) {
        String o;
        synchronized (this) {
            this.K1.n(str, this.L1, true);
            o = this.K1.o();
        }
        return o;
    }

    public String X() {
        return Y(2);
    }

    public String Y(int i2) {
        if (i2 >= 0 && i2 <= 3) {
            return this.F1[i2];
        }
        throw new IllegalArgumentException("Illegal style here: " + i2);
    }

    public String Z() {
        return this.E1;
    }

    public DateFormat.HourCycle a0() {
        char b0 = b0();
        if (b0 == 'H') {
            return DateFormat.HourCycle.HOUR_CYCLE_23;
        }
        if (b0 == 'K') {
            return DateFormat.HourCycle.HOUR_CYCLE_11;
        }
        if (b0 == 'h') {
            return DateFormat.HourCycle.HOUR_CYCLE_12;
        }
        if (b0 == 'k') {
            return DateFormat.HourCycle.HOUR_CYCLE_24;
        }
        throw new AssertionError("should be unreachable");
    }

    @Deprecated
    public char b0() {
        return this.I1;
    }

    @Override // java.lang.Object
    public Object clone() {
        try {
            DateTimePatternGenerator dateTimePatternGenerator = (DateTimePatternGenerator) super.clone();
            dateTimePatternGenerator.C1 = (TreeMap) this.C1.clone();
            dateTimePatternGenerator.D1 = (TreeMap) this.D1.clone();
            dateTimePatternGenerator.F1 = (String[]) this.F1.clone();
            dateTimePatternGenerator.G1 = (String[]) this.G1.clone();
            dateTimePatternGenerator.H1 = (String[][]) this.H1.clone();
            dateTimePatternGenerator.K1 = new f();
            dateTimePatternGenerator.L1 = new i();
            dateTimePatternGenerator.M1 = new h();
            dateTimePatternGenerator.J1 = false;
            return dateTimePatternGenerator;
        } catch (CloneNotSupportedException e2) {
            throw new ICUCloneNotSupportedException("Internal Error", e2);
        }
    }

    public String d0(int i2, DisplayWidth displayWidth) {
        return (i2 >= 16 || i2 < 0) ? "" : this.H1[i2][displayWidth.ordinal()];
    }

    @Deprecated
    public String f0(String str) {
        this.L1.f(str);
        StringBuilder sb = new StringBuilder();
        for (Object obj : this.L1.c()) {
            if (obj instanceof String) {
                sb.append(this.L1.e((String) obj));
            } else {
                sb.append("{" + m0(obj.toString()) + com.alipay.sdk.util.g.f6033d);
            }
        }
        return sb.toString();
    }

    @Override // com.ibm.icu.util.n
    public boolean isFrozen() {
        return this.J1;
    }

    @Deprecated
    public Collection<String> n0(Collection<String> collection) {
        synchronized (this) {
            if (collection == null) {
                collection = new LinkedHashSet<>();
            }
            for (f fVar : this.C1.keySet()) {
                String str = this.C1.get(fVar).f15163a;
                if (!p1.contains(str)) {
                    if (P(fVar.toString(), fVar, 0).equals(str)) {
                        collection.add(str);
                    }
                }
            }
        }
        return collection;
    }

    public String q0(String str) {
        String fVar;
        synchronized (this) {
            this.K1.n(str, this.L1, false);
            fVar = this.K1.toString();
        }
        return fVar;
    }

    @Deprecated
    public String r0(String str) {
        String fVar;
        synchronized (this) {
            this.K1.n(str, this.L1, true);
            fVar = this.K1.toString();
        }
        return fVar;
    }

    public Map<String, String> s0(Map<String, String> map) {
        if (map == null) {
            map = new LinkedHashMap<>();
        }
        for (f fVar : this.C1.keySet()) {
            String str = this.C1.get(fVar).f15163a;
            if (!p1.contains(str)) {
                map.put(fVar.toString(), str);
            }
        }
        return map;
    }

    public DateTimePatternGenerator u(String str, boolean z, j jVar) {
        return v(str, null, z, jVar);
    }

    @Deprecated
    public DateTimePatternGenerator v(String str, String str2, boolean z, j jVar) {
        f fVar;
        x();
        boolean z2 = false;
        if (str2 == null) {
            fVar = new f().n(str, this.L1, false);
        } else {
            fVar = new f().n(str2, this.L1, false);
        }
        String j2 = fVar.j();
        l lVar = this.D1.get(j2);
        if (lVar != null && (!lVar.f15164b || (str2 != null && !z))) {
            jVar.f15159d = 1;
            jVar.f15160e = lVar.f15163a;
            if (!z) {
                return this;
            }
        }
        l lVar2 = this.C1.get(fVar);
        if (lVar2 != null) {
            jVar.f15159d = 2;
            jVar.f15160e = lVar2.f15163a;
            if (!z || (str2 != null && lVar2.f15164b)) {
                return this;
            }
        }
        jVar.f15159d = 0;
        jVar.f15160e = "";
        if (str2 != null) {
            z2 = true;
        }
        l lVar3 = new l(str, z2);
        this.C1.put(fVar, lVar3);
        this.D1.put(j2, lVar3);
        return this;
    }

    /* renamed from: y */
    public DateTimePatternGenerator cloneAsThawed() {
        DateTimePatternGenerator dateTimePatternGenerator = (DateTimePatternGenerator) clone();
        this.J1 = false;
        return dateTimePatternGenerator;
    }
}
