package com.ibm.icu.util;

import com.ibm.icu.impl.CalType;
import com.ibm.icu.impl.q;
import java.util.Date;
import java.util.Locale;

public class JapaneseCalendar extends GregorianCalendar {
    public static final int CURRENT_ERA;
    public static final int HEISEI = 235;
    private static final int M1 = 1970;
    public static final int MEIJI = 232;
    private static final q N1;
    public static final int REIWA = 236;
    public static final int SHOWA = 234;
    public static final int TAISHO = 233;
    private static final long serialVersionUID = -2977189902603704691L;

    static {
        q f = q.f(CalType.JAPANESE, enableTentativeEra());
        N1 = f;
        CURRENT_ERA = f.d();
    }

    public JapaneseCalendar() {
    }

    @Deprecated
    public static boolean enableTentativeEra() {
        String property = System.getProperty("ICU_ENABLE_TENTATIVE_ERA");
        if (property == null) {
            property = System.getenv("ICU_ENABLE_TENTATIVE_ERA");
        }
        if (property != null) {
            return property.equalsIgnoreCase("true");
        }
        return System.getProperty("jdk.calendar.japanese.supplemental.era") != null;
    }

    /* access modifiers changed from: protected */
    @Override // com.ibm.icu.util.Calendar
    public int T(int i, int i2) {
        int[] h = N1.h(C0(0, CURRENT_ERA), null);
        if (i == h[0] && i2 == h[1] - 1) {
            return h[2];
        }
        return super.T(i, i2);
    }

    /* access modifiers changed from: protected */
    @Override // com.ibm.icu.util.Calendar
    public int U(int i) {
        int[] h = N1.h(C0(0, CURRENT_ERA), null);
        if (i == h[0]) {
            return h[1] - 1;
        }
        return super.U(i);
    }

    @Override // com.ibm.icu.util.Calendar, com.ibm.icu.util.GregorianCalendar
    public int getActualMaximum(int i) {
        if (i != 1) {
            return super.getActualMaximum(i);
        }
        int i2 = get(0);
        q qVar = N1;
        if (i2 == qVar.g() - 1) {
            return w0(1, 3);
        }
        int[] h = qVar.h(i2 + 1, null);
        int i3 = h[0];
        int i4 = h[1];
        int i5 = h[2];
        int i6 = (i3 - qVar.i(i2)) + 1;
        return (i4 == 1 && i5 == 1) ? i6 - 1 : i6;
    }

    @Override // com.ibm.icu.util.Calendar, com.ibm.icu.util.GregorianCalendar
    public String getType() {
        return "japanese";
    }

    @Override // com.ibm.icu.util.Calendar
    @Deprecated
    public boolean haveDefaultCentury() {
        return false;
    }

    /* access modifiers changed from: protected */
    @Override // com.ibm.icu.util.Calendar, com.ibm.icu.util.GregorianCalendar
    public void m0(int i) {
        super.m0(i);
        int B0 = B0(19);
        q qVar = N1;
        int e2 = qVar.e(B0, B0(2) + 1, B0(5));
        E0(0, e2);
        E0(1, (B0 - qVar.i(e2)) + 1);
    }

    /* access modifiers changed from: protected */
    @Override // com.ibm.icu.util.Calendar, com.ibm.icu.util.GregorianCalendar
    public int v0() {
        if (K0(19, 1) == 19 && K0(19, 0) == 19) {
            return C0(19, M1);
        }
        return (C0(1, 1) + N1.i(C0(0, CURRENT_ERA))) - 1;
    }

    /* access modifiers changed from: protected */
    @Override // com.ibm.icu.util.Calendar, com.ibm.icu.util.GregorianCalendar
    public int w0(int i, int i2) {
        if (i != 0) {
            if (i == 1) {
                if (i2 == 0 || i2 == 1 || i2 == 2) {
                    return 1;
                }
                if (i2 == 3) {
                    return super.w0(i, 3) - N1.i(CURRENT_ERA);
                }
            }
            return super.w0(i, i2);
        } else if (i2 == 0 || i2 == 1) {
            return 0;
        } else {
            return N1.g() - 1;
        }
    }

    public JapaneseCalendar(TimeZone timeZone) {
        super(timeZone);
    }

    public JapaneseCalendar(Locale locale) {
        super(locale);
    }

    public JapaneseCalendar(ULocale uLocale) {
        super(uLocale);
    }

    public JapaneseCalendar(TimeZone timeZone, Locale locale) {
        super(timeZone, locale);
    }

    public JapaneseCalendar(TimeZone timeZone, ULocale uLocale) {
        super(timeZone, uLocale);
    }

    public JapaneseCalendar(Date date) {
        this();
        setTime(date);
    }

    public JapaneseCalendar(int i, int i2, int i3, int i4) {
        super(i2, i3, i4);
        set(0, i);
    }

    public JapaneseCalendar(int i, int i2, int i3) {
        super(i, i2, i3);
        set(0, CURRENT_ERA);
    }

    public JapaneseCalendar(int i, int i2, int i3, int i4, int i5, int i6) {
        super(i, i2, i3, i4, i5, i6);
        set(0, CURRENT_ERA);
    }
}
