package com.ibm.icu.util;

import androidx.constraintlayout.core.motion.h.w;
import com.blankj.utilcode.util.ToastUtils;
import com.google.firebase.analytics.FirebaseAnalytics;
import com.ibm.icu.impl.ICUResourceBundle;
import com.ibm.icu.impl.a0;
import com.ibm.icu.impl.l2;
import com.ibm.icu.impl.n;
import com.ibm.icu.impl.units.MeasureUnitImpl;
import com.ibm.icu.text.UnicodeSet;
import java.io.Externalizable;
import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.ObjectStreamException;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class MeasureUnit implements Serializable {
    public static final MeasureUnit ACRE = internalGetInstance("area", "acre");
    public static final MeasureUnit ACRE_FOOT = internalGetInstance("volume", "acre-foot");
    public static final MeasureUnit AMPERE = internalGetInstance("electric", "ampere");
    public static final MeasureUnit ARC_MINUTE = internalGetInstance("angle", "arc-minute");
    public static final MeasureUnit ARC_SECOND = internalGetInstance("angle", "arc-second");
    public static final MeasureUnit ASTRONOMICAL_UNIT = internalGetInstance("length", "astronomical-unit");
    public static final MeasureUnit ATMOSPHERE = internalGetInstance("pressure", "atmosphere");
    public static final MeasureUnit BAR = internalGetInstance("pressure", "bar");
    public static final MeasureUnit BARREL = internalGetInstance("volume", "barrel");
    public static final MeasureUnit BIT = internalGetInstance("digital", "bit");
    public static final MeasureUnit BRITISH_THERMAL_UNIT = internalGetInstance("energy", "british-thermal-unit");
    public static final MeasureUnit BUSHEL = internalGetInstance("volume", "bushel");
    public static final MeasureUnit BYTE = internalGetInstance("digital", "byte");
    public static final MeasureUnit CALORIE = internalGetInstance("energy", "calorie");
    public static final MeasureUnit CANDELA = internalGetInstance(ToastUtils.MODE.LIGHT, "candela");
    public static final MeasureUnit CARAT = internalGetInstance("mass", "carat");
    public static final MeasureUnit CELSIUS = internalGetInstance("temperature", "celsius");
    public static final MeasureUnit CENTILITER = internalGetInstance("volume", "centiliter");
    public static final MeasureUnit CENTIMETER = internalGetInstance("length", "centimeter");
    public static final MeasureUnit CENTURY = internalGetInstance(w.h.f1707b, "century");
    public static final MeasureUnit CUBIC_CENTIMETER = internalGetInstance("volume", "cubic-centimeter");
    public static final MeasureUnit CUBIC_FOOT = internalGetInstance("volume", "cubic-foot");
    public static final MeasureUnit CUBIC_INCH = internalGetInstance("volume", "cubic-inch");
    public static final MeasureUnit CUBIC_KILOMETER = internalGetInstance("volume", "cubic-kilometer");
    public static final MeasureUnit CUBIC_METER = internalGetInstance("volume", "cubic-meter");
    public static final MeasureUnit CUBIC_MILE = internalGetInstance("volume", "cubic-mile");
    public static final MeasureUnit CUBIC_YARD = internalGetInstance("volume", "cubic-yard");
    public static final MeasureUnit CUP = internalGetInstance("volume", "cup");
    public static final MeasureUnit CUP_METRIC = internalGetInstance("volume", "cup-metric");
    public static final MeasureUnit DALTON = internalGetInstance("mass", "dalton");
    public static final TimeUnit DAY = ((TimeUnit) internalGetInstance(w.h.f1707b, "day"));
    public static final MeasureUnit DAY_PERSON = internalGetInstance(w.h.f1707b, "day-person");
    public static final MeasureUnit DECADE = internalGetInstance(w.h.f1707b, "decade");
    public static final MeasureUnit DECILITER = internalGetInstance("volume", "deciliter");
    public static final MeasureUnit DECIMETER = internalGetInstance("length", "decimeter");
    public static final MeasureUnit DEGREE = internalGetInstance("angle", "degree");
    public static final MeasureUnit DESSERT_SPOON = internalGetInstance("volume", "dessert-spoon");
    public static final MeasureUnit DESSERT_SPOON_IMPERIAL = internalGetInstance("volume", "dessert-spoon-imperial");
    public static final MeasureUnit DOT = internalGetInstance("graphics", "dot");
    public static final MeasureUnit DOT_PER_CENTIMETER = internalGetInstance("graphics", "dot-per-centimeter");
    public static final MeasureUnit DOT_PER_INCH = internalGetInstance("graphics", "dot-per-inch");
    public static final MeasureUnit DRAM = internalGetInstance("volume", "dram");
    public static final MeasureUnit DROP = internalGetInstance("volume", "drop");
    public static final MeasureUnit DUNAM = internalGetInstance("area", "dunam");
    public static final MeasureUnit EARTH_MASS = internalGetInstance("mass", "earth-mass");
    public static final MeasureUnit EARTH_RADIUS = internalGetInstance("length", "earth-radius");
    public static final MeasureUnit ELECTRONVOLT = internalGetInstance("energy", "electronvolt");
    public static final MeasureUnit EM = internalGetInstance("graphics", "em");
    public static final MeasureUnit FAHRENHEIT = internalGetInstance("temperature", "fahrenheit");
    public static final MeasureUnit FATHOM = internalGetInstance("length", "fathom");
    public static final MeasureUnit FLUID_OUNCE = internalGetInstance("volume", "fluid-ounce");
    public static final MeasureUnit FLUID_OUNCE_IMPERIAL = internalGetInstance("volume", "fluid-ounce-imperial");
    public static final MeasureUnit FOODCALORIE = internalGetInstance("energy", "foodcalorie");
    public static final MeasureUnit FOOT = internalGetInstance("length", "foot");
    public static final MeasureUnit FURLONG = internalGetInstance("length", "furlong");
    public static final MeasureUnit GALLON = internalGetInstance("volume", "gallon");
    public static final MeasureUnit GALLON_IMPERIAL = internalGetInstance("volume", "gallon-imperial");
    public static final MeasureUnit GENERIC_TEMPERATURE = internalGetInstance("temperature", "generic");
    public static final MeasureUnit GIGABIT = internalGetInstance("digital", "gigabit");
    public static final MeasureUnit GIGABYTE = internalGetInstance("digital", "gigabyte");
    public static final MeasureUnit GIGAHERTZ = internalGetInstance("frequency", "gigahertz");
    public static final MeasureUnit GIGAWATT = internalGetInstance("power", "gigawatt");
    public static final MeasureUnit GRAIN = internalGetInstance("mass", "grain");
    public static final MeasureUnit GRAM = internalGetInstance("mass", "gram");
    public static final MeasureUnit G_FORCE = internalGetInstance("acceleration", "g-force");
    public static final MeasureUnit HECTARE = internalGetInstance("area", "hectare");
    public static final MeasureUnit HECTOLITER = internalGetInstance("volume", "hectoliter");
    public static final MeasureUnit HECTOPASCAL = internalGetInstance("pressure", "hectopascal");
    public static final MeasureUnit HERTZ = internalGetInstance("frequency", "hertz");
    public static final MeasureUnit HORSEPOWER = internalGetInstance("power", "horsepower");
    public static final TimeUnit HOUR = ((TimeUnit) internalGetInstance(w.h.f1707b, "hour"));
    static final UnicodeSet I0 = new UnicodeSet(97, 122).freeze();
    public static final MeasureUnit INCH = internalGetInstance("length", "inch");
    public static final MeasureUnit INCH_HG = internalGetInstance("pressure", "inch-ofhg");
    public static final MeasureUnit ITEM = internalGetInstance("concentr", "item");
    static final UnicodeSet J0 = new UnicodeSet(45, 45, 48, 57, 97, 122).freeze();
    public static final MeasureUnit JIGGER = internalGetInstance("volume", "jigger");
    public static final MeasureUnit JOULE = internalGetInstance("energy", "joule");
    private static e K0 = new a();
    public static final MeasureUnit KARAT = internalGetInstance("concentr", "karat");
    public static final MeasureUnit KELVIN = internalGetInstance("temperature", "kelvin");
    public static final MeasureUnit KILOBIT = internalGetInstance("digital", "kilobit");
    public static final MeasureUnit KILOBYTE = internalGetInstance("digital", "kilobyte");
    public static final MeasureUnit KILOCALORIE = internalGetInstance("energy", "kilocalorie");
    public static final MeasureUnit KILOGRAM = internalGetInstance("mass", "kilogram");
    public static final MeasureUnit KILOHERTZ = internalGetInstance("frequency", "kilohertz");
    public static final MeasureUnit KILOJOULE = internalGetInstance("energy", "kilojoule");
    public static final MeasureUnit KILOMETER = internalGetInstance("length", "kilometer");
    public static final MeasureUnit KILOMETER_PER_HOUR = internalGetInstance("speed", "kilometer-per-hour");
    public static final MeasureUnit KILOPASCAL = internalGetInstance("pressure", "kilopascal");
    public static final MeasureUnit KILOWATT = internalGetInstance("power", "kilowatt");
    public static final MeasureUnit KILOWATT_HOUR = internalGetInstance("energy", "kilowatt-hour");
    public static final MeasureUnit KILOWATT_HOUR_PER_100_KILOMETER = internalGetInstance("force", "kilowatt-hour-per-100-kilometer");
    public static final MeasureUnit KNOT = internalGetInstance("speed", "knot");
    static e L0 = new b();
    public static final MeasureUnit LIGHT_YEAR = internalGetInstance("length", "light-year");
    public static final MeasureUnit LITER = internalGetInstance("volume", "liter");
    public static final MeasureUnit LITER_PER_100KILOMETERS = internalGetInstance("consumption", "liter-per-100-kilometer");
    public static final MeasureUnit LITER_PER_KILOMETER = internalGetInstance("consumption", "liter-per-kilometer");
    public static final MeasureUnit LUMEN = internalGetInstance(ToastUtils.MODE.LIGHT, "lumen");
    public static final MeasureUnit LUX = internalGetInstance(ToastUtils.MODE.LIGHT, "lux");
    static e M0 = new c();
    public static final MeasureUnit MEGABIT = internalGetInstance("digital", "megabit");
    public static final MeasureUnit MEGABYTE = internalGetInstance("digital", "megabyte");
    public static final MeasureUnit MEGAHERTZ = internalGetInstance("frequency", "megahertz");
    public static final MeasureUnit MEGALITER = internalGetInstance("volume", "megaliter");
    public static final MeasureUnit MEGAPASCAL = internalGetInstance("pressure", "megapascal");
    public static final MeasureUnit MEGAPIXEL = internalGetInstance("graphics", "megapixel");
    public static final MeasureUnit MEGAWATT = internalGetInstance("power", "megawatt");
    public static final MeasureUnit METER = internalGetInstance("length", "meter");
    public static final MeasureUnit METER_PER_SECOND = internalGetInstance("speed", "meter-per-second");
    public static final MeasureUnit METER_PER_SECOND_SQUARED = internalGetInstance("acceleration", "meter-per-square-second");
    public static final MeasureUnit METRIC_TON = internalGetInstance("mass", "tonne");
    public static final MeasureUnit MICROGRAM = internalGetInstance("mass", "microgram");
    public static final MeasureUnit MICROMETER = internalGetInstance("length", "micrometer");
    public static final MeasureUnit MICROSECOND = internalGetInstance(w.h.f1707b, "microsecond");
    public static final MeasureUnit MILE = internalGetInstance("length", "mile");
    public static final MeasureUnit MILE_PER_GALLON = internalGetInstance("consumption", "mile-per-gallon");
    public static final MeasureUnit MILE_PER_GALLON_IMPERIAL = internalGetInstance("consumption", "mile-per-gallon-imperial");
    public static final MeasureUnit MILE_PER_HOUR = internalGetInstance("speed", "mile-per-hour");
    public static final MeasureUnit MILE_SCANDINAVIAN = internalGetInstance("length", "mile-scandinavian");
    public static final MeasureUnit MILLIAMPERE = internalGetInstance("electric", "milliampere");
    public static final MeasureUnit MILLIBAR = internalGetInstance("pressure", "millibar");
    public static final MeasureUnit MILLIGRAM = internalGetInstance("mass", "milligram");
    public static final MeasureUnit MILLIGRAM_OFGLUCOSE_PER_DECILITER = internalGetInstance("concentr", "milligram-ofglucose-per-deciliter");
    public static final MeasureUnit MILLIGRAM_PER_DECILITER = internalGetInstance("concentr", "milligram-per-deciliter");
    public static final MeasureUnit MILLILITER = internalGetInstance("volume", "milliliter");
    public static final MeasureUnit MILLIMETER = internalGetInstance("length", "millimeter");
    public static final MeasureUnit MILLIMETER_OF_MERCURY = internalGetInstance("pressure", "millimeter-ofhg");
    public static final MeasureUnit MILLIMOLE_PER_LITER = internalGetInstance("concentr", "millimole-per-liter");
    public static final MeasureUnit MILLISECOND = internalGetInstance(w.h.f1707b, "millisecond");
    public static final MeasureUnit MILLIWATT = internalGetInstance("power", "milliwatt");
    public static final TimeUnit MINUTE = ((TimeUnit) internalGetInstance(w.h.f1707b, "minute"));
    public static final MeasureUnit MOLE = internalGetInstance("concentr", "mole");
    public static final TimeUnit MONTH = ((TimeUnit) internalGetInstance(w.h.f1707b, "month"));
    public static final MeasureUnit MONTH_PERSON = internalGetInstance(w.h.f1707b, "month-person");
    public static final MeasureUnit NANOMETER = internalGetInstance("length", "nanometer");
    public static final MeasureUnit NANOSECOND = internalGetInstance(w.h.f1707b, "nanosecond");
    public static final MeasureUnit NAUTICAL_MILE = internalGetInstance("length", "nautical-mile");
    public static final MeasureUnit NEWTON = internalGetInstance("force", "newton");
    public static final MeasureUnit NEWTON_METER = internalGetInstance("torque", "newton-meter");
    public static final MeasureUnit OHM = internalGetInstance("electric", "ohm");
    public static final MeasureUnit OUNCE = internalGetInstance("mass", "ounce");
    public static final MeasureUnit OUNCE_TROY = internalGetInstance("mass", "ounce-troy");
    public static final MeasureUnit PARSEC = internalGetInstance("length", "parsec");
    public static final MeasureUnit PART_PER_MILLION = internalGetInstance("concentr", "permillion");
    public static final MeasureUnit PASCAL = internalGetInstance("pressure", "pascal");
    public static final MeasureUnit PERCENT = internalGetInstance("concentr", "percent");
    public static final MeasureUnit PERMILLE = internalGetInstance("concentr", "permille");
    public static final MeasureUnit PERMYRIAD = internalGetInstance("concentr", "permyriad");
    public static final MeasureUnit PETABYTE = internalGetInstance("digital", "petabyte");
    public static final MeasureUnit PICOMETER = internalGetInstance("length", "picometer");
    public static final MeasureUnit PINCH = internalGetInstance("volume", "pinch");
    public static final MeasureUnit PINT = internalGetInstance("volume", "pint");
    public static final MeasureUnit PINT_METRIC = internalGetInstance("volume", "pint-metric");
    public static final MeasureUnit PIXEL = internalGetInstance("graphics", "pixel");
    public static final MeasureUnit PIXEL_PER_CENTIMETER = internalGetInstance("graphics", "pixel-per-centimeter");
    public static final MeasureUnit PIXEL_PER_INCH = internalGetInstance("graphics", "pixel-per-inch");
    public static final MeasureUnit POINT = internalGetInstance("length", "point");
    public static final MeasureUnit POUND = internalGetInstance("mass", "pound");
    public static final MeasureUnit POUND_FOOT = internalGetInstance("torque", "pound-force-foot");
    public static final MeasureUnit POUND_FORCE = internalGetInstance("force", "pound-force");
    public static final MeasureUnit POUND_PER_SQUARE_INCH = internalGetInstance("pressure", "pound-force-per-square-inch");
    public static final MeasureUnit QUART = internalGetInstance("volume", "quart");
    public static final MeasureUnit QUARTER = internalGetInstance(w.h.f1707b, "quarter");
    public static final MeasureUnit QUART_IMPERIAL = internalGetInstance("volume", "quart-imperial");
    public static final MeasureUnit RADIAN = internalGetInstance("angle", "radian");
    public static final MeasureUnit REVOLUTION_ANGLE = internalGetInstance("angle", "revolution");
    public static final TimeUnit SECOND = ((TimeUnit) internalGetInstance(w.h.f1707b, "second"));
    public static final MeasureUnit SOLAR_LUMINOSITY = internalGetInstance(ToastUtils.MODE.LIGHT, "solar-luminosity");
    public static final MeasureUnit SOLAR_MASS = internalGetInstance("mass", "solar-mass");
    public static final MeasureUnit SOLAR_RADIUS = internalGetInstance("length", "solar-radius");
    public static final MeasureUnit SQUARE_CENTIMETER = internalGetInstance("area", "square-centimeter");
    public static final MeasureUnit SQUARE_FOOT = internalGetInstance("area", "square-foot");
    public static final MeasureUnit SQUARE_INCH = internalGetInstance("area", "square-inch");
    public static final MeasureUnit SQUARE_KILOMETER = internalGetInstance("area", "square-kilometer");
    public static final MeasureUnit SQUARE_METER = internalGetInstance("area", "square-meter");
    public static final MeasureUnit SQUARE_MILE = internalGetInstance("area", "square-mile");
    public static final MeasureUnit SQUARE_YARD = internalGetInstance("area", "square-yard");
    public static final MeasureUnit STONE = internalGetInstance("mass", "stone");
    public static final MeasureUnit TABLESPOON = internalGetInstance("volume", "tablespoon");
    public static final MeasureUnit TEASPOON = internalGetInstance("volume", "teaspoon");
    public static final MeasureUnit TERABIT = internalGetInstance("digital", "terabit");
    public static final MeasureUnit TERABYTE = internalGetInstance("digital", "terabyte");
    public static final MeasureUnit THERM_US = internalGetInstance("energy", "therm-us");
    public static final MeasureUnit TON = internalGetInstance("mass", "ton");
    public static final MeasureUnit TONNE = internalGetInstance("mass", "tonne");
    public static final MeasureUnit VOLT = internalGetInstance("electric", "volt");
    public static final MeasureUnit WATT = internalGetInstance("power", "watt");
    public static final TimeUnit WEEK = ((TimeUnit) internalGetInstance(w.h.f1707b, "week"));
    public static final MeasureUnit WEEK_PERSON = internalGetInstance(w.h.f1707b, "week-person");
    public static final MeasureUnit YARD = internalGetInstance("length", "yard");
    public static final TimeUnit YEAR = ((TimeUnit) internalGetInstance(w.h.f1707b, "year"));
    public static final MeasureUnit YEAR_PERSON = internalGetInstance(w.h.f1707b, "year-person");

    /* renamed from: a  reason: collision with root package name */
    private static final Map<String, Map<String, MeasureUnit>> f16037a = new HashMap();

    /* renamed from: b  reason: collision with root package name */
    private static boolean f16038b = false;
    private static final long serialVersionUID = -1839973855554750484L;
    private MeasureUnitImpl measureUnitImpl;
    @Deprecated
    protected final String subType;
    @Deprecated
    protected final String type;

    public enum Complexity {
        SINGLE,
        COMPOUND,
        MIXED
    }

    public enum MeasurePrefix {
        YOTTA(24, "yotta", 10),
        ZETTA(21, "zetta", 10),
        EXA(18, "exa", 10),
        PETA(15, "peta", 10),
        TERA(12, "tera", 10),
        GIGA(9, "giga", 10),
        MEGA(6, "mega", 10),
        KILO(3, "kilo", 10),
        HECTO(2, "hecto", 10),
        DEKA(1, "deka", 10),
        ONE(0, "", 10),
        DECI(-1, "deci", 10),
        CENTI(-2, "centi", 10),
        MILLI(-3, "milli", 10),
        MICRO(-6, "micro", 10),
        NANO(-9, "nano", 10),
        PICO(-12, "pico", 10),
        FEMTO(-15, "femto", 10),
        ATTO(-18, "atto", 10),
        ZEPTO(-21, "zepto", 10),
        YOCTO(-24, "yocto", 10),
        KIBI(1, "kibi", 1024),
        MEBI(2, "mebi", 1024),
        GIBI(3, "gibi", 1024),
        TEBI(4, "tebi", 1024),
        PEBI(5, "pebi", 1024),
        EXBI(6, "exbi", 1024),
        ZEBI(7, "zebi", 1024),
        YOBI(8, "yobi", 1024);
        
        private final int base;
        private final String identifier;
        private final int power;

        private MeasurePrefix(int i, String str, int i2) {
            this.base = i2;
            this.power = i;
            this.identifier = str;
        }

        public int getBase() {
            return this.base;
        }

        @Deprecated
        public String getIdentifier() {
            return this.identifier;
        }

        public int getPower() {
            return this.power;
        }
    }

    /* access modifiers changed from: package-private */
    public static class a implements e {
        a() {
        }

        @Override // com.ibm.icu.util.MeasureUnit.e
        public MeasureUnit a(String str, String str2) {
            return new MeasureUnit(str, str2);
        }
    }

    static class b implements e {
        b() {
        }

        @Override // com.ibm.icu.util.MeasureUnit.e
        public MeasureUnit a(String str, String str2) {
            return new Currency(str2);
        }
    }

    static class c implements e {
        c() {
        }

        @Override // com.ibm.icu.util.MeasureUnit.e
        public MeasureUnit a(String str, String str2) {
            return new TimeUnit(str, str2);
        }
    }

    /* access modifiers changed from: private */
    public static final class d extends l2.c {
        private d() {
        }

        @Override // com.ibm.icu.impl.l2.c
        public void a(l2.b bVar, l2.e eVar, boolean z) {
            l2.d j = eVar.j();
            for (int i = 0; j.d(i, bVar, eVar); i++) {
                MeasureUnit.internalGetInstance(FirebaseAnalytics.b.f12316e, bVar.toString());
            }
        }

        /* synthetic */ d(a aVar) {
            this();
        }
    }

    /* access modifiers changed from: protected */
    @Deprecated
    public interface e {
        @Deprecated
        MeasureUnit a(String str, String str2);
    }

    /* access modifiers changed from: private */
    public static final class g extends l2.c {
        private g() {
        }

        @Override // com.ibm.icu.impl.l2.c
        public void a(l2.b bVar, l2.e eVar, boolean z) {
            l2.d j = eVar.j();
            for (int i = 0; j.d(i, bVar, eVar); i++) {
                if (!bVar.r("compound") && !bVar.r("coordinate")) {
                    String bVar2 = bVar.toString();
                    l2.d j2 = eVar.j();
                    for (int i2 = 0; j2.d(i2, bVar, eVar); i2++) {
                        MeasureUnit.internalGetInstance(bVar2, bVar.toString());
                    }
                }
            }
        }

        /* synthetic */ g(a aVar) {
            this();
        }
    }

    @Deprecated
    protected MeasureUnit(String str, String str2) {
        this.type = str;
        this.subType = str2;
    }

    @Deprecated
    protected static synchronized MeasureUnit a(String str, String str2, e eVar) {
        MeasureUnit measureUnit;
        synchronized (MeasureUnit.class) {
            Map<String, Map<String, MeasureUnit>> map = f16037a;
            Map<String, MeasureUnit> map2 = map.get(str);
            if (map2 == null) {
                map2 = new HashMap<>();
                map.put(str, map2);
            } else {
                str = map2.entrySet().iterator().next().getValue().type;
            }
            measureUnit = map2.get(str2);
            if (measureUnit == null) {
                measureUnit = eVar.a(str, str2);
                map2.put(str2, measureUnit);
            }
        }
        return measureUnit;
    }

    private MeasureUnitImpl b() {
        MeasureUnitImpl measureUnitImpl2 = this.measureUnitImpl;
        return measureUnitImpl2 == null ? MeasureUnitImpl.i(getIdentifier()) : measureUnitImpl2;
    }

    private com.ibm.icu.impl.units.c c() {
        MeasureUnitImpl measureUnitImpl2 = this.measureUnitImpl;
        if (measureUnitImpl2 == null) {
            return MeasureUnitImpl.i(getIdentifier()).l();
        }
        return measureUnitImpl2.l();
    }

    private static synchronized void d() {
        synchronized (MeasureUnit.class) {
            if (!f16038b) {
                f16038b = true;
                ((ICUResourceBundle) h0.l(a0.n, "en")).s0("units", new g(null));
                ((ICUResourceBundle) h0.m(a0.f13490d, "currencyNumericCodes", ICUResourceBundle.j)).s0("codeMap", new d(null));
            }
        }
    }

    @Deprecated
    public static MeasureUnit findBySubType(String str) {
        d();
        for (Map<String, MeasureUnit> map : f16037a.values()) {
            if (map.containsKey(str)) {
                return map.get(str);
            }
        }
        return null;
    }

    public static MeasureUnit forIdentifier(String str) {
        if (str == null || str.isEmpty()) {
            return v.f16192a;
        }
        return MeasureUnitImpl.i(str).d();
    }

    @Deprecated
    public static MeasureUnit fromMeasureUnitImpl(MeasureUnitImpl measureUnitImpl2) {
        measureUnitImpl2.n();
        MeasureUnit findBySubType = findBySubType(measureUnitImpl2.k());
        if (findBySubType != null) {
            return findBySubType;
        }
        return new MeasureUnit(measureUnitImpl2);
    }

    public static Set<MeasureUnit> getAvailable(String str) {
        d();
        Map<String, MeasureUnit> map = f16037a.get(str);
        if (map == null) {
            return Collections.emptySet();
        }
        return Collections.unmodifiableSet(new n(map.values()));
    }

    public static Set<String> getAvailableTypes() {
        d();
        return Collections.unmodifiableSet(f16037a.keySet());
    }

    @Deprecated
    public static MeasureUnit internalGetInstance(String str, String str2) {
        e eVar;
        if (str == null || str2 == null) {
            throw new NullPointerException("Type and subType must be non-null");
        } else if (FirebaseAnalytics.b.f12316e.equals(str) || (I0.T0(str) && J0.T0(str2))) {
            if (FirebaseAnalytics.b.f12316e.equals(str)) {
                eVar = L0;
            } else if (w.h.f1707b.equals(str)) {
                eVar = M0;
            } else {
                eVar = K0;
            }
            return a(str, str2, eVar);
        } else {
            throw new IllegalArgumentException("The type or subType are invalid.");
        }
    }

    private Object writeReplace() throws ObjectStreamException {
        return new f(this.type, this.subType);
    }

    public boolean equals(Object obj) {
        if (obj == this) {
            return true;
        }
        if (!(obj instanceof MeasureUnit)) {
            return false;
        }
        return getIdentifier().equals(((MeasureUnit) obj).getIdentifier());
    }

    public Complexity getComplexity() {
        MeasureUnitImpl measureUnitImpl2 = this.measureUnitImpl;
        if (measureUnitImpl2 == null) {
            return MeasureUnitImpl.i(getIdentifier()).j();
        }
        return measureUnitImpl2.j();
    }

    @Deprecated
    public MeasureUnitImpl getCopyOfMeasureUnitImpl() {
        MeasureUnitImpl measureUnitImpl2 = this.measureUnitImpl;
        if (measureUnitImpl2 == null) {
            return MeasureUnitImpl.i(getIdentifier());
        }
        return measureUnitImpl2.e();
    }

    public int getDimensionality() {
        return c().d();
    }

    public String getIdentifier() {
        MeasureUnitImpl measureUnitImpl2 = this.measureUnitImpl;
        String subtype = measureUnitImpl2 == null ? getSubtype() : measureUnitImpl2.k();
        return subtype == null ? "" : subtype;
    }

    public MeasurePrefix getPrefix() {
        return c().g();
    }

    public String getSubtype() {
        return this.subType;
    }

    public String getType() {
        return this.type;
    }

    public int hashCode() {
        return (this.type.hashCode() * 31) + this.subType.hashCode();
    }

    public MeasureUnit product(MeasureUnit measureUnit) {
        MeasureUnitImpl copyOfMeasureUnitImpl = getCopyOfMeasureUnitImpl();
        if (measureUnit == null) {
            return copyOfMeasureUnitImpl.d();
        }
        MeasureUnitImpl b2 = measureUnit.b();
        Complexity j = copyOfMeasureUnitImpl.j();
        Complexity complexity = Complexity.MIXED;
        if (j == complexity || b2.j() == complexity) {
            throw new UnsupportedOperationException();
        }
        Iterator<com.ibm.icu.impl.units.c> it = b2.m().iterator();
        while (it.hasNext()) {
            copyOfMeasureUnitImpl.b(it.next());
        }
        return copyOfMeasureUnitImpl.d();
    }

    public MeasureUnit reciprocal() {
        MeasureUnitImpl copyOfMeasureUnitImpl = getCopyOfMeasureUnitImpl();
        copyOfMeasureUnitImpl.p();
        return copyOfMeasureUnitImpl.d();
    }

    public List<MeasureUnit> splitToSingleUnits() {
        ArrayList<com.ibm.icu.impl.units.c> m = b().m();
        ArrayList arrayList = new ArrayList(m.size());
        Iterator<com.ibm.icu.impl.units.c> it = m.iterator();
        while (it.hasNext()) {
            arrayList.add(it.next().a());
        }
        return arrayList;
    }

    public String toString() {
        String str;
        MeasureUnitImpl measureUnitImpl2 = this.measureUnitImpl;
        if (measureUnitImpl2 == null) {
            str = this.type + com.ibm.icu.impl.locale.f.f14027b + this.subType;
        } else {
            str = measureUnitImpl2.k();
        }
        return str == null ? "" : str;
    }

    public MeasureUnit withDimensionality(int i) {
        com.ibm.icu.impl.units.c c2 = c();
        c2.j(i);
        return c2.a();
    }

    public MeasureUnit withPrefix(MeasurePrefix measurePrefix) {
        com.ibm.icu.impl.units.c c2 = c();
        c2.k(measurePrefix);
        return c2.a();
    }

    static final class f implements Externalizable {
        private static final long serialVersionUID = -3910681415330989598L;
        private String subType;
        private String type;

        public f(String str, String str2) {
            this.type = str;
            this.subType = str2;
        }

        private Object readResolve() throws ObjectStreamException {
            return MeasureUnit.internalGetInstance(this.type, this.subType);
        }

        @Override // java.io.Externalizable
        public void readExternal(ObjectInput objectInput) throws IOException, ClassNotFoundException {
            objectInput.readByte();
            this.type = objectInput.readUTF();
            this.subType = objectInput.readUTF();
            int readShort = objectInput.readShort();
            if (readShort > 0) {
                objectInput.read(new byte[readShort], 0, readShort);
            }
        }

        @Override // java.io.Externalizable
        public void writeExternal(ObjectOutput objectOutput) throws IOException {
            objectOutput.writeByte(0);
            objectOutput.writeUTF(this.type);
            objectOutput.writeUTF(this.subType);
            objectOutput.writeShort(0);
        }

        public f() {
        }
    }

    private MeasureUnit(MeasureUnitImpl measureUnitImpl2) {
        this.type = null;
        this.subType = null;
        this.measureUnitImpl = measureUnitImpl2.e();
    }

    public static synchronized Set<MeasureUnit> getAvailable() {
        Set<MeasureUnit> unmodifiableSet;
        synchronized (MeasureUnit.class) {
            HashSet hashSet = new HashSet();
            Iterator it = new HashSet(getAvailableTypes()).iterator();
            while (it.hasNext()) {
                for (MeasureUnit measureUnit : getAvailable((String) it.next())) {
                    hashSet.add(measureUnit);
                }
            }
            unmodifiableSet = Collections.unmodifiableSet(hashSet);
        }
        return unmodifiableSet;
    }
}
