package com.niming.weipa.share.utils;

import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageInfo;
import android.net.Uri;
import android.os.Build;
import android.os.Parcelable;
import android.os.StrictMode;
import android.text.TextUtils;
import com.blankj.utilcode.util.ToastUtils;
import com.blankj.utilcode.util.a0;
import java.io.File;
import java.util.ArrayList;
import java.util.List;
import org.nanohttpd.protocols.http.NanoHTTPD;

public class ShareFileUtils {
    private static void checkFileUriExposure() {
        if (Build.VERSION.SDK_INT >= 18) {
            StrictMode.VmPolicy.Builder builder = new StrictMode.VmPolicy.Builder();
            StrictMode.setVmPolicy(builder.build());
            builder.detectFileUriExposure();
        }
    }

    public static boolean isAppInstall(Context context, String str) {
        List<PackageInfo> installedPackages = context.getPackageManager().getInstalledPackages(0);
        if (installedPackages != null) {
            for (int i = 0; i < installedPackages.size(); i++) {
                if (str.equals(installedPackages.get(i).packageName)) {
                    return true;
                }
            }
        }
        return false;
    }

    public static void shareFile(Context context, String str) {
        if (!TextUtils.isEmpty(str)) {
            checkFileUriExposure();
            Intent intent = new Intent("android.intent.action.SEND");
            intent.setFlags(268435456);
            intent.putExtra("android.intent.extra.STREAM", Uri.fromFile(new File(str)));
            intent.setType("*/*");
            context.startActivity(Intent.createChooser(intent, "分享"));
        }
    }

    public static void shareImage(Context context, String str) {
        shareImage(context, str, null, null, null);
    }

    public static void shareImageToQQ(Context context, String str) {
        if (!isAppInstall(context, "com.tencent.mobileqq")) {
            ToastUtils.V("您还没有安装QQ");
        } else {
            shareImage(context, str, null, "com.tencent.mobileqq", "com.tencent.mobileqq.activity.JumpActivity");
        }
    }

    public static void shareImageToQZone(Context context, String str) {
        if (!isAppInstall(context, "com.qzone")) {
            ToastUtils.V("您还没有安装QQ空间");
        } else {
            shareImage(context, str, null, "com.qzone", "com.qzonex.module.operation.ui.QZonePublishMoodActivity");
        }
    }

    public static void shareImageToWeChat(Context context, String str) {
        if (!isAppInstall(context, "com.tencent.mm")) {
            ToastUtils.V("您还没有安装微信");
        } else {
            shareImage(context, str, null, "com.tencent.mm", "com.tencent.mm.ui.tools.ShareImgUI");
        }
    }

    public static void shareImageToWeChatFriend(Context context, String str) {
        if (!isAppInstall(context, "com.tencent.mm")) {
            ToastUtils.V("您还没有安装微信");
        } else {
            shareImage(context, str, null, "com.tencent.mm", "com.tencent.mm.ui.tools.ShareToTimeLineUI");
        }
    }

    public static void shareImageToWeibo(Context context, String str) {
        if (!isAppInstall(context, "com.sina.weibo")) {
            ToastUtils.V("您还没有安装新浪微博");
        } else {
            shareImage(context, str, null, "com.sina.weibo", "com.sina.weibo.EditActivity");
        }
    }

    public static void shareUrl(Context context, String str) {
        if (!TextUtils.isEmpty(str)) {
            checkFileUriExposure();
            Intent intent = new Intent("android.intent.action.SEND");
            intent.putExtra("android.intent.extra.TEXT", str);
            intent.setType(NanoHTTPD.MIME_PLAINTEXT);
            context.startActivity(Intent.createChooser(intent, "分享APP"));
        }
    }

    public static void shareImage(Context context, List<String> list) {
        shareImage(context, null, list, null, null);
    }

    private static void shareImage(Context context, String str, List<String> list, String str2, String str3) {
        if (str == null && list == null) {
            ToastUtils.V("找不到您要分享的图片文件");
            return;
        }
        checkFileUriExposure();
        if (str != null) {
            try {
                if (!a0.f0(str)) {
                    ToastUtils.V("图片不存在，请检查后重试");
                    return;
                }
                Intent intent = new Intent();
                if (!(str2 == null || str3 == null)) {
                    if (str2.equals("com.sina.weibo")) {
                        intent.setPackage(str2);
                    } else {
                        intent.setComponent(new ComponentName(str2, str3));
                    }
                }
                intent.setAction("android.intent.action.SEND");
                intent.setFlags(268435456);
                intent.putExtra("android.intent.extra.STREAM", Uri.fromFile(new File(str)));
                intent.setType("image/*");
                context.startActivity(Intent.createChooser(intent, "分享"));
            } catch (Exception unused) {
                ToastUtils.V("分享失败，未知错误");
            }
        } else {
            ArrayList<? extends Parcelable> arrayList = new ArrayList<>();
            for (int i = 0; i < list.size(); i++) {
                if (!a0.f0(list.get(i))) {
                    ToastUtils.V("第" + (i + 1) + "张图片不存在，请检查后重试");
                    return;
                }
                arrayList.add(Uri.fromFile(new File(list.get(i))));
            }
            Intent intent2 = new Intent();
            if (!(str2 == null || str3 == null)) {
                if (str2.equals("com.sina.weibo")) {
                    intent2.setPackage(str2);
                } else {
                    intent2.setComponent(new ComponentName(str2, str3));
                }
            }
            intent2.setAction("android.intent.action.SEND_MULTIPLE");
            intent2.putParcelableArrayListExtra("android.intent.extra.STREAM", arrayList);
            intent2.setFlags(268435456);
            intent2.setType("image/*");
            context.startActivity(Intent.createChooser(intent2, "分享"));
        }
    }

    public static void shareImageToQQ(Context context, List<String> list) {
        if (!isAppInstall(context, "com.tencent.mobileqq")) {
            ToastUtils.V("您还没有安装QQ");
        } else {
            shareImage(context, null, list, "com.tencent.mobileqq", "com.tencent.mobileqq.activity.JumpActivity");
        }
    }

    public static void shareImageToQZone(Context context, List<String> list) {
        if (!isAppInstall(context, "com.qzone")) {
            ToastUtils.V("您还没有安装QQ空间");
        } else {
            shareImage(context, null, list, "com.qzone", "com.qzonex.module.operation.ui.QZonePublishMoodActivity");
        }
    }

    public static void shareImageToWeChat(Context context, List<String> list) {
        if (!isAppInstall(context, "com.tencent.mm")) {
            ToastUtils.V("您还没有安装微信");
        } else {
            shareImage(context, null, list, "com.tencent.mm", "com.tencent.mm.ui.tools.ShareImgUI");
        }
    }

    public static void shareImageToWeChatFriend(Context context, List<String> list) {
        if (!isAppInstall(context, "com.tencent.mm")) {
            ToastUtils.V("您还没有安装微信");
        } else {
            shareImage(context, null, list, "com.tencent.mm", "com.tencent.mm.ui.tools.ShareToTimeLineUI");
        }
    }

    public static void shareImageToWeibo(Context context, List<String> list) {
        if (!isAppInstall(context, "com.sina.weibo")) {
            ToastUtils.V("您还没有安装新浪微博");
        } else {
            shareImage(context, null, list, "com.sina.weibo", "com.sina.weibo.EditActivity");
        }
    }
}
