package org.nanohttpd.protocols.http;

import c.a.b.h.e;
import c.a.b.i.a;
import com.google.firebase.analytics.FirebaseAnalytics;
import com.liulishuo.filedownloader.model.FileDownloadModel;
import java.io.BufferedInputStream;
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.DataOutput;
import java.io.DataOutputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.RandomAccessFile;
import java.net.InetAddress;
import java.net.SocketException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.logging.Level;
import java.util.regex.Matcher;
import javax.net.ssl.SSLException;
import org.nanohttpd.protocols.http.NanoHTTPD;
import org.nanohttpd.protocols.http.content.ContentType;
import org.nanohttpd.protocols.http.content.CookieHandler;
import org.nanohttpd.protocols.http.request.Method;
import org.nanohttpd.protocols.http.response.Response;
import org.nanohttpd.protocols.http.response.Status;
import org.nanohttpd.protocols.http.tempfiles.ITempFile;
import org.nanohttpd.protocols.http.tempfiles.ITempFileManager;

public class HTTPSession implements IHTTPSession {
    public static final int BUFSIZE = 8192;
    public static final int MAX_HEADER_SIZE = 1024;
    private static final int MEMORY_STORE_LIMIT = 1024;
    public static final String POST_DATA = "postData";
    private static final int REQUEST_BUFFER_LEN = 512;
    private CookieHandler cookies;
    private Map<String, String> headers;
    private final NanoHTTPD httpd;
    private final BufferedInputStream inputStream;
    private Method method;
    private final OutputStream outputStream;
    private Map<String, List<String>> parms;
    private String protocolVersion;
    private String queryParameterString;
    private String remoteIp;
    private int rlen;
    private int splitbyte;
    private final ITempFileManager tempFileManager;
    private String uri;

    public HTTPSession(NanoHTTPD nanoHTTPD, ITempFileManager iTempFileManager, InputStream inputStream2, OutputStream outputStream2) {
        this.httpd = nanoHTTPD;
        this.tempFileManager = iTempFileManager;
        this.inputStream = new BufferedInputStream(inputStream2, 8192);
        this.outputStream = outputStream2;
    }

    private void decodeHeader(BufferedReader bufferedReader, Map<String, String> map, Map<String, List<String>> map2, Map<String, String> map3) throws NanoHTTPD.ResponseException {
        String str;
        try {
            String readLine = bufferedReader.readLine();
            if (readLine != null) {
                StringTokenizer stringTokenizer = new StringTokenizer(readLine);
                if (stringTokenizer.hasMoreTokens()) {
                    map.put("method", stringTokenizer.nextToken());
                    if (stringTokenizer.hasMoreTokens()) {
                        String nextToken = stringTokenizer.nextToken();
                        int indexOf = nextToken.indexOf(63);
                        if (indexOf >= 0) {
                            decodeParms(nextToken.substring(indexOf + 1), map2);
                            str = NanoHTTPD.decodePercent(nextToken.substring(0, indexOf));
                        } else {
                            str = NanoHTTPD.decodePercent(nextToken);
                        }
                        if (stringTokenizer.hasMoreTokens()) {
                            this.protocolVersion = stringTokenizer.nextToken();
                        } else {
                            this.protocolVersion = "HTTP/1.1";
                            NanoHTTPD.LOG.log(Level.FINE, "no protocol version specified, strange. Assuming HTTP/1.1.");
                        }
                        String readLine2 = bufferedReader.readLine();
                        while (readLine2 != null && !readLine2.trim().isEmpty()) {
                            int indexOf2 = readLine2.indexOf(58);
                            if (indexOf2 >= 0) {
                                map3.put(readLine2.substring(0, indexOf2).trim().toLowerCase(Locale.US), readLine2.substring(indexOf2 + 1).trim());
                            }
                            readLine2 = bufferedReader.readLine();
                        }
                        map.put("uri", str);
                        return;
                    }
                    throw new NanoHTTPD.ResponseException(Status.BAD_REQUEST, "BAD REQUEST: Missing URI. Usage: GET /example/file.html");
                }
                throw new NanoHTTPD.ResponseException(Status.BAD_REQUEST, "BAD REQUEST: Syntax error. Usage: GET /example/file.html");
            }
        } catch (IOException e2) {
            Status status = Status.INTERNAL_ERROR;
            throw new NanoHTTPD.ResponseException(status, "SERVER INTERNAL ERROR: IOException: " + e2.getMessage(), e2);
        }
    }

    private void decodeMultipartFormData(ContentType contentType, ByteBuffer byteBuffer, Map<String, List<String>> map, Map<String, String> map2) throws NanoHTTPD.ResponseException {
        String str;
        try {
            int[] boundaryPositions = getBoundaryPositions(byteBuffer, contentType.getBoundary().getBytes());
            int i = 2;
            if (boundaryPositions.length >= 2) {
                int i2 = 1024;
                byte[] bArr = new byte[1024];
                int i3 = 0;
                int i4 = 0;
                int i5 = 0;
                while (true) {
                    int i6 = 1;
                    if (i4 < boundaryPositions.length - 1) {
                        byteBuffer.position(boundaryPositions[i4]);
                        int remaining = byteBuffer.remaining() < i2 ? byteBuffer.remaining() : 1024;
                        byteBuffer.get(bArr, i3, remaining);
                        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(bArr, i3, remaining), Charset.forName(contentType.getEncoding())), remaining);
                        String readLine = bufferedReader.readLine();
                        if (readLine != null && readLine.contains(contentType.getBoundary())) {
                            String readLine2 = bufferedReader.readLine();
                            String str2 = null;
                            String str3 = null;
                            String str4 = null;
                            int i7 = 2;
                            while (readLine2 != null && readLine2.trim().length() > 0) {
                                Matcher matcher = NanoHTTPD.CONTENT_DISPOSITION_PATTERN.matcher(readLine2);
                                if (matcher.matches()) {
                                    Matcher matcher2 = NanoHTTPD.CONTENT_DISPOSITION_ATTRIBUTE_PATTERN.matcher(matcher.group(i));
                                    while (matcher2.find()) {
                                        String group = matcher2.group(i6);
                                        if ("name".equalsIgnoreCase(group)) {
                                            str = matcher2.group(2);
                                        } else {
                                            if (FileDownloadModel.M0.equalsIgnoreCase(group)) {
                                                String group2 = matcher2.group(2);
                                                if (!group2.isEmpty()) {
                                                    if (i5 > 0) {
                                                        str = str2 + String.valueOf(i5);
                                                        str3 = group2;
                                                        i5++;
                                                    } else {
                                                        i5++;
                                                    }
                                                }
                                                str3 = group2;
                                            }
                                            i6 = 1;
                                        }
                                        str2 = str;
                                        i6 = 1;
                                    }
                                }
                                Matcher matcher3 = NanoHTTPD.CONTENT_TYPE_PATTERN.matcher(readLine2);
                                if (matcher3.matches()) {
                                    str4 = matcher3.group(2).trim();
                                }
                                readLine2 = bufferedReader.readLine();
                                i7++;
                                i = 2;
                                i6 = 1;
                            }
                            int i8 = 0;
                            while (true) {
                                int i9 = i7 - 1;
                                if (i7 <= 0) {
                                    break;
                                }
                                i8 = scipOverNewLine(bArr, i8);
                                i7 = i9;
                            }
                            if (i8 < remaining - 4) {
                                int i10 = boundaryPositions[i4] + i8;
                                i4++;
                                int i11 = boundaryPositions[i4] - 4;
                                byteBuffer.position(i10);
                                List<String> list = map.get(str2);
                                if (list == null) {
                                    list = new ArrayList<>();
                                    map.put(str2, list);
                                }
                                if (str4 == null) {
                                    byte[] bArr2 = new byte[(i11 - i10)];
                                    byteBuffer.get(bArr2);
                                    list.add(new String(bArr2, contentType.getEncoding()));
                                } else {
                                    String saveTmpFile = saveTmpFile(byteBuffer, i10, i11 - i10, str3);
                                    if (!map2.containsKey(str2)) {
                                        map2.put(str2, saveTmpFile);
                                    } else {
                                        int i12 = 2;
                                        while (true) {
                                            if (!map2.containsKey(str2 + i12)) {
                                                break;
                                            }
                                            i12++;
                                        }
                                        map2.put(str2 + i12, saveTmpFile);
                                    }
                                    list.add(str3);
                                }
                                i2 = 1024;
                                i = 2;
                                i3 = 0;
                            } else {
                                throw new NanoHTTPD.ResponseException(Status.INTERNAL_ERROR, "Multipart header size exceeds MAX_HEADER_SIZE.");
                            }
                        }
                    } else {
                        return;
                    }
                }
                throw new NanoHTTPD.ResponseException(Status.BAD_REQUEST, "BAD REQUEST: Content type is multipart/form-data but chunk does not start with boundary.");
            }
            throw new NanoHTTPD.ResponseException(Status.BAD_REQUEST, "BAD REQUEST: Content type is multipart/form-data but contains less than two boundary strings.");
        } catch (NanoHTTPD.ResponseException e2) {
            throw e2;
        } catch (Exception e3) {
            throw new NanoHTTPD.ResponseException(Status.INTERNAL_ERROR, e3.toString());
        }
    }

    private void decodeParms(String str, Map<String, List<String>> map) {
        String str2;
        String str3;
        if (str == null) {
            this.queryParameterString = "";
            return;
        }
        this.queryParameterString = str;
        StringTokenizer stringTokenizer = new StringTokenizer(str, a.f5058b);
        while (stringTokenizer.hasMoreTokens()) {
            String nextToken = stringTokenizer.nextToken();
            int indexOf = nextToken.indexOf(61);
            if (indexOf >= 0) {
                str3 = NanoHTTPD.decodePercent(nextToken.substring(0, indexOf)).trim();
                str2 = NanoHTTPD.decodePercent(nextToken.substring(indexOf + 1));
            } else {
                str3 = NanoHTTPD.decodePercent(nextToken).trim();
                str2 = "";
            }
            List<String> list = map.get(str3);
            if (list == null) {
                list = new ArrayList<>();
                map.put(str3, list);
            }
            list.add(str2);
        }
    }

    private int findHeaderEnd(byte[] bArr, int i) {
        int i2;
        int i3 = 0;
        while (true) {
            int i4 = i3 + 1;
            if (i4 >= i) {
                return 0;
            }
            if (bArr[i3] == 13 && bArr[i4] == 10 && (i2 = i3 + 3) < i && bArr[i3 + 2] == 13 && bArr[i2] == 10) {
                return i3 + 4;
            }
            if (bArr[i3] == 10 && bArr[i4] == 10) {
                return i3 + 2;
            }
            i3 = i4;
        }
    }

    private int[] getBoundaryPositions(ByteBuffer byteBuffer, byte[] bArr) {
        int[] iArr = new int[0];
        if (byteBuffer.remaining() < bArr.length) {
            return iArr;
        }
        int length = bArr.length + 4096;
        byte[] bArr2 = new byte[length];
        int remaining = byteBuffer.remaining() < length ? byteBuffer.remaining() : length;
        byteBuffer.get(bArr2, 0, remaining);
        int length2 = remaining - bArr.length;
        int i = 0;
        do {
            int i2 = 0;
            while (i2 < length2) {
                int i3 = 0;
                while (i3 < bArr.length && bArr2[i2 + i3] == bArr[i3]) {
                    if (i3 == bArr.length - 1) {
                        int[] iArr2 = new int[(iArr.length + 1)];
                        System.arraycopy(iArr, 0, iArr2, 0, iArr.length);
                        iArr2[iArr.length] = i + i2;
                        iArr = iArr2;
                    }
                    i3++;
                }
                i2++;
            }
            i += length2;
            System.arraycopy(bArr2, length - bArr.length, bArr2, 0, bArr.length);
            length2 = length - bArr.length;
            if (byteBuffer.remaining() < length2) {
                length2 = byteBuffer.remaining();
            }
            byteBuffer.get(bArr2, bArr.length, length2);
        } while (length2 > 0);
        return iArr;
    }

    private RandomAccessFile getTmpBucket() {
        try {
            return new RandomAccessFile(this.tempFileManager.createTempFile(null).getName(), "rw");
        } catch (Exception e2) {
            throw new Error(e2);
        }
    }

    private String saveTmpFile(ByteBuffer byteBuffer, int i, int i2, String str) {
        Throwable th;
        Exception e2;
        if (i2 <= 0) {
            return "";
        }
        FileOutputStream fileOutputStream = null;
        try {
            ITempFile createTempFile = this.tempFileManager.createTempFile(str);
            ByteBuffer duplicate = byteBuffer.duplicate();
            FileOutputStream fileOutputStream2 = new FileOutputStream(createTempFile.getName());
            try {
                FileChannel channel = fileOutputStream2.getChannel();
                duplicate.position(i).limit(i + i2);
                channel.write(duplicate.slice());
                String name = createTempFile.getName();
                NanoHTTPD.safeClose(fileOutputStream2);
                return name;
            } catch (Exception e3) {
                e2 = e3;
                fileOutputStream = fileOutputStream2;
                try {
                    throw new Error(e2);
                } catch (Throwable th2) {
                    th = th2;
                    NanoHTTPD.safeClose(fileOutputStream);
                    throw th;
                }
            } catch (Throwable th3) {
                th = th3;
                fileOutputStream = fileOutputStream2;
                NanoHTTPD.safeClose(fileOutputStream);
                throw th;
            }
        } catch (Exception e4) {
            e2 = e4;
            throw new Error(e2);
        }
    }

    private int scipOverNewLine(byte[] bArr, int i) {
        while (bArr[i] != 10) {
            i++;
        }
        return i + 1;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:55:0x0167, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:57:?, code lost:
        org.nanohttpd.protocols.http.response.Response.newFixedLengthResponse(r0.getStatus(), org.nanohttpd.protocols.http.NanoHTTPD.MIME_PLAINTEXT, r0.getMessage()).send(r10.outputStream);
        org.nanohttpd.protocols.http.NanoHTTPD.safeClose(r10.outputStream);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:59:0x0187, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x0188, code lost:
        r1 = org.nanohttpd.protocols.http.response.Status.INTERNAL_ERROR;
        org.nanohttpd.protocols.http.response.Response.newFixedLengthResponse(r1, org.nanohttpd.protocols.http.NanoHTTPD.MIME_PLAINTEXT, "SERVER INTERNAL ERROR: IOException: " + r0.getMessage()).send(r10.outputStream);
        org.nanohttpd.protocols.http.NanoHTTPD.safeClose(r10.outputStream);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:61:0x01ae, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:62:0x01af, code lost:
        r1 = org.nanohttpd.protocols.http.response.Status.INTERNAL_ERROR;
        org.nanohttpd.protocols.http.response.Response.newFixedLengthResponse(r1, org.nanohttpd.protocols.http.NanoHTTPD.MIME_PLAINTEXT, "SSL PROTOCOL FAILURE: " + r0.getMessage()).send(r10.outputStream);
        org.nanohttpd.protocols.http.NanoHTTPD.safeClose(r10.outputStream);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:64:0x01d6, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:65:0x01d7, code lost:
        throw r0;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:66:0x01d8, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:67:0x01d9, code lost:
        throw r0;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x0167 A[ExcHandler: ResponseException (r0v14 'e' org.nanohttpd.protocols.http.NanoHTTPD$ResponseException A[CUSTOM_DECLARE]), Splitter:B:1:0x0009] */
    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public void execute() throws IOException {
        Response response = null;
        try {
            byte[] bArr = new byte[8192];
            this.splitbyte = 0;
            this.rlen = 0;
            this.inputStream.mark(8192);
            int read = this.inputStream.read(bArr, 0, 8192);
            if (read != -1) {
                while (read > 0) {
                    int i = this.rlen + read;
                    this.rlen = i;
                    int findHeaderEnd = findHeaderEnd(bArr, i);
                    this.splitbyte = findHeaderEnd;
                    if (findHeaderEnd > 0) {
                        break;
                    }
                    BufferedInputStream bufferedInputStream = this.inputStream;
                    int i2 = this.rlen;
                    read = bufferedInputStream.read(bArr, i2, 8192 - i2);
                }
                if (this.splitbyte < this.rlen) {
                    this.inputStream.reset();
                    this.inputStream.skip((long) this.splitbyte);
                }
                this.parms = new HashMap();
                Map<String, String> map = this.headers;
                if (map == null) {
                    this.headers = new HashMap();
                } else {
                    map.clear();
                }
                BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(bArr, 0, this.rlen)));
                HashMap hashMap = new HashMap();
                decodeHeader(bufferedReader, hashMap, this.parms, this.headers);
                String str = this.remoteIp;
                if (str != null) {
                    this.headers.put("remote-addr", str);
                    this.headers.put("http-client-ip", this.remoteIp);
                }
                Method lookup = Method.lookup(hashMap.get("method"));
                this.method = lookup;
                if (lookup != null) {
                    this.uri = hashMap.get("uri");
                    this.cookies = new CookieHandler(this.headers);
                    String str2 = this.headers.get("connection");
                    boolean z = "HTTP/1.1".equals(this.protocolVersion) && (str2 == null || !str2.matches("(?i).*close.*"));
                    response = this.httpd.handle(this);
                    if (response != null) {
                        String str3 = this.headers.get("accept-encoding");
                        this.cookies.unloadQueue(response);
                        response.setRequestMethod(this.method);
                        if (str3 == null || !str3.contains("gzip")) {
                            response.setUseGzip(false);
                        }
                        response.setKeepAlive(z);
                        response.send(this.outputStream);
                        if (!z || response.isCloseConnection()) {
                            throw new SocketException("NanoHttpd Shutdown");
                        }
                        NanoHTTPD.safeClose(response);
                        this.tempFileManager.clear();
                        return;
                    }
                    throw new NanoHTTPD.ResponseException(Status.INTERNAL_ERROR, "SERVER INTERNAL ERROR: Serve() returned a null response.");
                }
                Status status = Status.BAD_REQUEST;
                throw new NanoHTTPD.ResponseException(status, "BAD REQUEST: Syntax error. HTTP verb " + hashMap.get("method") + " unhandled.");
            }
            NanoHTTPD.safeClose(this.inputStream);
            NanoHTTPD.safeClose(this.outputStream);
            throw new SocketException("NanoHttpd Shutdown");
        } catch (SSLException e2) {
            throw e2;
        } catch (IOException unused) {
            NanoHTTPD.safeClose(this.inputStream);
            NanoHTTPD.safeClose(this.outputStream);
            throw new SocketException("NanoHttpd Shutdown");
        } catch (NanoHTTPD.ResponseException e3) {
        } catch (Throwable th) {
            NanoHTTPD.safeClose(null);
            this.tempFileManager.clear();
            throw th;
        }
    }

    public long getBodySize() {
        if (this.headers.containsKey("content-length")) {
            return Long.parseLong(this.headers.get("content-length"));
        }
        int i = this.splitbyte;
        int i2 = this.rlen;
        if (i < i2) {
            return (long) (i2 - i);
        }
        return 0;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public CookieHandler getCookies() {
        return this.cookies;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public final Map<String, String> getHeaders() {
        return this.headers;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public final InputStream getInputStream() {
        return this.inputStream;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public final Method getMethod() {
        return this.method;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public final Map<String, List<String>> getParameters() {
        return this.parms;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    @Deprecated
    public final Map<String, String> getParms() {
        HashMap hashMap = new HashMap();
        for (String str : this.parms.keySet()) {
            hashMap.put(str, this.parms.get(str).get(0));
        }
        return hashMap;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public String getQueryParameterString() {
        return this.queryParameterString;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public String getRemoteIpAddress() {
        return this.remoteIp;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public final String getUri() {
        return this.uri;
    }

    @Override // org.nanohttpd.protocols.http.IHTTPSession
    public void parseBody(Map<String, String> map) throws IOException, NanoHTTPD.ResponseException {
        Throwable th;
        DataOutput dataOutput;
        RandomAccessFile randomAccessFile;
        ByteArrayOutputStream byteArrayOutputStream;
        ByteBuffer byteBuffer;
        RandomAccessFile randomAccessFile2 = null;
        try {
            long bodySize = getBodySize();
            if (bodySize < 1024) {
                byteArrayOutputStream = new ByteArrayOutputStream();
                dataOutput = new DataOutputStream(byteArrayOutputStream);
                randomAccessFile = null;
            } else {
                randomAccessFile = getTmpBucket();
                byteArrayOutputStream = null;
                dataOutput = randomAccessFile;
            }
            try {
                byte[] bArr = new byte[512];
                while (this.rlen >= 0 && bodySize > 0) {
                    int read = this.inputStream.read(bArr, 0, (int) Math.min(bodySize, 512L));
                    this.rlen = read;
                    bodySize -= (long) read;
                    if (read > 0) {
                        dataOutput.write(bArr, 0, read);
                    }
                }
                if (byteArrayOutputStream != null) {
                    byteBuffer = ByteBuffer.wrap(byteArrayOutputStream.toByteArray(), 0, byteArrayOutputStream.size());
                } else {
                    byteBuffer = randomAccessFile.getChannel().map(FileChannel.MapMode.READ_ONLY, 0, randomAccessFile.length());
                    randomAccessFile.seek(0);
                }
                if (Method.POST.equals(this.method)) {
                    ContentType contentType = new ContentType(this.headers.get(e.f5055d));
                    if (!contentType.isMultipart()) {
                        byte[] bArr2 = new byte[byteBuffer.remaining()];
                        byteBuffer.get(bArr2);
                        String trim = new String(bArr2, contentType.getEncoding()).trim();
                        if ("application/x-www-form-urlencoded".equalsIgnoreCase(contentType.getContentType())) {
                            decodeParms(trim, this.parms);
                        } else if (trim.length() != 0) {
                            map.put(POST_DATA, trim);
                        }
                    } else if (contentType.getBoundary() != null) {
                        decodeMultipartFormData(contentType, byteBuffer, this.parms, map);
                    } else {
                        throw new NanoHTTPD.ResponseException(Status.BAD_REQUEST, "BAD REQUEST: Content type is multipart/form-data but boundary missing. Usage: GET /example/file.html");
                    }
                } else if (Method.PUT.equals(this.method)) {
                    map.put(FirebaseAnalytics.b.N, saveTmpFile(byteBuffer, 0, byteBuffer.limit(), null));
                }
                NanoHTTPD.safeClose(randomAccessFile);
            } catch (Throwable th2) {
                th = th2;
                randomAccessFile2 = randomAccessFile;
                NanoHTTPD.safeClose(randomAccessFile2);
                throw th;
            }
        } catch (Throwable th3) {
            th = th3;
            NanoHTTPD.safeClose(randomAccessFile2);
            throw th;
        }
    }

    public HTTPSession(NanoHTTPD nanoHTTPD, ITempFileManager iTempFileManager, InputStream inputStream2, OutputStream outputStream2, InetAddress inetAddress) {
        this.httpd = nanoHTTPD;
        this.tempFileManager = iTempFileManager;
        this.inputStream = new BufferedInputStream(inputStream2, 8192);
        this.outputStream = outputStream2;
        this.remoteIp = (inetAddress.isLoopbackAddress() || inetAddress.isAnyLocalAddress()) ? "127.0.0.1" : inetAddress.getHostAddress().toString();
        this.headers = new HashMap();
    }
}
