package org.nanohttpd.protocols.http.response;

import androidx.constraintlayout.core.motion.h.w;
import com.ibm.icu.impl.number.Padder;
import com.ibm.icu.lang.c;

public enum Status implements IStatus {
    SWITCH_PROTOCOL(101, "Switching Protocols"),
    OK(200, "OK"),
    CREATED(c.p.V2, "Created"),
    ACCEPTED(c.p.W2, "Accepted"),
    NO_CONTENT(c.p.Y2, "No Content"),
    PARTIAL_CONTENT(c.p.a3, "Partial Content"),
    MULTI_STATUS(c.p.b3, "Multi-Status"),
    REDIRECT(301, "Moved Permanently"),
    FOUND(302, "Found"),
    REDIRECT_SEE_OTHER(303, "See Other"),
    NOT_MODIFIED(304, "Not Modified"),
    TEMPORARY_REDIRECT(307, "Temporary Redirect"),
    BAD_REQUEST(400, "Bad Request"),
    UNAUTHORIZED(w.c.f1682b, "Unauthorized"),
    FORBIDDEN(w.c.f1684d, "Forbidden"),
    NOT_FOUND(404, "Not Found"),
    METHOD_NOT_ALLOWED(405, "Method Not Allowed"),
    NOT_ACCEPTABLE(406, "Not Acceptable"),
    REQUEST_TIMEOUT(408, "Request Timeout"),
    CONFLICT(409, "Conflict"),
    GONE(410, "Gone"),
    LENGTH_REQUIRED(411, "Length Required"),
    PRECONDITION_FAILED(412, "Precondition Failed"),
    PAYLOAD_TOO_LARGE(413, "Payload Too Large"),
    UNSUPPORTED_MEDIA_TYPE(415, "Unsupported Media Type"),
    RANGE_NOT_SATISFIABLE(w.c.q, "Requested Range Not Satisfiable"),
    EXPECTATION_FAILED(417, "Expectation Failed"),
    TOO_MANY_REQUESTS(429, "Too Many Requests"),
    INTERNAL_ERROR(500, "Internal Server Error"),
    NOT_IMPLEMENTED(w.g.i, "Not Implemented"),
    SERVICE_UNAVAILABLE(w.g.k, "Service Unavailable"),
    UNSUPPORTED_HTTP_VERSION(w.g.m, "HTTP Version Not Supported");
    
    private final String description;
    private final int requestStatus;

    private Status(int i, String str) {
        this.requestStatus = i;
        this.description = str;
    }

    public static Status lookup(int i) {
        Status[] values = values();
        for (Status status : values) {
            if (status.getRequestStatus() == i) {
                return status;
            }
        }
        return null;
    }

    @Override // org.nanohttpd.protocols.http.response.IStatus
    public String getDescription() {
        return "" + this.requestStatus + Padder.f14124a + this.description;
    }

    @Override // org.nanohttpd.protocols.http.response.IStatus
    public int getRequestStatus() {
        return this.requestStatus;
    }
}
