package androidx.core.content.res;

import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Color;
import android.util.AttributeSet;
import android.util.Log;
import android.util.StateSet;
import android.util.TypedValue;
import android.util.Xml;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.FloatRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RestrictTo;
import androidx.annotation.XmlRes;
import androidx.core.R;
import androidx.core.view.ViewCompat;
import java.io.IOException;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
/* compiled from: ColorStateListInflaterCompat */
public final class a {

    /* renamed from: a  reason: collision with root package name */
    private static final ThreadLocal<TypedValue> f2471a = new ThreadLocal<>();

    private a() {
    }

    @NonNull
    public static ColorStateList a(@NonNull Resources resources, @NonNull XmlPullParser xmlPullParser, @Nullable Resources.Theme theme) throws XmlPullParserException, IOException {
        int next;
        AttributeSet asAttributeSet = Xml.asAttributeSet(xmlPullParser);
        do {
            next = xmlPullParser.next();
            if (next == 2) {
                break;
            }
        } while (next != 1);
        if (next == 2) {
            return b(resources, xmlPullParser, asAttributeSet, theme);
        }
        throw new XmlPullParserException("No start tag found");
    }

    @NonNull
    public static ColorStateList b(@NonNull Resources resources, @NonNull XmlPullParser xmlPullParser, @NonNull AttributeSet attributeSet, @Nullable Resources.Theme theme) throws XmlPullParserException, IOException {
        String name = xmlPullParser.getName();
        if (name.equals("selector")) {
            return e(resources, xmlPullParser, attributeSet, theme);
        }
        throw new XmlPullParserException(xmlPullParser.getPositionDescription() + ": invalid color state list tag " + name);
    }

    @NonNull
    private static TypedValue c() {
        ThreadLocal<TypedValue> threadLocal = f2471a;
        TypedValue typedValue = threadLocal.get();
        if (typedValue != null) {
            return typedValue;
        }
        TypedValue typedValue2 = new TypedValue();
        threadLocal.set(typedValue2);
        return typedValue2;
    }

    @Nullable
    public static ColorStateList d(@NonNull Resources resources, @XmlRes int i, @Nullable Resources.Theme theme) {
        try {
            return a(resources, resources.getXml(i), theme);
        } catch (Exception e2) {
            Log.e("CSLCompat", "Failed to inflate ColorStateList.", e2);
            return null;
        }
    }

    private static ColorStateList e(@NonNull Resources resources, @NonNull XmlPullParser xmlPullParser, @NonNull AttributeSet attributeSet, @Nullable Resources.Theme theme) throws XmlPullParserException, IOException {
        int depth;
        int i;
        int i2 = 1;
        int depth2 = xmlPullParser.getDepth() + 1;
        int[][] iArr = new int[20][];
        int[] iArr2 = new int[20];
        int i3 = 0;
        while (true) {
            int next = xmlPullParser.next();
            if (next == i2 || ((depth = xmlPullParser.getDepth()) < depth2 && next == 3)) {
                int[] iArr3 = new int[i3];
                int[][] iArr4 = new int[i3][];
                System.arraycopy(iArr2, 0, iArr3, 0, i3);
                System.arraycopy(iArr, 0, iArr4, 0, i3);
            } else {
                if (next == 2 && depth <= depth2 && xmlPullParser.getName().equals("item")) {
                    TypedArray h = h(resources, theme, attributeSet, R.styleable.ColorStateListItem);
                    int i4 = R.styleable.ColorStateListItem_android_color;
                    int resourceId = h.getResourceId(i4, -1);
                    if (resourceId == -1 || f(resources, resourceId)) {
                        i = h.getColor(i4, -65281);
                    } else {
                        try {
                            i = a(resources, resources.getXml(resourceId), theme).getDefaultColor();
                        } catch (Exception unused) {
                            i = h.getColor(R.styleable.ColorStateListItem_android_color, -65281);
                        }
                    }
                    float f = 1.0f;
                    int i5 = R.styleable.ColorStateListItem_android_alpha;
                    if (h.hasValue(i5)) {
                        f = h.getFloat(i5, 1.0f);
                    } else {
                        int i6 = R.styleable.ColorStateListItem_alpha;
                        if (h.hasValue(i6)) {
                            f = h.getFloat(i6, 1.0f);
                        }
                    }
                    h.recycle();
                    int attributeCount = attributeSet.getAttributeCount();
                    int[] iArr5 = new int[attributeCount];
                    int i7 = 0;
                    for (int i8 = 0; i8 < attributeCount; i8++) {
                        int attributeNameResource = attributeSet.getAttributeNameResource(i8);
                        if (!(attributeNameResource == 16843173 || attributeNameResource == 16843551 || attributeNameResource == R.attr.alpha)) {
                            int i9 = i7 + 1;
                            if (!attributeSet.getAttributeBooleanValue(i8, false)) {
                                attributeNameResource = -attributeNameResource;
                            }
                            iArr5[i7] = attributeNameResource;
                            i7 = i9;
                        }
                    }
                    int[] trimStateSet = StateSet.trimStateSet(iArr5, i7);
                    iArr2 = e.a(iArr2, i3, g(i, f));
                    iArr = (int[][]) e.c(iArr, i3, trimStateSet);
                    i3++;
                }
                i2 = 1;
            }
        }
        int[] iArr32 = new int[i3];
        int[][] iArr42 = new int[i3][];
        System.arraycopy(iArr2, 0, iArr32, 0, i3);
        System.arraycopy(iArr, 0, iArr42, 0, i3);
        return new ColorStateList(iArr42, iArr32);
    }

    private static boolean f(@NonNull Resources resources, @ColorRes int i) {
        TypedValue c2 = c();
        resources.getValue(i, c2, true);
        int i2 = c2.type;
        if (i2 < 28 || i2 > 31) {
            return false;
        }
        return true;
    }

    @ColorInt
    private static int g(@ColorInt int i, @FloatRange(from = 0.0d, to = 1.0d) float f) {
        return (i & ViewCompat.MEASURED_SIZE_MASK) | (Math.round(((float) Color.alpha(i)) * f) << 24);
    }

    private static TypedArray h(Resources resources, Resources.Theme theme, AttributeSet attributeSet, int[] iArr) {
        if (theme == null) {
            return resources.obtainAttributes(attributeSet, iArr);
        }
        return theme.obtainStyledAttributes(attributeSet, iArr, 0, 0);
    }
}
