package androidx.core.content.res;

import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Configuration;
import android.content.res.Resources;
import android.graphics.Typeface;
import android.graphics.drawable.Drawable;
import android.os.Build;
import android.os.Handler;
import android.os.Looper;
import android.util.Log;
import android.util.SparseArray;
import android.util.TypedValue;
import androidx.annotation.AnyRes;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.DimenRes;
import androidx.annotation.DrawableRes;
import androidx.annotation.FontRes;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.core.content.res.FontResourcesParserCompat;
import androidx.core.graphics.w;
import androidx.core.util.h;
import androidx.core.util.m;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.WeakHashMap;
import org.xmlpull.v1.XmlPullParserException;

/* compiled from: ResourcesCompat */
public final class f {

    /* renamed from: a  reason: collision with root package name */
    private static final String f2481a = "ResourcesCompat";

    /* renamed from: b  reason: collision with root package name */
    private static final ThreadLocal<TypedValue> f2482b = new ThreadLocal<>();

    /* renamed from: c  reason: collision with root package name */
    private static final WeakHashMap<b, SparseArray<a>> f2483c = new WeakHashMap<>(0);

    /* renamed from: d  reason: collision with root package name */
    private static final Object f2484d = new Object();
    @AnyRes

    /* renamed from: e  reason: collision with root package name */
    public static final int f2485e = 0;

    /* access modifiers changed from: private */
    /* compiled from: ResourcesCompat */
    public static class a {

        /* renamed from: a  reason: collision with root package name */
        final ColorStateList f2486a;

        /* renamed from: b  reason: collision with root package name */
        final Configuration f2487b;

        a(@NonNull ColorStateList colorStateList, @NonNull Configuration configuration) {
            this.f2486a = colorStateList;
            this.f2487b = configuration;
        }
    }

    /* access modifiers changed from: private */
    /* compiled from: ResourcesCompat */
    public static final class b {

        /* renamed from: a  reason: collision with root package name */
        final Resources f2488a;
        @Nullable

        /* renamed from: b  reason: collision with root package name */
        final Resources.Theme f2489b;

        b(@NonNull Resources resources, @Nullable Resources.Theme theme) {
            this.f2488a = resources;
            this.f2489b = theme;
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || b.class != obj.getClass()) {
                return false;
            }
            b bVar = (b) obj;
            if (!this.f2488a.equals(bVar.f2488a) || !h.a(this.f2489b, bVar.f2489b)) {
                return false;
            }
            return true;
        }

        public int hashCode() {
            return h.b(this.f2488a, this.f2489b);
        }
    }

    /* compiled from: ResourcesCompat */
    public static abstract class c {

        /* access modifiers changed from: package-private */
        /* compiled from: ResourcesCompat */
        public class a implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Typeface f2490a;

            a(Typeface typeface) {
                this.f2490a = typeface;
            }

            public void run() {
                c.this.e(this.f2490a);
            }
        }

        /* access modifiers changed from: package-private */
        /* compiled from: ResourcesCompat */
        public class b implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ int f2492a;

            b(int i) {
                this.f2492a = i;
            }

            public void run() {
                c.this.d(this.f2492a);
            }
        }

        @NonNull
        @RestrictTo({RestrictTo.Scope.LIBRARY})
        public static Handler c(@Nullable Handler handler) {
            return handler == null ? new Handler(Looper.getMainLooper()) : handler;
        }

        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
        public final void a(int i, @Nullable Handler handler) {
            c(handler).post(new b(i));
        }

        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
        public final void b(Typeface typeface, @Nullable Handler handler) {
            c(handler).post(new a(typeface));
        }

        public abstract void d(int i);

        public abstract void e(@NonNull Typeface typeface);
    }

    @RequiresApi(29)
    /* compiled from: ResourcesCompat */
    static class d {
        private d() {
        }

        static float a(@NonNull Resources resources, @DimenRes int i) {
            return resources.getFloat(i);
        }
    }

    /* compiled from: ResourcesCompat */
    public static final class e {

        /* access modifiers changed from: package-private */
        @RequiresApi(23)
        /* compiled from: ResourcesCompat */
        public static class a {

            /* renamed from: a  reason: collision with root package name */
            private static final Object f2494a = new Object();

            /* renamed from: b  reason: collision with root package name */
            private static Method f2495b;

            /* renamed from: c  reason: collision with root package name */
            private static boolean f2496c;

            private a() {
            }

            static void a(@NonNull Resources.Theme theme) {
                synchronized (f2494a) {
                    if (!f2496c) {
                        try {
                            Method declaredMethod = Resources.Theme.class.getDeclaredMethod("rebase", new Class[0]);
                            f2495b = declaredMethod;
                            declaredMethod.setAccessible(true);
                        } catch (NoSuchMethodException e2) {
                            Log.i(f.f2481a, "Failed to retrieve rebase() method", e2);
                        }
                        f2496c = true;
                    }
                    Method method = f2495b;
                    if (method != null) {
                        try {
                            method.invoke(theme, new Object[0]);
                        } catch (IllegalAccessException | InvocationTargetException e3) {
                            Log.i(f.f2481a, "Failed to invoke rebase() method via reflection", e3);
                            f2495b = null;
                        }
                    }
                }
            }
        }

        /* access modifiers changed from: package-private */
        @RequiresApi(29)
        /* compiled from: ResourcesCompat */
        public static class b {
            private b() {
            }

            static void a(@NonNull Resources.Theme theme) {
                theme.rebase();
            }
        }

        private e() {
        }

        public static void a(@NonNull Resources.Theme theme) {
            int i = Build.VERSION.SDK_INT;
            if (i >= 29) {
                b.a(theme);
            } else if (i >= 23) {
                a.a(theme);
            }
        }
    }

    private f() {
    }

    private static void a(@NonNull b bVar, @ColorRes int i, @NonNull ColorStateList colorStateList) {
        synchronized (f2484d) {
            WeakHashMap<b, SparseArray<a>> weakHashMap = f2483c;
            SparseArray<a> sparseArray = weakHashMap.get(bVar);
            if (sparseArray == null) {
                sparseArray = new SparseArray<>();
                weakHashMap.put(bVar, sparseArray);
            }
            sparseArray.append(i, new a(colorStateList, bVar.f2488a.getConfiguration()));
        }
    }

    @Nullable
    private static ColorStateList b(@NonNull b bVar, @ColorRes int i) {
        a aVar;
        synchronized (f2484d) {
            SparseArray<a> sparseArray = f2483c.get(bVar);
            if (!(sparseArray == null || sparseArray.size() <= 0 || (aVar = sparseArray.get(i)) == null)) {
                if (aVar.f2487b.equals(bVar.f2488a.getConfiguration())) {
                    return aVar.f2486a;
                }
                sparseArray.remove(i);
            }
            return null;
        }
    }

    @Nullable
    public static Typeface c(@NonNull Context context, @FontRes int i) throws Resources.NotFoundException {
        if (context.isRestricted()) {
            return null;
        }
        return o(context, i, new TypedValue(), 0, null, null, false, true);
    }

    @ColorInt
    public static int d(@NonNull Resources resources, @ColorRes int i, @Nullable Resources.Theme theme) throws Resources.NotFoundException {
        if (Build.VERSION.SDK_INT >= 23) {
            return resources.getColor(i, theme);
        }
        return resources.getColor(i);
    }

    @Nullable
    public static ColorStateList e(@NonNull Resources resources, @ColorRes int i, @Nullable Resources.Theme theme) throws Resources.NotFoundException {
        if (Build.VERSION.SDK_INT >= 23) {
            return resources.getColorStateList(i, theme);
        }
        b bVar = new b(resources, theme);
        ColorStateList b2 = b(bVar, i);
        if (b2 != null) {
            return b2;
        }
        ColorStateList m = m(resources, i, theme);
        if (m == null) {
            return resources.getColorStateList(i);
        }
        a(bVar, i, m);
        return m;
    }

    @Nullable
    public static Drawable f(@NonNull Resources resources, @DrawableRes int i, @Nullable Resources.Theme theme) throws Resources.NotFoundException {
        if (Build.VERSION.SDK_INT >= 21) {
            return resources.getDrawable(i, theme);
        }
        return resources.getDrawable(i);
    }

    @Nullable
    public static Drawable g(@NonNull Resources resources, @DrawableRes int i, int i2, @Nullable Resources.Theme theme) throws Resources.NotFoundException {
        int i3 = Build.VERSION.SDK_INT;
        if (i3 >= 21) {
            return resources.getDrawableForDensity(i, i2, theme);
        }
        if (i3 >= 15) {
            return resources.getDrawableForDensity(i, i2);
        }
        return resources.getDrawable(i);
    }

    public static float h(@NonNull Resources resources, @DimenRes int i) {
        if (Build.VERSION.SDK_INT >= 29) {
            return d.a(resources, i);
        }
        TypedValue l = l();
        resources.getValue(i, l, true);
        if (l.type == 4) {
            return l.getFloat();
        }
        throw new Resources.NotFoundException("Resource ID #0x" + Integer.toHexString(i) + " type #0x" + Integer.toHexString(l.type) + " is not valid");
    }

    @Nullable
    public static Typeface i(@NonNull Context context, @FontRes int i) throws Resources.NotFoundException {
        if (context.isRestricted()) {
            return null;
        }
        return o(context, i, new TypedValue(), 0, null, null, false, false);
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public static Typeface j(@NonNull Context context, @FontRes int i, TypedValue typedValue, int i2, @Nullable c cVar) throws Resources.NotFoundException {
        if (context.isRestricted()) {
            return null;
        }
        return o(context, i, typedValue, i2, cVar, null, true, false);
    }

    public static void k(@NonNull Context context, @FontRes int i, @NonNull c cVar, @Nullable Handler handler) throws Resources.NotFoundException {
        m.g(cVar);
        if (context.isRestricted()) {
            cVar.a(-4, handler);
        } else {
            o(context, i, new TypedValue(), 0, cVar, handler, false, false);
        }
    }

    @NonNull
    private static TypedValue l() {
        ThreadLocal<TypedValue> threadLocal = f2482b;
        TypedValue typedValue = threadLocal.get();
        if (typedValue != null) {
            return typedValue;
        }
        TypedValue typedValue2 = new TypedValue();
        threadLocal.set(typedValue2);
        return typedValue2;
    }

    @Nullable
    private static ColorStateList m(Resources resources, int i, @Nullable Resources.Theme theme) {
        if (n(resources, i)) {
            return null;
        }
        try {
            return a.a(resources, resources.getXml(i), theme);
        } catch (Exception e2) {
            Log.e(f2481a, "Failed to inflate ColorStateList, leaving it to the framework", e2);
            return null;
        }
    }

    private static boolean n(@NonNull Resources resources, @ColorRes int i) {
        TypedValue l = l();
        resources.getValue(i, l, true);
        int i2 = l.type;
        if (i2 < 28 || i2 > 31) {
            return false;
        }
        return true;
    }

    private static Typeface o(@NonNull Context context, int i, TypedValue typedValue, int i2, @Nullable c cVar, @Nullable Handler handler, boolean z, boolean z2) {
        Resources resources = context.getResources();
        resources.getValue(i, typedValue, true);
        Typeface p = p(context, resources, typedValue, i, i2, cVar, handler, z, z2);
        if (p != null || cVar != null || z2) {
            return p;
        }
        throw new Resources.NotFoundException("Font resource ID #0x" + Integer.toHexString(i) + " could not be retrieved.");
    }

    /* JADX WARNING: Removed duplicated region for block: B:36:0x00a6  */
    private static Typeface p(@NonNull Context context, Resources resources, TypedValue typedValue, int i, int i2, @Nullable c cVar, @Nullable Handler handler, boolean z, boolean z2) {
        CharSequence charSequence = typedValue.string;
        if (charSequence != null) {
            String charSequence2 = charSequence.toString();
            if (!charSequence2.startsWith("res/")) {
                if (cVar != null) {
                    cVar.a(-3, handler);
                }
                return null;
            }
            Typeface g = w.g(resources, i, i2);
            if (g != null) {
                if (cVar != null) {
                    cVar.b(g, handler);
                }
                return g;
            } else if (z2) {
                return null;
            } else {
                try {
                    if (charSequence2.toLowerCase().endsWith(".xml")) {
                        FontResourcesParserCompat.a b2 = FontResourcesParserCompat.b(resources.getXml(i), resources);
                        if (b2 != null) {
                            return w.d(context, b2, resources, i, i2, cVar, handler, z);
                        }
                        Log.e(f2481a, "Failed to find font-family tag");
                        if (cVar != null) {
                            cVar.a(-3, handler);
                        }
                        return null;
                    }
                    Typeface e2 = w.e(context, resources, i, charSequence2, i2);
                    if (cVar != null) {
                        if (e2 != null) {
                            cVar.b(e2, handler);
                        } else {
                            cVar.a(-3, handler);
                        }
                    }
                    return e2;
                } catch (XmlPullParserException e3) {
                    Log.e(f2481a, "Failed to parse xml resource " + charSequence2, e3);
                    if (cVar != null) {
                        cVar.a(-3, handler);
                    }
                    return null;
                } catch (IOException e4) {
                    Log.e(f2481a, "Failed to read xml resource " + charSequence2, e4);
                    if (cVar != null) {
                    }
                    return null;
                }
            }
        } else {
            throw new Resources.NotFoundException("Resource \"" + resources.getResourceName(i) + "\" (" + Integer.toHexString(i) + ") is not a Font: " + typedValue);
        }
    }
}
