package androidx.core.graphics.drawable;

import android.app.ActivityManager;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageManager;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.Shader;
import android.graphics.drawable.AdaptiveIconDrawable;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.Icon;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.Log;
import androidx.annotation.ColorInt;
import androidx.annotation.DrawableRes;
import androidx.annotation.IdRes;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.annotation.VisibleForTesting;
import androidx.core.content.d;
import androidx.core.content.res.f;
import androidx.core.util.m;
import androidx.core.view.ViewCompat;
import androidx.versionedparcelable.CustomVersionedParcelable;
import com.google.android.exoplayer2.C;
import com.google.firebase.analytics.FirebaseAnalytics;
import com.ibm.icu.impl.number.Padder;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.InputStream;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.reflect.InvocationTargetException;
import java.nio.charset.Charset;

public class IconCompat extends CustomVersionedParcelable {

    /* renamed from: a  reason: collision with root package name */
    private static final String f2515a = "IconCompat";

    /* renamed from: b  reason: collision with root package name */
    public static final int f2516b = -1;

    /* renamed from: c  reason: collision with root package name */
    public static final int f2517c = 1;

    /* renamed from: d  reason: collision with root package name */
    public static final int f2518d = 2;

    /* renamed from: e  reason: collision with root package name */
    public static final int f2519e = 3;
    public static final int f = 4;
    public static final int g = 5;
    public static final int h = 6;
    private static final float i = 0.25f;
    private static final float j = 0.6666667f;
    private static final float k = 0.9166667f;
    private static final float l = 0.010416667f;
    private static final float m = 0.020833334f;
    private static final int n = 61;
    private static final int o = 30;
    @VisibleForTesting
    static final String p = "type";
    @VisibleForTesting
    static final String q = "obj";
    @VisibleForTesting
    static final String r = "int1";
    @VisibleForTesting
    static final String s = "int2";
    @VisibleForTesting
    static final String t = "tint_list";
    @VisibleForTesting
    static final String u = "tint_mode";
    @VisibleForTesting
    static final String v = "string1";
    static final PorterDuff.Mode w = PorterDuff.Mode.SRC_IN;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public Parcelable A = null;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public int B = 0;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public int C = 0;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public ColorStateList D = null;
    PorterDuff.Mode E = w;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public String F = null;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public String G;
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public int x = -1;
    Object y;
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public byte[] z = null;

    @Retention(RetentionPolicy.SOURCE)
    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public @interface IconType {
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY})
    public IconCompat() {
    }

    @DrawableRes
    @IdRes
    @RequiresApi(23)
    private static int B(@NonNull Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getResId();
        }
        try {
            return ((Integer) icon.getClass().getMethod("getResId", new Class[0]).invoke(icon, new Object[0])).intValue();
        } catch (IllegalAccessException e2) {
            Log.e(f2515a, "Unable to get icon resource", e2);
            return 0;
        } catch (InvocationTargetException e3) {
            Log.e(f2515a, "Unable to get icon resource", e3);
            return 0;
        } catch (NoSuchMethodException e4) {
            Log.e(f2515a, "Unable to get icon resource", e4);
            return 0;
        }
    }

    @Nullable
    @RequiresApi(23)
    private static String D(@NonNull Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getResPackage();
        }
        try {
            return (String) icon.getClass().getMethod("getResPackage", new Class[0]).invoke(icon, new Object[0]);
        } catch (IllegalAccessException e2) {
            Log.e(f2515a, "Unable to get icon package", e2);
            return null;
        } catch (InvocationTargetException e3) {
            Log.e(f2515a, "Unable to get icon package", e3);
            return null;
        } catch (NoSuchMethodException e4) {
            Log.e(f2515a, "Unable to get icon package", e4);
            return null;
        }
    }

    private static Resources E(Context context, String str) {
        if ("android".equals(str)) {
            return Resources.getSystem();
        }
        PackageManager packageManager = context.getPackageManager();
        try {
            ApplicationInfo applicationInfo = packageManager.getApplicationInfo(str, 8192);
            if (applicationInfo != null) {
                return packageManager.getResourcesForApplication(applicationInfo);
            }
            return null;
        } catch (PackageManager.NameNotFoundException e2) {
            Log.e(f2515a, String.format("Unable to find pkg=%s for icon", str), e2);
            return null;
        }
    }

    @RequiresApi(23)
    private static int G(@NonNull Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getType();
        }
        try {
            return ((Integer) icon.getClass().getMethod("getType", new Class[0]).invoke(icon, new Object[0])).intValue();
        } catch (IllegalAccessException e2) {
            Log.e(f2515a, "Unable to get icon type " + icon, e2);
            return -1;
        } catch (InvocationTargetException e3) {
            Log.e(f2515a, "Unable to get icon type " + icon, e3);
            return -1;
        } catch (NoSuchMethodException e4) {
            Log.e(f2515a, "Unable to get icon type " + icon, e4);
            return -1;
        }
    }

    @Nullable
    @RequiresApi(23)
    private static Uri I(@NonNull Icon icon) {
        if (Build.VERSION.SDK_INT >= 28) {
            return icon.getUri();
        }
        try {
            return (Uri) icon.getClass().getMethod("getUri", new Class[0]).invoke(icon, new Object[0]);
        } catch (IllegalAccessException e2) {
            Log.e(f2515a, "Unable to get icon uri", e2);
            return null;
        } catch (InvocationTargetException e3) {
            Log.e(f2515a, "Unable to get icon uri", e3);
            return null;
        } catch (NoSuchMethodException e4) {
            Log.e(f2515a, "Unable to get icon uri", e4);
            return null;
        }
    }

    private Drawable L(Context context) {
        switch (this.x) {
            case 1:
                return new BitmapDrawable(context.getResources(), (Bitmap) this.y);
            case 2:
                String C2 = C();
                if (TextUtils.isEmpty(C2)) {
                    C2 = context.getPackageName();
                }
                try {
                    return f.f(E(context, C2), this.B, context.getTheme());
                } catch (RuntimeException e2) {
                    Log.e(f2515a, String.format("Unable to load resource 0x%08x from pkg=%s", Integer.valueOf(this.B), this.y), e2);
                    break;
                }
            case 3:
                return new BitmapDrawable(context.getResources(), BitmapFactory.decodeByteArray((byte[]) this.y, this.B, this.C));
            case 4:
                InputStream J = J(context);
                if (J != null) {
                    return new BitmapDrawable(context.getResources(), BitmapFactory.decodeStream(J));
                }
                break;
            case 5:
                return new BitmapDrawable(context.getResources(), p((Bitmap) this.y, false));
            case 6:
                InputStream J2 = J(context);
                if (J2 != null) {
                    if (Build.VERSION.SDK_INT >= 26) {
                        return new AdaptiveIconDrawable(null, new BitmapDrawable(context.getResources(), BitmapFactory.decodeStream(J2)));
                    }
                    return new BitmapDrawable(context.getResources(), p(BitmapFactory.decodeStream(J2), false));
                }
                break;
        }
        return null;
    }

    private static String R(int i2) {
        switch (i2) {
            case 1:
                return "BITMAP";
            case 2:
                return "RESOURCE";
            case 3:
                return "DATA";
            case 4:
                return "URI";
            case 5:
                return "BITMAP_MASKABLE";
            case 6:
                return "URI_MASKABLE";
            default:
                return "UNKNOWN";
        }
    }

    @Nullable
    public static IconCompat l(@NonNull Bundle bundle) {
        int i2 = bundle.getInt("type");
        IconCompat iconCompat = new IconCompat(i2);
        iconCompat.B = bundle.getInt(r);
        iconCompat.C = bundle.getInt(s);
        iconCompat.G = bundle.getString(v);
        if (bundle.containsKey(t)) {
            iconCompat.D = (ColorStateList) bundle.getParcelable(t);
        }
        if (bundle.containsKey(u)) {
            iconCompat.E = PorterDuff.Mode.valueOf(bundle.getString(u));
        }
        switch (i2) {
            case -1:
            case 1:
            case 5:
                iconCompat.y = bundle.getParcelable(q);
                break;
            case 0:
            default:
                Log.w(f2515a, "Unknown type " + i2);
                return null;
            case 2:
            case 4:
            case 6:
                iconCompat.y = bundle.getString(q);
                break;
            case 3:
                iconCompat.y = bundle.getByteArray(q);
                break;
        }
        return iconCompat;
    }

    @Nullable
    @RequiresApi(23)
    public static IconCompat m(@NonNull Context context, @NonNull Icon icon) {
        m.g(icon);
        int G2 = G(icon);
        if (G2 == 2) {
            String D2 = D(icon);
            try {
                return y(E(context, D2), D2, B(icon));
            } catch (Resources.NotFoundException unused) {
                throw new IllegalArgumentException("Icon resource cannot be found");
            }
        } else if (G2 == 4) {
            return u(I(icon));
        } else {
            if (G2 == 6) {
                return r(I(icon));
            }
            IconCompat iconCompat = new IconCompat(-1);
            iconCompat.y = icon;
            return iconCompat;
        }
    }

    @Nullable
    @RequiresApi(23)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public static IconCompat n(@NonNull Icon icon) {
        m.g(icon);
        int G2 = G(icon);
        if (G2 == 2) {
            return y(null, D(icon), B(icon));
        }
        if (G2 == 4) {
            return u(I(icon));
        }
        if (G2 == 6) {
            return r(I(icon));
        }
        IconCompat iconCompat = new IconCompat(-1);
        iconCompat.y = icon;
        return iconCompat;
    }

    @Nullable
    @RequiresApi(23)
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public static IconCompat o(@NonNull Icon icon) {
        if (G(icon) == 2 && B(icon) == 0) {
            return null;
        }
        return n(icon);
    }

    @VisibleForTesting
    static Bitmap p(Bitmap bitmap, boolean z2) {
        int min = (int) (((float) Math.min(bitmap.getWidth(), bitmap.getHeight())) * j);
        Bitmap createBitmap = Bitmap.createBitmap(min, min, Bitmap.Config.ARGB_8888);
        Canvas canvas = new Canvas(createBitmap);
        Paint paint = new Paint(3);
        float f2 = (float) min;
        float f3 = 0.5f * f2;
        float f4 = k * f3;
        if (z2) {
            float f5 = l * f2;
            paint.setColor(0);
            paint.setShadowLayer(f5, 0.0f, f2 * m, 1023410176);
            canvas.drawCircle(f3, f3, f4, paint);
            paint.setShadowLayer(f5, 0.0f, 0.0f, 503316480);
            canvas.drawCircle(f3, f3, f4, paint);
            paint.clearShadowLayer();
        }
        paint.setColor(ViewCompat.MEASURED_STATE_MASK);
        Shader.TileMode tileMode = Shader.TileMode.CLAMP;
        BitmapShader bitmapShader = new BitmapShader(bitmap, tileMode, tileMode);
        Matrix matrix = new Matrix();
        matrix.setTranslate((float) ((-(bitmap.getWidth() - min)) / 2), (float) ((-(bitmap.getHeight() - min)) / 2));
        bitmapShader.setLocalMatrix(matrix);
        paint.setShader(bitmapShader);
        canvas.drawCircle(f3, f3, f4, paint);
        canvas.setBitmap(null);
        return createBitmap;
    }

    public static IconCompat q(Bitmap bitmap) {
        if (bitmap != null) {
            IconCompat iconCompat = new IconCompat(5);
            iconCompat.y = bitmap;
            return iconCompat;
        }
        throw new IllegalArgumentException("Bitmap must not be null.");
    }

    @NonNull
    public static IconCompat r(@NonNull Uri uri) {
        if (uri != null) {
            return s(uri.toString());
        }
        throw new IllegalArgumentException("Uri must not be null.");
    }

    @NonNull
    public static IconCompat s(@NonNull String str) {
        if (str != null) {
            IconCompat iconCompat = new IconCompat(6);
            iconCompat.y = str;
            return iconCompat;
        }
        throw new IllegalArgumentException("Uri must not be null.");
    }

    public static IconCompat t(Bitmap bitmap) {
        if (bitmap != null) {
            IconCompat iconCompat = new IconCompat(1);
            iconCompat.y = bitmap;
            return iconCompat;
        }
        throw new IllegalArgumentException("Bitmap must not be null.");
    }

    public static IconCompat u(Uri uri) {
        if (uri != null) {
            return v(uri.toString());
        }
        throw new IllegalArgumentException("Uri must not be null.");
    }

    public static IconCompat v(String str) {
        if (str != null) {
            IconCompat iconCompat = new IconCompat(4);
            iconCompat.y = str;
            return iconCompat;
        }
        throw new IllegalArgumentException("Uri must not be null.");
    }

    public static IconCompat w(byte[] bArr, int i2, int i3) {
        if (bArr != null) {
            IconCompat iconCompat = new IconCompat(3);
            iconCompat.y = bArr;
            iconCompat.B = i2;
            iconCompat.C = i3;
            return iconCompat;
        }
        throw new IllegalArgumentException("Data must not be null.");
    }

    public static IconCompat x(Context context, @DrawableRes int i2) {
        if (context != null) {
            return y(context.getResources(), context.getPackageName(), i2);
        }
        throw new IllegalArgumentException("Context must not be null.");
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public static IconCompat y(Resources resources, String str, @DrawableRes int i2) {
        if (str == null) {
            throw new IllegalArgumentException("Package must not be null.");
        } else if (i2 != 0) {
            IconCompat iconCompat = new IconCompat(2);
            iconCompat.B = i2;
            if (resources != null) {
                try {
                    iconCompat.y = resources.getResourceName(i2);
                } catch (Resources.NotFoundException unused) {
                    throw new IllegalArgumentException("Icon resource cannot be found");
                }
            } else {
                iconCompat.y = str;
            }
            iconCompat.G = str;
            return iconCompat;
        } else {
            throw new IllegalArgumentException("Drawable resource ID must not be 0");
        }
    }

    @IdRes
    public int A() {
        int i2 = this.x;
        if (i2 == -1 && Build.VERSION.SDK_INT >= 23) {
            return B((Icon) this.y);
        }
        if (i2 == 2) {
            return this.B;
        }
        throw new IllegalStateException("called getResId() on " + this);
    }

    @NonNull
    public String C() {
        int i2 = this.x;
        if (i2 == -1 && Build.VERSION.SDK_INT >= 23) {
            return D((Icon) this.y);
        }
        if (i2 != 2) {
            throw new IllegalStateException("called getResPackage() on " + this);
        } else if (TextUtils.isEmpty(this.G)) {
            return ((String) this.y).split(":", -1)[0];
        } else {
            return this.G;
        }
    }

    public int F() {
        int i2 = this.x;
        return (i2 != -1 || Build.VERSION.SDK_INT < 23) ? i2 : G((Icon) this.y);
    }

    @NonNull
    public Uri H() {
        int i2 = this.x;
        if (i2 == -1 && Build.VERSION.SDK_INT >= 23) {
            return I((Icon) this.y);
        }
        if (i2 == 4 || i2 == 6) {
            return Uri.parse((String) this.y);
        }
        throw new IllegalStateException("called getUri() on " + this);
    }

    @Nullable
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
    public InputStream J(@NonNull Context context) {
        Uri H = H();
        String scheme = H.getScheme();
        if (FirebaseAnalytics.b.N.equals(scheme) || "file".equals(scheme)) {
            try {
                return context.getContentResolver().openInputStream(H);
            } catch (Exception e2) {
                Log.w(f2515a, "Unable to load image from URI: " + H, e2);
                return null;
            }
        } else {
            try {
                return new FileInputStream(new File((String) this.y));
            } catch (FileNotFoundException e3) {
                Log.w(f2515a, "Unable to load image from path: " + H, e3);
                return null;
            }
        }
    }

    @Nullable
    public Drawable K(@NonNull Context context) {
        k(context);
        if (Build.VERSION.SDK_INT >= 23) {
            return Q(context).loadDrawable(context);
        }
        Drawable L = L(context);
        if (!(L == null || (this.D == null && this.E == w))) {
            L.mutate();
            c.o(L, this.D);
            c.p(L, this.E);
        }
        return L;
    }

    public IconCompat M(@ColorInt int i2) {
        return N(ColorStateList.valueOf(i2));
    }

    public IconCompat N(ColorStateList colorStateList) {
        this.D = colorStateList;
        return this;
    }

    public IconCompat O(PorterDuff.Mode mode) {
        this.E = mode;
        return this;
    }

    @NonNull
    @RequiresApi(23)
    @Deprecated
    public Icon P() {
        return Q(null);
    }

    @NonNull
    @RequiresApi(23)
    public Icon Q(@Nullable Context context) {
        Icon icon;
        switch (this.x) {
            case -1:
                return (Icon) this.y;
            case 0:
            default:
                throw new IllegalArgumentException("Unknown type");
            case 1:
                icon = Icon.createWithBitmap((Bitmap) this.y);
                break;
            case 2:
                icon = Icon.createWithResource(C(), this.B);
                break;
            case 3:
                icon = Icon.createWithData((byte[]) this.y, this.B, this.C);
                break;
            case 4:
                icon = Icon.createWithContentUri((String) this.y);
                break;
            case 5:
                if (Build.VERSION.SDK_INT < 26) {
                    icon = Icon.createWithBitmap(p((Bitmap) this.y, false));
                    break;
                } else {
                    icon = Icon.createWithAdaptiveBitmap((Bitmap) this.y);
                    break;
                }
            case 6:
                int i2 = Build.VERSION.SDK_INT;
                if (i2 >= 30) {
                    icon = Icon.createWithAdaptiveBitmapContentUri(H());
                    break;
                } else if (context != null) {
                    InputStream J = J(context);
                    if (J != null) {
                        if (i2 < 26) {
                            icon = Icon.createWithBitmap(p(BitmapFactory.decodeStream(J), false));
                            break;
                        } else {
                            icon = Icon.createWithAdaptiveBitmap(BitmapFactory.decodeStream(J));
                            break;
                        }
                    } else {
                        throw new IllegalStateException("Cannot load adaptive icon from uri: " + H());
                    }
                } else {
                    throw new IllegalArgumentException("Context is required to resolve the file uri of the icon: " + H());
                }
        }
        ColorStateList colorStateList = this.D;
        if (colorStateList != null) {
            icon.setTintList(colorStateList);
        }
        PorterDuff.Mode mode = this.E;
        if (mode != w) {
            icon.setTintMode(mode);
        }
        return icon;
    }

    @NonNull
    public Bundle a() {
        Bundle bundle = new Bundle();
        switch (this.x) {
            case -1:
                bundle.putParcelable(q, (Parcelable) this.y);
                break;
            case 0:
            default:
                throw new IllegalArgumentException("Invalid icon");
            case 1:
            case 5:
                bundle.putParcelable(q, (Bitmap) this.y);
                break;
            case 2:
            case 4:
            case 6:
                bundle.putString(q, (String) this.y);
                break;
            case 3:
                bundle.putByteArray(q, (byte[]) this.y);
                break;
        }
        bundle.putInt("type", this.x);
        bundle.putInt(r, this.B);
        bundle.putInt(s, this.C);
        bundle.putString(v, this.G);
        ColorStateList colorStateList = this.D;
        if (colorStateList != null) {
            bundle.putParcelable(t, colorStateList);
        }
        PorterDuff.Mode mode = this.E;
        if (mode != w) {
            bundle.putString(u, mode.name());
        }
        return bundle;
    }

    @Override // androidx.versionedparcelable.CustomVersionedParcelable
    public void h() {
        this.E = PorterDuff.Mode.valueOf(this.F);
        switch (this.x) {
            case -1:
                Parcelable parcelable = this.A;
                if (parcelable != null) {
                    this.y = parcelable;
                    return;
                }
                throw new IllegalArgumentException("Invalid icon");
            case 0:
            default:
                return;
            case 1:
            case 5:
                Parcelable parcelable2 = this.A;
                if (parcelable2 != null) {
                    this.y = parcelable2;
                    return;
                }
                byte[] bArr = this.z;
                this.y = bArr;
                this.x = 3;
                this.B = 0;
                this.C = bArr.length;
                return;
            case 2:
            case 4:
            case 6:
                String str = new String(this.z, Charset.forName(C.k));
                this.y = str;
                if (this.x == 2 && this.G == null) {
                    this.G = str.split(":", -1)[0];
                    return;
                }
                return;
            case 3:
                this.y = this.z;
                return;
        }
    }

    @Override // androidx.versionedparcelable.CustomVersionedParcelable
    public void i(boolean z2) {
        this.F = this.E.name();
        switch (this.x) {
            case -1:
                if (!z2) {
                    this.A = (Parcelable) this.y;
                    return;
                }
                throw new IllegalArgumentException("Can't serialize Icon created with IconCompat#createFromIcon");
            case 0:
            default:
                return;
            case 1:
            case 5:
                if (z2) {
                    ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
                    ((Bitmap) this.y).compress(Bitmap.CompressFormat.PNG, 90, byteArrayOutputStream);
                    this.z = byteArrayOutputStream.toByteArray();
                    return;
                }
                this.A = (Parcelable) this.y;
                return;
            case 2:
                this.z = ((String) this.y).getBytes(Charset.forName(C.k));
                return;
            case 3:
                this.z = (byte[]) this.y;
                return;
            case 4:
            case 6:
                this.z = this.y.toString().getBytes(Charset.forName(C.k));
                return;
        }
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public void j(@NonNull Intent intent, @Nullable Drawable drawable, @NonNull Context context) {
        Bitmap bitmap;
        k(context);
        int i2 = this.x;
        if (i2 == 1) {
            bitmap = (Bitmap) this.y;
            if (drawable != null) {
                bitmap = bitmap.copy(bitmap.getConfig(), true);
            }
        } else if (i2 == 2) {
            try {
                Context createPackageContext = context.createPackageContext(C(), 0);
                if (drawable == null) {
                    intent.putExtra("android.intent.extra.shortcut.ICON_RESOURCE", Intent.ShortcutIconResource.fromContext(createPackageContext, this.B));
                    return;
                }
                Drawable i3 = d.i(createPackageContext, this.B);
                if (i3.getIntrinsicWidth() > 0) {
                    if (i3.getIntrinsicHeight() > 0) {
                        bitmap = Bitmap.createBitmap(i3.getIntrinsicWidth(), i3.getIntrinsicHeight(), Bitmap.Config.ARGB_8888);
                        i3.setBounds(0, 0, bitmap.getWidth(), bitmap.getHeight());
                        i3.draw(new Canvas(bitmap));
                    }
                }
                int launcherLargeIconSize = ((ActivityManager) createPackageContext.getSystemService("activity")).getLauncherLargeIconSize();
                bitmap = Bitmap.createBitmap(launcherLargeIconSize, launcherLargeIconSize, Bitmap.Config.ARGB_8888);
                i3.setBounds(0, 0, bitmap.getWidth(), bitmap.getHeight());
                i3.draw(new Canvas(bitmap));
            } catch (PackageManager.NameNotFoundException e2) {
                throw new IllegalArgumentException("Can't find package " + this.y, e2);
            }
        } else if (i2 == 5) {
            bitmap = p((Bitmap) this.y, true);
        } else {
            throw new IllegalArgumentException("Icon type not supported for intent shortcuts");
        }
        if (drawable != null) {
            int width = bitmap.getWidth();
            int height = bitmap.getHeight();
            drawable.setBounds(width / 2, height / 2, width, height);
            drawable.draw(new Canvas(bitmap));
        }
        intent.putExtra("android.intent.extra.shortcut.ICON", bitmap);
    }

    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public void k(@NonNull Context context) {
        Object obj;
        if (this.x == 2 && (obj = this.y) != null) {
            String str = (String) obj;
            if (str.contains(":")) {
                String str2 = str.split(":", -1)[1];
                String str3 = str2.split("/", -1)[0];
                String str4 = str2.split("/", -1)[1];
                String str5 = str.split(":", -1)[0];
                if ("0_resource_name_obfuscated".equals(str4)) {
                    Log.i(f2515a, "Found obfuscated resource, not trying to update resource id for it");
                    return;
                }
                String C2 = C();
                int identifier = E(context, C2).getIdentifier(str4, str3, str5);
                if (this.B != identifier) {
                    Log.i(f2515a, "Id has changed for " + C2 + Padder.f14124a + str);
                    this.B = identifier;
                }
            }
        }
    }

    @NonNull
    public String toString() {
        if (this.x == -1) {
            return String.valueOf(this.y);
        }
        StringBuilder sb = new StringBuilder("Icon(typ=");
        sb.append(R(this.x));
        switch (this.x) {
            case 1:
            case 5:
                sb.append(" size=");
                sb.append(((Bitmap) this.y).getWidth());
                sb.append(com.ibm.icu.impl.locale.f.f14028c);
                sb.append(((Bitmap) this.y).getHeight());
                break;
            case 2:
                sb.append(" pkg=");
                sb.append(this.G);
                sb.append(" id=");
                sb.append(String.format("0x%08x", Integer.valueOf(A())));
                break;
            case 3:
                sb.append(" len=");
                sb.append(this.B);
                if (this.C != 0) {
                    sb.append(" off=");
                    sb.append(this.C);
                    break;
                }
                break;
            case 4:
            case 6:
                sb.append(" uri=");
                sb.append(this.y);
                break;
        }
        if (this.D != null) {
            sb.append(" tint=");
            sb.append(this.D);
        }
        if (this.E != w) {
            sb.append(" mode=");
            sb.append(this.E);
        }
        sb.append(")");
        return sb.toString();
    }

    @Nullable
    @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP_PREFIX})
    public Bitmap z() {
        int i2 = this.x;
        if (i2 == -1 && Build.VERSION.SDK_INT >= 23) {
            Object obj = this.y;
            if (obj instanceof Bitmap) {
                return (Bitmap) obj;
            }
            return null;
        } else if (i2 == 1) {
            return (Bitmap) this.y;
        } else {
            if (i2 == 5) {
                return p((Bitmap) this.y, true);
            }
            throw new IllegalStateException("called getBitmap() on " + this);
        }
    }

    private IconCompat(int i2) {
        this.x = i2;
    }
}
