package androidx.core.location;

import android.content.Context;
import android.location.GnssStatus;
import android.location.GpsStatus;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Build;
import android.os.Bundle;
import android.os.CancellationSignal;
import android.os.Handler;
import android.os.Looper;
import android.os.SystemClock;
import android.provider.Settings;
import android.text.TextUtils;
import androidx.annotation.DoNotInline;
import androidx.annotation.GuardedBy;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RequiresPermission;
import androidx.core.location.GnssStatusCompat;
import androidx.core.os.b;
import androidx.core.util.m;
import java.lang.reflect.Field;
import java.util.concurrent.Callable;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.Executor;
import java.util.concurrent.FutureTask;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
import java.util.function.Consumer;

/* compiled from: LocationManagerCompat */
public final class e {

    /* renamed from: a  reason: collision with root package name */
    private static final long f2624a = 30000;

    /* renamed from: b  reason: collision with root package name */
    private static final long f2625b = 10000;

    /* renamed from: c  reason: collision with root package name */
    private static final long f2626c = 5;

    /* renamed from: d  reason: collision with root package name */
    private static Field f2627d;
    @GuardedBy("sGnssStatusListeners")

    /* renamed from: e  reason: collision with root package name */
    private static final b.b.i<Object, Object> f2628e = new b.b.i<>();

    /* compiled from: LocationManagerCompat */
    class a implements Runnable {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ androidx.core.util.c f2629a;

        /* renamed from: b  reason: collision with root package name */
        final /* synthetic */ Location f2630b;

        a(androidx.core.util.c cVar, Location location) {
            this.f2629a = cVar;
            this.f2630b = location;
        }

        public void run() {
            this.f2629a.accept(this.f2630b);
        }
    }

    /* compiled from: LocationManagerCompat */
    class b implements b.a {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ f f2631a;

        b(f fVar) {
            this.f2631a = fVar;
        }

        @Override // androidx.core.os.b.a
        @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
        public void onCancel() {
            this.f2631a.a();
        }
    }

    /* access modifiers changed from: package-private */
    /* compiled from: LocationManagerCompat */
    public class c implements Callable<Boolean> {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ LocationManager f2632a;

        /* renamed from: b  reason: collision with root package name */
        final /* synthetic */ h f2633b;

        c(LocationManager locationManager, h hVar) {
            this.f2632a = locationManager;
            this.f2633b = hVar;
        }

        @RequiresPermission("android.permission.ACCESS_FINE_LOCATION")
        /* renamed from: a */
        public Boolean call() {
            return Boolean.valueOf(this.f2632a.addGpsStatusListener(this.f2633b));
        }
    }

    @RequiresApi(28)
    /* compiled from: LocationManagerCompat */
    private static class d {
        private d() {
        }

        @DoNotInline
        static String a(LocationManager locationManager) {
            return locationManager.getGnssHardwareModelName();
        }

        @DoNotInline
        static int b(LocationManager locationManager) {
            return locationManager.getGnssYearOfHardware();
        }

        @DoNotInline
        static boolean c(LocationManager locationManager) {
            return locationManager.isLocationEnabled();
        }
    }

    @RequiresApi(30)
    /* renamed from: androidx.core.location.e$e  reason: collision with other inner class name */
    /* compiled from: LocationManagerCompat */
    private static class C0037e {

        /* access modifiers changed from: package-private */
        /* renamed from: androidx.core.location.e$e$a */
        /* compiled from: LocationManagerCompat */
        public class a implements Consumer<Location> {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ androidx.core.util.c f2634a;

            a(androidx.core.util.c cVar) {
                this.f2634a = cVar;
            }

            /* renamed from: a */
            public void accept(Location location) {
                this.f2634a.accept(location);
            }
        }

        private C0037e() {
        }

        @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
        @DoNotInline
        static void a(LocationManager locationManager, @NonNull String str, @Nullable androidx.core.os.b bVar, @NonNull Executor executor, @NonNull androidx.core.util.c<Location> cVar) {
            locationManager.getCurrentLocation(str, bVar != null ? (CancellationSignal) bVar.b() : null, executor, new a(cVar));
        }
    }

    /* compiled from: LocationManagerCompat */
    private static final class f implements LocationListener {

        /* renamed from: a  reason: collision with root package name */
        private final LocationManager f2635a;

        /* renamed from: b  reason: collision with root package name */
        private final Executor f2636b;

        /* renamed from: c  reason: collision with root package name */
        private final Handler f2637c = new Handler(Looper.getMainLooper());

        /* renamed from: d  reason: collision with root package name */
        private androidx.core.util.c<Location> f2638d;
        @GuardedBy("this")

        /* renamed from: e  reason: collision with root package name */
        private boolean f2639e;
        @Nullable
        Runnable f;

        /* access modifiers changed from: package-private */
        /* compiled from: LocationManagerCompat */
        public class a implements Runnable {
            a() {
            }

            @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
            public void run() {
                f fVar = f.this;
                fVar.f = null;
                fVar.onLocationChanged(null);
            }
        }

        /* access modifiers changed from: package-private */
        /* compiled from: LocationManagerCompat */
        public class b implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ androidx.core.util.c f2641a;

            /* renamed from: b  reason: collision with root package name */
            final /* synthetic */ Location f2642b;

            b(androidx.core.util.c cVar, Location location) {
                this.f2641a = cVar;
                this.f2642b = location;
            }

            public void run() {
                this.f2641a.accept(this.f2642b);
            }
        }

        f(LocationManager locationManager, Executor executor, androidx.core.util.c<Location> cVar) {
            this.f2635a = locationManager;
            this.f2636b = executor;
            this.f2638d = cVar;
        }

        @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
        private void b() {
            this.f2638d = null;
            this.f2635a.removeUpdates(this);
            Runnable runnable = this.f;
            if (runnable != null) {
                this.f2637c.removeCallbacks(runnable);
                this.f = null;
            }
        }

        @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
        public void a() {
            synchronized (this) {
                if (!this.f2639e) {
                    this.f2639e = true;
                    b();
                }
            }
        }

        public void c(long j) {
            synchronized (this) {
                if (!this.f2639e) {
                    a aVar = new a();
                    this.f = aVar;
                    this.f2637c.postDelayed(aVar, j);
                }
            }
        }

        @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
        public void onLocationChanged(@Nullable Location location) {
            synchronized (this) {
                if (!this.f2639e) {
                    this.f2639e = true;
                    this.f2636b.execute(new b(this.f2638d, location));
                    b();
                }
            }
        }

        @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
        public void onProviderDisabled(@NonNull String str) {
            onLocationChanged(null);
        }

        public void onProviderEnabled(@NonNull String str) {
        }

        public void onStatusChanged(String str, int i, Bundle bundle) {
        }
    }

    /* access modifiers changed from: private */
    @RequiresApi(30)
    /* compiled from: LocationManagerCompat */
    public static class g extends GnssStatus.Callback {

        /* renamed from: a  reason: collision with root package name */
        final GnssStatusCompat.a f2643a;

        g(GnssStatusCompat.a aVar) {
            m.b(aVar != null, "invalid null callback");
            this.f2643a = aVar;
        }

        public void onFirstFix(int i) {
            this.f2643a.a(i);
        }

        public void onSatelliteStatusChanged(GnssStatus gnssStatus) {
            this.f2643a.b(GnssStatusCompat.n(gnssStatus));
        }

        public void onStarted() {
            this.f2643a.c();
        }

        public void onStopped() {
            this.f2643a.d();
        }
    }

    /* access modifiers changed from: private */
    /* compiled from: LocationManagerCompat */
    public static class h implements GpsStatus.Listener {

        /* renamed from: a  reason: collision with root package name */
        private final LocationManager f2644a;

        /* renamed from: b  reason: collision with root package name */
        final GnssStatusCompat.a f2645b;
        @Nullable

        /* renamed from: c  reason: collision with root package name */
        volatile Executor f2646c;

        /* compiled from: LocationManagerCompat */
        class a implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2647a;

            a(Executor executor) {
                this.f2647a = executor;
            }

            public void run() {
                if (h.this.f2646c == this.f2647a) {
                    h.this.f2645b.c();
                }
            }
        }

        /* compiled from: LocationManagerCompat */
        class b implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2649a;

            b(Executor executor) {
                this.f2649a = executor;
            }

            public void run() {
                if (h.this.f2646c == this.f2649a) {
                    h.this.f2645b.d();
                }
            }
        }

        /* compiled from: LocationManagerCompat */
        class c implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2651a;

            /* renamed from: b  reason: collision with root package name */
            final /* synthetic */ int f2652b;

            c(Executor executor, int i) {
                this.f2651a = executor;
                this.f2652b = i;
            }

            public void run() {
                if (h.this.f2646c == this.f2651a) {
                    h.this.f2645b.a(this.f2652b);
                }
            }
        }

        /* compiled from: LocationManagerCompat */
        class d implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2653a;

            /* renamed from: b  reason: collision with root package name */
            final /* synthetic */ GnssStatusCompat f2654b;

            d(Executor executor, GnssStatusCompat gnssStatusCompat) {
                this.f2653a = executor;
                this.f2654b = gnssStatusCompat;
            }

            public void run() {
                if (h.this.f2646c == this.f2653a) {
                    h.this.f2645b.b(this.f2654b);
                }
            }
        }

        h(LocationManager locationManager, GnssStatusCompat.a aVar) {
            m.b(aVar != null, "invalid null callback");
            this.f2644a = locationManager;
            this.f2645b = aVar;
        }

        public void a(Executor executor) {
            m.i(this.f2646c == null);
            this.f2646c = executor;
        }

        public void b() {
            this.f2646c = null;
        }

        @RequiresPermission("android.permission.ACCESS_FINE_LOCATION")
        public void onGpsStatusChanged(int i) {
            GpsStatus gpsStatus;
            Executor executor = this.f2646c;
            if (executor != null) {
                if (i == 1) {
                    executor.execute(new a(executor));
                } else if (i == 2) {
                    executor.execute(new b(executor));
                } else if (i == 3) {
                    GpsStatus gpsStatus2 = this.f2644a.getGpsStatus(null);
                    if (gpsStatus2 != null) {
                        executor.execute(new c(executor, gpsStatus2.getTimeToFirstFix()));
                    }
                } else if (i == 4 && (gpsStatus = this.f2644a.getGpsStatus(null)) != null) {
                    executor.execute(new d(executor, GnssStatusCompat.o(gpsStatus)));
                }
            }
        }
    }

    /* compiled from: LocationManagerCompat */
    private static final class i implements Executor {

        /* renamed from: a  reason: collision with root package name */
        private final Handler f2655a;

        i(@NonNull Handler handler) {
            this.f2655a = (Handler) m.g(handler);
        }

        public void execute(@NonNull Runnable runnable) {
            if (Looper.myLooper() == this.f2655a.getLooper()) {
                runnable.run();
            } else if (!this.f2655a.post((Runnable) m.g(runnable))) {
                throw new RejectedExecutionException(this.f2655a + " is shutting down");
            }
        }
    }

    /* access modifiers changed from: private */
    @RequiresApi(24)
    /* compiled from: LocationManagerCompat */
    public static class j extends GnssStatus.Callback {

        /* renamed from: a  reason: collision with root package name */
        final GnssStatusCompat.a f2656a;
        @Nullable

        /* renamed from: b  reason: collision with root package name */
        volatile Executor f2657b;

        /* compiled from: LocationManagerCompat */
        class a implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2658a;

            a(Executor executor) {
                this.f2658a = executor;
            }

            public void run() {
                if (j.this.f2657b == this.f2658a) {
                    j.this.f2656a.c();
                }
            }
        }

        /* compiled from: LocationManagerCompat */
        class b implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2660a;

            b(Executor executor) {
                this.f2660a = executor;
            }

            public void run() {
                if (j.this.f2657b == this.f2660a) {
                    j.this.f2656a.d();
                }
            }
        }

        /* compiled from: LocationManagerCompat */
        class c implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2662a;

            /* renamed from: b  reason: collision with root package name */
            final /* synthetic */ int f2663b;

            c(Executor executor, int i) {
                this.f2662a = executor;
                this.f2663b = i;
            }

            public void run() {
                if (j.this.f2657b == this.f2662a) {
                    j.this.f2656a.a(this.f2663b);
                }
            }
        }

        /* compiled from: LocationManagerCompat */
        class d implements Runnable {

            /* renamed from: a  reason: collision with root package name */
            final /* synthetic */ Executor f2664a;

            /* renamed from: b  reason: collision with root package name */
            final /* synthetic */ GnssStatus f2665b;

            d(Executor executor, GnssStatus gnssStatus) {
                this.f2664a = executor;
                this.f2665b = gnssStatus;
            }

            public void run() {
                if (j.this.f2657b == this.f2664a) {
                    j.this.f2656a.b(GnssStatusCompat.n(this.f2665b));
                }
            }
        }

        j(GnssStatusCompat.a aVar) {
            m.b(aVar != null, "invalid null callback");
            this.f2656a = aVar;
        }

        public void a(Executor executor) {
            boolean z = true;
            m.b(executor != null, "invalid null executor");
            if (this.f2657b != null) {
                z = false;
            }
            m.i(z);
            this.f2657b = executor;
        }

        public void b() {
            this.f2657b = null;
        }

        public void onFirstFix(int i) {
            Executor executor = this.f2657b;
            if (executor != null) {
                executor.execute(new c(executor, i));
            }
        }

        public void onSatelliteStatusChanged(GnssStatus gnssStatus) {
            Executor executor = this.f2657b;
            if (executor != null) {
                executor.execute(new d(executor, gnssStatus));
            }
        }

        public void onStarted() {
            Executor executor = this.f2657b;
            if (executor != null) {
                executor.execute(new a(executor));
            }
        }

        public void onStopped() {
            Executor executor = this.f2657b;
            if (executor != null) {
                executor.execute(new b(executor));
            }
        }
    }

    private e() {
    }

    @RequiresPermission(anyOf = {"android.permission.ACCESS_COARSE_LOCATION", "android.permission.ACCESS_FINE_LOCATION"})
    public static void a(@NonNull LocationManager locationManager, @NonNull String str, @Nullable androidx.core.os.b bVar, @NonNull Executor executor, @NonNull androidx.core.util.c<Location> cVar) {
        if (Build.VERSION.SDK_INT >= 30) {
            C0037e.a(locationManager, str, bVar, executor, cVar);
            return;
        }
        if (bVar != null) {
            bVar.e();
        }
        Location lastKnownLocation = locationManager.getLastKnownLocation(str);
        if (lastKnownLocation == null || SystemClock.elapsedRealtime() - c.a(lastKnownLocation) >= 10000) {
            f fVar = new f(locationManager, executor, cVar);
            locationManager.requestLocationUpdates(str, 0, 0.0f, fVar, Looper.getMainLooper());
            if (bVar != null) {
                bVar.d(new b(fVar));
            }
            fVar.c(30000);
            return;
        }
        executor.execute(new a(cVar, lastKnownLocation));
    }

    @Nullable
    public static String b(@NonNull LocationManager locationManager) {
        if (Build.VERSION.SDK_INT >= 28) {
            return d.a(locationManager);
        }
        return null;
    }

    public static int c(@NonNull LocationManager locationManager) {
        if (Build.VERSION.SDK_INT >= 28) {
            return d.b(locationManager);
        }
        return 0;
    }

    public static boolean d(@NonNull LocationManager locationManager) {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 >= 28) {
            return d.c(locationManager);
        }
        if (i2 <= 19) {
            try {
                if (f2627d == null) {
                    Field declaredField = LocationManager.class.getDeclaredField("mContext");
                    f2627d = declaredField;
                    declaredField.setAccessible(true);
                }
                Context context = (Context) f2627d.get(locationManager);
                if (context != null) {
                    if (i2 != 19) {
                        return !TextUtils.isEmpty(Settings.Secure.getString(context.getContentResolver(), "location_providers_allowed"));
                    }
                    if (Settings.Secure.getInt(context.getContentResolver(), "location_mode", 0) != 0) {
                        return true;
                    }
                    return false;
                }
            } catch (ClassCastException | IllegalAccessException | NoSuchFieldException | SecurityException unused) {
            }
        }
        if (locationManager.isProviderEnabled("network") || locationManager.isProviderEnabled("gps")) {
            return true;
        }
        return false;
    }

    /* JADX WARNING: Missing exception handler attribute for start block: B:76:0x00d8 */
    /* JADX WARNING: Removed duplicated region for block: B:102:0x0129  */
    /* JADX WARNING: Removed duplicated region for block: B:92:0x010a A[Catch:{ ExecutionException -> 0x0100, TimeoutException -> 0x00e7, all -> 0x00e4, all -> 0x0126 }] */
    /* JADX WARNING: Removed duplicated region for block: B:98:0x011f A[Catch:{ ExecutionException -> 0x0100, TimeoutException -> 0x00e7, all -> 0x00e4, all -> 0x0126 }] */
    @RequiresPermission("android.permission.ACCESS_FINE_LOCATION")
    private static boolean e(LocationManager locationManager, Handler handler, Executor executor, GnssStatusCompat.a aVar) {
        Throwable th;
        ExecutionException e2;
        TimeoutException e3;
        long nanos;
        boolean z;
        int i2 = Build.VERSION.SDK_INT;
        boolean z2 = true;
        if (i2 >= 30) {
            b.b.i<Object, Object> iVar = f2628e;
            synchronized (iVar) {
                GnssStatus.Callback callback = (g) iVar.get(aVar);
                if (callback == null) {
                    callback = new g(aVar);
                }
                if (!locationManager.registerGnssStatusCallback(executor, callback)) {
                    return false;
                }
                iVar.put(aVar, callback);
                return true;
            }
        } else if (i2 >= 24) {
            m.a(handler != null);
            b.b.i<Object, Object> iVar2 = f2628e;
            synchronized (iVar2) {
                j jVar = (j) iVar2.get(aVar);
                if (jVar == null) {
                    jVar = new j(aVar);
                } else {
                    jVar.b();
                }
                jVar.a(executor);
                if (!locationManager.registerGnssStatusCallback(jVar, handler)) {
                    return false;
                }
                iVar2.put(aVar, jVar);
                return true;
            }
        } else {
            m.a(handler != null);
            b.b.i<Object, Object> iVar3 = f2628e;
            synchronized (iVar3) {
                h hVar = (h) iVar3.get(aVar);
                if (hVar == null) {
                    hVar = new h(locationManager, aVar);
                } else {
                    hVar.b();
                }
                hVar.a(executor);
                FutureTask futureTask = new FutureTask(new c(locationManager, hVar));
                if (Looper.myLooper() == handler.getLooper()) {
                    futureTask.run();
                } else if (!handler.post(futureTask)) {
                    throw new IllegalStateException(handler + " is shutting down");
                }
                try {
                    nanos = TimeUnit.SECONDS.toNanos(5);
                    z = false;
                    while (true) {
                        try {
                            break;
                        } catch (InterruptedException unknown) {
                            try {
                                nanos = (System.nanoTime() + nanos) - System.nanoTime();
                                z = true;
                            } catch (ExecutionException e4) {
                                e2 = e4;
                                if (e2.getCause() instanceof RuntimeException) {
                                }
                            } catch (TimeoutException e5) {
                                e3 = e5;
                                throw new IllegalStateException(handler + " appears to be blocked, please run registerGnssStatusCallback() directly on a Looper thread or ensure the main Looper is not blocked by this thread", e3);
                            }
                        } catch (ExecutionException e6) {
                            e2 = e6;
                            if (e2.getCause() instanceof RuntimeException) {
                            }
                        } catch (TimeoutException e7) {
                            e3 = e7;
                            z2 = z;
                            throw new IllegalStateException(handler + " appears to be blocked, please run registerGnssStatusCallback() directly on a Looper thread or ensure the main Looper is not blocked by this thread", e3);
                        } catch (Throwable th2) {
                            th = th2;
                            z2 = z;
                            if (z2) {
                            }
                            throw th;
                        }
                        nanos = (System.nanoTime() + nanos) - System.nanoTime();
                        z = true;
                    }
                    if (((Boolean) futureTask.get(nanos, TimeUnit.NANOSECONDS)).booleanValue()) {
                        f2628e.put(aVar, hVar);
                        if (z) {
                            Thread.currentThread().interrupt();
                        }
                        return true;
                    }
                    if (z) {
                        Thread.currentThread().interrupt();
                    }
                    return false;
                } catch (ExecutionException e8) {
                    e2 = e8;
                    if (e2.getCause() instanceof RuntimeException) {
                        throw ((RuntimeException) e2.getCause());
                    } else if (e2.getCause() instanceof Error) {
                        throw ((Error) e2.getCause());
                    } else {
                        throw new IllegalStateException(e2);
                    }
                } catch (TimeoutException e9) {
                    e3 = e9;
                    z2 = false;
                    throw new IllegalStateException(handler + " appears to be blocked, please run registerGnssStatusCallback() directly on a Looper thread or ensure the main Looper is not blocked by this thread", e3);
                } catch (Throwable th3) {
                    th = th3;
                    if (z2) {
                    }
                    throw th;
                }
            }
        }
    }

    @RequiresPermission("android.permission.ACCESS_FINE_LOCATION")
    public static boolean f(@NonNull LocationManager locationManager, @NonNull GnssStatusCompat.a aVar, @NonNull Handler handler) {
        if (Build.VERSION.SDK_INT >= 30) {
            return g(locationManager, androidx.core.os.e.a(handler), aVar);
        }
        return g(locationManager, new i(handler), aVar);
    }

    @RequiresPermission("android.permission.ACCESS_FINE_LOCATION")
    public static boolean g(@NonNull LocationManager locationManager, @NonNull Executor executor, @NonNull GnssStatusCompat.a aVar) {
        if (Build.VERSION.SDK_INT >= 30) {
            return e(locationManager, null, executor, aVar);
        }
        Looper myLooper = Looper.myLooper();
        if (myLooper == null) {
            myLooper = Looper.getMainLooper();
        }
        return e(locationManager, new Handler(myLooper), executor, aVar);
    }

    public static void h(@NonNull LocationManager locationManager, @NonNull GnssStatusCompat.a aVar) {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 >= 30) {
            b.b.i<Object, Object> iVar = f2628e;
            synchronized (iVar) {
                GnssStatus.Callback callback = (g) iVar.remove(aVar);
                if (callback != null) {
                    locationManager.unregisterGnssStatusCallback(callback);
                }
            }
        } else if (i2 >= 24) {
            b.b.i<Object, Object> iVar2 = f2628e;
            synchronized (iVar2) {
                j jVar = (j) iVar2.remove(aVar);
                if (jVar != null) {
                    jVar.b();
                    locationManager.unregisterGnssStatusCallback(jVar);
                }
            }
        } else {
            b.b.i<Object, Object> iVar3 = f2628e;
            synchronized (iVar3) {
                h hVar = (h) iVar3.remove(aVar);
                if (hVar != null) {
                    hVar.b();
                    locationManager.removeGpsStatusListener(hVar);
                }
            }
        }
    }
}
