package androidx.core.view;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ValueAnimator;
import android.annotation.SuppressLint;
import android.os.Build;
import android.view.View;
import android.view.ViewGroup;
import android.view.WindowInsets;
import android.view.WindowInsetsAnimation;
import android.view.animation.DecelerateInterpolator;
import android.view.animation.Interpolator;
import androidx.annotation.FloatRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.core.R;
import androidx.core.graphics.i;
import androidx.core.view.WindowInsetsCompat;
import com.alipay.sdk.util.g;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Objects;

public final class WindowInsetsAnimationCompat {
    private static final boolean DEBUG = false;
    private static final String TAG = "WindowInsetsAnimCompat";
    private c mImpl;

    public static abstract class Callback {
        public static final int DISPATCH_MODE_CONTINUE_ON_SUBTREE = 1;
        public static final int DISPATCH_MODE_STOP = 0;
        WindowInsets mDispachedInsets;
        private final int mDispatchMode;

        @Retention(RetentionPolicy.SOURCE)
        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
        public @interface DispatchMode {
        }

        public Callback(int i) {
            this.mDispatchMode = i;
        }

        public final int getDispatchMode() {
            return this.mDispatchMode;
        }

        public void onEnd(@NonNull WindowInsetsAnimationCompat windowInsetsAnimationCompat) {
        }

        public void onPrepare(@NonNull WindowInsetsAnimationCompat windowInsetsAnimationCompat) {
        }

        @NonNull
        public abstract WindowInsetsCompat onProgress(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull List<WindowInsetsAnimationCompat> list);

        @NonNull
        public BoundsCompat onStart(@NonNull WindowInsetsAnimationCompat windowInsetsAnimationCompat, @NonNull BoundsCompat boundsCompat) {
            return boundsCompat;
        }
    }

    /* access modifiers changed from: private */
    @RequiresApi(21)
    public static class a extends c {

        /* access modifiers changed from: private */
        @RequiresApi(21)
        /* renamed from: androidx.core.view.WindowInsetsAnimationCompat$a$a  reason: collision with other inner class name */
        public static class View$OnApplyWindowInsetsListenerC0043a implements View.OnApplyWindowInsetsListener {

            /* renamed from: a  reason: collision with root package name */
            private static final int f2882a = 160;

            /* renamed from: b  reason: collision with root package name */
            final Callback f2883b;

            /* renamed from: c  reason: collision with root package name */
            private WindowInsetsCompat f2884c;

            /* renamed from: androidx.core.view.WindowInsetsAnimationCompat$a$a$a  reason: collision with other inner class name */
            class C0044a implements ValueAnimator.AnimatorUpdateListener {
                final /* synthetic */ WindowInsetsCompat I0;
                final /* synthetic */ int J0;
                final /* synthetic */ View K0;

                /* renamed from: a  reason: collision with root package name */
                final /* synthetic */ WindowInsetsAnimationCompat f2885a;

                /* renamed from: b  reason: collision with root package name */
                final /* synthetic */ WindowInsetsCompat f2886b;

                C0044a(WindowInsetsAnimationCompat windowInsetsAnimationCompat, WindowInsetsCompat windowInsetsCompat, WindowInsetsCompat windowInsetsCompat2, int i, View view) {
                    this.f2885a = windowInsetsAnimationCompat;
                    this.f2886b = windowInsetsCompat;
                    this.I0 = windowInsetsCompat2;
                    this.J0 = i;
                    this.K0 = view;
                }

                public void onAnimationUpdate(ValueAnimator valueAnimator) {
                    this.f2885a.setFraction(valueAnimator.getAnimatedFraction());
                    a.n(this.K0, a.r(this.f2886b, this.I0, this.f2885a.getInterpolatedFraction(), this.J0), Collections.singletonList(this.f2885a));
                }
            }

            /* renamed from: androidx.core.view.WindowInsetsAnimationCompat$a$a$b */
            class b extends AnimatorListenerAdapter {

                /* renamed from: a  reason: collision with root package name */
                final /* synthetic */ WindowInsetsAnimationCompat f2887a;

                /* renamed from: b  reason: collision with root package name */
                final /* synthetic */ View f2888b;

                b(WindowInsetsAnimationCompat windowInsetsAnimationCompat, View view) {
                    this.f2887a = windowInsetsAnimationCompat;
                    this.f2888b = view;
                }

                public void onAnimationEnd(Animator animator) {
                    this.f2887a.setFraction(1.0f);
                    a.l(this.f2888b, this.f2887a);
                }
            }

            /* renamed from: androidx.core.view.WindowInsetsAnimationCompat$a$a$c */
            class c implements Runnable {
                final /* synthetic */ BoundsCompat I0;
                final /* synthetic */ ValueAnimator J0;

                /* renamed from: a  reason: collision with root package name */
                final /* synthetic */ View f2889a;

                /* renamed from: b  reason: collision with root package name */
                final /* synthetic */ WindowInsetsAnimationCompat f2890b;

                c(View view, WindowInsetsAnimationCompat windowInsetsAnimationCompat, BoundsCompat boundsCompat, ValueAnimator valueAnimator) {
                    this.f2889a = view;
                    this.f2890b = windowInsetsAnimationCompat;
                    this.I0 = boundsCompat;
                    this.J0 = valueAnimator;
                }

                public void run() {
                    a.o(this.f2889a, this.f2890b, this.I0);
                    this.J0.start();
                }
            }

            View$OnApplyWindowInsetsListenerC0043a(@NonNull View view, @NonNull Callback callback) {
                this.f2883b = callback;
                WindowInsetsCompat rootWindowInsets = ViewCompat.getRootWindowInsets(view);
                this.f2884c = rootWindowInsets != null ? new WindowInsetsCompat.Builder(rootWindowInsets).build() : null;
            }

            public WindowInsets onApplyWindowInsets(View view, WindowInsets windowInsets) {
                if (!view.isLaidOut()) {
                    this.f2884c = WindowInsetsCompat.toWindowInsetsCompat(windowInsets, view);
                    return a.p(view, windowInsets);
                }
                WindowInsetsCompat windowInsetsCompat = WindowInsetsCompat.toWindowInsetsCompat(windowInsets, view);
                if (this.f2884c == null) {
                    this.f2884c = ViewCompat.getRootWindowInsets(view);
                }
                if (this.f2884c == null) {
                    this.f2884c = windowInsetsCompat;
                    return a.p(view, windowInsets);
                }
                Callback q = a.q(view);
                if (q != null && Objects.equals(q.mDispachedInsets, windowInsets)) {
                    return a.p(view, windowInsets);
                }
                int i = a.i(windowInsetsCompat, this.f2884c);
                if (i == 0) {
                    return a.p(view, windowInsets);
                }
                WindowInsetsCompat windowInsetsCompat2 = this.f2884c;
                WindowInsetsAnimationCompat windowInsetsAnimationCompat = new WindowInsetsAnimationCompat(i, new DecelerateInterpolator(), 160);
                windowInsetsAnimationCompat.setFraction(0.0f);
                ValueAnimator duration = ValueAnimator.ofFloat(0.0f, 1.0f).setDuration(windowInsetsAnimationCompat.getDurationMillis());
                BoundsCompat j = a.j(windowInsetsCompat, windowInsetsCompat2, i);
                a.m(view, windowInsetsAnimationCompat, windowInsets, false);
                duration.addUpdateListener(new C0044a(windowInsetsAnimationCompat, windowInsetsCompat, windowInsetsCompat2, i, view));
                duration.addListener(new b(windowInsetsAnimationCompat, view));
                OneShotPreDrawListener.add(view, new c(view, windowInsetsAnimationCompat, j, duration));
                this.f2884c = windowInsetsCompat;
                return a.p(view, windowInsets);
            }
        }

        a(int i, @Nullable Interpolator interpolator, long j) {
            super(i, interpolator, j);
        }

        @SuppressLint({"WrongConstant"})
        static int i(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsetsCompat windowInsetsCompat2) {
            int i = 0;
            for (int i2 = 1; i2 <= 256; i2 <<= 1) {
                if (!windowInsetsCompat.getInsets(i2).equals(windowInsetsCompat2.getInsets(i2))) {
                    i |= i2;
                }
            }
            return i;
        }

        @NonNull
        static BoundsCompat j(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsetsCompat windowInsetsCompat2, int i) {
            i insets = windowInsetsCompat.getInsets(i);
            i insets2 = windowInsetsCompat2.getInsets(i);
            return new BoundsCompat(i.d(Math.min(insets.f2545b, insets2.f2545b), Math.min(insets.f2546c, insets2.f2546c), Math.min(insets.f2547d, insets2.f2547d), Math.min(insets.f2548e, insets2.f2548e)), i.d(Math.max(insets.f2545b, insets2.f2545b), Math.max(insets.f2546c, insets2.f2546c), Math.max(insets.f2547d, insets2.f2547d), Math.max(insets.f2548e, insets2.f2548e)));
        }

        @NonNull
        private static View.OnApplyWindowInsetsListener k(@NonNull View view, @NonNull Callback callback) {
            return new View$OnApplyWindowInsetsListenerC0043a(view, callback);
        }

        static void l(@NonNull View view, @NonNull WindowInsetsAnimationCompat windowInsetsAnimationCompat) {
            Callback q = q(view);
            if (q != null) {
                q.onEnd(windowInsetsAnimationCompat);
                if (q.getDispatchMode() == 0) {
                    return;
                }
            }
            if (view instanceof ViewGroup) {
                ViewGroup viewGroup = (ViewGroup) view;
                for (int i = 0; i < viewGroup.getChildCount(); i++) {
                    l(viewGroup.getChildAt(i), windowInsetsAnimationCompat);
                }
            }
        }

        static void m(View view, WindowInsetsAnimationCompat windowInsetsAnimationCompat, WindowInsets windowInsets, boolean z) {
            Callback q = q(view);
            if (q != null) {
                q.mDispachedInsets = windowInsets;
                if (!z) {
                    q.onPrepare(windowInsetsAnimationCompat);
                    z = q.getDispatchMode() == 0;
                }
            }
            if (view instanceof ViewGroup) {
                ViewGroup viewGroup = (ViewGroup) view;
                for (int i = 0; i < viewGroup.getChildCount(); i++) {
                    m(viewGroup.getChildAt(i), windowInsetsAnimationCompat, windowInsets, z);
                }
            }
        }

        static void n(@NonNull View view, @NonNull WindowInsetsCompat windowInsetsCompat, @NonNull List<WindowInsetsAnimationCompat> list) {
            Callback q = q(view);
            if (q != null) {
                windowInsetsCompat = q.onProgress(windowInsetsCompat, list);
                if (q.getDispatchMode() == 0) {
                    return;
                }
            }
            if (view instanceof ViewGroup) {
                ViewGroup viewGroup = (ViewGroup) view;
                for (int i = 0; i < viewGroup.getChildCount(); i++) {
                    n(viewGroup.getChildAt(i), windowInsetsCompat, list);
                }
            }
        }

        static void o(View view, WindowInsetsAnimationCompat windowInsetsAnimationCompat, BoundsCompat boundsCompat) {
            Callback q = q(view);
            if (q != null) {
                q.onStart(windowInsetsAnimationCompat, boundsCompat);
                if (q.getDispatchMode() == 0) {
                    return;
                }
            }
            if (view instanceof ViewGroup) {
                ViewGroup viewGroup = (ViewGroup) view;
                for (int i = 0; i < viewGroup.getChildCount(); i++) {
                    o(viewGroup.getChildAt(i), windowInsetsAnimationCompat, boundsCompat);
                }
            }
        }

        @NonNull
        static WindowInsets p(@NonNull View view, @NonNull WindowInsets windowInsets) {
            if (view.getTag(R.id.tag_on_apply_window_listener) != null) {
                return windowInsets;
            }
            return view.onApplyWindowInsets(windowInsets);
        }

        @Nullable
        static Callback q(View view) {
            Object tag = view.getTag(R.id.tag_window_insets_animation_callback);
            if (tag instanceof View$OnApplyWindowInsetsListenerC0043a) {
                return ((View$OnApplyWindowInsetsListenerC0043a) tag).f2883b;
            }
            return null;
        }

        @SuppressLint({"WrongConstant"})
        static WindowInsetsCompat r(WindowInsetsCompat windowInsetsCompat, WindowInsetsCompat windowInsetsCompat2, float f, int i) {
            WindowInsetsCompat.Builder builder = new WindowInsetsCompat.Builder(windowInsetsCompat);
            for (int i2 = 1; i2 <= 256; i2 <<= 1) {
                if ((i & i2) == 0) {
                    builder.setInsets(i2, windowInsetsCompat.getInsets(i2));
                } else {
                    i insets = windowInsetsCompat.getInsets(i2);
                    i insets2 = windowInsetsCompat2.getInsets(i2);
                    float f2 = 1.0f - f;
                    builder.setInsets(i2, WindowInsetsCompat.insetInsets(insets, (int) (((double) (((float) (insets.f2545b - insets2.f2545b)) * f2)) + 0.5d), (int) (((double) (((float) (insets.f2546c - insets2.f2546c)) * f2)) + 0.5d), (int) (((double) (((float) (insets.f2547d - insets2.f2547d)) * f2)) + 0.5d), (int) (((double) (((float) (insets.f2548e - insets2.f2548e)) * f2)) + 0.5d)));
                }
            }
            return builder.build();
        }

        static void s(@NonNull View view, @Nullable Callback callback) {
            Object tag = view.getTag(R.id.tag_on_apply_window_listener);
            if (callback == null) {
                view.setTag(R.id.tag_window_insets_animation_callback, null);
                if (tag == null) {
                    view.setOnApplyWindowInsetsListener(null);
                    return;
                }
                return;
            }
            View.OnApplyWindowInsetsListener k = k(view, callback);
            view.setTag(R.id.tag_window_insets_animation_callback, k);
            if (tag == null) {
                view.setOnApplyWindowInsetsListener(k);
            }
        }
    }

    /* access modifiers changed from: private */
    public static class c {

        /* renamed from: a  reason: collision with root package name */
        private final int f2895a;

        /* renamed from: b  reason: collision with root package name */
        private float f2896b;
        @Nullable

        /* renamed from: c  reason: collision with root package name */
        private final Interpolator f2897c;

        /* renamed from: d  reason: collision with root package name */
        private final long f2898d;

        /* renamed from: e  reason: collision with root package name */
        private float f2899e;

        c(int i, @Nullable Interpolator interpolator, long j) {
            this.f2895a = i;
            this.f2897c = interpolator;
            this.f2898d = j;
        }

        public float a() {
            return this.f2899e;
        }

        public long b() {
            return this.f2898d;
        }

        public float c() {
            return this.f2896b;
        }

        public float d() {
            Interpolator interpolator = this.f2897c;
            if (interpolator != null) {
                return interpolator.getInterpolation(this.f2896b);
            }
            return this.f2896b;
        }

        @Nullable
        public Interpolator e() {
            return this.f2897c;
        }

        public int f() {
            return this.f2895a;
        }

        public void g(float f) {
            this.f2899e = f;
        }

        public void h(float f) {
            this.f2896b = f;
        }
    }

    public WindowInsetsAnimationCompat(int i, @Nullable Interpolator interpolator, long j) {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 >= 30) {
            this.mImpl = new b(i, interpolator, j);
        } else if (i2 >= 21) {
            this.mImpl = new a(i, interpolator, j);
        } else {
            this.mImpl = new c(0, interpolator, j);
        }
    }

    static void setCallback(@NonNull View view, @Nullable Callback callback) {
        int i = Build.VERSION.SDK_INT;
        if (i >= 30) {
            b.l(view, callback);
        } else if (i >= 21) {
            a.s(view, callback);
        }
    }

    @RequiresApi(30)
    static WindowInsetsAnimationCompat toWindowInsetsAnimationCompat(WindowInsetsAnimation windowInsetsAnimation) {
        return new WindowInsetsAnimationCompat(windowInsetsAnimation);
    }

    @FloatRange(from = 0.0d, to = 1.0d)
    public float getAlpha() {
        return this.mImpl.a();
    }

    public long getDurationMillis() {
        return this.mImpl.b();
    }

    @FloatRange(from = 0.0d, to = 1.0d)
    public float getFraction() {
        return this.mImpl.c();
    }

    public float getInterpolatedFraction() {
        return this.mImpl.d();
    }

    @Nullable
    public Interpolator getInterpolator() {
        return this.mImpl.e();
    }

    public int getTypeMask() {
        return this.mImpl.f();
    }

    public void setAlpha(@FloatRange(from = 0.0d, to = 1.0d) float f) {
        this.mImpl.g(f);
    }

    public void setFraction(@FloatRange(from = 0.0d, to = 1.0d) float f) {
        this.mImpl.h(f);
    }

    /* access modifiers changed from: private */
    @RequiresApi(30)
    public static class b extends c {
        @NonNull
        private final WindowInsetsAnimation f;

        /* access modifiers changed from: private */
        @RequiresApi(30)
        public static class a extends WindowInsetsAnimation.Callback {

            /* renamed from: a  reason: collision with root package name */
            private final Callback f2891a;

            /* renamed from: b  reason: collision with root package name */
            private List<WindowInsetsAnimationCompat> f2892b;

            /* renamed from: c  reason: collision with root package name */
            private ArrayList<WindowInsetsAnimationCompat> f2893c;

            /* renamed from: d  reason: collision with root package name */
            private final HashMap<WindowInsetsAnimation, WindowInsetsAnimationCompat> f2894d = new HashMap<>();

            a(@NonNull Callback callback) {
                super(callback.getDispatchMode());
                this.f2891a = callback;
            }

            @NonNull
            private WindowInsetsAnimationCompat a(@NonNull WindowInsetsAnimation windowInsetsAnimation) {
                WindowInsetsAnimationCompat windowInsetsAnimationCompat = this.f2894d.get(windowInsetsAnimation);
                if (windowInsetsAnimationCompat != null) {
                    return windowInsetsAnimationCompat;
                }
                WindowInsetsAnimationCompat windowInsetsAnimationCompat2 = WindowInsetsAnimationCompat.toWindowInsetsAnimationCompat(windowInsetsAnimation);
                this.f2894d.put(windowInsetsAnimation, windowInsetsAnimationCompat2);
                return windowInsetsAnimationCompat2;
            }

            public void b(@NonNull WindowInsetsAnimation windowInsetsAnimation) {
                this.f2891a.onEnd(a(windowInsetsAnimation));
                this.f2894d.remove(windowInsetsAnimation);
            }

            public void c(@NonNull WindowInsetsAnimation windowInsetsAnimation) {
                this.f2891a.onPrepare(a(windowInsetsAnimation));
            }

            @NonNull
            public WindowInsets d(@NonNull WindowInsets windowInsets, @NonNull List<WindowInsetsAnimation> list) {
                ArrayList<WindowInsetsAnimationCompat> arrayList = this.f2893c;
                if (arrayList == null) {
                    ArrayList<WindowInsetsAnimationCompat> arrayList2 = new ArrayList<>(list.size());
                    this.f2893c = arrayList2;
                    this.f2892b = Collections.unmodifiableList(arrayList2);
                } else {
                    arrayList.clear();
                }
                for (int size = list.size() - 1; size >= 0; size--) {
                    WindowInsetsAnimation windowInsetsAnimation = list.get(size);
                    WindowInsetsAnimationCompat a2 = a(windowInsetsAnimation);
                    a2.setFraction(windowInsetsAnimation.getFraction());
                    this.f2893c.add(a2);
                }
                return this.f2891a.onProgress(WindowInsetsCompat.toWindowInsetsCompat(windowInsets), this.f2892b).toWindowInsets();
            }

            @NonNull
            public WindowInsetsAnimation.Bounds e(@NonNull WindowInsetsAnimation windowInsetsAnimation, @NonNull WindowInsetsAnimation.Bounds bounds) {
                return this.f2891a.onStart(a(windowInsetsAnimation), BoundsCompat.toBoundsCompat(bounds)).toBounds();
            }
        }

        b(@NonNull WindowInsetsAnimation windowInsetsAnimation) {
            super(0, null, 0);
            this.f = windowInsetsAnimation;
        }

        @NonNull
        public static WindowInsetsAnimation.Bounds i(@NonNull BoundsCompat boundsCompat) {
            return new WindowInsetsAnimation.Bounds(boundsCompat.getLowerBound().h(), boundsCompat.getUpperBound().h());
        }

        @NonNull
        public static i j(@NonNull WindowInsetsAnimation.Bounds bounds) {
            return i.g(bounds.getUpperBound());
        }

        @NonNull
        public static i k(@NonNull WindowInsetsAnimation.Bounds bounds) {
            return i.g(bounds.getLowerBound());
        }

        public static void l(@NonNull View view, @Nullable Callback callback) {
            view.setWindowInsetsAnimationCallback(callback != null ? new a(callback) : null);
        }

        @Override // androidx.core.view.WindowInsetsAnimationCompat.c
        public long b() {
            return this.f.getDurationMillis();
        }

        @Override // androidx.core.view.WindowInsetsAnimationCompat.c
        public float c() {
            return this.f.getFraction();
        }

        @Override // androidx.core.view.WindowInsetsAnimationCompat.c
        public float d() {
            return this.f.getInterpolatedFraction();
        }

        @Override // androidx.core.view.WindowInsetsAnimationCompat.c
        @Nullable
        public Interpolator e() {
            return this.f.getInterpolator();
        }

        @Override // androidx.core.view.WindowInsetsAnimationCompat.c
        public int f() {
            return this.f.getTypeMask();
        }

        @Override // androidx.core.view.WindowInsetsAnimationCompat.c
        public void h(float f2) {
            this.f.setFraction(f2);
        }

        b(int i, Interpolator interpolator, long j) {
            this(new WindowInsetsAnimation(i, interpolator, j));
        }
    }

    public static final class BoundsCompat {
        private final i mLowerBound;
        private final i mUpperBound;

        public BoundsCompat(@NonNull i iVar, @NonNull i iVar2) {
            this.mLowerBound = iVar;
            this.mUpperBound = iVar2;
        }

        @NonNull
        @RequiresApi(30)
        public static BoundsCompat toBoundsCompat(@NonNull WindowInsetsAnimation.Bounds bounds) {
            return new BoundsCompat(bounds);
        }

        @NonNull
        public i getLowerBound() {
            return this.mLowerBound;
        }

        @NonNull
        public i getUpperBound() {
            return this.mUpperBound;
        }

        @NonNull
        public BoundsCompat inset(@NonNull i iVar) {
            return new BoundsCompat(WindowInsetsCompat.insetInsets(this.mLowerBound, iVar.f2545b, iVar.f2546c, iVar.f2547d, iVar.f2548e), WindowInsetsCompat.insetInsets(this.mUpperBound, iVar.f2545b, iVar.f2546c, iVar.f2547d, iVar.f2548e));
        }

        @NonNull
        @RequiresApi(30)
        public WindowInsetsAnimation.Bounds toBounds() {
            return b.i(this);
        }

        public String toString() {
            return "Bounds{lower=" + this.mLowerBound + " upper=" + this.mUpperBound + g.f6033d;
        }

        @RequiresApi(30)
        private BoundsCompat(@NonNull WindowInsetsAnimation.Bounds bounds) {
            this.mLowerBound = b.k(bounds);
            this.mUpperBound = b.j(bounds);
        }
    }

    @RequiresApi(30)
    private WindowInsetsAnimationCompat(@NonNull WindowInsetsAnimation windowInsetsAnimation) {
        this(0, null, 0);
        if (Build.VERSION.SDK_INT >= 30) {
            this.mImpl = new b(windowInsetsAnimation);
        }
    }
}
