package androidx.core.view;

import android.annotation.SuppressLint;
import android.graphics.Rect;
import android.os.Build;
import android.util.Log;
import android.view.View;
import android.view.WindowInsets;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.core.util.m;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.Method;
import java.util.Objects;

public class WindowInsetsCompat {
    @NonNull
    public static final WindowInsetsCompat CONSUMED;
    private static final String TAG = "WindowInsetsCompat";
    private final k mImpl;

    public static final class Type {
        static final int CAPTION_BAR = 4;
        static final int DISPLAY_CUTOUT = 128;
        static final int FIRST = 1;
        static final int IME = 8;
        static final int LAST = 256;
        static final int MANDATORY_SYSTEM_GESTURES = 32;
        static final int NAVIGATION_BARS = 2;
        static final int SIZE = 9;
        static final int STATUS_BARS = 1;
        static final int SYSTEM_GESTURES = 16;
        static final int TAPPABLE_ELEMENT = 64;
        static final int WINDOW_DECOR = 256;

        @Retention(RetentionPolicy.SOURCE)
        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
        public @interface InsetsType {
        }

        private Type() {
        }

        @SuppressLint({"WrongConstant"})
        @RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
        static int all() {
            return -1;
        }

        public static int captionBar() {
            return 4;
        }

        public static int displayCutout() {
            return 128;
        }

        public static int ime() {
            return 8;
        }

        static int indexOf(int i) {
            if (i == 1) {
                return 0;
            }
            if (i == 2) {
                return 1;
            }
            if (i == 4) {
                return 2;
            }
            if (i == 8) {
                return 3;
            }
            if (i == 16) {
                return 4;
            }
            if (i == 32) {
                return 5;
            }
            if (i == 64) {
                return 6;
            }
            if (i == 128) {
                return 7;
            }
            if (i == 256) {
                return 8;
            }
            throw new IllegalArgumentException("type needs to be >= FIRST and <= LAST, type=" + i);
        }

        public static int mandatorySystemGestures() {
            return 32;
        }

        public static int navigationBars() {
            return 2;
        }

        public static int statusBars() {
            return 1;
        }

        public static int systemBars() {
            return 7;
        }

        public static int systemGestures() {
            return 16;
        }

        public static int tappableElement() {
            return 64;
        }
    }

    /* access modifiers changed from: package-private */
    @RequiresApi(21)
    public static class a {

        /* renamed from: a  reason: collision with root package name */
        private static Field f2901a;

        /* renamed from: b  reason: collision with root package name */
        private static Field f2902b;

        /* renamed from: c  reason: collision with root package name */
        private static Field f2903c;

        /* renamed from: d  reason: collision with root package name */
        private static boolean f2904d = true;

        static {
            try {
                Field declaredField = View.class.getDeclaredField("mAttachInfo");
                f2901a = declaredField;
                declaredField.setAccessible(true);
                Class<?> cls = Class.forName("android.view.View$AttachInfo");
                Field declaredField2 = cls.getDeclaredField("mStableInsets");
                f2902b = declaredField2;
                declaredField2.setAccessible(true);
                Field declaredField3 = cls.getDeclaredField("mContentInsets");
                f2903c = declaredField3;
                declaredField3.setAccessible(true);
            } catch (ReflectiveOperationException e2) {
                Log.w(WindowInsetsCompat.TAG, "Failed to get visible insets from AttachInfo " + e2.getMessage(), e2);
            }
        }

        private a() {
        }

        @Nullable
        public static WindowInsetsCompat a(@NonNull View view) {
            if (f2904d && view.isAttachedToWindow()) {
                try {
                    Object obj = f2901a.get(view.getRootView());
                    if (obj != null) {
                        Rect rect = (Rect) f2902b.get(obj);
                        Rect rect2 = (Rect) f2903c.get(obj);
                        if (!(rect == null || rect2 == null)) {
                            WindowInsetsCompat build = new Builder().setStableInsets(androidx.core.graphics.i.e(rect)).setSystemWindowInsets(androidx.core.graphics.i.e(rect2)).build();
                            build.setRootWindowInsets(build);
                            build.copyRootViewBounds(view.getRootView());
                            return build;
                        }
                    }
                } catch (IllegalAccessException e2) {
                    Log.w(WindowInsetsCompat.TAG, "Failed to get insets from AttachInfo. " + e2.getMessage(), e2);
                }
            }
            return null;
        }
    }

    @RequiresApi(30)
    private static class d extends c {
        d() {
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void d(int i, @NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setInsets(l.a(i), iVar.h());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void e(int i, @NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setInsetsIgnoringVisibility(l.a(i), iVar.h());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void k(int i, boolean z) {
            this.f2908c.setVisible(l.a(i), z);
        }

        d(@NonNull WindowInsetsCompat windowInsetsCompat) {
            super(windowInsetsCompat);
        }
    }

    /* access modifiers changed from: private */
    public static class e {

        /* renamed from: a  reason: collision with root package name */
        private final WindowInsetsCompat f2909a;

        /* renamed from: b  reason: collision with root package name */
        androidx.core.graphics.i[] f2910b;

        e() {
            this(new WindowInsetsCompat((WindowInsetsCompat) null));
        }

        /* access modifiers changed from: protected */
        public final void a() {
            androidx.core.graphics.i[] iVarArr = this.f2910b;
            if (iVarArr != null) {
                androidx.core.graphics.i iVar = iVarArr[Type.indexOf(1)];
                androidx.core.graphics.i iVar2 = this.f2910b[Type.indexOf(2)];
                if (iVar2 == null) {
                    iVar2 = this.f2909a.getInsets(2);
                }
                if (iVar == null) {
                    iVar = this.f2909a.getInsets(1);
                }
                i(androidx.core.graphics.i.b(iVar, iVar2));
                androidx.core.graphics.i iVar3 = this.f2910b[Type.indexOf(16)];
                if (iVar3 != null) {
                    h(iVar3);
                }
                androidx.core.graphics.i iVar4 = this.f2910b[Type.indexOf(32)];
                if (iVar4 != null) {
                    f(iVar4);
                }
                androidx.core.graphics.i iVar5 = this.f2910b[Type.indexOf(64)];
                if (iVar5 != null) {
                    j(iVar5);
                }
            }
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public WindowInsetsCompat b() {
            a();
            return this.f2909a;
        }

        /* access modifiers changed from: package-private */
        public void c(@Nullable DisplayCutoutCompat displayCutoutCompat) {
        }

        /* access modifiers changed from: package-private */
        public void d(int i, @NonNull androidx.core.graphics.i iVar) {
            if (this.f2910b == null) {
                this.f2910b = new androidx.core.graphics.i[9];
            }
            for (int i2 = 1; i2 <= 256; i2 <<= 1) {
                if ((i & i2) != 0) {
                    this.f2910b[Type.indexOf(i2)] = iVar;
                }
            }
        }

        /* access modifiers changed from: package-private */
        public void e(int i, @NonNull androidx.core.graphics.i iVar) {
            if (i == 8) {
                throw new IllegalArgumentException("Ignoring visibility inset not available for IME");
            }
        }

        /* access modifiers changed from: package-private */
        public void f(@NonNull androidx.core.graphics.i iVar) {
        }

        /* access modifiers changed from: package-private */
        public void g(@NonNull androidx.core.graphics.i iVar) {
        }

        /* access modifiers changed from: package-private */
        public void h(@NonNull androidx.core.graphics.i iVar) {
        }

        /* access modifiers changed from: package-private */
        public void i(@NonNull androidx.core.graphics.i iVar) {
        }

        /* access modifiers changed from: package-private */
        public void j(@NonNull androidx.core.graphics.i iVar) {
        }

        /* access modifiers changed from: package-private */
        public void k(int i, boolean z) {
        }

        e(@NonNull WindowInsetsCompat windowInsetsCompat) {
            this.f2909a = windowInsetsCompat;
        }
    }

    @RequiresApi(28)
    private static class h extends g {
        h(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsets windowInsets) {
            super(windowInsetsCompat, windowInsets);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public WindowInsetsCompat a() {
            return WindowInsetsCompat.toWindowInsetsCompat(this.i.consumeDisplayCutout());
        }

        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.f
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof h)) {
                return false;
            }
            h hVar = (h) obj;
            if (!Objects.equals(this.i, hVar.i) || !Objects.equals(this.m, hVar.m)) {
                return false;
            }
            return true;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @Nullable
        public DisplayCutoutCompat f() {
            return DisplayCutoutCompat.wrap(this.i.getDisplayCutout());
        }

        @Override // androidx.core.view.WindowInsetsCompat.k
        public int hashCode() {
            return this.i.hashCode();
        }

        h(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull h hVar) {
            super(windowInsetsCompat, hVar);
        }
    }

    @RequiresApi(30)
    private static class j extends i {
        @NonNull
        static final WindowInsetsCompat r = WindowInsetsCompat.toWindowInsetsCompat(WindowInsets.CONSUMED);

        j(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsets windowInsets) {
            super(windowInsetsCompat, windowInsets);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.f
        public final void d(@NonNull View view) {
        }

        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.f
        @NonNull
        public androidx.core.graphics.i g(int i) {
            return androidx.core.graphics.i.g(this.i.getInsets(l.a(i)));
        }

        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.f
        @NonNull
        public androidx.core.graphics.i h(int i) {
            return androidx.core.graphics.i.g(this.i.getInsetsIgnoringVisibility(l.a(i)));
        }

        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.f
        public boolean q(int i) {
            return this.i.isVisible(l.a(i));
        }

        j(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull j jVar) {
            super(windowInsetsCompat, jVar);
        }
    }

    /* access modifiers changed from: private */
    public static class k {
        @NonNull

        /* renamed from: a  reason: collision with root package name */
        static final WindowInsetsCompat f2914a = new Builder().build().consumeDisplayCutout().consumeStableInsets().consumeSystemWindowInsets();

        /* renamed from: b  reason: collision with root package name */
        final WindowInsetsCompat f2915b;

        k(@NonNull WindowInsetsCompat windowInsetsCompat) {
            this.f2915b = windowInsetsCompat;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public WindowInsetsCompat a() {
            return this.f2915b;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public WindowInsetsCompat b() {
            return this.f2915b;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public WindowInsetsCompat c() {
            return this.f2915b;
        }

        /* access modifiers changed from: package-private */
        public void d(@NonNull View view) {
        }

        /* access modifiers changed from: package-private */
        public void e(@NonNull WindowInsetsCompat windowInsetsCompat) {
        }

        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof k)) {
                return false;
            }
            k kVar = (k) obj;
            if (p() != kVar.p() || o() != kVar.o() || !androidx.core.util.h.a(l(), kVar.l()) || !androidx.core.util.h.a(j(), kVar.j()) || !androidx.core.util.h.a(f(), kVar.f())) {
                return false;
            }
            return true;
        }

        /* access modifiers changed from: package-private */
        @Nullable
        public DisplayCutoutCompat f() {
            return null;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i g(int i) {
            return androidx.core.graphics.i.f2544a;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i h(int i) {
            if ((i & 8) == 0) {
                return androidx.core.graphics.i.f2544a;
            }
            throw new IllegalArgumentException("Unable to query the maximum insets for IME");
        }

        public int hashCode() {
            return androidx.core.util.h.b(Boolean.valueOf(p()), Boolean.valueOf(o()), l(), j(), f());
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i i() {
            return l();
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i j() {
            return androidx.core.graphics.i.f2544a;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i k() {
            return l();
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i l() {
            return androidx.core.graphics.i.f2544a;
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public androidx.core.graphics.i m() {
            return l();
        }

        /* access modifiers changed from: package-private */
        @NonNull
        public WindowInsetsCompat n(int i, int i2, int i3, int i4) {
            return f2914a;
        }

        /* access modifiers changed from: package-private */
        public boolean o() {
            return false;
        }

        /* access modifiers changed from: package-private */
        public boolean p() {
            return false;
        }

        /* access modifiers changed from: package-private */
        public boolean q(int i) {
            return true;
        }

        public void r(androidx.core.graphics.i[] iVarArr) {
        }

        /* access modifiers changed from: package-private */
        public void s(@NonNull androidx.core.graphics.i iVar) {
        }

        /* access modifiers changed from: package-private */
        public void t(@Nullable WindowInsetsCompat windowInsetsCompat) {
        }

        public void u(androidx.core.graphics.i iVar) {
        }
    }

    @RequiresApi(30)
    private static final class l {
        private l() {
        }

        static int a(int i) {
            int i2;
            int i3 = 0;
            for (int i4 = 1; i4 <= 256; i4 <<= 1) {
                if ((i & i4) != 0) {
                    if (i4 == 1) {
                        i2 = WindowInsets.Type.statusBars();
                    } else if (i4 == 2) {
                        i2 = WindowInsets.Type.navigationBars();
                    } else if (i4 == 4) {
                        i2 = WindowInsets.Type.captionBar();
                    } else if (i4 == 8) {
                        i2 = WindowInsets.Type.ime();
                    } else if (i4 == 16) {
                        i2 = WindowInsets.Type.systemGestures();
                    } else if (i4 == 32) {
                        i2 = WindowInsets.Type.mandatorySystemGestures();
                    } else if (i4 == 64) {
                        i2 = WindowInsets.Type.tappableElement();
                    } else if (i4 == 128) {
                        i2 = WindowInsets.Type.displayCutout();
                    }
                    i3 |= i2;
                }
            }
            return i3;
        }
    }

    static {
        if (Build.VERSION.SDK_INT >= 30) {
            CONSUMED = j.r;
        } else {
            CONSUMED = k.f2914a;
        }
    }

    @RequiresApi(20)
    private WindowInsetsCompat(@NonNull WindowInsets windowInsets) {
        int i2 = Build.VERSION.SDK_INT;
        if (i2 >= 30) {
            this.mImpl = new j(this, windowInsets);
        } else if (i2 >= 29) {
            this.mImpl = new i(this, windowInsets);
        } else if (i2 >= 28) {
            this.mImpl = new h(this, windowInsets);
        } else if (i2 >= 21) {
            this.mImpl = new g(this, windowInsets);
        } else if (i2 >= 20) {
            this.mImpl = new f(this, windowInsets);
        } else {
            this.mImpl = new k(this);
        }
    }

    static androidx.core.graphics.i insetInsets(@NonNull androidx.core.graphics.i iVar, int i2, int i3, int i4, int i5) {
        int max = Math.max(0, iVar.f2545b - i2);
        int max2 = Math.max(0, iVar.f2546c - i3);
        int max3 = Math.max(0, iVar.f2547d - i4);
        int max4 = Math.max(0, iVar.f2548e - i5);
        if (max == i2 && max2 == i3 && max3 == i4 && max4 == i5) {
            return iVar;
        }
        return androidx.core.graphics.i.d(max, max2, max3, max4);
    }

    @NonNull
    @RequiresApi(20)
    public static WindowInsetsCompat toWindowInsetsCompat(@NonNull WindowInsets windowInsets) {
        return toWindowInsetsCompat(windowInsets, null);
    }

    @NonNull
    @Deprecated
    public WindowInsetsCompat consumeDisplayCutout() {
        return this.mImpl.a();
    }

    @NonNull
    @Deprecated
    public WindowInsetsCompat consumeStableInsets() {
        return this.mImpl.b();
    }

    @NonNull
    @Deprecated
    public WindowInsetsCompat consumeSystemWindowInsets() {
        return this.mImpl.c();
    }

    /* access modifiers changed from: package-private */
    public void copyRootViewBounds(@NonNull View view) {
        this.mImpl.d(view);
    }

    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof WindowInsetsCompat)) {
            return false;
        }
        return androidx.core.util.h.a(this.mImpl, ((WindowInsetsCompat) obj).mImpl);
    }

    @Nullable
    public DisplayCutoutCompat getDisplayCutout() {
        return this.mImpl.f();
    }

    @NonNull
    public androidx.core.graphics.i getInsets(int i2) {
        return this.mImpl.g(i2);
    }

    @NonNull
    public androidx.core.graphics.i getInsetsIgnoringVisibility(int i2) {
        return this.mImpl.h(i2);
    }

    @NonNull
    @Deprecated
    public androidx.core.graphics.i getMandatorySystemGestureInsets() {
        return this.mImpl.i();
    }

    @Deprecated
    public int getStableInsetBottom() {
        return this.mImpl.j().f2548e;
    }

    @Deprecated
    public int getStableInsetLeft() {
        return this.mImpl.j().f2545b;
    }

    @Deprecated
    public int getStableInsetRight() {
        return this.mImpl.j().f2547d;
    }

    @Deprecated
    public int getStableInsetTop() {
        return this.mImpl.j().f2546c;
    }

    @NonNull
    @Deprecated
    public androidx.core.graphics.i getStableInsets() {
        return this.mImpl.j();
    }

    @NonNull
    @Deprecated
    public androidx.core.graphics.i getSystemGestureInsets() {
        return this.mImpl.k();
    }

    @Deprecated
    public int getSystemWindowInsetBottom() {
        return this.mImpl.l().f2548e;
    }

    @Deprecated
    public int getSystemWindowInsetLeft() {
        return this.mImpl.l().f2545b;
    }

    @Deprecated
    public int getSystemWindowInsetRight() {
        return this.mImpl.l().f2547d;
    }

    @Deprecated
    public int getSystemWindowInsetTop() {
        return this.mImpl.l().f2546c;
    }

    @NonNull
    @Deprecated
    public androidx.core.graphics.i getSystemWindowInsets() {
        return this.mImpl.l();
    }

    @NonNull
    @Deprecated
    public androidx.core.graphics.i getTappableElementInsets() {
        return this.mImpl.m();
    }

    public boolean hasInsets() {
        androidx.core.graphics.i insets = getInsets(Type.all());
        androidx.core.graphics.i iVar = androidx.core.graphics.i.f2544a;
        return !insets.equals(iVar) || !getInsetsIgnoringVisibility(Type.all() ^ Type.ime()).equals(iVar) || getDisplayCutout() != null;
    }

    @Deprecated
    public boolean hasStableInsets() {
        return !this.mImpl.j().equals(androidx.core.graphics.i.f2544a);
    }

    @Deprecated
    public boolean hasSystemWindowInsets() {
        return !this.mImpl.l().equals(androidx.core.graphics.i.f2544a);
    }

    public int hashCode() {
        k kVar = this.mImpl;
        if (kVar == null) {
            return 0;
        }
        return kVar.hashCode();
    }

    @NonNull
    public WindowInsetsCompat inset(@NonNull androidx.core.graphics.i iVar) {
        return inset(iVar.f2545b, iVar.f2546c, iVar.f2547d, iVar.f2548e);
    }

    public boolean isConsumed() {
        return this.mImpl.o();
    }

    public boolean isRound() {
        return this.mImpl.p();
    }

    public boolean isVisible(int i2) {
        return this.mImpl.q(i2);
    }

    @NonNull
    @Deprecated
    public WindowInsetsCompat replaceSystemWindowInsets(int i2, int i3, int i4, int i5) {
        return new Builder(this).setSystemWindowInsets(androidx.core.graphics.i.d(i2, i3, i4, i5)).build();
    }

    /* access modifiers changed from: package-private */
    public void setOverriddenInsets(androidx.core.graphics.i[] iVarArr) {
        this.mImpl.r(iVarArr);
    }

    /* access modifiers changed from: package-private */
    public void setRootViewData(@NonNull androidx.core.graphics.i iVar) {
        this.mImpl.s(iVar);
    }

    /* access modifiers changed from: package-private */
    public void setRootWindowInsets(@Nullable WindowInsetsCompat windowInsetsCompat) {
        this.mImpl.t(windowInsetsCompat);
    }

    /* access modifiers changed from: package-private */
    public void setStableInsets(@Nullable androidx.core.graphics.i iVar) {
        this.mImpl.u(iVar);
    }

    @Nullable
    @RequiresApi(20)
    public WindowInsets toWindowInsets() {
        k kVar = this.mImpl;
        if (kVar instanceof f) {
            return ((f) kVar).i;
        }
        return null;
    }

    @RequiresApi(api = 20)
    private static class b extends e {

        /* renamed from: c  reason: collision with root package name */
        private static Field f2905c;

        /* renamed from: d  reason: collision with root package name */
        private static boolean f2906d;

        /* renamed from: e  reason: collision with root package name */
        private static Constructor<WindowInsets> f2907e;
        private static boolean f;
        private WindowInsets g;
        private androidx.core.graphics.i h;

        b() {
            this.g = l();
        }

        @Nullable
        private static WindowInsets l() {
            if (!f2906d) {
                try {
                    f2905c = WindowInsets.class.getDeclaredField("CONSUMED");
                } catch (ReflectiveOperationException e2) {
                    Log.i(WindowInsetsCompat.TAG, "Could not retrieve WindowInsets.CONSUMED field", e2);
                }
                f2906d = true;
            }
            Field field = f2905c;
            if (field != null) {
                try {
                    WindowInsets windowInsets = (WindowInsets) field.get(null);
                    if (windowInsets != null) {
                        return new WindowInsets(windowInsets);
                    }
                } catch (ReflectiveOperationException e3) {
                    Log.i(WindowInsetsCompat.TAG, "Could not get value from WindowInsets.CONSUMED field", e3);
                }
            }
            if (!f) {
                try {
                    f2907e = WindowInsets.class.getConstructor(Rect.class);
                } catch (ReflectiveOperationException e4) {
                    Log.i(WindowInsetsCompat.TAG, "Could not retrieve WindowInsets(Rect) constructor", e4);
                }
                f = true;
            }
            Constructor<WindowInsets> constructor = f2907e;
            if (constructor != null) {
                try {
                    return constructor.newInstance(new Rect());
                } catch (ReflectiveOperationException e5) {
                    Log.i(WindowInsetsCompat.TAG, "Could not invoke WindowInsets(Rect) constructor", e5);
                }
            }
            return null;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        @NonNull
        public WindowInsetsCompat b() {
            a();
            WindowInsetsCompat windowInsetsCompat = WindowInsetsCompat.toWindowInsetsCompat(this.g);
            windowInsetsCompat.setOverriddenInsets(this.f2910b);
            windowInsetsCompat.setStableInsets(this.h);
            return windowInsetsCompat;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void g(@Nullable androidx.core.graphics.i iVar) {
            this.h = iVar;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void i(@NonNull androidx.core.graphics.i iVar) {
            WindowInsets windowInsets = this.g;
            if (windowInsets != null) {
                this.g = windowInsets.replaceSystemWindowInsets(iVar.f2545b, iVar.f2546c, iVar.f2547d, iVar.f2548e);
            }
        }

        b(@NonNull WindowInsetsCompat windowInsetsCompat) {
            super(windowInsetsCompat);
            this.g = windowInsetsCompat.toWindowInsets();
        }
    }

    @RequiresApi(api = 29)
    private static class c extends e {

        /* renamed from: c  reason: collision with root package name */
        final WindowInsets.Builder f2908c;

        c() {
            this.f2908c = new WindowInsets.Builder();
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        @NonNull
        public WindowInsetsCompat b() {
            a();
            WindowInsetsCompat windowInsetsCompat = WindowInsetsCompat.toWindowInsetsCompat(this.f2908c.build());
            windowInsetsCompat.setOverriddenInsets(this.f2910b);
            return windowInsetsCompat;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void c(@Nullable DisplayCutoutCompat displayCutoutCompat) {
            this.f2908c.setDisplayCutout(displayCutoutCompat != null ? displayCutoutCompat.unwrap() : null);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void f(@NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setMandatorySystemGestureInsets(iVar.h());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void g(@NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setStableInsets(iVar.h());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void h(@NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setSystemGestureInsets(iVar.h());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void i(@NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setSystemWindowInsets(iVar.h());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.e
        public void j(@NonNull androidx.core.graphics.i iVar) {
            this.f2908c.setTappableElementInsets(iVar.h());
        }

        c(@NonNull WindowInsetsCompat windowInsetsCompat) {
            super(windowInsetsCompat);
            WindowInsets.Builder builder;
            WindowInsets windowInsets = windowInsetsCompat.toWindowInsets();
            if (windowInsets != null) {
                builder = new WindowInsets.Builder(windowInsets);
            } else {
                builder = new WindowInsets.Builder();
            }
            this.f2908c = builder;
        }
    }

    @RequiresApi(21)
    private static class g extends f {
        private androidx.core.graphics.i n = null;

        g(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsets windowInsets) {
            super(windowInsetsCompat, windowInsets);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public WindowInsetsCompat b() {
            return WindowInsetsCompat.toWindowInsetsCompat(this.i.consumeStableInsets());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public WindowInsetsCompat c() {
            return WindowInsetsCompat.toWindowInsetsCompat(this.i.consumeSystemWindowInsets());
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public final androidx.core.graphics.i j() {
            if (this.n == null) {
                this.n = androidx.core.graphics.i.d(this.i.getStableInsetLeft(), this.i.getStableInsetTop(), this.i.getStableInsetRight(), this.i.getStableInsetBottom());
            }
            return this.n;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        public boolean o() {
            return this.i.isConsumed();
        }

        @Override // androidx.core.view.WindowInsetsCompat.k
        public void u(@Nullable androidx.core.graphics.i iVar) {
            this.n = iVar;
        }

        g(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull g gVar) {
            super(windowInsetsCompat, gVar);
            this.n = gVar.n;
        }
    }

    @NonNull
    @RequiresApi(20)
    public static WindowInsetsCompat toWindowInsetsCompat(@NonNull WindowInsets windowInsets, @Nullable View view) {
        WindowInsetsCompat windowInsetsCompat = new WindowInsetsCompat((WindowInsets) m.g(windowInsets));
        if (view != null && view.isAttachedToWindow()) {
            windowInsetsCompat.setRootWindowInsets(ViewCompat.getRootWindowInsets(view));
            windowInsetsCompat.copyRootViewBounds(view.getRootView());
        }
        return windowInsetsCompat;
    }

    @NonNull
    public WindowInsetsCompat inset(@IntRange(from = 0) int i2, @IntRange(from = 0) int i3, @IntRange(from = 0) int i4, @IntRange(from = 0) int i5) {
        return this.mImpl.n(i2, i3, i4, i5);
    }

    /* access modifiers changed from: private */
    @RequiresApi(20)
    public static class f extends k {

        /* renamed from: c  reason: collision with root package name */
        private static boolean f2911c;

        /* renamed from: d  reason: collision with root package name */
        private static Method f2912d;

        /* renamed from: e  reason: collision with root package name */
        private static Class<?> f2913e;
        private static Class<?> f;
        private static Field g;
        private static Field h;
        @NonNull
        final WindowInsets i;
        private androidx.core.graphics.i[] j;
        private androidx.core.graphics.i k;
        private WindowInsetsCompat l;
        androidx.core.graphics.i m;

        f(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsets windowInsets) {
            super(windowInsetsCompat);
            this.k = null;
            this.i = windowInsets;
        }

        @SuppressLint({"PrivateApi"})
        private static void A() {
            try {
                f2912d = View.class.getDeclaredMethod("getViewRootImpl", new Class[0]);
                f2913e = Class.forName("android.view.ViewRootImpl");
                Class<?> cls = Class.forName("android.view.View$AttachInfo");
                f = cls;
                g = cls.getDeclaredField("mVisibleInsets");
                h = f2913e.getDeclaredField("mAttachInfo");
                g.setAccessible(true);
                h.setAccessible(true);
            } catch (ReflectiveOperationException e2) {
                Log.e(WindowInsetsCompat.TAG, "Failed to get visible insets. (Reflection error). " + e2.getMessage(), e2);
            }
            f2911c = true;
        }

        @NonNull
        @SuppressLint({"WrongConstant"})
        private androidx.core.graphics.i v(int i2, boolean z) {
            androidx.core.graphics.i iVar = androidx.core.graphics.i.f2544a;
            for (int i3 = 1; i3 <= 256; i3 <<= 1) {
                if ((i2 & i3) != 0) {
                    iVar = androidx.core.graphics.i.b(iVar, w(i3, z));
                }
            }
            return iVar;
        }

        private androidx.core.graphics.i x() {
            WindowInsetsCompat windowInsetsCompat = this.l;
            if (windowInsetsCompat != null) {
                return windowInsetsCompat.getStableInsets();
            }
            return androidx.core.graphics.i.f2544a;
        }

        @Nullable
        private androidx.core.graphics.i y(@NonNull View view) {
            if (Build.VERSION.SDK_INT < 30) {
                if (!f2911c) {
                    A();
                }
                Method method = f2912d;
                if (!(method == null || f == null || g == null)) {
                    try {
                        Object invoke = method.invoke(view, new Object[0]);
                        if (invoke == null) {
                            Log.w(WindowInsetsCompat.TAG, "Failed to get visible insets. getViewRootImpl() returned null from the provided view. This means that the view is either not attached or the method has been overridden", new NullPointerException());
                            return null;
                        }
                        Rect rect = (Rect) g.get(h.get(invoke));
                        if (rect != null) {
                            return androidx.core.graphics.i.e(rect);
                        }
                        return null;
                    } catch (ReflectiveOperationException e2) {
                        Log.e(WindowInsetsCompat.TAG, "Failed to get visible insets. (Reflection error). " + e2.getMessage(), e2);
                    }
                }
                return null;
            }
            throw new UnsupportedOperationException("getVisibleInsets() should not be called on API >= 30. Use WindowInsets.isVisible() instead.");
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        public void d(@NonNull View view) {
            androidx.core.graphics.i y = y(view);
            if (y == null) {
                y = androidx.core.graphics.i.f2544a;
            }
            s(y);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        public void e(@NonNull WindowInsetsCompat windowInsetsCompat) {
            windowInsetsCompat.setRootWindowInsets(this.l);
            windowInsetsCompat.setRootViewData(this.m);
        }

        @Override // androidx.core.view.WindowInsetsCompat.k
        public boolean equals(Object obj) {
            if (!super.equals(obj)) {
                return false;
            }
            return Objects.equals(this.m, ((f) obj).m);
        }

        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public androidx.core.graphics.i g(int i2) {
            return v(i2, false);
        }

        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public androidx.core.graphics.i h(int i2) {
            return v(i2, true);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public final androidx.core.graphics.i l() {
            if (this.k == null) {
                this.k = androidx.core.graphics.i.d(this.i.getSystemWindowInsetLeft(), this.i.getSystemWindowInsetTop(), this.i.getSystemWindowInsetRight(), this.i.getSystemWindowInsetBottom());
            }
            return this.k;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public WindowInsetsCompat n(int i2, int i3, int i4, int i5) {
            Builder builder = new Builder(WindowInsetsCompat.toWindowInsetsCompat(this.i));
            builder.setSystemWindowInsets(WindowInsetsCompat.insetInsets(l(), i2, i3, i4, i5));
            builder.setStableInsets(WindowInsetsCompat.insetInsets(j(), i2, i3, i4, i5));
            return builder.build();
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        public boolean p() {
            return this.i.isRound();
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @SuppressLint({"WrongConstant"})
        public boolean q(int i2) {
            for (int i3 = 1; i3 <= 256; i3 <<= 1) {
                if ((i2 & i3) != 0 && !z(i3)) {
                    return false;
                }
            }
            return true;
        }

        @Override // androidx.core.view.WindowInsetsCompat.k
        public void r(androidx.core.graphics.i[] iVarArr) {
            this.j = iVarArr;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        public void s(@NonNull androidx.core.graphics.i iVar) {
            this.m = iVar;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        public void t(@Nullable WindowInsetsCompat windowInsetsCompat) {
            this.l = windowInsetsCompat;
        }

        /* access modifiers changed from: protected */
        @NonNull
        public androidx.core.graphics.i w(int i2, boolean z) {
            int i3;
            DisplayCutoutCompat displayCutoutCompat;
            if (i2 != 1) {
                androidx.core.graphics.i iVar = null;
                if (i2 != 2) {
                    if (i2 == 8) {
                        androidx.core.graphics.i[] iVarArr = this.j;
                        if (iVarArr != null) {
                            iVar = iVarArr[Type.indexOf(8)];
                        }
                        if (iVar != null) {
                            return iVar;
                        }
                        androidx.core.graphics.i l2 = l();
                        androidx.core.graphics.i x = x();
                        int i4 = l2.f2548e;
                        if (i4 > x.f2548e) {
                            return androidx.core.graphics.i.d(0, 0, 0, i4);
                        }
                        androidx.core.graphics.i iVar2 = this.m;
                        if (iVar2 == null || iVar2.equals(androidx.core.graphics.i.f2544a) || (i3 = this.m.f2548e) <= x.f2548e) {
                            return androidx.core.graphics.i.f2544a;
                        }
                        return androidx.core.graphics.i.d(0, 0, 0, i3);
                    } else if (i2 == 16) {
                        return k();
                    } else {
                        if (i2 == 32) {
                            return i();
                        }
                        if (i2 == 64) {
                            return m();
                        }
                        if (i2 != 128) {
                            return androidx.core.graphics.i.f2544a;
                        }
                        WindowInsetsCompat windowInsetsCompat = this.l;
                        if (windowInsetsCompat != null) {
                            displayCutoutCompat = windowInsetsCompat.getDisplayCutout();
                        } else {
                            displayCutoutCompat = f();
                        }
                        if (displayCutoutCompat != null) {
                            return androidx.core.graphics.i.d(displayCutoutCompat.getSafeInsetLeft(), displayCutoutCompat.getSafeInsetTop(), displayCutoutCompat.getSafeInsetRight(), displayCutoutCompat.getSafeInsetBottom());
                        }
                        return androidx.core.graphics.i.f2544a;
                    }
                } else if (z) {
                    androidx.core.graphics.i x2 = x();
                    androidx.core.graphics.i j2 = j();
                    return androidx.core.graphics.i.d(Math.max(x2.f2545b, j2.f2545b), 0, Math.max(x2.f2547d, j2.f2547d), Math.max(x2.f2548e, j2.f2548e));
                } else {
                    androidx.core.graphics.i l3 = l();
                    WindowInsetsCompat windowInsetsCompat2 = this.l;
                    if (windowInsetsCompat2 != null) {
                        iVar = windowInsetsCompat2.getStableInsets();
                    }
                    int i5 = l3.f2548e;
                    if (iVar != null) {
                        i5 = Math.min(i5, iVar.f2548e);
                    }
                    return androidx.core.graphics.i.d(l3.f2545b, 0, l3.f2547d, i5);
                }
            } else if (z) {
                return androidx.core.graphics.i.d(0, Math.max(x().f2546c, l().f2546c), 0, 0);
            } else {
                return androidx.core.graphics.i.d(0, l().f2546c, 0, 0);
            }
        }

        /* access modifiers changed from: protected */
        public boolean z(int i2) {
            if (!(i2 == 1 || i2 == 2)) {
                if (i2 == 4) {
                    return false;
                }
                if (!(i2 == 8 || i2 == 128)) {
                    return true;
                }
            }
            return !w(i2, false).equals(androidx.core.graphics.i.f2544a);
        }

        f(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull f fVar) {
            this(windowInsetsCompat, new WindowInsets(fVar.i));
        }
    }

    @RequiresApi(29)
    private static class i extends h {
        private androidx.core.graphics.i o = null;
        private androidx.core.graphics.i p = null;
        private androidx.core.graphics.i q = null;

        i(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull WindowInsets windowInsets) {
            super(windowInsetsCompat, windowInsets);
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public androidx.core.graphics.i i() {
            if (this.p == null) {
                this.p = androidx.core.graphics.i.g(this.i.getMandatorySystemGestureInsets());
            }
            return this.p;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public androidx.core.graphics.i k() {
            if (this.o == null) {
                this.o = androidx.core.graphics.i.g(this.i.getSystemGestureInsets());
            }
            return this.o;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k
        @NonNull
        public androidx.core.graphics.i m() {
            if (this.q == null) {
                this.q = androidx.core.graphics.i.g(this.i.getTappableElementInsets());
            }
            return this.q;
        }

        /* access modifiers changed from: package-private */
        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.f
        @NonNull
        public WindowInsetsCompat n(int i, int i2, int i3, int i4) {
            return WindowInsetsCompat.toWindowInsetsCompat(this.i.inset(i, i2, i3, i4));
        }

        @Override // androidx.core.view.WindowInsetsCompat.k, androidx.core.view.WindowInsetsCompat.g
        public void u(@Nullable androidx.core.graphics.i iVar) {
        }

        i(@NonNull WindowInsetsCompat windowInsetsCompat, @NonNull i iVar) {
            super(windowInsetsCompat, iVar);
        }
    }

    @NonNull
    @Deprecated
    public WindowInsetsCompat replaceSystemWindowInsets(@NonNull Rect rect) {
        return new Builder(this).setSystemWindowInsets(androidx.core.graphics.i.e(rect)).build();
    }

    public static final class Builder {
        private final e mImpl;

        public Builder() {
            int i = Build.VERSION.SDK_INT;
            if (i >= 30) {
                this.mImpl = new d();
            } else if (i >= 29) {
                this.mImpl = new c();
            } else if (i >= 20) {
                this.mImpl = new b();
            } else {
                this.mImpl = new e();
            }
        }

        @NonNull
        public WindowInsetsCompat build() {
            return this.mImpl.b();
        }

        @NonNull
        public Builder setDisplayCutout(@Nullable DisplayCutoutCompat displayCutoutCompat) {
            this.mImpl.c(displayCutoutCompat);
            return this;
        }

        @NonNull
        public Builder setInsets(int i, @NonNull androidx.core.graphics.i iVar) {
            this.mImpl.d(i, iVar);
            return this;
        }

        @NonNull
        public Builder setInsetsIgnoringVisibility(int i, @NonNull androidx.core.graphics.i iVar) {
            this.mImpl.e(i, iVar);
            return this;
        }

        @NonNull
        @Deprecated
        public Builder setMandatorySystemGestureInsets(@NonNull androidx.core.graphics.i iVar) {
            this.mImpl.f(iVar);
            return this;
        }

        @NonNull
        @Deprecated
        public Builder setStableInsets(@NonNull androidx.core.graphics.i iVar) {
            this.mImpl.g(iVar);
            return this;
        }

        @NonNull
        @Deprecated
        public Builder setSystemGestureInsets(@NonNull androidx.core.graphics.i iVar) {
            this.mImpl.h(iVar);
            return this;
        }

        @NonNull
        @Deprecated
        public Builder setSystemWindowInsets(@NonNull androidx.core.graphics.i iVar) {
            this.mImpl.i(iVar);
            return this;
        }

        @NonNull
        @Deprecated
        public Builder setTappableElementInsets(@NonNull androidx.core.graphics.i iVar) {
            this.mImpl.j(iVar);
            return this;
        }

        @NonNull
        public Builder setVisible(int i, boolean z) {
            this.mImpl.k(i, z);
            return this;
        }

        public Builder(@NonNull WindowInsetsCompat windowInsetsCompat) {
            int i = Build.VERSION.SDK_INT;
            if (i >= 30) {
                this.mImpl = new d(windowInsetsCompat);
            } else if (i >= 29) {
                this.mImpl = new c(windowInsetsCompat);
            } else if (i >= 20) {
                this.mImpl = new b(windowInsetsCompat);
            } else {
                this.mImpl = new e(windowInsetsCompat);
            }
        }
    }

    public WindowInsetsCompat(@Nullable WindowInsetsCompat windowInsetsCompat) {
        if (windowInsetsCompat != null) {
            k kVar = windowInsetsCompat.mImpl;
            int i2 = Build.VERSION.SDK_INT;
            if (i2 >= 30 && (kVar instanceof j)) {
                this.mImpl = new j(this, (j) kVar);
            } else if (i2 >= 29 && (kVar instanceof i)) {
                this.mImpl = new i(this, (i) kVar);
            } else if (i2 >= 28 && (kVar instanceof h)) {
                this.mImpl = new h(this, (h) kVar);
            } else if (i2 >= 21 && (kVar instanceof g)) {
                this.mImpl = new g(this, (g) kVar);
            } else if (i2 < 20 || !(kVar instanceof f)) {
                this.mImpl = new k(this);
            } else {
                this.mImpl = new f(this, (f) kVar);
            }
            kVar.e(this);
            return;
        }
        this.mImpl = new k(this);
    }
}
