package com.blankj.utilcode.util;

import java.lang.reflect.AccessibleObject;
import java.lang.reflect.Constructor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.Member;
import java.lang.reflect.Method;
import java.lang.reflect.Modifier;
import java.lang.reflect.Proxy;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Map;

public final class ReflectUtils {

    /* renamed from: a  reason: collision with root package name */
    private final Class<?> f6550a;

    /* renamed from: b  reason: collision with root package name */
    private final Object f6551b;

    public static class ReflectException extends RuntimeException {
        private static final long serialVersionUID = 858774075258496016L;

        public ReflectException(String str) {
            super(str);
        }

        public ReflectException(String str, Throwable th) {
            super(str, th);
        }

        public ReflectException(Throwable th) {
            super(th);
        }
    }

    /* access modifiers changed from: package-private */
    public class a implements Comparator<Constructor<?>> {
        a() {
        }

        /* renamed from: a */
        public int compare(Constructor<?> constructor, Constructor<?> constructor2) {
            Class<?>[] parameterTypes = constructor.getParameterTypes();
            Class<?>[] parameterTypes2 = constructor2.getParameterTypes();
            int length = parameterTypes.length;
            for (int i = 0; i < length; i++) {
                if (!parameterTypes[i].equals(parameterTypes2[i])) {
                    return ReflectUtils.this.G(parameterTypes[i]).isAssignableFrom(ReflectUtils.this.G(parameterTypes2[i])) ? 1 : -1;
                }
            }
            return 0;
        }
    }

    /* access modifiers changed from: package-private */
    public class b implements Comparator<Method> {
        b() {
        }

        /* renamed from: a */
        public int compare(Method method, Method method2) {
            Class<?>[] parameterTypes = method.getParameterTypes();
            Class<?>[] parameterTypes2 = method2.getParameterTypes();
            int length = parameterTypes.length;
            for (int i = 0; i < length; i++) {
                if (!parameterTypes[i].equals(parameterTypes2[i])) {
                    return ReflectUtils.this.G(parameterTypes[i]).isAssignableFrom(ReflectUtils.this.G(parameterTypes2[i])) ? 1 : -1;
                }
            }
            return 0;
        }
    }

    class c implements InvocationHandler {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ boolean f6554a;

        c(boolean z) {
            this.f6554a = z;
        }

        @Override // java.lang.reflect.InvocationHandler
        public Object invoke(Object obj, Method method, Object[] objArr) {
            int i;
            String name = method.getName();
            try {
                return ReflectUtils.y(ReflectUtils.this.f6551b).q(name, objArr).j();
            } catch (ReflectException e2) {
                if (this.f6554a) {
                    Map map = (Map) ReflectUtils.this.f6551b;
                    if (objArr == null) {
                        i = 0;
                    } else {
                        i = objArr.length;
                    }
                    if (i == 0 && name.startsWith("get")) {
                        return map.get(ReflectUtils.v(name.substring(3)));
                    }
                    if (i == 0 && name.startsWith("is")) {
                        return map.get(ReflectUtils.v(name.substring(2)));
                    }
                    if (i == 1 && name.startsWith("set")) {
                        map.put(ReflectUtils.v(name.substring(3)), objArr[0]);
                        return null;
                    }
                }
                throw e2;
            }
        }
    }

    /* access modifiers changed from: private */
    public static class d {
        private d() {
        }
    }

    private ReflectUtils(Class<?> cls) {
        this(cls, cls);
    }

    public static ReflectUtils A(String str, ClassLoader classLoader) throws ReflectException {
        return x(i(str, classLoader));
    }

    private Method B(String str, Class<?>[] clsArr) throws NoSuchMethodException {
        Class<?> E = E();
        ArrayList arrayList = new ArrayList();
        Method[] methods = E.getMethods();
        for (Method method : methods) {
            if (n(method, str, clsArr)) {
                arrayList.add(method);
            }
        }
        if (!arrayList.isEmpty()) {
            D(arrayList);
            return arrayList.get(0);
        }
        do {
            Method[] declaredMethods = E.getDeclaredMethods();
            for (Method method2 : declaredMethods) {
                if (n(method2, str, clsArr)) {
                    arrayList.add(method2);
                }
            }
            if (!arrayList.isEmpty()) {
                D(arrayList);
                return arrayList.get(0);
            }
            E = E.getSuperclass();
        } while (E != null);
        throw new NoSuchMethodException("No similar method " + str + " with params " + Arrays.toString(clsArr) + " could be found on type " + E() + ".");
    }

    private void C(List<Constructor<?>> list) {
        Collections.sort(list, new a());
    }

    private void D(List<Method> list) {
        Collections.sort(list, new b());
    }

    private Class<?> E() {
        return this.f6550a;
    }

    private Object F(Object obj) {
        return obj instanceof ReflectUtils ? ((ReflectUtils) obj).j() : obj;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private Class<?> G(Class<?> cls) {
        if (cls == null) {
            return null;
        }
        if (!cls.isPrimitive()) {
            return cls;
        }
        if (Boolean.TYPE == cls) {
            return Boolean.class;
        }
        if (Integer.TYPE == cls) {
            return Integer.class;
        }
        if (Long.TYPE == cls) {
            return Long.class;
        }
        if (Short.TYPE == cls) {
            return Short.class;
        }
        if (Byte.TYPE == cls) {
            return Byte.class;
        }
        if (Double.TYPE == cls) {
            return Double.class;
        }
        if (Float.TYPE == cls) {
            return Float.class;
        }
        if (Character.TYPE == cls) {
            return Character.class;
        }
        return Void.TYPE == cls ? Void.class : cls;
    }

    private <T extends AccessibleObject> T d(T t) {
        if (t == null) {
            return null;
        }
        if (t instanceof Member) {
            Member member = (Member) t;
            if (Modifier.isPublic(member.getModifiers()) && Modifier.isPublic(member.getDeclaringClass().getModifiers())) {
                return t;
            }
        }
        if (!t.isAccessible()) {
            t.setAccessible(true);
        }
        return t;
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:14:0x0009 */
    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:1:0x0004 */
    /* JADX DEBUG: Multi-variable search result rejected for r2v0, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r2v1, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r2v2, resolved type: java.lang.String */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r2v6, types: [java.lang.reflect.Method] */
    /* JADX WARNING: Can't wrap try/catch for region: R(4:4|5|12|6) */
    /* JADX WARNING: Code restructure failed: missing block: B:11:0x001a, code lost:
        throw new java.lang.NoSuchMethodException();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:6:0x000d, code lost:
        return r0.getDeclaredMethod(r2, r3);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:7:0x000e, code lost:
        r0 = r0.getSuperclass();
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0012, code lost:
        if (r0 != null) goto L_0x0009;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:4:0x0009 */
    private Method e(String str, Class<?>[] clsArr) throws NoSuchMethodException {
        Class<?> E = E();
        str = E.getMethod(str, clsArr);
        return str;
    }

    private static Class<?> h(String str) {
        try {
            return Class.forName(str);
        } catch (ClassNotFoundException e2) {
            throw new ReflectException(e2);
        }
    }

    private static Class<?> i(String str, ClassLoader classLoader) {
        try {
            return Class.forName(str, true, classLoader);
        } catch (ClassNotFoundException e2) {
            throw new ReflectException(e2);
        }
    }

    private Field k(String str) {
        Class<?> E = E();
        try {
            return (Field) d(E.getField(str));
        } catch (NoSuchFieldException e2) {
            do {
                try {
                    return (Field) d(E.getDeclaredField(str));
                } catch (NoSuchFieldException unused) {
                    E = E.getSuperclass();
                    if (E != null) {
                        throw new ReflectException(e2);
                    }
                }
            } while (E != null);
            throw new ReflectException(e2);
        }
    }

    private Class<?>[] l(Object... objArr) {
        if (objArr == null) {
            return new Class[0];
        }
        Class<?>[] clsArr = new Class[objArr.length];
        for (int i = 0; i < objArr.length; i++) {
            Object obj = objArr[i];
            clsArr[i] = obj == null ? d.class : obj.getClass();
        }
        return clsArr;
    }

    private Field m(String str) throws IllegalAccessException {
        Field k = k(str);
        if ((k.getModifiers() & 16) == 16) {
            try {
                Field declaredField = Field.class.getDeclaredField("modifiers");
                declaredField.setAccessible(true);
                declaredField.setInt(k, k.getModifiers() & -17);
            } catch (NoSuchFieldException unused) {
                k.setAccessible(true);
            }
        }
        return k;
    }

    private boolean n(Method method, String str, Class<?>[] clsArr) {
        return method.getName().equals(str) && o(method.getParameterTypes(), clsArr);
    }

    private boolean o(Class<?>[] clsArr, Class<?>[] clsArr2) {
        if (clsArr.length != clsArr2.length) {
            return false;
        }
        for (int i = 0; i < clsArr2.length; i++) {
            if (!(clsArr2[i] == d.class || G(clsArr[i]).isAssignableFrom(G(clsArr2[i])))) {
                return false;
            }
        }
        return true;
    }

    private ReflectUtils r(Method method, Object obj, Object... objArr) {
        try {
            d(method);
            if (method.getReturnType() != Void.TYPE) {
                return y(method.invoke(obj, objArr));
            }
            method.invoke(obj, objArr);
            return y(obj);
        } catch (Exception e2) {
            throw new ReflectException(e2);
        }
    }

    private ReflectUtils t(Constructor<?> constructor, Object... objArr) {
        try {
            return new ReflectUtils(constructor.getDeclaringClass(), ((Constructor) d(constructor)).newInstance(objArr));
        } catch (Exception e2) {
            throw new ReflectException(e2);
        }
    }

    /* access modifiers changed from: private */
    public static String v(String str) {
        int length = str.length();
        if (length == 0) {
            return "";
        }
        if (length == 1) {
            return str.toLowerCase();
        }
        return str.substring(0, 1).toLowerCase() + str.substring(1);
    }

    public static ReflectUtils x(Class<?> cls) throws ReflectException {
        return new ReflectUtils(cls);
    }

    public static ReflectUtils y(Object obj) throws ReflectException {
        return new ReflectUtils(obj == null ? Object.class : obj.getClass(), obj);
    }

    public static ReflectUtils z(String str) throws ReflectException {
        return x(h(str));
    }

    public boolean equals(Object obj) {
        return (obj instanceof ReflectUtils) && this.f6551b.equals(((ReflectUtils) obj).j());
    }

    public ReflectUtils f(String str) {
        try {
            Field m = m(str);
            return new ReflectUtils(m.getType(), m.get(this.f6551b));
        } catch (IllegalAccessException e2) {
            throw new ReflectException(e2);
        }
    }

    public ReflectUtils g(String str, Object obj) {
        try {
            m(str).set(this.f6551b, F(obj));
            return this;
        } catch (Exception e2) {
            throw new ReflectException(e2);
        }
    }

    public int hashCode() {
        return this.f6551b.hashCode();
    }

    public <T> T j() {
        return (T) this.f6551b;
    }

    public ReflectUtils p(String str) throws ReflectException {
        return q(str, new Object[0]);
    }

    /* JADX DEBUG: Failed to insert an additional move for type inference into block B:1:0x0004 */
    /* JADX DEBUG: Multi-variable search result rejected for r4v0, resolved type: java.lang.String */
    /* JADX DEBUG: Multi-variable search result rejected for r4v1, resolved type: java.lang.String */
    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r4v5, types: [com.blankj.utilcode.util.ReflectUtils] */
    /* JADX WARNING: Can't wrap try/catch for region: R(3:4|5|6) */
    /* JADX WARNING: Code restructure failed: missing block: B:6:0x0019, code lost:
        return r(B(r4, r0), r3.f6551b, r5);
     */
    /* JADX WARNING: Code restructure failed: missing block: B:7:0x001a, code lost:
        r4 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:9:0x0020, code lost:
        throw new com.blankj.utilcode.util.ReflectUtils.ReflectException(r4);
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:4:0x000f */
    public ReflectUtils q(String str, Object... objArr) throws ReflectException {
        Class<?>[] l = l(objArr);
        str = r(e(str, l), this.f6551b, objArr);
        return str;
    }

    public ReflectUtils s() {
        return u(new Object[0]);
    }

    public String toString() {
        return this.f6551b.toString();
    }

    public ReflectUtils u(Object... objArr) {
        Class<?>[] l = l(objArr);
        try {
            return t(E().getDeclaredConstructor(l), objArr);
        } catch (NoSuchMethodException e2) {
            ArrayList arrayList = new ArrayList();
            Constructor<?>[] declaredConstructors = E().getDeclaredConstructors();
            for (Constructor<?> constructor : declaredConstructors) {
                if (o(constructor.getParameterTypes(), l)) {
                    arrayList.add(constructor);
                }
            }
            if (!arrayList.isEmpty()) {
                C(arrayList);
                return t(arrayList.get(0), objArr);
            }
            throw new ReflectException(e2);
        }
    }

    public <P> P w(Class<P> cls) {
        c cVar = new c(this.f6551b instanceof Map);
        return (P) Proxy.newProxyInstance(cls.getClassLoader(), new Class[]{cls}, cVar);
    }

    private ReflectUtils(Class<?> cls, Object obj) {
        this.f6550a = cls;
        this.f6551b = obj;
    }
}
