package com.google.android.exoplayer2.mediacodec;

import android.annotation.SuppressLint;
import android.annotation.TargetApi;
import android.media.MediaCodecInfo;
import android.media.MediaCodecList;
import android.text.TextUtils;
import android.util.Log;
import android.util.Pair;
import android.util.SparseIntArray;
import androidx.annotation.Nullable;
import com.google.android.exoplayer2.util.b0;
import com.google.android.exoplayer2.util.n;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

@SuppressLint({"InlinedApi"})
@TargetApi(16)
public final class MediaCodecUtil {

    /* renamed from: a  reason: collision with root package name */
    private static final String f8545a = "MediaCodecUtil";

    /* renamed from: b  reason: collision with root package name */
    private static final String f8546b = "OMX.google.raw.decoder";

    /* renamed from: c  reason: collision with root package name */
    private static final String f8547c = "OMX.MTK.AUDIO.DECODER.RAW";

    /* renamed from: d  reason: collision with root package name */
    private static final a f8548d = a.u(f8546b);

    /* renamed from: e  reason: collision with root package name */
    private static final Pattern f8549e = Pattern.compile("^\\D?(\\d+)$");
    private static final HashMap<b, List<a>> f = new HashMap<>();
    private static final SparseIntArray g;
    private static final SparseIntArray h;
    private static final String i = "avc1";
    private static final String j = "avc2";
    private static final Map<String, Integer> k;
    private static final String l = "hev1";
    private static final String m = "hvc1";
    private static int n = -1;

    public static class DecoderQueryException extends Exception {
        private DecoderQueryException(Throwable th) {
            super("Failed to query underlying media codecs", th);
        }
    }

    /* access modifiers changed from: private */
    public static final class b {

        /* renamed from: a  reason: collision with root package name */
        public final String f8550a;

        /* renamed from: b  reason: collision with root package name */
        public final boolean f8551b;

        public b(String str, boolean z) {
            this.f8550a = str;
            this.f8551b = z;
        }

        public boolean equals(@Nullable Object obj) {
            if (this == obj) {
                return true;
            }
            if (obj == null || obj.getClass() != b.class) {
                return false;
            }
            b bVar = (b) obj;
            if (!TextUtils.equals(this.f8550a, bVar.f8550a) || this.f8551b != bVar.f8551b) {
                return false;
            }
            return true;
        }

        public int hashCode() {
            String str = this.f8550a;
            return (((str == null ? 0 : str.hashCode()) + 31) * 31) + (this.f8551b ? 1231 : 1237);
        }
    }

    /* access modifiers changed from: private */
    public interface c {
        MediaCodecInfo a(int i);

        boolean b(String str, MediaCodecInfo.CodecCapabilities codecCapabilities);

        int c();

        boolean d();
    }

    /* access modifiers changed from: private */
    public static final class d implements c {
        private d() {
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public MediaCodecInfo a(int i) {
            return MediaCodecList.getCodecInfoAt(i);
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public boolean b(String str, MediaCodecInfo.CodecCapabilities codecCapabilities) {
            return n.h.equals(str);
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public int c() {
            return MediaCodecList.getCodecCount();
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public boolean d() {
            return false;
        }
    }

    /* access modifiers changed from: private */
    @TargetApi(21)
    public static final class e implements c {

        /* renamed from: a  reason: collision with root package name */
        private final int f8552a;

        /* renamed from: b  reason: collision with root package name */
        private MediaCodecInfo[] f8553b;

        public e(boolean z) {
            this.f8552a = z ? 1 : 0;
        }

        private void e() {
            if (this.f8553b == null) {
                this.f8553b = new MediaCodecList(this.f8552a).getCodecInfos();
            }
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public MediaCodecInfo a(int i) {
            e();
            return this.f8553b[i];
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public boolean b(String str, MediaCodecInfo.CodecCapabilities codecCapabilities) {
            return codecCapabilities.isFeatureSupported("secure-playback");
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public int c() {
            e();
            return this.f8553b.length;
        }

        @Override // com.google.android.exoplayer2.mediacodec.MediaCodecUtil.c
        public boolean d() {
            return true;
        }
    }

    static {
        SparseIntArray sparseIntArray = new SparseIntArray();
        g = sparseIntArray;
        sparseIntArray.put(66, 1);
        sparseIntArray.put(77, 2);
        sparseIntArray.put(88, 4);
        sparseIntArray.put(100, 8);
        SparseIntArray sparseIntArray2 = new SparseIntArray();
        h = sparseIntArray2;
        sparseIntArray2.put(10, 1);
        sparseIntArray2.put(11, 4);
        sparseIntArray2.put(12, 8);
        sparseIntArray2.put(13, 16);
        sparseIntArray2.put(20, 32);
        sparseIntArray2.put(21, 64);
        sparseIntArray2.put(22, 128);
        sparseIntArray2.put(30, 256);
        sparseIntArray2.put(31, 512);
        sparseIntArray2.put(32, 1024);
        sparseIntArray2.put(40, 2048);
        sparseIntArray2.put(41, 4096);
        sparseIntArray2.put(42, 8192);
        sparseIntArray2.put(50, 16384);
        sparseIntArray2.put(51, 32768);
        sparseIntArray2.put(52, 65536);
        HashMap hashMap = new HashMap();
        k = hashMap;
        hashMap.put("L30", 1);
        hashMap.put("L60", 4);
        hashMap.put("L63", 16);
        hashMap.put("L90", 64);
        hashMap.put("L93", 256);
        hashMap.put("L120", 1024);
        hashMap.put("L123", 4096);
        hashMap.put("L150", 16384);
        hashMap.put("L153", 65536);
        hashMap.put("L156", 262144);
        hashMap.put("L180", 1048576);
        hashMap.put("L183", 4194304);
        hashMap.put("L186", 16777216);
        hashMap.put("H30", 2);
        hashMap.put("H60", 8);
        hashMap.put("H63", 32);
        hashMap.put("H90", 128);
        hashMap.put("H93", 512);
        hashMap.put("H120", 2048);
        hashMap.put("H123", 8192);
        hashMap.put("H150", 32768);
        hashMap.put("H153", 131072);
        hashMap.put("H156", 524288);
        hashMap.put("H180", 2097152);
        hashMap.put("H183", 8388608);
        hashMap.put("H186", 33554432);
    }

    private MediaCodecUtil() {
    }

    private static void a(List<a> list) {
        if (b0.f9571a < 26) {
            if (list.size() > 1 && f8547c.equals(list.get(0).f8556c)) {
                for (int i2 = 1; i2 < list.size(); i2++) {
                    a aVar = list.get(i2);
                    if (f8546b.equals(aVar.f8556c)) {
                        list.remove(i2);
                        list.add(0, aVar);
                        return;
                    }
                }
            }
        }
    }

    private static int b(int i2) {
        if (i2 == 1 || i2 == 2) {
            return 25344;
        }
        switch (i2) {
            case 8:
            case 16:
            case 32:
                return 101376;
            case 64:
                return 202752;
            case 128:
            case 256:
                return 414720;
            case 512:
                return 921600;
            case 1024:
                return 1310720;
            case 2048:
            case 4096:
                return 2097152;
            case 8192:
                return 2228224;
            case 16384:
                return 5652480;
            case 32768:
            case 65536:
                return 9437184;
            default:
                return -1;
        }
    }

    private static boolean c(String str) {
        if (b0.f9571a <= 22) {
            String str2 = b0.f9574d;
            if (("ODROID-XU3".equals(str2) || "Nexus 10".equals(str2)) && ("OMX.Exynos.AVC.Decoder".equals(str) || "OMX.Exynos.AVC.Decoder.secure".equals(str))) {
                return true;
            }
        }
        return false;
    }

    private static Pair<Integer, Integer> d(String str, String[] strArr) {
        Integer num;
        Integer num2;
        if (strArr.length < 2) {
            Log.w(f8545a, "Ignoring malformed AVC codec string: " + str);
            return null;
        }
        try {
            if (strArr[1].length() == 6) {
                num2 = Integer.valueOf(Integer.parseInt(strArr[1].substring(0, 2), 16));
                num = Integer.valueOf(Integer.parseInt(strArr[1].substring(4), 16));
            } else if (strArr.length >= 3) {
                Integer valueOf = Integer.valueOf(Integer.parseInt(strArr[1]));
                num = Integer.valueOf(Integer.parseInt(strArr[2]));
                num2 = valueOf;
            } else {
                Log.w(f8545a, "Ignoring malformed AVC codec string: " + str);
                return null;
            }
            int i2 = g.get(num2.intValue(), -1);
            if (i2 == -1) {
                Log.w(f8545a, "Unknown AVC profile: " + num2);
                return null;
            }
            int i3 = h.get(num.intValue(), -1);
            if (i3 != -1) {
                return new Pair<>(Integer.valueOf(i2), Integer.valueOf(i3));
            }
            Log.w(f8545a, "Unknown AVC level: " + num);
            return null;
        } catch (NumberFormatException unused) {
            Log.w(f8545a, "Ignoring malformed AVC codec string: " + str);
            return null;
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:16:0x0041, code lost:
        if (r3.equals(com.google.android.exoplayer2.mediacodec.MediaCodecUtil.i) == false) goto L_0x0018;
     */
    public static Pair<Integer, Integer> e(String str) {
        if (str == null) {
            return null;
        }
        String[] split = str.split("\\.");
        char c2 = 0;
        String str2 = split[0];
        str2.hashCode();
        switch (str2.hashCode()) {
            case 3006243:
                break;
            case 3006244:
                if (str2.equals(j)) {
                    c2 = 1;
                    break;
                }
                c2 = 65535;
                break;
            case 3199032:
                if (str2.equals(l)) {
                    c2 = 2;
                    break;
                }
                c2 = 65535;
                break;
            case 3214780:
                if (str2.equals(m)) {
                    c2 = 3;
                    break;
                }
                c2 = 65535;
                break;
            default:
                c2 = 65535;
                break;
        }
        switch (c2) {
            case 0:
            case 1:
                return d(str, split);
            case 2:
            case 3:
                return i(str, split);
            default:
                return null;
        }
    }

    @Nullable
    public static a f(String str, boolean z) throws DecoderQueryException {
        List<a> g2 = g(str, z);
        if (g2.isEmpty()) {
            return null;
        }
        return g2.get(0);
    }

    public static synchronized List<a> g(String str, boolean z) throws DecoderQueryException {
        synchronized (MediaCodecUtil.class) {
            b bVar = new b(str, z);
            HashMap<b, List<a>> hashMap = f;
            List<a> list = hashMap.get(bVar);
            if (list != null) {
                return list;
            }
            int i2 = b0.f9571a;
            c eVar = i2 >= 21 ? new e(z) : new d();
            ArrayList<a> h2 = h(bVar, eVar, str);
            if (z && h2.isEmpty() && 21 <= i2 && i2 <= 23) {
                eVar = new d();
                h2 = h(bVar, eVar, str);
                if (!h2.isEmpty()) {
                    Log.w(f8545a, "MediaCodecList API didn't list secure decoder for: " + str + ". Assuming: " + h2.get(0).f8556c);
                }
            }
            if (n.B.equals(str)) {
                h2.addAll(h(new b(n.A, bVar.f8551b), eVar, str));
            }
            a(h2);
            List<a> unmodifiableList = Collections.unmodifiableList(h2);
            hashMap.put(bVar, unmodifiableList);
            return unmodifiableList;
        }
    }

    private static ArrayList<a> h(b bVar, c cVar, String str) throws DecoderQueryException {
        int i2;
        Exception e2;
        c cVar2 = cVar;
        try {
            ArrayList<a> arrayList = new ArrayList<>();
            String str2 = bVar.f8550a;
            int c2 = cVar.c();
            boolean d2 = cVar.d();
            int i3 = 0;
            while (i3 < c2) {
                MediaCodecInfo a2 = cVar2.a(i3);
                String name = a2.getName();
                if (k(a2, name, d2, str)) {
                    String[] supportedTypes = a2.getSupportedTypes();
                    int length = supportedTypes.length;
                    int i4 = 0;
                    while (i4 < length) {
                        String str3 = supportedTypes[i4];
                        if (str3.equalsIgnoreCase(str2)) {
                            try {
                                MediaCodecInfo.CodecCapabilities capabilitiesForType = a2.getCapabilitiesForType(str3);
                                boolean b2 = cVar2.b(str2, capabilitiesForType);
                                boolean c3 = c(name);
                                if (d2) {
                                    i2 = c2;
                                    try {
                                        if (bVar.f8551b != b2) {
                                            if (!d2 || bVar.f8551b) {
                                                if (!d2 && b2) {
                                                    arrayList.add(a.t(name + ".secure", str2, capabilitiesForType, c3, true));
                                                    return arrayList;
                                                }
                                            }
                                        }
                                    } catch (Exception e3) {
                                        e2 = e3;
                                        if (b0.f9571a <= 23) {
                                        }
                                        Log.e(f8545a, "Failed to query codec " + name + " (" + str3 + ")");
                                        throw e2;
                                    }
                                } else {
                                    i2 = c2;
                                    if (!d2) {
                                    }
                                    arrayList.add(a.t(name + ".secure", str2, capabilitiesForType, c3, true));
                                    return arrayList;
                                }
                                arrayList.add(a.t(name, str2, capabilitiesForType, c3, false));
                            } catch (Exception e4) {
                                e2 = e4;
                                i2 = c2;
                                if (b0.f9571a <= 23 || arrayList.isEmpty()) {
                                    Log.e(f8545a, "Failed to query codec " + name + " (" + str3 + ")");
                                    throw e2;
                                }
                                Log.e(f8545a, "Skipping codec " + name + " (failed to query capabilities)");
                                i4++;
                                cVar2 = cVar;
                                c2 = i2;
                            }
                        } else {
                            i2 = c2;
                        }
                        i4++;
                        cVar2 = cVar;
                        c2 = i2;
                    }
                    continue;
                }
                i3++;
                cVar2 = cVar;
                c2 = c2;
            }
            return arrayList;
        } catch (Exception e5) {
            throw new DecoderQueryException(e5);
        }
    }

    private static Pair<Integer, Integer> i(String str, String[] strArr) {
        int i2;
        if (strArr.length < 4) {
            Log.w(f8545a, "Ignoring malformed HEVC codec string: " + str);
            return null;
        }
        Matcher matcher = f8549e.matcher(strArr[1]);
        if (!matcher.matches()) {
            Log.w(f8545a, "Ignoring malformed HEVC codec string: " + str);
            return null;
        }
        String group = matcher.group(1);
        if ("1".equals(group)) {
            i2 = 1;
        } else if ("2".equals(group)) {
            i2 = 2;
        } else {
            Log.w(f8545a, "Unknown HEVC profile string: " + group);
            return null;
        }
        Integer num = k.get(strArr[3]);
        if (num != null) {
            return new Pair<>(Integer.valueOf(i2), num);
        }
        Log.w(f8545a, "Unknown HEVC level string: " + matcher.group(1));
        return null;
    }

    public static a j() {
        return f8548d;
    }

    private static boolean k(MediaCodecInfo mediaCodecInfo, String str, boolean z, String str2) {
        if (mediaCodecInfo.isEncoder() || (!z && str.endsWith(".secure"))) {
            return false;
        }
        int i2 = b0.f9571a;
        if (i2 < 21 && ("CIPAACDecoder".equals(str) || "CIPMP3Decoder".equals(str) || "CIPVorbisDecoder".equals(str) || "CIPAMRNBDecoder".equals(str) || "AACDecoder".equals(str) || "MP3Decoder".equals(str))) {
            return false;
        }
        if (i2 < 18 && "OMX.SEC.MP3.Decoder".equals(str)) {
            return false;
        }
        if (i2 < 18 && "OMX.MTK.AUDIO.DECODER.AAC".equals(str)) {
            String str3 = b0.f9572b;
            if ("a70".equals(str3) || ("Xiaomi".equals(b0.f9573c) && str3.startsWith("HM"))) {
                return false;
            }
        }
        if (i2 == 16 && "OMX.qcom.audio.decoder.mp3".equals(str)) {
            String str4 = b0.f9572b;
            if ("dlxu".equals(str4) || "protou".equals(str4) || "ville".equals(str4) || "villeplus".equals(str4) || "villec2".equals(str4) || str4.startsWith("gee") || "C6602".equals(str4) || "C6603".equals(str4) || "C6606".equals(str4) || "C6616".equals(str4) || "L36h".equals(str4) || "SO-02E".equals(str4)) {
                return false;
            }
        }
        if (i2 == 16 && "OMX.qcom.audio.decoder.aac".equals(str)) {
            String str5 = b0.f9572b;
            if ("C1504".equals(str5) || "C1505".equals(str5) || "C1604".equals(str5) || "C1605".equals(str5)) {
                return false;
            }
        }
        if (i2 < 24 && (("OMX.SEC.aac.dec".equals(str) || "OMX.Exynos.AAC.Decoder".equals(str)) && "samsung".equals(b0.f9573c))) {
            String str6 = b0.f9572b;
            if (str6.startsWith("zeroflte") || str6.startsWith("zerolte") || str6.startsWith("zenlte") || "SC-05G".equals(str6) || "marinelteatt".equals(str6) || "404SC".equals(str6) || "SC-04G".equals(str6) || "SCV31".equals(str6)) {
                return false;
            }
        }
        if (i2 <= 19 && "OMX.SEC.vp8.dec".equals(str) && "samsung".equals(b0.f9573c)) {
            String str7 = b0.f9572b;
            if (str7.startsWith("d2") || str7.startsWith("serrano") || str7.startsWith("jflte") || str7.startsWith("santos") || str7.startsWith("t0")) {
                return false;
            }
        }
        if (i2 <= 19 && b0.f9572b.startsWith("jflte") && "OMX.qcom.video.decoder.vp8".equals(str)) {
            return false;
        }
        if (!n.B.equals(str2) || !"OMX.MTK.AUDIO.DECODER.DSPAC3".equals(str)) {
            return true;
        }
        return false;
    }

    public static int l() throws DecoderQueryException {
        if (n == -1) {
            int i2 = 0;
            a f2 = f(n.h, false);
            if (f2 != null) {
                MediaCodecInfo.CodecProfileLevel[] f3 = f2.f();
                int length = f3.length;
                int i3 = 0;
                while (i2 < length) {
                    i3 = Math.max(b(f3[i2].level), i3);
                    i2++;
                }
                i2 = Math.max(i3, b0.f9571a >= 21 ? 345600 : 172800);
            }
            n = i2;
        }
        return n;
    }

    public static void m(String str, boolean z) {
        try {
            g(str, z);
        } catch (DecoderQueryException e2) {
            Log.e(f8545a, "Codec warming failed", e2);
        }
    }
}
