package com.google.android.exoplayer2.source.hls.playlist;

import android.net.Uri;
import android.util.Base64;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.Format;
import com.google.android.exoplayer2.ParserException;
import com.google.android.exoplayer2.drm.DrmInitData;
import com.google.android.exoplayer2.source.UnrecognizedInputFormatException;
import com.google.android.exoplayer2.source.hls.playlist.HlsMediaPlaylist;
import com.google.android.exoplayer2.source.hls.playlist.b;
import com.google.android.exoplayer2.upstream.s;
import com.google.android.exoplayer2.util.b0;
import com.google.android.exoplayer2.util.n;
import com.ibm.icu.impl.locale.f;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.UnsupportedEncodingException;
import java.util.ArrayDeque;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Queue;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/* compiled from: HlsPlaylistParser */
public final class d implements s.a<c> {
    private static final String A = "SAMPLE-AES-CENC";
    private static final String B = "SAMPLE-AES-CTR";
    private static final String C = "identity";
    private static final String D = "urn:uuid:edef8ba9-79d6-4ace-a3c8-27dcd51d21ed";
    private static final String E = "com.widevine";
    private static final String F = "YES";
    private static final String G = "NO";
    private static final String H = "CLOSED-CAPTIONS=NONE";
    private static final Pattern I = Pattern.compile("AVERAGE-BANDWIDTH=(\\d+)\\b");
    private static final Pattern J = Pattern.compile("AUDIO=\"(.+?)\"");
    private static final Pattern K = Pattern.compile("[^-]BANDWIDTH=(\\d+)\\b");
    private static final Pattern L = Pattern.compile("CODECS=\"(.+?)\"");
    private static final Pattern M = Pattern.compile("RESOLUTION=(\\d+x\\d+)");
    private static final Pattern N = Pattern.compile("FRAME-RATE=([\\d\\.]+)\\b");
    private static final Pattern O = Pattern.compile("#EXT-X-TARGETDURATION:(\\d+)\\b");
    private static final Pattern P = Pattern.compile("#EXT-X-VERSION:(\\d+)\\b");
    private static final Pattern Q = Pattern.compile("#EXT-X-PLAYLIST-TYPE:(.+)\\b");
    private static final Pattern R = Pattern.compile("#EXT-X-MEDIA-SEQUENCE:(\\d+)\\b");
    private static final Pattern S = Pattern.compile("#EXTINF:([\\d\\.]+)\\b");
    private static final Pattern T = Pattern.compile("TIME-OFFSET=(-?[\\d\\.]+)\\b");
    private static final Pattern U = Pattern.compile("#EXT-X-BYTERANGE:(\\d+(?:@\\d+)?)\\b");
    private static final Pattern V = Pattern.compile("BYTERANGE=\"(\\d+(?:@\\d+)?)\\b\"");
    private static final Pattern W = Pattern.compile("METHOD=(NONE|AES-128|SAMPLE-AES|SAMPLE-AES-CENC|SAMPLE-AES-CTR)\\s*(,|$)");
    private static final Pattern X = Pattern.compile("KEYFORMAT=\"(.+?)\"");
    private static final Pattern Y = Pattern.compile("URI=\"(.+?)\"");
    private static final Pattern Z = Pattern.compile("IV=([^,.*]+)");

    /* renamed from: a  reason: collision with root package name */
    private static final String f9016a = "#EXTM3U";
    private static final Pattern a0 = Pattern.compile("TYPE=(AUDIO|VIDEO|SUBTITLES|CLOSED-CAPTIONS)");

    /* renamed from: b  reason: collision with root package name */
    private static final String f9017b = "#EXT";
    private static final Pattern b0 = Pattern.compile("LANGUAGE=\"(.+?)\"");

    /* renamed from: c  reason: collision with root package name */
    private static final String f9018c = "#EXT-X-VERSION";
    private static final Pattern c0 = Pattern.compile("NAME=\"(.+?)\"");

    /* renamed from: d  reason: collision with root package name */
    private static final String f9019d = "#EXT-X-PLAYLIST-TYPE";
    private static final Pattern d0 = Pattern.compile("GROUP-ID=\"(.+?)\"");

    /* renamed from: e  reason: collision with root package name */
    private static final String f9020e = "#EXT-X-STREAM-INF";
    private static final Pattern e0 = Pattern.compile("INSTREAM-ID=\"((?:CC|SERVICE)\\d+)\"");
    private static final String f = "#EXT-X-MEDIA";
    private static final Pattern f0 = c("AUTOSELECT");
    private static final String g = "#EXT-X-TARGETDURATION";
    private static final Pattern g0 = c("DEFAULT");
    private static final String h = "#EXT-X-DISCONTINUITY";
    private static final Pattern h0 = c("FORCED");
    private static final String i = "#EXT-X-DISCONTINUITY-SEQUENCE";
    private static final String j = "#EXT-X-PROGRAM-DATE-TIME";
    private static final String k = "#EXT-X-MAP";
    private static final String l = "#EXT-X-INDEPENDENT-SEGMENTS";
    private static final String m = "#EXTINF";
    private static final String n = "#EXT-X-MEDIA-SEQUENCE";
    private static final String o = "#EXT-X-START";
    private static final String p = "#EXT-X-ENDLIST";
    private static final String q = "#EXT-X-KEY";
    private static final String r = "#EXT-X-BYTERANGE";
    private static final String s = "#EXT-X-GAP";
    private static final String t = "AUDIO";
    private static final String u = "VIDEO";
    private static final String v = "SUBTITLES";
    private static final String w = "CLOSED-CAPTIONS";
    private static final String x = "NONE";
    private static final String y = "AES-128";
    private static final String z = "SAMPLE-AES";

    /* access modifiers changed from: private */
    /* compiled from: HlsPlaylistParser */
    public static class a {

        /* renamed from: a  reason: collision with root package name */
        private final BufferedReader f9021a;

        /* renamed from: b  reason: collision with root package name */
        private final Queue<String> f9022b;

        /* renamed from: c  reason: collision with root package name */
        private String f9023c;

        public a(Queue<String> queue, BufferedReader bufferedReader) {
            this.f9022b = queue;
            this.f9021a = bufferedReader;
        }

        public boolean a() throws IOException {
            String trim;
            if (this.f9023c != null) {
                return true;
            }
            if (!this.f9022b.isEmpty()) {
                this.f9023c = this.f9022b.poll();
                return true;
            }
            do {
                String readLine = this.f9021a.readLine();
                this.f9023c = readLine;
                if (readLine == null) {
                    return false;
                }
                trim = readLine.trim();
                this.f9023c = trim;
            } while (trim.isEmpty());
            return true;
        }

        public String b() throws IOException {
            if (!a()) {
                return null;
            }
            String str = this.f9023c;
            this.f9023c = null;
            return str;
        }
    }

    private static boolean b(BufferedReader bufferedReader) throws IOException {
        int read = bufferedReader.read();
        if (read == 239) {
            if (!(bufferedReader.read() == 187 && bufferedReader.read() == 191)) {
                return false;
            }
            read = bufferedReader.read();
        }
        int o2 = o(bufferedReader, true, read);
        for (int i2 = 0; i2 < 7; i2++) {
            if (o2 != f9016a.charAt(i2)) {
                return false;
            }
            o2 = bufferedReader.read();
        }
        return b0.Y(o(bufferedReader, false, o2));
    }

    private static Pattern c(String str) {
        return Pattern.compile(str + "=(" + G + "|" + F + ")");
    }

    private static boolean e(String str, Pattern pattern, boolean z2) {
        Matcher matcher = pattern.matcher(str);
        return matcher.find() ? matcher.group(1).equals(F) : z2;
    }

    private static double f(String str, Pattern pattern) throws ParserException {
        return Double.parseDouble(m(str, pattern));
    }

    private static int g(String str, Pattern pattern) throws ParserException {
        return Integer.parseInt(m(str, pattern));
    }

    private static long h(String str, Pattern pattern) throws ParserException {
        return Long.parseLong(m(str, pattern));
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private static b i(a aVar, String str) throws IOException {
        char c2;
        String str2;
        int i2;
        int i3;
        int i4;
        int i5;
        HashSet hashSet = new HashSet();
        HashMap hashMap = new HashMap();
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        ArrayList arrayList3 = new ArrayList();
        ArrayList arrayList4 = new ArrayList();
        ArrayList arrayList5 = new ArrayList();
        boolean z2 = false;
        while (aVar.a()) {
            String b2 = aVar.b();
            if (b2.startsWith(f9017b)) {
                arrayList5.add(b2);
            }
            if (b2.startsWith(f)) {
                arrayList4.add(b2);
            } else if (b2.startsWith(f9020e)) {
                z2 |= b2.contains(H);
                int g2 = g(b2, K);
                String k2 = k(b2, I);
                if (k2 != null) {
                    g2 = Integer.parseInt(k2);
                }
                String k3 = k(b2, L);
                String k4 = k(b2, M);
                if (k4 != null) {
                    String[] split = k4.split(f.f14028c);
                    int parseInt = Integer.parseInt(split[0]);
                    int parseInt2 = Integer.parseInt(split[1]);
                    if (parseInt <= 0 || parseInt2 <= 0) {
                        i5 = -1;
                        parseInt2 = -1;
                    } else {
                        i5 = parseInt;
                    }
                    i4 = i5;
                    i3 = parseInt2;
                } else {
                    i4 = -1;
                    i3 = -1;
                }
                String k5 = k(b2, N);
                float parseFloat = k5 != null ? Float.parseFloat(k5) : -1.0f;
                String k6 = k(b2, J);
                if (!(k6 == null || k3 == null)) {
                    hashMap.put(k6, b0.A(k3, 1));
                }
                String b3 = aVar.b();
                if (hashSet.add(b3)) {
                    arrayList.add(new b.a(b3, Format.x(Integer.toString(arrayList.size()), n.T, null, k3, g2, i4, i3, parseFloat, null, 0)));
                }
            }
        }
        Format format = null;
        int i6 = 0;
        ArrayList arrayList6 = null;
        while (i6 < arrayList4.size()) {
            String str3 = (String) arrayList4.get(i6);
            int l2 = l(str3);
            String k7 = k(str3, Y);
            String m2 = m(str3, c0);
            String k8 = k(str3, b0);
            String k9 = k(str3, d0);
            String m3 = m(str3, a0);
            m3.hashCode();
            switch (m3.hashCode()) {
                case -959297733:
                    if (m3.equals(v)) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -333210994:
                    if (m3.equals(w)) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 62628790:
                    if (m3.equals(t)) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    arrayList3.add(new b.a(k7, Format.q(m2, n.T, n.O, null, -1, l2, k8)));
                    break;
                case 1:
                    String m4 = m(str3, e0);
                    if (m4.startsWith("CC")) {
                        i2 = Integer.parseInt(m4.substring(2));
                        str2 = n.W;
                    } else {
                        i2 = Integer.parseInt(m4.substring(7));
                        str2 = n.X;
                    }
                    if (arrayList6 == null) {
                        arrayList6 = new ArrayList();
                    }
                    arrayList6.add(Format.r(m2, null, str2, null, -1, l2, k8, i2));
                    break;
                case 2:
                    String str4 = (String) hashMap.get(k9);
                    Format i7 = Format.i(m2, n.T, str4 != null ? n.d(str4) : null, str4, -1, -1, -1, null, l2, k8);
                    if (k7 != null) {
                        arrayList2.add(new b.a(k7, i7));
                        break;
                    } else {
                        format = i7;
                        break;
                    }
            }
            i6++;
            arrayList4 = arrayList4;
        }
        return new b(str, arrayList5, arrayList, arrayList2, arrayList3, format, z2 ? Collections.emptyList() : arrayList6);
    }

    private static HlsMediaPlaylist j(a aVar, String str) throws IOException {
        DrmInitData.SchemeData n2;
        ArrayList arrayList = new ArrayList();
        ArrayList arrayList2 = new ArrayList();
        long j2 = -9223372036854775807L;
        long j3 = -9223372036854775807L;
        int i2 = 0;
        int i3 = 0;
        long j4 = 0;
        boolean z2 = false;
        int i4 = 0;
        long j5 = 0;
        int i5 = 1;
        boolean z3 = false;
        boolean z4 = false;
        DrmInitData drmInitData = null;
        long j6 = 0;
        long j7 = 0;
        boolean z5 = false;
        long j8 = -1;
        long j9 = 0;
        String str2 = null;
        String str3 = null;
        HlsMediaPlaylist.a aVar2 = null;
        loop0:
        while (true) {
            long j10 = 0;
            while (aVar.a()) {
                String b2 = aVar.b();
                if (b2.startsWith(f9017b)) {
                    arrayList2.add(b2);
                }
                if (b2.startsWith(f9019d)) {
                    String m2 = m(b2, Q);
                    if ("VOD".equals(m2)) {
                        i3 = 1;
                    } else if ("EVENT".equals(m2)) {
                        i3 = 2;
                    }
                } else if (b2.startsWith(o)) {
                    j2 = (long) (f(b2, T) * 1000000.0d);
                } else if (b2.startsWith(k)) {
                    String m3 = m(b2, Y);
                    String k2 = k(b2, V);
                    if (k2 != null) {
                        String[] split = k2.split("@");
                        j8 = Long.parseLong(split[0]);
                        if (split.length > 1) {
                            j6 = Long.parseLong(split[1]);
                        }
                    }
                    aVar2 = new HlsMediaPlaylist.a(m3, j6, j8);
                    j6 = 0;
                    j8 = -1;
                } else if (b2.startsWith(g)) {
                    j3 = 1000000 * ((long) g(b2, O));
                } else if (b2.startsWith(n)) {
                    j7 = h(b2, R);
                    j5 = j7;
                } else if (b2.startsWith(f9018c)) {
                    i5 = g(b2, P);
                } else if (b2.startsWith(m)) {
                    j10 = (long) (f(b2, S) * 1000000.0d);
                } else if (b2.startsWith(q)) {
                    String k3 = k(b2, W);
                    String k4 = k(b2, X);
                    if (!x.equals(k3)) {
                        String k5 = k(b2, Z);
                        if (C.equals(k4) || k4 == null) {
                            if (y.equals(k3)) {
                                str2 = m(b2, Y);
                                str3 = k5;
                            }
                        } else if (!(k3 == null || (n2 = n(b2, k4)) == null)) {
                            drmInitData = new DrmInitData((A.equals(k3) || B.equals(k3)) ? C.d1 : C.g1, n2);
                        }
                        str3 = k5;
                        str2 = null;
                    } else {
                        str2 = null;
                        str3 = null;
                    }
                } else if (b2.startsWith(r)) {
                    String[] split2 = m(b2, U).split("@");
                    j8 = Long.parseLong(split2[0]);
                    if (split2.length > 1) {
                        j6 = Long.parseLong(split2[1]);
                    }
                } else if (b2.startsWith(i)) {
                    i4 = Integer.parseInt(b2.substring(b2.indexOf(58) + 1));
                    z2 = true;
                } else if (b2.equals(h)) {
                    i2++;
                } else if (b2.startsWith(j)) {
                    if (j4 == 0) {
                        j4 = C.b(b0.e0(b2.substring(b2.indexOf(58) + 1))) - j9;
                    }
                } else if (b2.equals(s)) {
                    z5 = true;
                } else if (b2.equals(l)) {
                    z3 = true;
                } else if (b2.equals(p)) {
                    z4 = true;
                } else if (!b2.startsWith("#")) {
                    String hexString = str2 == null ? null : str3 != null ? str3 : Long.toHexString(j7);
                    long j11 = j7 + 1;
                    int i6 = (j8 > -1 ? 1 : (j8 == -1 ? 0 : -1));
                    if (i6 == 0) {
                        j6 = 0;
                    }
                    arrayList.add(new HlsMediaPlaylist.a(b2, aVar2, j10, i2, j9, str2, hexString, j6, j8, z5));
                    j9 += j10;
                    if (i6 != 0) {
                        j6 += j8;
                    }
                    j7 = j11;
                    z5 = false;
                    j8 = -1;
                }
            }
            break loop0;
        }
        return new HlsMediaPlaylist(i3, str, arrayList2, j2, j4, z2, i4, j5, i5, j3, z3, z4, j4 != 0, drmInitData, arrayList);
    }

    private static String k(String str, Pattern pattern) {
        Matcher matcher = pattern.matcher(str);
        if (matcher.find()) {
            return matcher.group(1);
        }
        return null;
    }

    private static int l(String str) {
        int i2 = 0;
        int i3 = (e(str, g0, false) ? 1 : 0) | (e(str, h0, false) ? 2 : 0);
        if (e(str, f0, false)) {
            i2 = 4;
        }
        return i3 | i2;
    }

    private static String m(String str, Pattern pattern) throws ParserException {
        Matcher matcher = pattern.matcher(str);
        if (matcher.find() && matcher.groupCount() == 1) {
            return matcher.group(1);
        }
        throw new ParserException("Couldn't match " + pattern.pattern() + " in " + str);
    }

    private static DrmInitData.SchemeData n(String str, String str2) throws ParserException {
        if (D.equals(str2)) {
            String m2 = m(str, Y);
            return new DrmInitData.SchemeData(C.k1, "video/mp4", Base64.decode(m2.substring(m2.indexOf(44)), 0));
        } else if (!E.equals(str2)) {
            return null;
        } else {
            try {
                return new DrmInitData.SchemeData(C.k1, "hls", str.getBytes("UTF-8"));
            } catch (UnsupportedEncodingException e2) {
                throw new ParserException(e2);
            }
        }
    }

    private static int o(BufferedReader bufferedReader, boolean z2, int i2) throws IOException {
        while (i2 != -1 && Character.isWhitespace(i2) && (z2 || !b0.Y(i2))) {
            i2 = bufferedReader.read();
        }
        return i2;
    }

    /* renamed from: d */
    public c a(Uri uri, InputStream inputStream) throws IOException {
        String trim;
        BufferedReader bufferedReader = new BufferedReader(new InputStreamReader(inputStream));
        ArrayDeque arrayDeque = new ArrayDeque();
        try {
            if (b(bufferedReader)) {
                while (true) {
                    String readLine = bufferedReader.readLine();
                    if (readLine != null) {
                        trim = readLine.trim();
                        if (!trim.isEmpty()) {
                            if (trim.startsWith(f9020e)) {
                                arrayDeque.add(trim);
                                b i2 = i(new a(arrayDeque, bufferedReader), uri.toString());
                                b0.k(bufferedReader);
                                return i2;
                            } else if (trim.startsWith(g) || trim.startsWith(n) || trim.startsWith(m) || trim.startsWith(q) || trim.startsWith(r) || trim.equals(h) || trim.equals(i) || trim.equals(p)) {
                                arrayDeque.add(trim);
                            } else {
                                arrayDeque.add(trim);
                            }
                        }
                    } else {
                        b0.k(bufferedReader);
                        throw new ParserException("Failed to parse the playlist, could not identify any tags.");
                    }
                }
                arrayDeque.add(trim);
                return j(new a(arrayDeque, bufferedReader), uri.toString());
            }
            throw new UnrecognizedInputFormatException("Input does not start with the #EXTM3U header.", uri);
        } finally {
            b0.k(bufferedReader);
        }
    }
}
