package com.google.android.exoplayer2.text.ttml;

import android.text.Layout;
import android.util.Log;
import com.google.android.exoplayer2.C;
import com.google.android.exoplayer2.text.SubtitleDecoderException;
import com.google.android.exoplayer2.util.b0;
import com.google.android.exoplayer2.util.c0;
import com.google.android.exoplayer2.util.e;
import com.ibm.icu.impl.number.Padder;
import com.ibm.icu.text.DateFormat;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.util.ArrayDeque;
import java.util.HashMap;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;
import org.xmlpull.v1.XmlPullParser;
import org.xmlpull.v1.XmlPullParserException;
import org.xmlpull.v1.XmlPullParserFactory;

/* compiled from: TtmlDecoder */
public final class a extends com.google.android.exoplayer2.text.a {
    private static final int A = 30;
    private static final b B = new b(30.0f, 1, 1);
    private static final C0226a C = new C0226a(32, 15);
    private static final String o = "TtmlDecoder";
    private static final String p = "http://www.w3.org/ns/ttml#parameter";
    private static final String q = "begin";
    private static final String r = "dur";
    private static final String s = "end";
    private static final String t = "style";
    private static final String u = "region";
    private static final Pattern v = Pattern.compile("^([0-9][0-9]+):([0-9][0-9]):([0-9][0-9])(?:(\\.[0-9]+)|:([0-9][0-9])(?:\\.([0-9]+))?)?$");
    private static final Pattern w = Pattern.compile("^([0-9]+(?:\\.[0-9]+)?)(h|m|s|ms|f|t)$");
    private static final Pattern x = Pattern.compile("^(([0-9]*.)?[0-9]+)(px|em|%)$");
    private static final Pattern y = Pattern.compile("^(\\d+\\.?\\d*?)% (\\d+\\.?\\d*?)%$");
    private static final Pattern z = Pattern.compile("^(\\d+) (\\d+)$");
    private final XmlPullParserFactory D;

    /* access modifiers changed from: private */
    /* renamed from: com.google.android.exoplayer2.text.ttml.a$a  reason: collision with other inner class name */
    /* compiled from: TtmlDecoder */
    public static final class C0226a {

        /* renamed from: a  reason: collision with root package name */
        final int f9234a;

        /* renamed from: b  reason: collision with root package name */
        final int f9235b;

        C0226a(int i, int i2) {
            this.f9234a = i;
            this.f9235b = i2;
        }
    }

    /* access modifiers changed from: private */
    /* compiled from: TtmlDecoder */
    public static final class b {

        /* renamed from: a  reason: collision with root package name */
        final float f9236a;

        /* renamed from: b  reason: collision with root package name */
        final int f9237b;

        /* renamed from: c  reason: collision with root package name */
        final int f9238c;

        b(float f, int i, int i2) {
            this.f9236a = f;
            this.f9237b = i;
            this.f9238c = i2;
        }
    }

    public a() {
        super(o);
        try {
            XmlPullParserFactory newInstance = XmlPullParserFactory.newInstance();
            this.D = newInstance;
            newInstance.setNamespaceAware(true);
        } catch (XmlPullParserException e2) {
            throw new RuntimeException("Couldn't create XmlPullParserFactory instance", e2);
        }
    }

    private TtmlStyle B(TtmlStyle ttmlStyle) {
        return ttmlStyle == null ? new TtmlStyle() : ttmlStyle;
    }

    private static boolean D(String str) {
        return str.equals(b.f9239a) || str.equals("head") || str.equals(b.f9241c) || str.equals(b.f9242d) || str.equals(b.f9243e) || str.equals(b.f) || str.equals(b.g) || str.equals("style") || str.equals(b.i) || str.equals(b.j) || str.equals("region") || str.equals(b.l) || str.equals(b.m) || str.equals(b.n) || str.equals(b.o);
    }

    private C0226a E(XmlPullParser xmlPullParser, C0226a aVar) throws SubtitleDecoderException {
        String attributeValue = xmlPullParser.getAttributeValue(p, "cellResolution");
        if (attributeValue == null) {
            return aVar;
        }
        Matcher matcher = z.matcher(attributeValue);
        if (!matcher.matches()) {
            Log.w(o, "Ignoring malformed cell resolution: " + attributeValue);
            return aVar;
        }
        try {
            int parseInt = Integer.parseInt(matcher.group(1));
            int parseInt2 = Integer.parseInt(matcher.group(2));
            if (parseInt != 0 && parseInt2 != 0) {
                return new C0226a(parseInt, parseInt2);
            }
            throw new SubtitleDecoderException("Invalid cell resolution " + parseInt + Padder.f14124a + parseInt2);
        } catch (NumberFormatException unused) {
            Log.w(o, "Ignoring malformed cell resolution: " + attributeValue);
            return aVar;
        }
    }

    private static void F(String str, TtmlStyle ttmlStyle) throws SubtitleDecoderException {
        Matcher matcher;
        String[] q0 = b0.q0(str, "\\s+");
        if (q0.length == 1) {
            matcher = x.matcher(str);
        } else if (q0.length == 2) {
            matcher = x.matcher(q0[1]);
            Log.w(o, "Multiple values in fontSize attribute. Picking the second value for vertical font size and ignoring the first.");
        } else {
            throw new SubtitleDecoderException("Invalid number of entries for fontSize: " + q0.length + ".");
        }
        if (matcher.matches()) {
            String group = matcher.group(3);
            group.hashCode();
            char c2 = 65535;
            switch (group.hashCode()) {
                case 37:
                    if (group.equals("%")) {
                        c2 = 0;
                        break;
                    }
                    break;
                case 3240:
                    if (group.equals("em")) {
                        c2 = 1;
                        break;
                    }
                    break;
                case 3592:
                    if (group.equals("px")) {
                        c2 = 2;
                        break;
                    }
                    break;
            }
            switch (c2) {
                case 0:
                    ttmlStyle.u(3);
                    break;
                case 1:
                    ttmlStyle.u(2);
                    break;
                case 2:
                    ttmlStyle.u(1);
                    break;
                default:
                    throw new SubtitleDecoderException("Invalid unit for fontSize: '" + group + "'.");
            }
            ttmlStyle.t(Float.valueOf(matcher.group(1)).floatValue());
            return;
        }
        throw new SubtitleDecoderException("Invalid expression for fontSize: '" + str + "'.");
    }

    private b G(XmlPullParser xmlPullParser) throws SubtitleDecoderException {
        String attributeValue = xmlPullParser.getAttributeValue(p, "frameRate");
        int parseInt = attributeValue != null ? Integer.parseInt(attributeValue) : 30;
        float f = 1.0f;
        String attributeValue2 = xmlPullParser.getAttributeValue(p, "frameRateMultiplier");
        if (attributeValue2 != null) {
            String[] q0 = b0.q0(attributeValue2, Padder.f14124a);
            if (q0.length == 2) {
                f = ((float) Integer.parseInt(q0[0])) / ((float) Integer.parseInt(q0[1]));
            } else {
                throw new SubtitleDecoderException("frameRateMultiplier doesn't have 2 parts");
            }
        }
        b bVar = B;
        int i = bVar.f9237b;
        String attributeValue3 = xmlPullParser.getAttributeValue(p, "subFrameRate");
        if (attributeValue3 != null) {
            i = Integer.parseInt(attributeValue3);
        }
        int i2 = bVar.f9238c;
        String attributeValue4 = xmlPullParser.getAttributeValue(p, "tickRate");
        if (attributeValue4 != null) {
            i2 = Integer.parseInt(attributeValue4);
        }
        return new b(((float) parseInt) * f, i, i2);
    }

    private Map<String, TtmlStyle> H(XmlPullParser xmlPullParser, Map<String, TtmlStyle> map, Map<String, c> map2, C0226a aVar) throws IOException, XmlPullParserException {
        c J;
        do {
            xmlPullParser.next();
            if (c0.f(xmlPullParser, "style")) {
                String a2 = c0.a(xmlPullParser, "style");
                TtmlStyle K = K(xmlPullParser, new TtmlStyle());
                if (a2 != null) {
                    for (String str : L(a2)) {
                        K.a(map.get(str));
                    }
                }
                if (K.g() != null) {
                    map.put(K.g(), K);
                }
            } else if (c0.f(xmlPullParser, "region") && (J = J(xmlPullParser, aVar)) != null) {
                map2.put(J.f9244a, J);
            }
        } while (!c0.d(xmlPullParser, "head"));
        return map;
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    private b I(XmlPullParser xmlPullParser, b bVar, Map<String, c> map, b bVar2) throws SubtitleDecoderException {
        long j;
        long j2;
        char c2;
        int attributeCount = xmlPullParser.getAttributeCount();
        TtmlStyle K = K(xmlPullParser, null);
        String[] strArr = null;
        String str = "";
        long j3 = C.f7870b;
        long j4 = C.f7870b;
        long j5 = C.f7870b;
        for (int i = 0; i < attributeCount; i++) {
            String attributeName = xmlPullParser.getAttributeName(i);
            String attributeValue = xmlPullParser.getAttributeValue(i);
            attributeName.hashCode();
            switch (attributeName.hashCode()) {
                case -934795532:
                    if (attributeName.equals("region")) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 99841:
                    if (attributeName.equals(r)) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 100571:
                    if (attributeName.equals("end")) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 93616297:
                    if (attributeName.equals(q)) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 109780401:
                    if (attributeName.equals("style")) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    if (map.containsKey(attributeValue)) {
                        str = attributeValue;
                        continue;
                    }
                case 1:
                    j5 = M(attributeValue, bVar2);
                    break;
                case 2:
                    j4 = M(attributeValue, bVar2);
                    break;
                case 3:
                    j3 = M(attributeValue, bVar2);
                    break;
                case 4:
                    String[] L = L(attributeValue);
                    if (L.length > 0) {
                        strArr = L;
                        break;
                    }
                    break;
            }
        }
        if (bVar != null) {
            long j6 = bVar.Q;
            j = C.f7870b;
            if (j6 != C.f7870b) {
                if (j3 != C.f7870b) {
                    j3 += j6;
                }
                if (j4 != C.f7870b) {
                    j4 += j6;
                }
            }
        } else {
            j = C.f7870b;
        }
        if (j4 == j) {
            if (j5 != j) {
                j2 = j3 + j5;
            } else if (bVar != null) {
                long j7 = bVar.R;
                if (j7 != j) {
                    j2 = j7;
                }
            }
            return b.c(xmlPullParser.getName(), j3, j2, K, strArr, str);
        }
        j2 = j4;
        return b.c(xmlPullParser.getName(), j3, j2, K, strArr, str);
    }

    private c J(XmlPullParser xmlPullParser, C0226a aVar) {
        float f;
        String a2 = c0.a(xmlPullParser, "id");
        if (a2 == null) {
            return null;
        }
        String a3 = c0.a(xmlPullParser, "origin");
        if (a3 != null) {
            Pattern pattern = y;
            Matcher matcher = pattern.matcher(a3);
            if (matcher.matches()) {
                int i = 1;
                try {
                    float parseFloat = Float.parseFloat(matcher.group(1)) / 100.0f;
                    float parseFloat2 = Float.parseFloat(matcher.group(2)) / 100.0f;
                    String a4 = c0.a(xmlPullParser, b.s);
                    if (a4 != null) {
                        Matcher matcher2 = pattern.matcher(a4);
                        if (matcher2.matches()) {
                            try {
                                float parseFloat3 = Float.parseFloat(matcher2.group(1)) / 100.0f;
                                float parseFloat4 = Float.parseFloat(matcher2.group(2)) / 100.0f;
                                String a5 = c0.a(xmlPullParser, b.t);
                                if (a5 != null) {
                                    String w0 = b0.w0(a5);
                                    w0.hashCode();
                                    if (w0.equals(b.J)) {
                                        f = parseFloat2 + (parseFloat4 / 2.0f);
                                    } else if (w0.equals("after")) {
                                        f = parseFloat2 + parseFloat4;
                                        i = 2;
                                    }
                                    return new c(a2, parseFloat, f, 0, i, parseFloat3, 1, 1.0f / ((float) aVar.f9235b));
                                }
                                f = parseFloat2;
                                i = 0;
                                return new c(a2, parseFloat, f, 0, i, parseFloat3, 1, 1.0f / ((float) aVar.f9235b));
                            } catch (NumberFormatException unused) {
                                Log.w(o, "Ignoring region with malformed extent: " + a3);
                                return null;
                            }
                        } else {
                            Log.w(o, "Ignoring region with unsupported extent: " + a3);
                            return null;
                        }
                    } else {
                        Log.w(o, "Ignoring region without an extent");
                        return null;
                    }
                } catch (NumberFormatException unused2) {
                    Log.w(o, "Ignoring region with malformed origin: " + a3);
                    return null;
                }
            } else {
                Log.w(o, "Ignoring region with unsupported origin: " + a3);
                return null;
            }
        } else {
            Log.w(o, "Ignoring region without an origin");
            return null;
        }
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:56:0x012e, code lost:
        if (r3.equals(com.google.android.exoplayer2.text.ttml.b.C) == false) goto L_0x0126;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:75:0x0194, code lost:
        if (r3.equals("start") == false) goto L_0x018c;
     */
    private TtmlStyle K(XmlPullParser xmlPullParser, TtmlStyle ttmlStyle) {
        char c2;
        int attributeCount = xmlPullParser.getAttributeCount();
        for (int i = 0; i < attributeCount; i++) {
            String attributeValue = xmlPullParser.getAttributeValue(i);
            String attributeName = xmlPullParser.getAttributeName(i);
            attributeName.hashCode();
            char c3 = 4;
            char c4 = 3;
            switch (attributeName.hashCode()) {
                case -1550943582:
                    if (attributeName.equals(b.v)) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1224696685:
                    if (attributeName.equals(b.x)) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -1065511464:
                    if (attributeName.equals(b.B)) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -879295043:
                    if (attributeName.equals(b.A)) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case -734428249:
                    if (attributeName.equals(b.y)) {
                        c2 = 4;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3355:
                    if (attributeName.equals("id")) {
                        c2 = 5;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 94842723:
                    if (attributeName.equals("color")) {
                        c2 = 6;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 365601008:
                    if (attributeName.equals(b.w)) {
                        c2 = 7;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 1287124693:
                    if (attributeName.equals(b.u)) {
                        c2 = '\b';
                        break;
                    }
                    c2 = 65535;
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    ttmlStyle = B(ttmlStyle).w(b.G.equalsIgnoreCase(attributeValue));
                    break;
                case 1:
                    ttmlStyle = B(ttmlStyle).s(attributeValue);
                    break;
                case 2:
                    String w0 = b0.w0(attributeValue);
                    w0.hashCode();
                    switch (w0.hashCode()) {
                        case -1364013995:
                            if (w0.equals(b.J)) {
                                c3 = 0;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case 100571:
                            if (w0.equals("end")) {
                                c3 = 1;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case 3317767:
                            if (w0.equals(b.I)) {
                                c3 = 2;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case 108511772:
                            if (w0.equals(b.K)) {
                                c3 = 3;
                                break;
                            }
                            c3 = 65535;
                            break;
                        case 109757538:
                            break;
                        default:
                            c3 = 65535;
                            break;
                    }
                    switch (c3) {
                        case 0:
                            ttmlStyle = B(ttmlStyle).y(Layout.Alignment.ALIGN_CENTER);
                            continue;
                        case 1:
                            ttmlStyle = B(ttmlStyle).y(Layout.Alignment.ALIGN_OPPOSITE);
                            continue;
                        case 2:
                            ttmlStyle = B(ttmlStyle).y(Layout.Alignment.ALIGN_NORMAL);
                            continue;
                        case 3:
                            ttmlStyle = B(ttmlStyle).y(Layout.Alignment.ALIGN_OPPOSITE);
                            continue;
                        case 4:
                            ttmlStyle = B(ttmlStyle).y(Layout.Alignment.ALIGN_NORMAL);
                            continue;
                    }
                case 3:
                    String w02 = b0.w0(attributeValue);
                    w02.hashCode();
                    switch (w02.hashCode()) {
                        case -1461280213:
                            if (w02.equals(b.F)) {
                                c4 = 0;
                                break;
                            }
                            c4 = 65535;
                            break;
                        case -1026963764:
                            if (w02.equals(b.E)) {
                                c4 = 1;
                                break;
                            }
                            c4 = 65535;
                            break;
                        case 913457136:
                            if (w02.equals(b.D)) {
                                c4 = 2;
                                break;
                            }
                            c4 = 65535;
                            break;
                        case 1679736913:
                            break;
                        default:
                            c4 = 65535;
                            break;
                    }
                    switch (c4) {
                        case 0:
                            ttmlStyle = B(ttmlStyle).z(false);
                            continue;
                        case 1:
                            ttmlStyle = B(ttmlStyle).z(true);
                            continue;
                        case 2:
                            ttmlStyle = B(ttmlStyle).x(false);
                            continue;
                        case 3:
                            ttmlStyle = B(ttmlStyle).x(true);
                            continue;
                    }
                case 4:
                    ttmlStyle = B(ttmlStyle).q(b.H.equalsIgnoreCase(attributeValue));
                    break;
                case 5:
                    if ("style".equals(xmlPullParser.getName())) {
                        ttmlStyle = B(ttmlStyle).v(attributeValue);
                        break;
                    } else {
                        break;
                    }
                case 6:
                    ttmlStyle = B(ttmlStyle);
                    try {
                        ttmlStyle.r(e.d(attributeValue));
                        break;
                    } catch (IllegalArgumentException unused) {
                        Log.w(o, "Failed parsing color value: " + attributeValue);
                        break;
                    }
                case 7:
                    try {
                        ttmlStyle = B(ttmlStyle);
                        F(attributeValue, ttmlStyle);
                        break;
                    } catch (SubtitleDecoderException unused2) {
                        Log.w(o, "Failed parsing fontSize value: " + attributeValue);
                        break;
                    }
                case '\b':
                    ttmlStyle = B(ttmlStyle);
                    try {
                        ttmlStyle.p(e.d(attributeValue));
                        break;
                    } catch (IllegalArgumentException unused3) {
                        Log.w(o, "Failed parsing background value: " + attributeValue);
                        break;
                    }
            }
        }
        return ttmlStyle;
    }

    private String[] L(String str) {
        String trim = str.trim();
        return trim.isEmpty() ? new String[0] : b0.q0(trim, "\\s+");
    }

    /* JADX INFO: Can't fix incorrect switch cases order, some code will duplicate */
    /* JADX WARNING: Code restructure failed: missing block: B:21:0x00a1, code lost:
        if (r13.equals(com.ibm.icu.text.DateFormat.MINUTE_SECOND) == false) goto L_0x0099;
     */
    private static long M(String str, b bVar) throws SubtitleDecoderException {
        double d2;
        double d3;
        Matcher matcher = v.matcher(str);
        char c2 = 4;
        if (matcher.matches()) {
            double parseLong = ((double) (Long.parseLong(matcher.group(1)) * 3600)) + ((double) (Long.parseLong(matcher.group(2)) * 60)) + ((double) Long.parseLong(matcher.group(3)));
            String group = matcher.group(4);
            double d4 = 0.0d;
            double parseDouble = parseLong + (group != null ? Double.parseDouble(group) : 0.0d);
            String group2 = matcher.group(5);
            double parseLong2 = parseDouble + (group2 != null ? (double) (((float) Long.parseLong(group2)) / bVar.f9236a) : 0.0d);
            String group3 = matcher.group(6);
            if (group3 != null) {
                d4 = (((double) Long.parseLong(group3)) / ((double) bVar.f9237b)) / ((double) bVar.f9236a);
            }
            return (long) ((parseLong2 + d4) * 1000000.0d);
        }
        Matcher matcher2 = w.matcher(str);
        if (matcher2.matches()) {
            double parseDouble2 = Double.parseDouble(matcher2.group(1));
            String group4 = matcher2.group(2);
            group4.hashCode();
            switch (group4.hashCode()) {
                case 102:
                    if (group4.equals("f")) {
                        c2 = 0;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 104:
                    if (group4.equals("h")) {
                        c2 = 1;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 109:
                    if (group4.equals(DateFormat.MINUTE)) {
                        c2 = 2;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 116:
                    if (group4.equals("t")) {
                        c2 = 3;
                        break;
                    }
                    c2 = 65535;
                    break;
                case 3494:
                    break;
                default:
                    c2 = 65535;
                    break;
            }
            switch (c2) {
                case 0:
                    d2 = (double) bVar.f9236a;
                    parseDouble2 /= d2;
                    return (long) (parseDouble2 * 1000000.0d);
                case 1:
                    d3 = 3600.0d;
                    parseDouble2 *= d3;
                    return (long) (parseDouble2 * 1000000.0d);
                case 2:
                    d3 = 60.0d;
                    parseDouble2 *= d3;
                    return (long) (parseDouble2 * 1000000.0d);
                case 3:
                    d2 = (double) bVar.f9238c;
                    parseDouble2 /= d2;
                    return (long) (parseDouble2 * 1000000.0d);
                case 4:
                    d2 = 1000.0d;
                    parseDouble2 /= d2;
                    return (long) (parseDouble2 * 1000000.0d);
                default:
                    return (long) (parseDouble2 * 1000000.0d);
            }
        } else {
            throw new SubtitleDecoderException("Malformed time expression: " + str);
        }
    }

    /* access modifiers changed from: protected */
    /* renamed from: C */
    public e y(byte[] bArr, int i, boolean z2) throws SubtitleDecoderException {
        try {
            XmlPullParser newPullParser = this.D.newPullParser();
            HashMap hashMap = new HashMap();
            HashMap hashMap2 = new HashMap();
            e eVar = null;
            hashMap2.put("", new c(null));
            int i2 = 0;
            newPullParser.setInput(new ByteArrayInputStream(bArr, 0, i), null);
            ArrayDeque arrayDeque = new ArrayDeque();
            b bVar = B;
            C0226a aVar = C;
            for (int eventType = newPullParser.getEventType(); eventType != 1; eventType = newPullParser.getEventType()) {
                b bVar2 = (b) arrayDeque.peek();
                if (i2 == 0) {
                    String name = newPullParser.getName();
                    if (eventType == 2) {
                        if (b.f9239a.equals(name)) {
                            bVar = G(newPullParser);
                            aVar = E(newPullParser, C);
                        }
                        if (!D(name)) {
                            Log.i(o, "Ignoring unsupported tag: " + newPullParser.getName());
                        } else if ("head".equals(name)) {
                            H(newPullParser, hashMap, hashMap2, aVar);
                        } else {
                            try {
                                b I = I(newPullParser, bVar2, hashMap2, bVar);
                                arrayDeque.push(I);
                                if (bVar2 != null) {
                                    bVar2.a(I);
                                }
                            } catch (SubtitleDecoderException e2) {
                                Log.w(o, "Suppressing parser error", e2);
                            }
                        }
                    } else if (eventType == 4) {
                        bVar2.a(b.d(newPullParser.getText()));
                    } else if (eventType == 3) {
                        if (newPullParser.getName().equals(b.f9239a)) {
                            eVar = new e((b) arrayDeque.peek(), hashMap, hashMap2);
                        }
                        arrayDeque.pop();
                    }
                    newPullParser.next();
                } else if (eventType != 2) {
                    if (eventType == 3) {
                        i2--;
                    }
                    newPullParser.next();
                }
                i2++;
                newPullParser.next();
            }
            return eVar;
        } catch (XmlPullParserException e3) {
            throw new SubtitleDecoderException("Unable to decode source", e3);
        } catch (IOException e4) {
            throw new IllegalStateException("Unexpected error when reading input.", e4);
        }
    }
}
