package com.google.android.exoplayer2.upstream.cache;

import androidx.annotation.Nullable;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.charset.Charset;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* compiled from: DefaultContentMetadata */
public final class l implements i {

    /* renamed from: b  reason: collision with root package name */
    public static final l f9462b = new l(Collections.emptyMap());

    /* renamed from: c  reason: collision with root package name */
    private static final int f9463c = 10485760;

    /* renamed from: d  reason: collision with root package name */
    private int f9464d;

    /* renamed from: e  reason: collision with root package name */
    private final Map<String, byte[]> f9465e;

    private l(Map<String, byte[]> map) {
        this.f9465e = Collections.unmodifiableMap(map);
    }

    private static void e(HashMap<String, byte[]> hashMap, Map<String, Object> map) {
        for (String str : map.keySet()) {
            byte[] h = h(map.get(str));
            if (h.length <= f9463c) {
                hashMap.put(str, h);
            } else {
                throw new IllegalArgumentException(String.format("The size of %s (%d) is greater than maximum allowed: %d", str, Integer.valueOf(h.length), Integer.valueOf((int) f9463c)));
            }
        }
    }

    private static Map<String, byte[]> f(Map<String, byte[]> map, k kVar) {
        HashMap hashMap = new HashMap(map);
        k(hashMap, kVar.c());
        e(hashMap, kVar.b());
        return hashMap;
    }

    private static byte[] h(Object obj) {
        if (obj instanceof Long) {
            return ByteBuffer.allocate(8).putLong(((Long) obj).longValue()).array();
        }
        if (obj instanceof String) {
            return ((String) obj).getBytes(Charset.forName("UTF-8"));
        }
        if (obj instanceof byte[]) {
            return (byte[]) obj;
        }
        throw new IllegalArgumentException();
    }

    private boolean i(Map<String, byte[]> map) {
        if (this.f9465e.size() != map.size()) {
            return false;
        }
        for (Map.Entry<String, byte[]> entry : this.f9465e.entrySet()) {
            if (!Arrays.equals(entry.getValue(), map.get(entry.getKey()))) {
                return false;
            }
        }
        return true;
    }

    public static l j(DataInputStream dataInputStream) throws IOException {
        int readInt = dataInputStream.readInt();
        HashMap hashMap = new HashMap();
        for (int i = 0; i < readInt; i++) {
            String readUTF = dataInputStream.readUTF();
            int readInt2 = dataInputStream.readInt();
            if (readInt2 < 0 || readInt2 > f9463c) {
                throw new IOException("Invalid value size: " + readInt2);
            }
            byte[] bArr = new byte[readInt2];
            dataInputStream.readFully(bArr);
            hashMap.put(readUTF, bArr);
        }
        return new l(hashMap);
    }

    private static void k(HashMap<String, byte[]> hashMap, List<String> list) {
        for (int i = 0; i < list.size(); i++) {
            hashMap.remove(list.get(i));
        }
    }

    @Override // com.google.android.exoplayer2.upstream.cache.i
    public final boolean a(String str) {
        return this.f9465e.containsKey(str);
    }

    @Override // com.google.android.exoplayer2.upstream.cache.i
    public final String b(String str, String str2) {
        return this.f9465e.containsKey(str) ? new String(this.f9465e.get(str), Charset.forName("UTF-8")) : str2;
    }

    @Override // com.google.android.exoplayer2.upstream.cache.i
    public final long c(String str, long j) {
        return this.f9465e.containsKey(str) ? ByteBuffer.wrap(this.f9465e.get(str)).getLong() : j;
    }

    @Override // com.google.android.exoplayer2.upstream.cache.i
    public final byte[] d(String str, byte[] bArr) {
        if (!this.f9465e.containsKey(str)) {
            return bArr;
        }
        byte[] bArr2 = this.f9465e.get(str);
        return Arrays.copyOf(bArr2, bArr2.length);
    }

    public boolean equals(@Nullable Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null || l.class != obj.getClass()) {
            return false;
        }
        return i(((l) obj).f9465e);
    }

    public l g(k kVar) {
        Map<String, byte[]> f = f(this.f9465e, kVar);
        if (i(f)) {
            return this;
        }
        return new l(f);
    }

    public int hashCode() {
        if (this.f9464d == 0) {
            int i = 0;
            for (Map.Entry<String, byte[]> entry : this.f9465e.entrySet()) {
                i += Arrays.hashCode(entry.getValue()) ^ entry.getKey().hashCode();
            }
            this.f9464d = i;
        }
        return this.f9464d;
    }

    public void l(DataOutputStream dataOutputStream) throws IOException {
        dataOutputStream.writeInt(this.f9465e.size());
        for (Map.Entry<String, byte[]> entry : this.f9465e.entrySet()) {
            dataOutputStream.writeUTF(entry.getKey());
            byte[] value = entry.getValue();
            dataOutputStream.writeInt(value.length);
            dataOutputStream.write(value);
        }
    }
}
