package com.google.android.gms.common.data;

import android.content.ContentValues;
import android.database.CharArrayBuffer;
import android.database.Cursor;
import android.database.CursorIndexOutOfBoundsException;
import android.database.CursorWindow;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.Log;
import com.google.android.gms.common.annotation.KeepForSdk;
import com.google.android.gms.common.annotation.KeepName;
import com.google.android.gms.common.internal.a0;
import com.google.android.gms.common.internal.d;
import com.google.android.gms.common.internal.safeparcel.AbstractSafeParcelable;
import com.google.android.gms.common.internal.safeparcel.SafeParcelable;
import java.io.Closeable;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@SafeParcelable.Class(creator = "DataHolderCreator", validate = true)
@KeepForSdk
@KeepName
public final class DataHolder extends AbstractSafeParcelable implements Closeable {
    @KeepForSdk
    public static final Parcelable.Creator<DataHolder> CREATOR = new o();

    /* renamed from: a  reason: collision with root package name */
    private static final a f9996a = new n(new String[0], null);
    @SafeParcelable.Field(getter = "getColumns", id = 1)
    private final String[] I0;
    private Bundle J0;
    @SafeParcelable.Field(getter = "getWindows", id = 2)
    private final CursorWindow[] K0;
    @SafeParcelable.Field(getter = "getStatusCode", id = 3)
    private final int L0;
    @SafeParcelable.Field(getter = "getMetadata", id = 4)
    private final Bundle M0;
    private int[] N0;
    private int O0;
    private boolean P0;
    private boolean Q0;
    @SafeParcelable.VersionField(id = 1000)

    /* renamed from: b  reason: collision with root package name */
    private final int f9997b;

    public static class zaa extends RuntimeException {
        public zaa(String str) {
            super(str);
        }
    }

    @SafeParcelable.Constructor
    DataHolder(@SafeParcelable.Param(id = 1000) int i, @SafeParcelable.Param(id = 1) String[] strArr, @SafeParcelable.Param(id = 2) CursorWindow[] cursorWindowArr, @SafeParcelable.Param(id = 3) int i2, @SafeParcelable.Param(id = 4) Bundle bundle) {
        this.P0 = false;
        this.Q0 = true;
        this.f9997b = i;
        this.I0 = strArr;
        this.K0 = cursorWindowArr;
        this.L0 = i2;
        this.M0 = bundle;
    }

    private final void L1(String str, int i) {
        Bundle bundle = this.J0;
        if (bundle == null || !bundle.containsKey(str)) {
            String valueOf = String.valueOf(str);
            throw new IllegalArgumentException(valueOf.length() != 0 ? "No such column: ".concat(valueOf) : new String("No such column: "));
        } else if (isClosed()) {
            throw new IllegalArgumentException("Buffer is closed.");
        } else if (i < 0 || i >= this.O0) {
            throw new CursorIndexOutOfBoundsException(i, this.O0);
        }
    }

    private static CursorWindow[] Q1(a aVar, int i) {
        List list;
        if (aVar.f9998a.length == 0) {
            return new CursorWindow[0];
        }
        if (i < 0 || i >= aVar.f9999b.size()) {
            list = aVar.f9999b;
        } else {
            list = aVar.f9999b.subList(0, i);
        }
        int size = list.size();
        CursorWindow cursorWindow = new CursorWindow(false);
        ArrayList arrayList = new ArrayList();
        arrayList.add(cursorWindow);
        cursorWindow.setNumColumns(aVar.f9998a.length);
        int i2 = 0;
        boolean z = false;
        while (i2 < size) {
            try {
                if (!cursorWindow.allocRow()) {
                    StringBuilder sb = new StringBuilder(72);
                    sb.append("Allocating additional cursor window for large data set (row ");
                    sb.append(i2);
                    sb.append(")");
                    Log.d("DataHolder", sb.toString());
                    cursorWindow = new CursorWindow(false);
                    cursorWindow.setStartPosition(i2);
                    cursorWindow.setNumColumns(aVar.f9998a.length);
                    arrayList.add(cursorWindow);
                    if (!cursorWindow.allocRow()) {
                        Log.e("DataHolder", "Unable to allocate row to hold data.");
                        arrayList.remove(cursorWindow);
                        return (CursorWindow[]) arrayList.toArray(new CursorWindow[arrayList.size()]);
                    }
                }
                Map map = (Map) list.get(i2);
                boolean z2 = true;
                for (int i3 = 0; i3 < aVar.f9998a.length && z2; i3++) {
                    String str = aVar.f9998a[i3];
                    Object obj = map.get(str);
                    if (obj == null) {
                        z2 = cursorWindow.putNull(i2, i3);
                    } else if (obj instanceof String) {
                        z2 = cursorWindow.putString((String) obj, i2, i3);
                    } else if (obj instanceof Long) {
                        z2 = cursorWindow.putLong(((Long) obj).longValue(), i2, i3);
                    } else if (obj instanceof Integer) {
                        z2 = cursorWindow.putLong((long) ((Integer) obj).intValue(), i2, i3);
                    } else if (obj instanceof Boolean) {
                        z2 = cursorWindow.putLong(((Boolean) obj).booleanValue() ? 1 : 0, i2, i3);
                    } else if (obj instanceof byte[]) {
                        z2 = cursorWindow.putBlob((byte[]) obj, i2, i3);
                    } else if (obj instanceof Double) {
                        z2 = cursorWindow.putDouble(((Double) obj).doubleValue(), i2, i3);
                    } else if (obj instanceof Float) {
                        z2 = cursorWindow.putDouble((double) ((Float) obj).floatValue(), i2, i3);
                    } else {
                        String valueOf = String.valueOf(obj);
                        StringBuilder sb2 = new StringBuilder(String.valueOf(str).length() + 32 + valueOf.length());
                        sb2.append("Unsupported object for column ");
                        sb2.append(str);
                        sb2.append(": ");
                        sb2.append(valueOf);
                        throw new IllegalArgumentException(sb2.toString());
                    }
                }
                if (z2) {
                    z = false;
                } else if (!z) {
                    StringBuilder sb3 = new StringBuilder(74);
                    sb3.append("Couldn't populate window data for row ");
                    sb3.append(i2);
                    sb3.append(" - allocating new window.");
                    Log.d("DataHolder", sb3.toString());
                    cursorWindow.freeLastRow();
                    cursorWindow = new CursorWindow(false);
                    cursorWindow.setStartPosition(i2);
                    cursorWindow.setNumColumns(aVar.f9998a.length);
                    arrayList.add(cursorWindow);
                    i2--;
                    z = true;
                } else {
                    throw new zaa("Could not add the value to a new CursorWindow. The size of value may be larger than what a CursorWindow can handle.");
                }
                i2++;
            } catch (RuntimeException e2) {
                int size2 = arrayList.size();
                for (int i4 = 0; i4 < size2; i4++) {
                    ((CursorWindow) arrayList.get(i4)).close();
                }
                throw e2;
            }
        }
        return (CursorWindow[]) arrayList.toArray(new CursorWindow[arrayList.size()]);
    }

    /* JADX INFO: finally extract failed */
    private static CursorWindow[] U1(com.google.android.gms.common.o.a aVar) {
        int i;
        ArrayList arrayList = new ArrayList();
        try {
            int count = aVar.getCount();
            CursorWindow window = aVar.getWindow();
            if (window == null || window.getStartPosition() != 0) {
                i = 0;
            } else {
                window.acquireReference();
                aVar.a(null);
                arrayList.add(window);
                i = window.getNumRows();
            }
            while (i < count && aVar.moveToPosition(i)) {
                CursorWindow window2 = aVar.getWindow();
                if (window2 != null) {
                    window2.acquireReference();
                    aVar.a(null);
                } else {
                    window2 = new CursorWindow(false);
                    window2.setStartPosition(i);
                    aVar.fillWindow(i, window2);
                }
                if (window2.getNumRows() == 0) {
                    break;
                }
                arrayList.add(window2);
                i = window2.getStartPosition() + window2.getNumRows();
            }
            aVar.close();
            return (CursorWindow[]) arrayList.toArray(new CursorWindow[arrayList.size()]);
        } catch (Throwable th) {
            aVar.close();
            throw th;
        }
    }

    @KeepForSdk
    public static a e0(String[] strArr) {
        return new a(strArr, null, null);
    }

    @KeepForSdk
    public static DataHolder o0(int i) {
        return new DataHolder(f9996a, i, (Bundle) null);
    }

    @KeepForSdk
    public final int C1(int i) {
        int[] iArr;
        int i2 = 0;
        a0.q(i >= 0 && i < this.O0);
        while (true) {
            iArr = this.N0;
            if (i2 >= iArr.length) {
                break;
            } else if (i < iArr[i2]) {
                i2--;
                break;
            } else {
                i2++;
            }
        }
        return i2 == iArr.length ? i2 - 1 : i2;
    }

    @KeepForSdk
    public final boolean D1(String str) {
        return this.J0.containsKey(str);
    }

    @KeepForSdk
    public final boolean E1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].isNull(i, this.J0.getInt(str));
    }

    public final float F1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].getFloat(i, this.J0.getInt(str));
    }

    public final void O1(String str, int i, int i2, CharArrayBuffer charArrayBuffer) {
        L1(str, i);
        this.K0[i2].copyStringToBuffer(i, this.J0.getInt(str), charArrayBuffer);
    }

    public final double V1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].getDouble(i, this.J0.getInt(str));
    }

    public final void W1() {
        this.J0 = new Bundle();
        int i = 0;
        int i2 = 0;
        while (true) {
            String[] strArr = this.I0;
            if (i2 >= strArr.length) {
                break;
            }
            this.J0.putInt(strArr[i2], i2);
            i2++;
        }
        this.N0 = new int[this.K0.length];
        int i3 = 0;
        while (true) {
            CursorWindow[] cursorWindowArr = this.K0;
            if (i < cursorWindowArr.length) {
                this.N0[i] = i3;
                i3 += this.K0[i].getNumRows() - (i3 - cursorWindowArr[i].getStartPosition());
                i++;
            } else {
                this.O0 = i3;
                return;
            }
        }
    }

    @Override // java.io.Closeable, java.lang.AutoCloseable
    @KeepForSdk
    public final void close() {
        synchronized (this) {
            if (!this.P0) {
                this.P0 = true;
                int i = 0;
                while (true) {
                    CursorWindow[] cursorWindowArr = this.K0;
                    if (i >= cursorWindowArr.length) {
                        break;
                    }
                    cursorWindowArr[i].close();
                    i++;
                }
            }
        }
    }

    @KeepForSdk
    public final byte[] d1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].getBlob(i, this.J0.getInt(str));
    }

    /* access modifiers changed from: protected */
    @Override // java.lang.Object
    public final void finalize() throws Throwable {
        try {
            if (this.Q0 && this.K0.length > 0 && !isClosed()) {
                close();
                String obj = toString();
                StringBuilder sb = new StringBuilder(String.valueOf(obj).length() + 178);
                sb.append("Internal data leak within a DataBuffer object detected!  Be sure to explicitly call release() on all DataBuffer extending objects when you are done with them. (internal object: ");
                sb.append(obj);
                sb.append(")");
                Log.e("DataBuffer", sb.toString());
            }
        } finally {
            super.finalize();
        }
    }

    @KeepForSdk
    public final int getCount() {
        return this.O0;
    }

    @KeepForSdk
    public final Bundle getMetadata() {
        return this.M0;
    }

    @KeepForSdk
    public final boolean isClosed() {
        boolean z;
        synchronized (this) {
            z = this.P0;
        }
        return z;
    }

    @KeepForSdk
    public final int m1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].getInt(i, this.J0.getInt(str));
    }

    @KeepForSdk
    public final long s1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].getLong(i, this.J0.getInt(str));
    }

    @KeepForSdk
    public final int u1() {
        return this.L0;
    }

    public final void writeToParcel(Parcel parcel, int i) {
        int a2 = com.google.android.gms.common.internal.safeparcel.a.a(parcel);
        com.google.android.gms.common.internal.safeparcel.a.Y(parcel, 1, this.I0, false);
        com.google.android.gms.common.internal.safeparcel.a.b0(parcel, 2, this.K0, i, false);
        com.google.android.gms.common.internal.safeparcel.a.F(parcel, 3, u1());
        com.google.android.gms.common.internal.safeparcel.a.k(parcel, 4, getMetadata(), false);
        com.google.android.gms.common.internal.safeparcel.a.F(parcel, 1000, this.f9997b);
        com.google.android.gms.common.internal.safeparcel.a.b(parcel, a2);
        if ((i & 1) != 0) {
            close();
        }
    }

    @KeepForSdk
    public final boolean x0(String str, int i, int i2) {
        L1(str, i);
        return Long.valueOf(this.K0[i2].getLong(i, this.J0.getInt(str))).longValue() == 1;
    }

    @KeepForSdk
    public final String z1(String str, int i, int i2) {
        L1(str, i);
        return this.K0[i2].getString(i, this.J0.getInt(str));
    }

    @KeepForSdk
    public static class a {

        /* renamed from: a  reason: collision with root package name */
        private final String[] f9998a;

        /* renamed from: b  reason: collision with root package name */
        private final ArrayList<HashMap<String, Object>> f9999b;

        /* renamed from: c  reason: collision with root package name */
        private final String f10000c;

        /* renamed from: d  reason: collision with root package name */
        private final HashMap<Object, Integer> f10001d;

        /* renamed from: e  reason: collision with root package name */
        private boolean f10002e;
        private String f;

        private a(String[] strArr, String str) {
            this.f9998a = (String[]) a0.k(strArr);
            this.f9999b = new ArrayList<>();
            this.f10000c = str;
            this.f10001d = new HashMap<>();
            this.f10002e = false;
            this.f = null;
        }

        @KeepForSdk
        public DataHolder a(int i) {
            return new DataHolder(this, i, (Bundle) null, (n) null);
        }

        @KeepForSdk
        public DataHolder b(int i, Bundle bundle) {
            return new DataHolder(this, i, bundle, -1, (n) null);
        }

        @KeepForSdk
        public a c(ContentValues contentValues) {
            d.c(contentValues);
            HashMap<String, Object> hashMap = new HashMap<>(contentValues.size());
            for (Map.Entry<String, Object> entry : contentValues.valueSet()) {
                hashMap.put(entry.getKey(), entry.getValue());
            }
            return d(hashMap);
        }

        /* JADX WARNING: Removed duplicated region for block: B:10:0x0031  */
        /* JADX WARNING: Removed duplicated region for block: B:11:0x0037  */
        public a d(HashMap<String, Object> hashMap) {
            int i;
            Object obj;
            d.c(hashMap);
            String str = this.f10000c;
            if (!(str == null || (obj = hashMap.get(str)) == null)) {
                Integer num = this.f10001d.get(obj);
                if (num == null) {
                    this.f10001d.put(obj, Integer.valueOf(this.f9999b.size()));
                } else {
                    i = num.intValue();
                    if (i != -1) {
                        this.f9999b.add(hashMap);
                    } else {
                        this.f9999b.remove(i);
                        this.f9999b.add(i, hashMap);
                    }
                    this.f10002e = false;
                    return this;
                }
            }
            i = -1;
            if (i != -1) {
            }
            this.f10002e = false;
            return this;
        }

        /* synthetic */ a(String[] strArr, String str, n nVar) {
            this(strArr, null);
        }
    }

    @KeepForSdk
    public DataHolder(String[] strArr, CursorWindow[] cursorWindowArr, int i, Bundle bundle) {
        this.P0 = false;
        this.Q0 = true;
        this.f9997b = 1;
        this.I0 = (String[]) a0.k(strArr);
        this.K0 = (CursorWindow[]) a0.k(cursorWindowArr);
        this.L0 = i;
        this.M0 = bundle;
        W1();
    }

    private DataHolder(com.google.android.gms.common.o.a aVar, int i, Bundle bundle) {
        this(aVar.getColumnNames(), U1(aVar), i, bundle);
    }

    @KeepForSdk
    public DataHolder(Cursor cursor, int i, Bundle bundle) {
        this(new com.google.android.gms.common.o.a(cursor), i, bundle);
    }

    private DataHolder(a aVar, int i, Bundle bundle) {
        this(aVar.f9998a, Q1(aVar, -1), i, (Bundle) null);
    }

    private DataHolder(a aVar, int i, Bundle bundle, int i2) {
        this(aVar.f9998a, Q1(aVar, -1), i, bundle);
    }

    /* synthetic */ DataHolder(a aVar, int i, Bundle bundle, n nVar) {
        this(aVar, i, (Bundle) null);
    }

    /* synthetic */ DataHolder(a aVar, int i, Bundle bundle, int i2, n nVar) {
        this(aVar, i, bundle, -1);
    }
}
