package com.google.android.gms.common.images;

import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.os.ParcelFileDescriptor;
import android.os.ResultReceiver;
import android.os.SystemClock;
import android.util.Log;
import android.widget.ImageView;
import b.b.g;
import com.google.android.gms.common.annotation.KeepName;
import com.google.android.gms.common.internal.h;
import com.google.android.gms.internal.base.j;
import com.google.android.gms.internal.base.o;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public final class ImageManager {

    /* renamed from: a  reason: collision with root package name */
    private static final Object f10029a = new Object();

    /* renamed from: b  reason: collision with root package name */
    private static HashSet<Uri> f10030b = new HashSet<>();

    /* renamed from: c  reason: collision with root package name */
    private static ImageManager f10031c;

    /* renamed from: d  reason: collision with root package name */
    private final Context f10032d;

    /* renamed from: e  reason: collision with root package name */
    private final Handler f10033e = new o(Looper.getMainLooper());
    private final ExecutorService f = Executors.newFixedThreadPool(4);
    private final b g = null;
    private final j h = new j();
    private final Map<b, ImageReceiver> i = new HashMap();
    private final Map<Uri, ImageReceiver> j = new HashMap();
    private final Map<Uri, Long> k = new HashMap();

    /* access modifiers changed from: private */
    @KeepName
    public final class ImageReceiver extends ResultReceiver {

        /* renamed from: a  reason: collision with root package name */
        private final Uri f10034a;

        /* renamed from: b  reason: collision with root package name */
        private final ArrayList<b> f10035b = new ArrayList<>();

        ImageReceiver(Uri uri) {
            super(new o(Looper.getMainLooper()));
            this.f10034a = uri;
        }

        public final void b(b bVar) {
            com.google.android.gms.common.internal.d.a("ImageReceiver.addImageRequest() must be called in the main thread");
            this.f10035b.add(bVar);
        }

        public final void c(b bVar) {
            com.google.android.gms.common.internal.d.a("ImageReceiver.removeImageRequest() must be called in the main thread");
            this.f10035b.remove(bVar);
        }

        public final void d() {
            Intent intent = new Intent(h.f10117c);
            intent.putExtra(h.f10118d, this.f10034a);
            intent.putExtra(h.f10119e, this);
            intent.putExtra(h.f, 3);
            ImageManager.this.f10032d.sendBroadcast(intent);
        }

        public final void onReceiveResult(int i, Bundle bundle) {
            ImageManager.this.f.execute(new c(this.f10034a, (ParcelFileDescriptor) bundle.getParcelable("com.google.android.gms.extra.fileDescriptor")));
        }
    }

    public interface a {
        void a(Uri uri, Drawable drawable, boolean z);
    }

    /* access modifiers changed from: private */
    public static final class b extends g<c, Bitmap> {
        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [boolean, java.lang.Object, java.lang.Object, java.lang.Object] */
        /* access modifiers changed from: protected */
        @Override // b.b.g
        public final /* synthetic */ void c(boolean z, c cVar, Bitmap bitmap, Bitmap bitmap2) {
            super.c(z, cVar, bitmap, bitmap2);
        }

        /* JADX DEBUG: Method arguments types fixed to match base method, original types: [java.lang.Object, java.lang.Object] */
        /* access modifiers changed from: protected */
        @Override // b.b.g
        public final /* synthetic */ int p(c cVar, Bitmap bitmap) {
            Bitmap bitmap2 = bitmap;
            return bitmap2.getHeight() * bitmap2.getRowBytes();
        }
    }

    private final class c implements Runnable {

        /* renamed from: a  reason: collision with root package name */
        private final Uri f10036a;

        /* renamed from: b  reason: collision with root package name */
        private final ParcelFileDescriptor f10037b;

        public c(Uri uri, ParcelFileDescriptor parcelFileDescriptor) {
            this.f10036a = uri;
            this.f10037b = parcelFileDescriptor;
        }

        public final void run() {
            boolean z;
            Bitmap bitmap;
            com.google.android.gms.common.internal.d.b("LoadBitmapFromDiskRunnable can't be executed in the main thread");
            ParcelFileDescriptor parcelFileDescriptor = this.f10037b;
            boolean z2 = false;
            Bitmap bitmap2 = null;
            if (parcelFileDescriptor != null) {
                try {
                    bitmap2 = BitmapFactory.decodeFileDescriptor(parcelFileDescriptor.getFileDescriptor());
                } catch (OutOfMemoryError e2) {
                    String valueOf = String.valueOf(this.f10036a);
                    StringBuilder sb = new StringBuilder(valueOf.length() + 34);
                    sb.append("OOM while loading bitmap for uri: ");
                    sb.append(valueOf);
                    Log.e("ImageManager", sb.toString(), e2);
                    z2 = true;
                }
                try {
                    this.f10037b.close();
                } catch (IOException e3) {
                    Log.e("ImageManager", "closed failed", e3);
                }
                z = z2;
                bitmap = bitmap2;
            } else {
                bitmap = null;
                z = false;
            }
            CountDownLatch countDownLatch = new CountDownLatch(1);
            ImageManager.this.f10033e.post(new e(this.f10036a, bitmap, z, countDownLatch));
            try {
                countDownLatch.await();
            } catch (InterruptedException unused) {
                String valueOf2 = String.valueOf(this.f10036a);
                StringBuilder sb2 = new StringBuilder(valueOf2.length() + 32);
                sb2.append("Latch interrupted while posting ");
                sb2.append(valueOf2);
                Log.w("ImageManager", sb2.toString());
            }
        }
    }

    /* access modifiers changed from: private */
    public final class d implements Runnable {

        /* renamed from: a  reason: collision with root package name */
        private final b f10038a;

        public d(b bVar) {
            this.f10038a = bVar;
        }

        public final void run() {
            com.google.android.gms.common.internal.d.a("LoadImageRunnable must be executed on the main thread");
            ImageReceiver imageReceiver = (ImageReceiver) ImageManager.this.i.get(this.f10038a);
            if (imageReceiver != null) {
                ImageManager.this.i.remove(this.f10038a);
                imageReceiver.c(this.f10038a);
            }
            b bVar = this.f10038a;
            c cVar = bVar.f10046a;
            if (cVar.f10051a == null) {
                bVar.c(ImageManager.this.f10032d, ImageManager.this.h, true);
                return;
            }
            Bitmap h = ImageManager.this.h(cVar);
            if (h != null) {
                this.f10038a.a(ImageManager.this.f10032d, h, true);
                return;
            }
            Long l = (Long) ImageManager.this.k.get(cVar.f10051a);
            if (l != null) {
                if (SystemClock.elapsedRealtime() - l.longValue() < 3600000) {
                    this.f10038a.c(ImageManager.this.f10032d, ImageManager.this.h, true);
                    return;
                }
                ImageManager.this.k.remove(cVar.f10051a);
            }
            this.f10038a.b(ImageManager.this.f10032d, ImageManager.this.h);
            ImageReceiver imageReceiver2 = (ImageReceiver) ImageManager.this.j.get(cVar.f10051a);
            if (imageReceiver2 == null) {
                imageReceiver2 = new ImageReceiver(cVar.f10051a);
                ImageManager.this.j.put(cVar.f10051a, imageReceiver2);
            }
            imageReceiver2.b(this.f10038a);
            if (!(this.f10038a instanceof e)) {
                ImageManager.this.i.put(this.f10038a, imageReceiver2);
            }
            synchronized (ImageManager.f10029a) {
                if (!ImageManager.f10030b.contains(cVar.f10051a)) {
                    ImageManager.f10030b.add(cVar.f10051a);
                    imageReceiver2.d();
                }
            }
        }
    }

    private final class e implements Runnable {
        private final CountDownLatch I0;
        private boolean J0;

        /* renamed from: a  reason: collision with root package name */
        private final Uri f10040a;

        /* renamed from: b  reason: collision with root package name */
        private final Bitmap f10041b;

        public e(Uri uri, Bitmap bitmap, boolean z, CountDownLatch countDownLatch) {
            this.f10040a = uri;
            this.f10041b = bitmap;
            this.J0 = z;
            this.I0 = countDownLatch;
        }

        public final void run() {
            com.google.android.gms.common.internal.d.a("OnBitmapLoadedRunnable must be executed in the main thread");
            boolean z = this.f10041b != null;
            if (ImageManager.this.g != null) {
                if (this.J0) {
                    ImageManager.this.g.d();
                    System.gc();
                    this.J0 = false;
                    ImageManager.this.f10033e.post(this);
                    return;
                } else if (z) {
                    ImageManager.this.g.j(new c(this.f10040a), this.f10041b);
                }
            }
            ImageReceiver imageReceiver = (ImageReceiver) ImageManager.this.j.remove(this.f10040a);
            if (imageReceiver != null) {
                ArrayList arrayList = imageReceiver.f10035b;
                int size = arrayList.size();
                for (int i = 0; i < size; i++) {
                    b bVar = (b) arrayList.get(i);
                    if (z) {
                        bVar.a(ImageManager.this.f10032d, this.f10041b, false);
                    } else {
                        ImageManager.this.k.put(this.f10040a, Long.valueOf(SystemClock.elapsedRealtime()));
                        bVar.c(ImageManager.this.f10032d, ImageManager.this.h, false);
                    }
                    if (!(bVar instanceof e)) {
                        ImageManager.this.i.remove(bVar);
                    }
                }
            }
            this.I0.countDown();
            synchronized (ImageManager.f10029a) {
                ImageManager.f10030b.remove(this.f10040a);
            }
        }
    }

    private ImageManager(Context context, boolean z) {
        this.f10032d = context.getApplicationContext();
    }

    public static ImageManager a(Context context) {
        if (f10031c == null) {
            f10031c = new ImageManager(context, false);
        }
        return f10031c;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private final Bitmap h(c cVar) {
        b bVar = this.g;
        if (bVar == null) {
            return null;
        }
        return (Bitmap) bVar.f(cVar);
    }

    private final void j(b bVar) {
        com.google.android.gms.common.internal.d.a("ImageManager.loadImage() must be called in the main thread");
        new d(bVar).run();
    }

    public final void b(ImageView imageView, int i2) {
        j(new d(imageView, i2));
    }

    public final void c(ImageView imageView, Uri uri) {
        j(new d(imageView, uri));
    }

    public final void d(ImageView imageView, Uri uri, int i2) {
        d dVar = new d(imageView, uri);
        dVar.f10048c = i2;
        j(dVar);
    }

    public final void e(a aVar, Uri uri) {
        j(new e(aVar, uri));
    }

    public final void f(a aVar, Uri uri, int i2) {
        e eVar = new e(aVar, uri);
        eVar.f10048c = i2;
        j(eVar);
    }
}
