package com.google.android.gms.measurement.internal;

import android.content.ContentValues;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.os.Parcelable;
import android.text.TextUtils;
import android.util.Pair;
import androidx.annotation.WorkerThread;
import com.alipay.sdk.app.c.b;
import com.google.android.gms.common.internal.a0;
import com.google.android.gms.common.util.VisibleForTesting;
import com.google.android.gms.internal.measurement.d4;
import com.google.android.gms.internal.measurement.w9;
import com.google.android.gms.internal.measurement.zzbj;
import com.google.android.gms.internal.measurement.zzbr;
import com.google.android.gms.measurement.a.a;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import kotlin.time.DurationKt;

/* access modifiers changed from: package-private */
/* compiled from: com.google.android.gms:play-services-measurement@@17.2.0 */
public final class d extends h9 {

    /* renamed from: d  reason: collision with root package name */
    private static final String[] f10805d = {"last_bundled_timestamp", "ALTER TABLE events ADD COLUMN last_bundled_timestamp INTEGER;", "last_bundled_day", "ALTER TABLE events ADD COLUMN last_bundled_day INTEGER;", "last_sampled_complex_event_id", "ALTER TABLE events ADD COLUMN last_sampled_complex_event_id INTEGER;", "last_sampling_rate", "ALTER TABLE events ADD COLUMN last_sampling_rate INTEGER;", "last_exempt_from_sampling", "ALTER TABLE events ADD COLUMN last_exempt_from_sampling INTEGER;", "current_session_count", "ALTER TABLE events ADD COLUMN current_session_count INTEGER;"};

    /* renamed from: e  reason: collision with root package name */
    private static final String[] f10806e = {"origin", "ALTER TABLE user_attributes ADD COLUMN origin TEXT;"};
    private static final String[] f = {"app_version", "ALTER TABLE apps ADD COLUMN app_version TEXT;", "app_store", "ALTER TABLE apps ADD COLUMN app_store TEXT;", "gmp_version", "ALTER TABLE apps ADD COLUMN gmp_version INTEGER;", "dev_cert_hash", "ALTER TABLE apps ADD COLUMN dev_cert_hash INTEGER;", "measurement_enabled", "ALTER TABLE apps ADD COLUMN measurement_enabled INTEGER;", "last_bundle_start_timestamp", "ALTER TABLE apps ADD COLUMN last_bundle_start_timestamp INTEGER;", "day", "ALTER TABLE apps ADD COLUMN day INTEGER;", "daily_public_events_count", "ALTER TABLE apps ADD COLUMN daily_public_events_count INTEGER;", "daily_events_count", "ALTER TABLE apps ADD COLUMN daily_events_count INTEGER;", "daily_conversions_count", "ALTER TABLE apps ADD COLUMN daily_conversions_count INTEGER;", "remote_config", "ALTER TABLE apps ADD COLUMN remote_config BLOB;", "config_fetched_time", "ALTER TABLE apps ADD COLUMN config_fetched_time INTEGER;", "failed_config_fetch_time", "ALTER TABLE apps ADD COLUMN failed_config_fetch_time INTEGER;", "app_version_int", "ALTER TABLE apps ADD COLUMN app_version_int INTEGER;", "firebase_instance_id", "ALTER TABLE apps ADD COLUMN firebase_instance_id TEXT;", "daily_error_events_count", "ALTER TABLE apps ADD COLUMN daily_error_events_count INTEGER;", "daily_realtime_events_count", "ALTER TABLE apps ADD COLUMN daily_realtime_events_count INTEGER;", "health_monitor_sample", "ALTER TABLE apps ADD COLUMN health_monitor_sample TEXT;", "android_id", "ALTER TABLE apps ADD COLUMN android_id INTEGER;", "adid_reporting_enabled", "ALTER TABLE apps ADD COLUMN adid_reporting_enabled INTEGER;", "ssaid_reporting_enabled", "ALTER TABLE apps ADD COLUMN ssaid_reporting_enabled INTEGER;", "admob_app_id", "ALTER TABLE apps ADD COLUMN admob_app_id TEXT;", "linked_admob_app_id", "ALTER TABLE apps ADD COLUMN linked_admob_app_id TEXT;", "dynamite_version", "ALTER TABLE apps ADD COLUMN dynamite_version INTEGER;", "safelisted_events", "ALTER TABLE apps ADD COLUMN safelisted_events TEXT;", "ga_app_id", "ALTER TABLE apps ADD COLUMN ga_app_id TEXT;"};
    private static final String[] g = {"realtime", "ALTER TABLE raw_events ADD COLUMN realtime INTEGER;"};
    private static final String[] h = {"has_realtime", "ALTER TABLE queue ADD COLUMN has_realtime INTEGER;", "retry_count", "ALTER TABLE queue ADD COLUMN retry_count INTEGER;"};
    private static final String[] i = {"session_scoped", "ALTER TABLE event_filters ADD COLUMN session_scoped BOOLEAN;"};
    private static final String[] j = {"session_scoped", "ALTER TABLE property_filters ADD COLUMN session_scoped BOOLEAN;"};
    private static final String[] k = {"previous_install_count", "ALTER TABLE app2 ADD COLUMN previous_install_count INTEGER;"};
    private final e l = new e(this, i(), "google_app_measurement.db");
    private final d9 m = new d9(m());

    d(l9 l9Var) {
        super(l9Var);
    }

    @WorkerThread
    private final long B(String str, String[] strArr, long j2) {
        Cursor cursor = null;
        try {
            Cursor rawQuery = y().rawQuery(str, strArr);
            if (rawQuery.moveToFirst()) {
                long j3 = rawQuery.getLong(0);
                rawQuery.close();
                return j3;
            }
            rawQuery.close();
            return j2;
        } catch (SQLiteException e2) {
            h().H().c("Database error", str, e2);
            throw e2;
        } catch (Throwable th) {
            if (0 != 0) {
                cursor.close();
            }
            throw th;
        }
    }

    @VisibleForTesting
    @WorkerThread
    private final Object G(Cursor cursor, int i2) {
        int type = cursor.getType(i2);
        if (type == 0) {
            h().H().a("Loaded invalid null value from database");
            return null;
        } else if (type == 1) {
            return Long.valueOf(cursor.getLong(i2));
        } else {
            if (type == 2) {
                return Double.valueOf(cursor.getDouble(i2));
            }
            if (type == 3) {
                return cursor.getString(i2);
            }
            if (type != 4) {
                h().H().b("Loaded invalid unknown value type, ignoring it", Integer.valueOf(type));
                return null;
            }
            h().H().a("Loaded invalid blob type value, ignoring it");
            return null;
        }
    }

    @WorkerThread
    private static void M(ContentValues contentValues, String str, Object obj) {
        a0.g(str);
        a0.k(obj);
        if (obj instanceof String) {
            contentValues.put(str, (String) obj);
        } else if (obj instanceof Long) {
            contentValues.put(str, (Long) obj);
        } else if (obj instanceof Double) {
            contentValues.put(str, (Double) obj);
        } else {
            throw new IllegalArgumentException("Invalid value type");
        }
    }

    @WorkerThread
    private final boolean V(String str, int i2, zzbj.b bVar) {
        t();
        e();
        a0.g(str);
        a0.k(bVar);
        Integer num = null;
        if (TextUtils.isEmpty(bVar.H())) {
            y3 K = h().K();
            Object y = w3.y(str);
            Integer valueOf = Integer.valueOf(i2);
            if (bVar.F()) {
                num = Integer.valueOf(bVar.G());
            }
            K.d("Event filter had no event name. Audience definition ignored. appId, audienceId, filterId", y, valueOf, String.valueOf(num));
            return false;
        }
        byte[] i3 = bVar.i();
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, str);
        contentValues.put("audience_id", Integer.valueOf(i2));
        contentValues.put("filter_id", bVar.F() ? Integer.valueOf(bVar.G()) : null);
        contentValues.put("event_name", bVar.H());
        if (n().C(str, o.w0)) {
            contentValues.put("session_scoped", bVar.O() ? Boolean.valueOf(bVar.P()) : null);
        }
        contentValues.put("data", i3);
        try {
            if (y().insertWithOnConflict("event_filters", null, contentValues, 5) != -1) {
                return true;
            }
            h().H().b("Failed to insert event filter (got -1). appId", w3.y(str));
            return true;
        } catch (SQLiteException e2) {
            h().H().c("Error storing event filter. appId", w3.y(str), e2);
            return false;
        }
    }

    @WorkerThread
    private final boolean W(String str, int i2, zzbj.d dVar) {
        t();
        e();
        a0.g(str);
        a0.k(dVar);
        Integer num = null;
        if (TextUtils.isEmpty(dVar.E())) {
            y3 K = h().K();
            Object y = w3.y(str);
            Integer valueOf = Integer.valueOf(i2);
            if (dVar.C()) {
                num = Integer.valueOf(dVar.D());
            }
            K.d("Property filter had no property name. Audience definition ignored. appId, audienceId, filterId", y, valueOf, String.valueOf(num));
            return false;
        }
        byte[] i3 = dVar.i();
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, str);
        contentValues.put("audience_id", Integer.valueOf(i2));
        contentValues.put("filter_id", dVar.C() ? Integer.valueOf(dVar.D()) : null);
        contentValues.put("property_name", dVar.E());
        if (n().C(str, o.w0)) {
            contentValues.put("session_scoped", dVar.I() ? Boolean.valueOf(dVar.J()) : null);
        }
        contentValues.put("data", i3);
        try {
            if (y().insertWithOnConflict("property_filters", null, contentValues, 5) != -1) {
                return true;
            }
            h().H().b("Failed to insert property filter (got -1). appId", w3.y(str));
            return false;
        } catch (SQLiteException e2) {
            h().H().c("Error storing property filter. appId", w3.y(str), e2);
            return false;
        }
    }

    private final boolean h0() {
        return i().getDatabasePath("google_app_measurement.db").exists();
    }

    @WorkerThread
    private final long i0(String str, String[] strArr) {
        Cursor cursor = null;
        try {
            Cursor rawQuery = y().rawQuery(str, strArr);
            if (rawQuery.moveToFirst()) {
                long j2 = rawQuery.getLong(0);
                rawQuery.close();
                return j2;
            }
            throw new SQLiteException("Database returned empty set");
        } catch (SQLiteException e2) {
            h().H().c("Database error", str, e2);
            throw e2;
        } catch (Throwable th) {
            if (0 != 0) {
                cursor.close();
            }
            throw th;
        }
    }

    private final boolean p0(String str, List<Integer> list) {
        a0.g(str);
        t();
        e();
        SQLiteDatabase y = y();
        try {
            long i0 = i0("select count(1) from audience_filter_values where app_id=?", new String[]{str});
            int max = Math.max(0, Math.min(2000, n().t(str, o.M)));
            if (i0 <= ((long) max)) {
                return false;
            }
            ArrayList arrayList = new ArrayList();
            for (int i2 = 0; i2 < list.size(); i2++) {
                Integer num = list.get(i2);
                if (num == null) {
                    return false;
                }
                arrayList.add(Integer.toString(num.intValue()));
            }
            String join = TextUtils.join(",", arrayList);
            StringBuilder sb = new StringBuilder(String.valueOf(join).length() + 2);
            sb.append("(");
            sb.append(join);
            sb.append(")");
            String sb2 = sb.toString();
            StringBuilder sb3 = new StringBuilder(String.valueOf(sb2).length() + 140);
            sb3.append("audience_id in (select audience_id from audience_filter_values where app_id=? and audience_id not in ");
            sb3.append(sb2);
            sb3.append(" order by rowid desc limit -1 offset ?)");
            return y.delete("audience_filter_values", sb3.toString(), new String[]{str, Integer.toString(max)}) > 0;
        } catch (SQLiteException e2) {
            h().H().c("Database error querying filters. appId", w3.y(str), e2);
            return false;
        }
    }

    public final long A(zzbr.g gVar) throws IOException {
        e();
        t();
        a0.k(gVar);
        a0.g(gVar.K2());
        byte[] i2 = gVar.i();
        long y = p().y(i2);
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, gVar.K2());
        contentValues.put("metadata_fingerprint", Long.valueOf(y));
        contentValues.put(com.google.android.exoplayer2.text.ttml.b.l, i2);
        try {
            y().insertWithOnConflict("raw_events_metadata", null, contentValues, 4);
            return y;
        } catch (SQLiteException e2) {
            h().H().c("Error storing raw event metadata. appId", w3.y(gVar.K2()), e2);
            throw e2;
        }
    }

    @WorkerThread
    public final void A0() {
        t();
        y().endTransaction();
    }

    public final boolean B0() {
        return i0("select count(1) > 0 from queue where has_realtime = 1", null) != 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0086  */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x008e  */
    public final Pair<zzbr.c, Long> C(String str, Long l2) {
        Throwable th;
        SQLiteException e2;
        Cursor cursor;
        e();
        t();
        Cursor cursor2 = null;
        try {
            cursor = y().rawQuery("select main_event, children_to_process from main_event_params where app_id=? and event_id=?", new String[]{str, String.valueOf(l2)});
            try {
                if (!cursor.moveToFirst()) {
                    h().P().a("Main event not found");
                    cursor.close();
                    return null;
                }
                try {
                    Pair<zzbr.c, Long> create = Pair.create((zzbr.c) ((d4) ((zzbr.c.a) p9.B(zzbr.c.a0(), cursor.getBlob(0))).o()), Long.valueOf(cursor.getLong(1)));
                    cursor.close();
                    return create;
                } catch (IOException e3) {
                    h().H().d("Failed to merge main event. appId, eventId", w3.y(str), l2, e3);
                    cursor.close();
                    return null;
                }
            } catch (SQLiteException e4) {
                e2 = e4;
                try {
                    h().H().b("Error selecting main event", e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().b("Error selecting main event", e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void C0() {
        int delete;
        e();
        t();
        if (h0()) {
            long a2 = l().i.a();
            long b2 = m().b();
            if (Math.abs(b2 - a2) > o.F.a(null).longValue()) {
                l().i.b(b2);
                e();
                t();
                if (h0() && (delete = y().delete("queue", "abs(bundle_end_timestamp - ?) > cast(? as integer)", new String[]{String.valueOf(m().a()), String.valueOf(ga.N())})) > 0) {
                    h().P().b("Deleted stale rows. rowsDeleted", Integer.valueOf(delete));
                }
            }
        }
    }

    @WorkerThread
    public final c D(long j2, String str, boolean z, boolean z2, boolean z3, boolean z4, boolean z5) {
        a0.g(str);
        e();
        t();
        String[] strArr = {str};
        c cVar = new c();
        Cursor cursor = null;
        try {
            SQLiteDatabase y = y();
            Cursor query = y.query("apps", new String[]{"day", "daily_events_count", "daily_public_events_count", "daily_conversions_count", "daily_error_events_count", "daily_realtime_events_count"}, "app_id=?", new String[]{str}, null, null, null);
            if (!query.moveToFirst()) {
                h().K().b("Not updating daily counts, app is not known. appId", w3.y(str));
                query.close();
                return cVar;
            }
            if (query.getLong(0) == j2) {
                cVar.f10786b = query.getLong(1);
                cVar.f10785a = query.getLong(2);
                cVar.f10787c = query.getLong(3);
                cVar.f10788d = query.getLong(4);
                cVar.f10789e = query.getLong(5);
            }
            if (z) {
                cVar.f10786b++;
            }
            if (z2) {
                cVar.f10785a++;
            }
            if (z3) {
                cVar.f10787c++;
            }
            if (z4) {
                cVar.f10788d++;
            }
            if (z5) {
                cVar.f10789e++;
            }
            ContentValues contentValues = new ContentValues();
            contentValues.put("day", Long.valueOf(j2));
            contentValues.put("daily_public_events_count", Long.valueOf(cVar.f10785a));
            contentValues.put("daily_events_count", Long.valueOf(cVar.f10786b));
            contentValues.put("daily_conversions_count", Long.valueOf(cVar.f10787c));
            contentValues.put("daily_error_events_count", Long.valueOf(cVar.f10788d));
            contentValues.put("daily_realtime_events_count", Long.valueOf(cVar.f10789e));
            y.update("apps", contentValues, "app_id=?", strArr);
            query.close();
            return cVar;
        } catch (SQLiteException e2) {
            h().H().c("Error updating daily counts. appId", w3.y(str), e2);
            if (0 != 0) {
                cursor.close();
            }
            return cVar;
        } catch (Throwable th) {
            if (0 != 0) {
                cursor.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final long D0() {
        return B("select max(bundle_end_timestamp) from queue", null, 0);
    }

    /* JADX WARNING: Removed duplicated region for block: B:63:0x0156  */
    /* JADX WARNING: Removed duplicated region for block: B:68:0x015f  */
    @WorkerThread
    public final k E(String str, String str2) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        Cursor cursor2;
        Boolean bool;
        a0.g(str);
        a0.g(str2);
        e();
        t();
        boolean C = n().C(str, o.x0);
        ArrayList arrayList = new ArrayList(Arrays.asList("lifetime_count", "current_bundle_count", "last_fire_timestamp", "last_bundled_timestamp", "last_bundled_day", "last_sampled_complex_event_id", "last_sampling_rate", "last_exempt_from_sampling"));
        if (C) {
            arrayList.add("current_session_count");
        }
        Cursor cursor3 = null;
        try {
            boolean z = false;
            cursor = y().query("events", (String[]) arrayList.toArray(new String[0]), "app_id=? and name=?", new String[]{str, str2}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return null;
                }
                long j2 = cursor.getLong(0);
                long j3 = cursor.getLong(1);
                long j4 = cursor.getLong(2);
                long j5 = 0;
                long j6 = cursor.isNull(3) ? 0 : cursor.getLong(3);
                Long valueOf = cursor.isNull(4) ? null : Long.valueOf(cursor.getLong(4));
                Long valueOf2 = cursor.isNull(5) ? null : Long.valueOf(cursor.getLong(5));
                Long valueOf3 = cursor.isNull(6) ? null : Long.valueOf(cursor.getLong(6));
                if (!cursor.isNull(7)) {
                    try {
                        if (cursor.getLong(7) == 1) {
                            z = true;
                        }
                        bool = Boolean.valueOf(z);
                    } catch (SQLiteException e3) {
                        e2 = e3;
                        try {
                            h().H().d("Error querying events. appId", w3.y(str), g().z(str2), e2);
                            if (cursor != null) {
                            }
                            return null;
                        } catch (Throwable th2) {
                            th = th2;
                            cursor3 = cursor;
                            if (cursor3 != null) {
                            }
                            throw th;
                        }
                    }
                } else {
                    bool = null;
                }
                if (C && !cursor.isNull(8)) {
                    j5 = cursor.getLong(8);
                }
                cursor2 = cursor;
                try {
                    k kVar = new k(str, str2, j2, j3, j5, j4, j6, valueOf, valueOf2, valueOf3, bool);
                    if (cursor2.moveToNext()) {
                        h().H().b("Got multiple records for event aggregates, expected one. appId", w3.y(str));
                    }
                    cursor2.close();
                    return kVar;
                } catch (SQLiteException e4) {
                    e2 = e4;
                    cursor = cursor2;
                    h().H().d("Error querying events. appId", w3.y(str), g().z(str2), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th3) {
                    th = th3;
                    cursor3 = cursor2;
                    if (cursor3 != null) {
                    }
                    throw th;
                }
            } catch (SQLiteException e5) {
                e2 = e5;
                h().H().d("Error querying events. appId", w3.y(str), g().z(str2), e2);
                if (cursor != null) {
                }
                return null;
            } catch (Throwable th4) {
                th = th4;
                cursor2 = cursor;
                cursor3 = cursor2;
                if (cursor3 != null) {
                }
                throw th;
            }
        } catch (SQLiteException e6) {
            e2 = e6;
            cursor = null;
            h().H().d("Error querying events. appId", w3.y(str), g().z(str2), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th5) {
            th = th5;
            if (cursor3 != null) {
                cursor3.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final long E0() {
        return B("select max(timestamp) from raw_events", null, 0);
    }

    public final boolean F0() {
        return i0("select count(1) > 0 from raw_events", null) != 0;
    }

    public final boolean G0() {
        return i0("select count(1) > 0 from raw_events where realtime = 1", null) != 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:18:0x004f  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0057  */
    public final String H(long j2) {
        Throwable th;
        SQLiteException e2;
        Cursor cursor;
        e();
        t();
        Cursor cursor2 = null;
        try {
            cursor = y().rawQuery("select app_id from apps where app_id in (select distinct app_id from raw_events) and config_fetched_time < ? order by failed_config_fetch_time limit 1;", new String[]{String.valueOf(j2)});
            try {
                if (!cursor.moveToFirst()) {
                    h().P().a("No expired configs for apps with pending events");
                    cursor.close();
                    return null;
                }
                String string = cursor.getString(0);
                cursor.close();
                return string;
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().b("Error selecting expired configs", e2);
                    if (cursor != null) {
                        cursor.close();
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e4) {
            e2 = e4;
            cursor = null;
            h().H().b("Error selecting expired configs", e2);
            if (cursor != null) {
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:26:0x0095  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x009d  */
    @WorkerThread
    public final List<t9> I(String str) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        a0.g(str);
        e();
        t();
        ArrayList arrayList = new ArrayList();
        Cursor cursor2 = null;
        try {
            cursor = y().query("user_attributes", new String[]{"name", "origin", "set_timestamp", "value"}, "app_id=?", new String[]{str}, null, null, "rowid", "1000");
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return arrayList;
                }
                do {
                    String string = cursor.getString(0);
                    String string2 = cursor.getString(1);
                    if (string2 == null) {
                        string2 = "";
                    }
                    long j2 = cursor.getLong(2);
                    Object G = G(cursor, 3);
                    if (G == null) {
                        h().H().b("Read invalid user property value, ignoring it. appId", w3.y(str));
                    } else {
                        arrayList.add(new t9(str, string2, string, j2, G));
                    }
                } while (cursor.moveToNext());
                cursor.close();
                return arrayList;
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().c("Error querying user properties. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e4) {
            e2 = e4;
            cursor = null;
            h().H().c("Error querying user properties. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final List<Pair<zzbr.g, Long>> J(String str, int i2, int i3) {
        e();
        t();
        a0.a(i2 > 0);
        a0.a(i3 > 0);
        a0.g(str);
        Cursor cursor = null;
        try {
            Cursor query = y().query("queue", new String[]{"rowid", "data", "retry_count"}, "app_id=?", new String[]{str}, null, null, "rowid", String.valueOf(i2));
            if (!query.moveToFirst()) {
                List<Pair<zzbr.g, Long>> emptyList = Collections.emptyList();
                query.close();
                return emptyList;
            }
            ArrayList arrayList = new ArrayList();
            int i4 = 0;
            do {
                long j2 = query.getLong(0);
                try {
                    byte[] V = p().V(query.getBlob(1));
                    if (!arrayList.isEmpty() && V.length + i4 > i3) {
                        break;
                    }
                    try {
                        zzbr.g.a aVar = (zzbr.g.a) p9.B(zzbr.g.Q0(), V);
                        if (!query.isNull(2)) {
                            aVar.w0(query.getInt(2));
                        }
                        i4 += V.length;
                        arrayList.add(Pair.create((zzbr.g) ((d4) aVar.o()), Long.valueOf(j2)));
                    } catch (IOException e2) {
                        h().H().c("Failed to merge queued bundle. appId", w3.y(str), e2);
                    }
                    if (!query.moveToNext()) {
                        break;
                    }
                } catch (IOException e3) {
                    h().H().c("Failed to unzip queued bundle. appId", w3.y(str), e3);
                }
            } while (i4 <= i3);
            query.close();
            return arrayList;
        } catch (SQLiteException e4) {
            h().H().c("Error querying bundles. appId", w3.y(str), e4);
            List<Pair<zzbr.g, Long>> emptyList2 = Collections.emptyList();
            if (0 != 0) {
                cursor.close();
            }
            return emptyList2;
        } catch (Throwable th) {
            if (0 != 0) {
                cursor.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00f4, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:46:0x00fc, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:48:0x0100, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:60:0x0123, code lost:
        r1.close();
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x00fc A[ExcHandler: all (th java.lang.Throwable), Splitter:B:1:0x000f] */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x011b  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0123  */
    @WorkerThread
    public final List<t9> K(String str, String str2, String str3) {
        Throwable th;
        Cursor cursor;
        String str4;
        SQLiteException e2;
        a0.g(str);
        e();
        t();
        ArrayList arrayList = new ArrayList();
        Cursor cursor2 = null;
        try {
            ArrayList arrayList2 = new ArrayList(3);
            arrayList2.add(str);
            StringBuilder sb = new StringBuilder("app_id=?");
            if (!TextUtils.isEmpty(str2)) {
                str4 = str2;
                arrayList2.add(str4);
                sb.append(" and origin=?");
            } else {
                str4 = str2;
            }
            if (!TextUtils.isEmpty(str3)) {
                arrayList2.add(String.valueOf(str3).concat("*"));
                sb.append(" and name glob ?");
            }
            cursor = y().query("user_attributes", new String[]{"name", "set_timestamp", "value", "origin"}, sb.toString(), (String[]) arrayList2.toArray(new String[arrayList2.size()]), null, null, "rowid", "1001");
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return arrayList;
                }
                while (true) {
                    if (arrayList.size() >= 1000) {
                        h().H().b("Read more than the max allowed user properties, ignoring excess", 1000);
                        break;
                    }
                    String string = cursor.getString(0);
                    long j2 = cursor.getLong(1);
                    try {
                        Object G = G(cursor, 2);
                        String string2 = cursor.getString(3);
                        if (G == null) {
                            try {
                                h().H().d("(2)Read invalid user property value, ignoring it", w3.y(str), string2, str3);
                            } catch (SQLiteException e3) {
                                e2 = e3;
                                str4 = string2;
                                try {
                                    h().H().d("(2)Error querying user properties", w3.y(str), str4, e2);
                                    if (cursor != null) {
                                    }
                                    return null;
                                } catch (Throwable th2) {
                                    th = th2;
                                    cursor2 = cursor;
                                    if (cursor2 != null) {
                                    }
                                    throw th;
                                }
                            }
                        } else {
                            arrayList.add(new t9(str, string2, string, j2, G));
                        }
                        if (!cursor.moveToNext()) {
                            break;
                        }
                        str4 = string2;
                    } catch (SQLiteException e4) {
                        e2 = e4;
                        h().H().d("(2)Error querying user properties", w3.y(str), str4, e2);
                        if (cursor != null) {
                            cursor.close();
                        }
                        return null;
                    }
                }
                cursor.close();
                return arrayList;
            } catch (SQLiteException e5) {
                e2 = e5;
                h().H().d("(2)Error querying user properties", w3.y(str), str4, e2);
                if (cursor != null) {
                }
                return null;
            } catch (Throwable th3) {
                th = th3;
                cursor2 = cursor;
                if (cursor2 != null) {
                }
                throw th;
            }
        } catch (SQLiteException e6) {
            e2 = e6;
            str4 = str2;
            cursor = null;
            h().H().d("(2)Error querying user properties", w3.y(str), str4, e2);
            if (cursor != null) {
            }
            return null;
        } catch (Throwable th4) {
        }
    }

    public final List<zzv> L(String str, String[] strArr) {
        e();
        t();
        ArrayList arrayList = new ArrayList();
        Cursor cursor = null;
        try {
            cursor = y().query("conditional_properties", new String[]{b.t0, "origin", "name", "value", a.C0251a.n, a.C0251a.f10740d, a.C0251a.f10741e, "timed_out_event", a.C0251a.m, "triggered_event", a.C0251a.o, a.C0251a.j, "expired_event"}, str, strArr, null, null, "rowid", "1001");
            if (!cursor.moveToFirst()) {
                cursor.close();
                return arrayList;
            }
            while (true) {
                if (arrayList.size() < 1000) {
                    boolean z = false;
                    String string = cursor.getString(0);
                    String string2 = cursor.getString(1);
                    String string3 = cursor.getString(2);
                    Object G = G(cursor, 3);
                    if (cursor.getInt(4) != 0) {
                        z = true;
                    }
                    String string4 = cursor.getString(5);
                    long j2 = cursor.getLong(6);
                    p9 p = p();
                    byte[] blob = cursor.getBlob(7);
                    Parcelable.Creator<zzan> creator = zzan.CREATOR;
                    long j3 = cursor.getLong(8);
                    arrayList.add(new zzv(string, string2, new zzkj(string3, cursor.getLong(10), G, string2), j3, z, string4, (zzan) p.z(blob, creator), j2, (zzan) p().z(cursor.getBlob(9), creator), cursor.getLong(11), (zzan) p().z(cursor.getBlob(12), creator)));
                    if (!cursor.moveToNext()) {
                        break;
                    }
                } else {
                    h().H().b("Read more than the max allowed conditional properties, ignoring extra", 1000);
                    break;
                }
            }
            cursor.close();
            return arrayList;
        } catch (SQLiteException e2) {
            h().H().b("Error querying conditional user property value", e2);
            List<zzv> emptyList = Collections.emptyList();
            if (cursor != null) {
                cursor.close();
            }
            return emptyList;
        } catch (Throwable th) {
            if (cursor != null) {
                cursor.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final void N(k kVar) {
        a0.k(kVar);
        e();
        t();
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, kVar.f10930a);
        contentValues.put("name", kVar.f10931b);
        contentValues.put("lifetime_count", Long.valueOf(kVar.f10932c));
        contentValues.put("current_bundle_count", Long.valueOf(kVar.f10933d));
        contentValues.put("last_fire_timestamp", Long.valueOf(kVar.f));
        contentValues.put("last_bundled_timestamp", Long.valueOf(kVar.g));
        contentValues.put("last_bundled_day", kVar.h);
        contentValues.put("last_sampled_complex_event_id", kVar.i);
        contentValues.put("last_sampling_rate", kVar.j);
        if (n().C(kVar.f10930a, o.x0)) {
            contentValues.put("current_session_count", Long.valueOf(kVar.f10934e));
        }
        Boolean bool = kVar.k;
        contentValues.put("last_exempt_from_sampling", (bool == null || !bool.booleanValue()) ? null : 1L);
        try {
            if (y().insertWithOnConflict("events", null, contentValues, 5) == -1) {
                h().H().b("Failed to insert/update event aggregates (got -1). appId", w3.y(kVar.f10930a));
            }
        } catch (SQLiteException e2) {
            h().H().c("Error storing event aggregates. appId", w3.y(kVar.f10930a), e2);
        }
    }

    @WorkerThread
    public final void O(e5 e5Var) {
        a0.k(e5Var);
        e();
        t();
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, e5Var.t());
        contentValues.put("app_instance_id", e5Var.x());
        contentValues.put("gmp_app_id", e5Var.A());
        contentValues.put("resettable_device_id_hash", e5Var.J());
        contentValues.put("last_bundle_index", Long.valueOf(e5Var.f0()));
        contentValues.put("last_bundle_start_timestamp", Long.valueOf(e5Var.P()));
        contentValues.put("last_bundle_end_timestamp", Long.valueOf(e5Var.R()));
        contentValues.put("app_version", e5Var.T());
        contentValues.put("app_store", e5Var.X());
        contentValues.put("gmp_version", Long.valueOf(e5Var.Z()));
        contentValues.put("dev_cert_hash", Long.valueOf(e5Var.b0()));
        contentValues.put("measurement_enabled", Boolean.valueOf(e5Var.e0()));
        contentValues.put("day", Long.valueOf(e5Var.j0()));
        contentValues.put("daily_public_events_count", Long.valueOf(e5Var.k0()));
        contentValues.put("daily_events_count", Long.valueOf(e5Var.l0()));
        contentValues.put("daily_conversions_count", Long.valueOf(e5Var.m0()));
        contentValues.put("config_fetched_time", Long.valueOf(e5Var.g0()));
        contentValues.put("failed_config_fetch_time", Long.valueOf(e5Var.h0()));
        contentValues.put("app_version_int", Long.valueOf(e5Var.V()));
        contentValues.put("firebase_instance_id", e5Var.M());
        contentValues.put("daily_error_events_count", Long.valueOf(e5Var.h()));
        contentValues.put("daily_realtime_events_count", Long.valueOf(e5Var.g()));
        contentValues.put("health_monitor_sample", e5Var.i());
        contentValues.put("android_id", Long.valueOf(e5Var.k()));
        contentValues.put("adid_reporting_enabled", Boolean.valueOf(e5Var.l()));
        contentValues.put("ssaid_reporting_enabled", Boolean.valueOf(e5Var.m()));
        contentValues.put("admob_app_id", e5Var.D());
        contentValues.put("dynamite_version", Long.valueOf(e5Var.d0()));
        if (e5Var.o() != null) {
            if (e5Var.o().size() == 0) {
                h().K().b("Safelisted events should not be an empty list. appId", e5Var.t());
            } else {
                contentValues.put("safelisted_events", TextUtils.join(",", e5Var.o()));
            }
        }
        if (w9.a() && n().C(e5Var.t(), o.N0)) {
            contentValues.put("ga_app_id", e5Var.G());
        }
        try {
            SQLiteDatabase y = y();
            if (((long) y.update("apps", contentValues, "app_id = ?", new String[]{e5Var.t()})) == 0 && y.insertWithOnConflict("apps", null, contentValues, 5) == -1) {
                h().H().b("Failed to insert/update app (got -1). appId", w3.y(e5Var.t()));
            }
        } catch (SQLiteException e2) {
            h().H().c("Error storing app. appId", w3.y(e5Var.t()), e2);
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void P(String str, List<zzbj.a> list) {
        boolean z;
        t();
        e();
        a0.g(str);
        a0.k(list);
        SQLiteDatabase y = y();
        y.beginTransaction();
        try {
            t();
            e();
            a0.g(str);
            SQLiteDatabase y2 = y();
            y2.delete("property_filters", "app_id=?", new String[]{str});
            y2.delete("event_filters", "app_id=?", new String[]{str});
            for (zzbj.a aVar : list) {
                t();
                e();
                a0.g(str);
                a0.k(aVar);
                if (!aVar.F()) {
                    h().K().b("Audience with no ID. appId", w3.y(str));
                } else {
                    int G = aVar.G();
                    Iterator<zzbj.b> it = aVar.K().iterator();
                    while (true) {
                        if (it.hasNext()) {
                            if (!it.next().F()) {
                                h().K().c("Event filter with no ID. Audience definition ignored. appId, audienceId", w3.y(str), Integer.valueOf(G));
                                break;
                            }
                        } else {
                            Iterator<zzbj.d> it2 = aVar.I().iterator();
                            while (true) {
                                if (it2.hasNext()) {
                                    if (!it2.next().C()) {
                                        h().K().c("Property filter with no ID. Audience definition ignored. appId, audienceId", w3.y(str), Integer.valueOf(G));
                                        break;
                                    }
                                } else {
                                    Iterator<zzbj.b> it3 = aVar.K().iterator();
                                    while (true) {
                                        if (it3.hasNext()) {
                                            if (!V(str, G, it3.next())) {
                                                z = false;
                                                break;
                                            }
                                        } else {
                                            z = true;
                                            break;
                                        }
                                    }
                                    if (z) {
                                        Iterator<zzbj.d> it4 = aVar.I().iterator();
                                        while (true) {
                                            if (it4.hasNext()) {
                                                if (!W(str, G, it4.next())) {
                                                    z = false;
                                                    break;
                                                }
                                            } else {
                                                break;
                                            }
                                        }
                                    }
                                    if (!z) {
                                        t();
                                        e();
                                        a0.g(str);
                                        SQLiteDatabase y3 = y();
                                        y3.delete("property_filters", "app_id=? and audience_id=?", new String[]{str, String.valueOf(G)});
                                        y3.delete("event_filters", "app_id=? and audience_id=?", new String[]{str, String.valueOf(G)});
                                    }
                                }
                            }
                        }
                    }
                }
            }
            ArrayList arrayList = new ArrayList();
            for (zzbj.a aVar2 : list) {
                arrayList.add(aVar2.F() ? Integer.valueOf(aVar2.G()) : null);
            }
            p0(str, arrayList);
            y.setTransactionSuccessful();
        } finally {
            y.endTransaction();
        }
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    @WorkerThread
    public final void Q(List<Long> list) {
        e();
        t();
        a0.k(list);
        a0.m(list.size());
        if (h0()) {
            String join = TextUtils.join(",", list);
            StringBuilder sb = new StringBuilder(String.valueOf(join).length() + 2);
            sb.append("(");
            sb.append(join);
            sb.append(")");
            String sb2 = sb.toString();
            StringBuilder sb3 = new StringBuilder(String.valueOf(sb2).length() + 80);
            sb3.append("SELECT COUNT(1) FROM queue WHERE rowid IN ");
            sb3.append(sb2);
            sb3.append(" AND retry_count =  2147483647 LIMIT 1");
            if (i0(sb3.toString(), null) > 0) {
                h().K().a("The number of upload retries exceeds the limit. Will remain unchanged.");
            }
            try {
                SQLiteDatabase y = y();
                StringBuilder sb4 = new StringBuilder(String.valueOf(sb2).length() + 127);
                sb4.append("UPDATE queue SET retry_count = IFNULL(retry_count, 0) + 1 WHERE rowid IN ");
                sb4.append(sb2);
                sb4.append(" AND (retry_count IS NULL OR retry_count < 2147483647)");
                y.execSQL(sb4.toString());
            } catch (SQLiteException e2) {
                h().H().b("Error incrementing retry count. error", e2);
            }
        }
    }

    @WorkerThread
    public final boolean R(zzbr.g gVar, boolean z) {
        e();
        t();
        a0.k(gVar);
        a0.g(gVar.K2());
        a0.q(gVar.n2());
        C0();
        long a2 = m().a();
        if (gVar.o2() < a2 - ga.N() || gVar.o2() > ga.N() + a2) {
            h().K().d("Storing bundle outside of the max uploading time span. appId, now, timestamp", w3.y(gVar.K2()), Long.valueOf(a2), Long.valueOf(gVar.o2()));
        }
        try {
            byte[] W = p().W(gVar.i());
            h().P().b("Saving bundle, size", Integer.valueOf(W.length));
            ContentValues contentValues = new ContentValues();
            contentValues.put(b.t0, gVar.K2());
            contentValues.put("bundle_end_timestamp", Long.valueOf(gVar.o2()));
            contentValues.put("data", W);
            contentValues.put("has_realtime", Integer.valueOf(z ? 1 : 0));
            if (gVar.z0()) {
                contentValues.put("retry_count", Integer.valueOf(gVar.M0()));
            }
            try {
                if (y().insert("queue", null, contentValues) != -1) {
                    return true;
                }
                h().H().b("Failed to insert bundle (got -1). appId", w3.y(gVar.K2()));
                return false;
            } catch (SQLiteException e2) {
                h().H().c("Error storing bundle. appId", w3.y(gVar.K2()), e2);
                return false;
            }
        } catch (IOException e3) {
            h().H().c("Data loss. Failed to serialize bundle. appId", w3.y(gVar.K2()), e3);
            return false;
        }
    }

    public final boolean S(l lVar, long j2, boolean z) {
        e();
        t();
        a0.k(lVar);
        a0.g(lVar.f10952a);
        zzbr.c.a K = zzbr.c.a0().K(lVar.f10956e);
        Iterator<String> it = lVar.f.iterator();
        while (it.hasNext()) {
            String next = it.next();
            zzbr.e.a D = zzbr.e.S().D(next);
            p().J(D, lVar.f.x0(next));
            K.D(D);
        }
        byte[] i2 = ((zzbr.c) ((d4) K.o())).i();
        h().P().c("Saving event, name, data size", g().z(lVar.f10953b), Integer.valueOf(i2.length));
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, lVar.f10952a);
        contentValues.put("name", lVar.f10953b);
        contentValues.put("timestamp", Long.valueOf(lVar.f10955d));
        contentValues.put("metadata_fingerprint", Long.valueOf(j2));
        contentValues.put("data", i2);
        contentValues.put("realtime", Integer.valueOf(z ? 1 : 0));
        try {
            if (y().insert("raw_events", null, contentValues) != -1) {
                return true;
            }
            h().H().b("Failed to insert raw event (got -1). appId", w3.y(lVar.f10952a));
            return false;
        } catch (SQLiteException e2) {
            h().H().c("Error storing raw event. appId", w3.y(lVar.f10952a), e2);
            return false;
        }
    }

    @WorkerThread
    public final boolean T(t9 t9Var) {
        a0.k(t9Var);
        e();
        t();
        if (o0(t9Var.f11129a, t9Var.f11131c) == null) {
            if (s9.Y(t9Var.f11131c)) {
                if (i0("select count(1) from user_attributes where app_id=? and name not like '!_%' escape '!'", new String[]{t9Var.f11129a}) >= 25) {
                    return false;
                }
            } else if (!n().C(t9Var.f11129a, o.k0)) {
                if (i0("select count(1) from user_attributes where app_id=? and origin=? AND name like '!_%' escape '!'", new String[]{t9Var.f11129a, t9Var.f11130b}) >= 25) {
                    return false;
                }
            } else if (!"_npa".equals(t9Var.f11131c)) {
                if (i0("select count(1) from user_attributes where app_id=? and origin=? AND name like '!_%' escape '!'", new String[]{t9Var.f11129a, t9Var.f11130b}) >= 25) {
                    return false;
                }
            }
        }
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, t9Var.f11129a);
        contentValues.put("origin", t9Var.f11130b);
        contentValues.put("name", t9Var.f11131c);
        contentValues.put("set_timestamp", Long.valueOf(t9Var.f11132d));
        M(contentValues, "value", t9Var.f11133e);
        try {
            if (y().insertWithOnConflict("user_attributes", null, contentValues, 5) == -1) {
                h().H().b("Failed to insert/update user property (got -1). appId", w3.y(t9Var.f11129a));
            }
        } catch (SQLiteException e2) {
            h().H().c("Error storing user property. appId", w3.y(t9Var.f11129a), e2);
        }
        return true;
    }

    @WorkerThread
    public final boolean U(zzv zzv) {
        a0.k(zzv);
        e();
        t();
        if (o0(zzv.f11239a, zzv.I0.f11236b) == null) {
            if (i0("SELECT COUNT(1) FROM conditional_properties WHERE app_id=?", new String[]{zzv.f11239a}) >= 1000) {
                return false;
            }
        }
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, zzv.f11239a);
        contentValues.put("origin", zzv.f11240b);
        contentValues.put("name", zzv.I0.f11236b);
        M(contentValues, "value", zzv.I0.e0());
        contentValues.put(a.C0251a.n, Boolean.valueOf(zzv.K0));
        contentValues.put(a.C0251a.f10740d, zzv.L0);
        contentValues.put(a.C0251a.f10741e, Long.valueOf(zzv.N0));
        k();
        contentValues.put("timed_out_event", s9.g0(zzv.M0));
        contentValues.put(a.C0251a.m, Long.valueOf(zzv.J0));
        k();
        contentValues.put("triggered_event", s9.g0(zzv.O0));
        contentValues.put(a.C0251a.o, Long.valueOf(zzv.I0.I0));
        contentValues.put(a.C0251a.j, Long.valueOf(zzv.P0));
        k();
        contentValues.put("expired_event", s9.g0(zzv.Q0));
        try {
            if (y().insertWithOnConflict("conditional_properties", null, contentValues, 5) == -1) {
                h().H().b("Failed to insert/update conditional user property (got -1)", w3.y(zzv.f11239a));
            }
        } catch (SQLiteException e2) {
            h().H().c("Error storing conditional user property", w3.y(zzv.f11239a), e2);
        }
        return true;
    }

    public final boolean X(String str, Long l2, long j2, zzbr.c cVar) {
        e();
        t();
        a0.k(cVar);
        a0.g(str);
        a0.k(l2);
        byte[] i2 = cVar.i();
        h().P().c("Saving complex main event, appId, data size", g().z(str), Integer.valueOf(i2.length));
        ContentValues contentValues = new ContentValues();
        contentValues.put(b.t0, str);
        contentValues.put("event_id", l2);
        contentValues.put("children_to_process", Long.valueOf(j2));
        contentValues.put("main_event", i2);
        try {
            if (y().insertWithOnConflict("main_event_params", null, contentValues, 5) != -1) {
                return true;
            }
            h().H().b("Failed to insert complex main event (got -1). appId", w3.y(str));
            return false;
        } catch (SQLiteException e2) {
            h().H().c("Error storing complex main event. appId", w3.y(str), e2);
            return false;
        }
    }

    public final long Y() {
        Cursor cursor = null;
        try {
            cursor = y().rawQuery("select rowid from raw_events order by rowid desc limit 1;", null);
            if (!cursor.moveToFirst()) {
                cursor.close();
                return -1;
            }
            long j2 = cursor.getLong(0);
            cursor.close();
            return j2;
        } catch (SQLiteException e2) {
            h().H().b("Error querying raw events", e2);
            if (cursor != null) {
                cursor.close();
            }
            return -1;
        } catch (Throwable th) {
            if (cursor != null) {
                cursor.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x0119 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:20:0x011d A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x0153 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:24:0x0155 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:27:0x0164 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x0179 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:40:0x0195 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:41:0x0196 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:44:0x01a5 A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:52:0x01db A[Catch:{ SQLiteException -> 0x01f0 }] */
    /* JADX WARNING: Removed duplicated region for block: B:67:0x0215  */
    /* JADX WARNING: Removed duplicated region for block: B:72:0x021d  */
    @WorkerThread
    public final e5 j0(String str) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        boolean z;
        boolean z2;
        a0.g(str);
        e();
        t();
        Cursor cursor2 = null;
        try {
            boolean z3 = true;
            cursor = y().query("apps", new String[]{"app_instance_id", "gmp_app_id", "resettable_device_id_hash", "last_bundle_index", "last_bundle_start_timestamp", "last_bundle_end_timestamp", "app_version", "app_store", "gmp_version", "dev_cert_hash", "measurement_enabled", "day", "daily_public_events_count", "daily_events_count", "daily_conversions_count", "config_fetched_time", "failed_config_fetch_time", "app_version_int", "firebase_instance_id", "daily_error_events_count", "daily_realtime_events_count", "health_monitor_sample", "android_id", "adid_reporting_enabled", "ssaid_reporting_enabled", "admob_app_id", "dynamite_version", "safelisted_events", "ga_app_id"}, "app_id=?", new String[]{str}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return null;
                }
                try {
                    e5 e5Var = new e5(this.f10929b.g0(), str);
                    e5Var.c(cursor.getString(0));
                    e5Var.r(cursor.getString(1));
                    e5Var.C(cursor.getString(2));
                    e5Var.H(cursor.getLong(3));
                    e5Var.a(cursor.getLong(4));
                    e5Var.q(cursor.getLong(5));
                    e5Var.I(cursor.getString(6));
                    e5Var.L(cursor.getString(7));
                    e5Var.y(cursor.getLong(8));
                    e5Var.B(cursor.getLong(9));
                    if (!cursor.isNull(10)) {
                        if (cursor.getInt(10) == 0) {
                            z = false;
                            e5Var.e(z);
                            e5Var.Q(cursor.getLong(11));
                            e5Var.S(cursor.getLong(12));
                            e5Var.U(cursor.getLong(13));
                            e5Var.W(cursor.getLong(14));
                            e5Var.K(cursor.getLong(15));
                            e5Var.N(cursor.getLong(16));
                            e5Var.u(!cursor.isNull(17) ? -2147483648L : (long) cursor.getInt(17));
                            e5Var.F(cursor.getString(18));
                            e5Var.a0(cursor.getLong(19));
                            e5Var.Y(cursor.getLong(20));
                            e5Var.O(cursor.getString(21));
                            long j2 = 0;
                            e5Var.c0(!cursor.isNull(22) ? 0 : cursor.getLong(22));
                            if (!cursor.isNull(23)) {
                                if (cursor.getInt(23) == 0) {
                                    z2 = false;
                                    e5Var.s(z2);
                                    if (!cursor.isNull(24)) {
                                        if (cursor.getInt(24) == 0) {
                                            z3 = false;
                                        }
                                    }
                                    e5Var.w(z3);
                                    e5Var.v(cursor.getString(25));
                                    if (!cursor.isNull(26)) {
                                        j2 = cursor.getLong(26);
                                    }
                                    e5Var.E(j2);
                                    if (!cursor.isNull(27)) {
                                        e5Var.d(Arrays.asList(cursor.getString(27).split(",", -1)));
                                    }
                                    if (w9.a() && n().C(str, o.N0)) {
                                        e5Var.z(cursor.getString(28));
                                    }
                                    e5Var.p();
                                    if (cursor.moveToNext()) {
                                        h().H().b("Got multiple records for app, expected one. appId", w3.y(str));
                                    }
                                    cursor.close();
                                    return e5Var;
                                }
                            }
                            z2 = true;
                            e5Var.s(z2);
                            if (!cursor.isNull(24)) {
                            }
                            e5Var.w(z3);
                            e5Var.v(cursor.getString(25));
                            if (!cursor.isNull(26)) {
                            }
                            e5Var.E(j2);
                            if (!cursor.isNull(27)) {
                            }
                            e5Var.z(cursor.getString(28));
                            e5Var.p();
                            if (cursor.moveToNext()) {
                            }
                            cursor.close();
                            return e5Var;
                        }
                    }
                    z = true;
                    e5Var.e(z);
                    e5Var.Q(cursor.getLong(11));
                    e5Var.S(cursor.getLong(12));
                    e5Var.U(cursor.getLong(13));
                    e5Var.W(cursor.getLong(14));
                    e5Var.K(cursor.getLong(15));
                    e5Var.N(cursor.getLong(16));
                    e5Var.u(!cursor.isNull(17) ? -2147483648L : (long) cursor.getInt(17));
                    e5Var.F(cursor.getString(18));
                    e5Var.a0(cursor.getLong(19));
                    e5Var.Y(cursor.getLong(20));
                    e5Var.O(cursor.getString(21));
                    long j22 = 0;
                    e5Var.c0(!cursor.isNull(22) ? 0 : cursor.getLong(22));
                    if (!cursor.isNull(23)) {
                    }
                    z2 = true;
                    e5Var.s(z2);
                    if (!cursor.isNull(24)) {
                    }
                    e5Var.w(z3);
                    e5Var.v(cursor.getString(25));
                    if (!cursor.isNull(26)) {
                    }
                    e5Var.E(j22);
                    if (!cursor.isNull(27)) {
                    }
                    e5Var.z(cursor.getString(28));
                    e5Var.p();
                    if (cursor.moveToNext()) {
                    }
                    cursor.close();
                    return e5Var;
                } catch (SQLiteException e3) {
                    e2 = e3;
                    try {
                        h().H().c("Error querying app. appId", w3.y(str), e2);
                        if (cursor != null) {
                        }
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor2 = cursor;
                        if (cursor2 != null) {
                        }
                        throw th;
                    }
                }
            } catch (SQLiteException e4) {
                e2 = e4;
                h().H().c("Error querying app. appId", w3.y(str), e2);
                if (cursor != null) {
                }
                return null;
            } catch (Throwable th3) {
                th = th3;
                cursor2 = cursor;
                if (cursor2 != null) {
                }
                throw th;
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().c("Error querying app. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th4) {
            th = th4;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final List<zzv> k0(String str, String str2, String str3) {
        a0.g(str);
        e();
        t();
        ArrayList arrayList = new ArrayList(3);
        arrayList.add(str);
        StringBuilder sb = new StringBuilder("app_id=?");
        if (!TextUtils.isEmpty(str2)) {
            arrayList.add(str2);
            sb.append(" and origin=?");
        }
        if (!TextUtils.isEmpty(str3)) {
            arrayList.add(String.valueOf(str3).concat("*"));
            sb.append(" and name glob ?");
        }
        return L(sb.toString(), (String[]) arrayList.toArray(new String[arrayList.size()]));
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x00be  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x00c6  */
    public final Map<Integer, List<Integer>> l0(String str, List<String> list) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        t();
        e();
        a0.g(str);
        a0.k(list);
        b.b.a aVar = new b.b.a();
        if (list.isEmpty()) {
            return aVar;
        }
        StringBuilder sb = new StringBuilder();
        sb.append("app_id=? AND property_name in (");
        for (int i2 = 0; i2 < list.size(); i2++) {
            if (i2 > 0) {
                sb.append(",");
            }
            sb.append("?");
        }
        sb.append(")");
        ArrayList arrayList = new ArrayList(list);
        arrayList.add(0, str);
        Cursor cursor2 = null;
        try {
            cursor = y().query("property_filters", new String[]{"audience_id", "filter_id"}, sb.toString(), (String[]) arrayList.toArray(new String[0]), null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return aVar;
                }
                do {
                    int i3 = cursor.getInt(0);
                    List list2 = (List) aVar.get(Integer.valueOf(i3));
                    if (list2 == null) {
                        list2 = new ArrayList();
                        aVar.put(Integer.valueOf(i3), list2);
                    }
                    list2.add(Integer.valueOf(cursor.getInt(1)));
                } while (cursor.moveToNext());
                cursor.close();
                return aVar;
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().c("Database error querying filters. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e4) {
            e2 = e4;
            cursor = null;
            h().H().c("Database error querying filters. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final void m0(String str, String str2) {
        a0.g(str);
        a0.g(str2);
        e();
        t();
        try {
            h().P().b("Deleted user attribute rows", Integer.valueOf(y().delete("user_attributes", "app_id=? and name=?", new String[]{str, str2})));
        } catch (SQLiteException e2) {
            h().H().d("Error deleting user attribute. appId", w3.y(str), g().C(str2), e2);
        }
    }

    public final long n0(String str) {
        a0.g(str);
        e();
        t();
        try {
            return (long) y().delete("raw_events", "rowid in (select rowid from raw_events where app_id=? order by rowid desc limit -1 offset ?)", new String[]{str, String.valueOf(Math.max(0, Math.min((int) DurationKt.NANOS_IN_MILLIS, n().t(str, o.w))))});
        } catch (SQLiteException e2) {
            h().H().c("Error deleting over the limit events. appId", w3.y(str), e2);
            return 0;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:27:0x009d  */
    /* JADX WARNING: Removed duplicated region for block: B:32:0x00a5  */
    @WorkerThread
    public final t9 o0(String str, String str2) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        a0.g(str);
        a0.g(str2);
        e();
        t();
        Cursor cursor2 = null;
        try {
            cursor = y().query("user_attributes", new String[]{"set_timestamp", "value", "origin"}, "app_id=? and name=?", new String[]{str, str2}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return null;
                }
                try {
                    t9 t9Var = new t9(str, cursor.getString(2), str2, cursor.getLong(0), G(cursor, 1));
                    if (cursor.moveToNext()) {
                        h().H().b("Got multiple records for user property, expected one. appId", w3.y(str));
                    }
                    cursor.close();
                    return t9Var;
                } catch (SQLiteException e3) {
                    e2 = e3;
                    try {
                        h().H().d("Error querying user property. appId", w3.y(str), g().C(str2), e2);
                        if (cursor != null) {
                        }
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor2 = cursor;
                        if (cursor2 != null) {
                            cursor2.close();
                        }
                        throw th;
                    }
                }
            } catch (SQLiteException e4) {
                e2 = e4;
                h().H().d("Error querying user property. appId", w3.y(str), g().C(str2), e2);
                if (cursor != null) {
                }
                return null;
            } catch (Throwable th3) {
                th = th3;
                cursor2 = cursor;
                if (cursor2 != null) {
                }
                throw th;
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().d("Error querying user property. appId", w3.y(str), g().C(str2), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th4) {
            th = th4;
            if (cursor2 != null) {
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:31:0x0115  */
    /* JADX WARNING: Removed duplicated region for block: B:36:0x011d  */
    @WorkerThread
    public final zzv q0(String str, String str2) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        a0.g(str);
        a0.g(str2);
        e();
        t();
        Cursor cursor2 = null;
        try {
            cursor = y().query("conditional_properties", new String[]{"origin", "value", a.C0251a.n, a.C0251a.f10740d, a.C0251a.f10741e, "timed_out_event", a.C0251a.m, "triggered_event", a.C0251a.o, a.C0251a.j, "expired_event"}, "app_id=? and name=?", new String[]{str, str2}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return null;
                }
                String string = cursor.getString(0);
                try {
                    Object G = G(cursor, 1);
                    boolean z = cursor.getInt(2) != 0;
                    String string2 = cursor.getString(3);
                    long j2 = cursor.getLong(4);
                    p9 p = p();
                    byte[] blob = cursor.getBlob(5);
                    Parcelable.Creator<zzan> creator = zzan.CREATOR;
                    zzv zzv = new zzv(str, string, new zzkj(str2, cursor.getLong(8), G, string), cursor.getLong(6), z, string2, (zzan) p.z(blob, creator), j2, (zzan) p().z(cursor.getBlob(7), creator), cursor.getLong(9), (zzan) p().z(cursor.getBlob(10), creator));
                    if (cursor.moveToNext()) {
                        h().H().c("Got multiple records for conditional property, expected one", w3.y(str), g().C(str2));
                    }
                    cursor.close();
                    return zzv;
                } catch (SQLiteException e3) {
                    e2 = e3;
                    try {
                        h().H().d("Error querying conditional property", w3.y(str), g().C(str2), e2);
                        if (cursor != null) {
                            cursor.close();
                        }
                        return null;
                    } catch (Throwable th2) {
                        th = th2;
                        cursor2 = cursor;
                        if (cursor2 != null) {
                        }
                        throw th;
                    }
                }
            } catch (SQLiteException e4) {
                e2 = e4;
                h().H().d("Error querying conditional property", w3.y(str), g().C(str2), e2);
                if (cursor != null) {
                }
                return null;
            } catch (Throwable th3) {
                th = th3;
                cursor2 = cursor;
                if (cursor2 != null) {
                }
                throw th;
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().d("Error querying conditional property", w3.y(str), g().C(str2), e2);
            if (cursor != null) {
            }
            return null;
        } catch (Throwable th4) {
            th = th4;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:20:0x0067  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x006f  */
    @WorkerThread
    public final byte[] r0(String str) {
        Throwable th;
        SQLiteException e2;
        Cursor cursor;
        a0.g(str);
        e();
        t();
        Cursor cursor2 = null;
        try {
            cursor = y().query("apps", new String[]{"remote_config"}, "app_id=?", new String[]{str}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return null;
                }
                byte[] blob = cursor.getBlob(0);
                if (cursor.moveToNext()) {
                    h().H().b("Got multiple records for app config, expected one. appId", w3.y(str));
                }
                cursor.close();
                return blob;
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().c("Error querying remote config. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e4) {
            e2 = e4;
            cursor = null;
            h().H().c("Error querying remote config. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    @WorkerThread
    public final int s0(String str, String str2) {
        a0.g(str);
        a0.g(str2);
        e();
        t();
        try {
            return y().delete("conditional_properties", "app_id=? and name=?", new String[]{str, str2});
        } catch (SQLiteException e2) {
            h().H().d("Error deleting conditional property", w3.y(str), g().C(str2), e2);
            return 0;
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x007a  */
    /* JADX WARNING: Removed duplicated region for block: B:28:0x0082  */
    public final Map<Integer, List<Integer>> t0(String str) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        t();
        e();
        a0.g(str);
        b.b.a aVar = new b.b.a();
        Cursor cursor2 = null;
        try {
            cursor = y().rawQuery("select audience_id, filter_id from event_filters where app_id = ? and session_scoped = 1 UNION select audience_id, filter_id from property_filters where app_id = ? and session_scoped = 1;", new String[]{str, str});
            try {
                if (!cursor.moveToFirst()) {
                    Map<Integer, List<Integer>> emptyMap = Collections.emptyMap();
                    cursor.close();
                    return emptyMap;
                }
                do {
                    int i2 = cursor.getInt(0);
                    List list = (List) aVar.get(Integer.valueOf(i2));
                    if (list == null) {
                        list = new ArrayList();
                        aVar.put(Integer.valueOf(i2), list);
                    }
                    list.add(Integer.valueOf(cursor.getInt(1)));
                } while (cursor.moveToNext());
                cursor.close();
                return aVar;
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().c("Database error querying scoped filters. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e4) {
            e2 = e4;
            cursor = null;
            h().H().c("Database error querying scoped filters. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:26:0x0091  */
    /* JADX WARNING: Removed duplicated region for block: B:31:0x0099  */
    public final Map<Integer, zzbr.h> u0(String str) {
        Throwable th;
        SQLiteException e2;
        Cursor cursor;
        t();
        e();
        a0.g(str);
        Cursor cursor2 = null;
        try {
            cursor = y().query("audience_filter_values", new String[]{"audience_id", "current_results"}, "app_id=?", new String[]{str}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    cursor.close();
                    return null;
                }
                b.b.a aVar = new b.b.a();
                do {
                    int i2 = cursor.getInt(0);
                    try {
                        aVar.put(Integer.valueOf(i2), (zzbr.h) ((d4) ((zzbr.h.a) p9.B(zzbr.h.Y(), cursor.getBlob(1))).o()));
                    } catch (IOException e3) {
                        h().H().d("Failed to merge filter results. appId, audienceId, error", w3.y(str), Integer.valueOf(i2), e3);
                    }
                } while (cursor.moveToNext());
                cursor.close();
                return aVar;
            } catch (SQLiteException e4) {
                e2 = e4;
                try {
                    h().H().c("Database error querying filter results. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().c("Database error querying filter results. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x00ab  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x00b3  */
    public final Map<Integer, List<zzbj.b>> v0(String str, String str2) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        t();
        e();
        a0.g(str);
        a0.g(str2);
        b.b.a aVar = new b.b.a();
        Cursor cursor2 = null;
        try {
            cursor = y().query("event_filters", new String[]{"audience_id", "data"}, "app_id=? AND event_name=?", new String[]{str, str2}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    Map<Integer, List<zzbj.b>> emptyMap = Collections.emptyMap();
                    cursor.close();
                    return emptyMap;
                }
                do {
                    try {
                        zzbj.b bVar = (zzbj.b) ((d4) ((zzbj.b.a) p9.B(zzbj.b.Q(), cursor.getBlob(1))).o());
                        int i2 = cursor.getInt(0);
                        List list = (List) aVar.get(Integer.valueOf(i2));
                        if (list == null) {
                            list = new ArrayList();
                            aVar.put(Integer.valueOf(i2), list);
                        }
                        list.add(bVar);
                    } catch (IOException e3) {
                        h().H().c("Failed to merge filter. appId", w3.y(str), e3);
                    }
                } while (cursor.moveToNext());
                cursor.close();
                return aVar;
            } catch (SQLiteException e4) {
                e2 = e4;
                try {
                    h().H().c("Database error querying filters. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().c("Database error querying filters. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* access modifiers changed from: protected */
    @Override // com.google.android.gms.measurement.internal.h9
    public final boolean w() {
        return false;
    }

    @WorkerThread
    public final void w0() {
        t();
        y().beginTransaction();
    }

    @WorkerThread
    public final void x() {
        t();
        y().setTransactionSuccessful();
    }

    public final long x0(String str) {
        a0.g(str);
        return B("select count(1) from events where app_id=? and name not like '!_%' escape '!'", new String[]{str}, 0);
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    @WorkerThread
    public final SQLiteDatabase y() {
        e();
        try {
            return this.l.getWritableDatabase();
        } catch (SQLiteException e2) {
            h().K().b("Error opening database", e2);
            throw e2;
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:29:0x00ab  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x00b3  */
    public final Map<Integer, List<zzbj.d>> y0(String str, String str2) {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        t();
        e();
        a0.g(str);
        a0.g(str2);
        b.b.a aVar = new b.b.a();
        Cursor cursor2 = null;
        try {
            cursor = y().query("property_filters", new String[]{"audience_id", "data"}, "app_id=? AND property_name=?", new String[]{str, str2}, null, null, null);
            try {
                if (!cursor.moveToFirst()) {
                    Map<Integer, List<zzbj.d>> emptyMap = Collections.emptyMap();
                    cursor.close();
                    return emptyMap;
                }
                do {
                    try {
                        zzbj.d dVar = (zzbj.d) ((d4) ((zzbj.d.a) p9.B(zzbj.d.K(), cursor.getBlob(1))).o());
                        int i2 = cursor.getInt(0);
                        List list = (List) aVar.get(Integer.valueOf(i2));
                        if (list == null) {
                            list = new ArrayList();
                            aVar.put(Integer.valueOf(i2), list);
                        }
                        list.add(dVar);
                    } catch (IOException e3) {
                        h().H().c("Failed to merge filter", w3.y(str), e3);
                    }
                } while (cursor.moveToNext());
                cursor.close();
                return aVar;
            } catch (SQLiteException e4) {
                e2 = e4;
                try {
                    h().H().c("Database error querying filters. appId", w3.y(str), e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    cursor2 = cursor;
                    if (cursor2 != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            cursor = null;
            h().H().c("Database error querying filters. appId", w3.y(str), e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            if (cursor2 != null) {
                cursor2.close();
            }
            throw th;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:19:0x0036  */
    /* JADX WARNING: Removed duplicated region for block: B:23:0x003d  */
    @WorkerThread
    public final String z() {
        Throwable th;
        Cursor cursor;
        SQLiteException e2;
        try {
            cursor = y().rawQuery("select app_id from queue order by has_realtime desc, rowid asc limit 1;", null);
            try {
                if (cursor.moveToFirst()) {
                    String string = cursor.getString(0);
                    cursor.close();
                    return string;
                }
                cursor.close();
                return null;
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().b("Database error getting next bundle app id", e2);
                    if (cursor != null) {
                    }
                    return null;
                } catch (Throwable th2) {
                    th = th2;
                    if (cursor != null) {
                    }
                    throw th;
                }
            }
        } catch (SQLiteException e4) {
            e2 = e4;
            cursor = null;
            h().H().b("Database error getting next bundle app id", e2);
            if (cursor != null) {
                cursor.close();
            }
            return null;
        } catch (Throwable th3) {
            th = th3;
            cursor = null;
            if (cursor != null) {
                cursor.close();
            }
            throw th;
        }
    }

    /* access modifiers changed from: protected */
    @VisibleForTesting
    @WorkerThread
    public final long z0(String str, String str2) {
        Throwable th;
        SQLiteException e2;
        long B;
        a0.g(str);
        a0.g(str2);
        e();
        t();
        SQLiteDatabase y = y();
        y.beginTransaction();
        long j2 = 0;
        try {
            StringBuilder sb = new StringBuilder(String.valueOf(str2).length() + 32);
            sb.append("select ");
            sb.append(str2);
            sb.append(" from app2 where app_id=?");
            try {
                B = B(sb.toString(), new String[]{str}, -1);
                if (B == -1) {
                    ContentValues contentValues = new ContentValues();
                    contentValues.put(b.t0, str);
                    contentValues.put("first_open_count", (Integer) 0);
                    contentValues.put("previous_install_count", (Integer) 0);
                    if (y.insertWithOnConflict("app2", null, contentValues, 5) == -1) {
                        h().H().c("Failed to insert column (got -1). appId", w3.y(str), str2);
                        y.endTransaction();
                        return -1;
                    }
                    B = 0;
                }
            } catch (SQLiteException e3) {
                e2 = e3;
                try {
                    h().H().d("Error inserting column. appId", w3.y(str), str2, e2);
                    y.endTransaction();
                    return j2;
                } catch (Throwable th2) {
                    th = th2;
                    y.endTransaction();
                    throw th;
                }
            }
            try {
                ContentValues contentValues2 = new ContentValues();
                contentValues2.put(b.t0, str);
                contentValues2.put(str2, Long.valueOf(1 + B));
                if (((long) y.update("app2", contentValues2, "app_id = ?", new String[]{str})) == 0) {
                    h().H().c("Failed to update column (got 0). appId", w3.y(str), str2);
                    y.endTransaction();
                    return -1;
                }
                y.setTransactionSuccessful();
                y.endTransaction();
                return B;
            } catch (SQLiteException e4) {
                e2 = e4;
                j2 = B;
                h().H().d("Error inserting column. appId", w3.y(str), str2, e2);
                y.endTransaction();
                return j2;
            }
        } catch (SQLiteException e5) {
            e2 = e5;
            h().H().d("Error inserting column. appId", w3.y(str), str2, e2);
            y.endTransaction();
            return j2;
        } catch (Throwable th3) {
            th = th3;
            y.endTransaction();
            throw th;
        }
    }
}
