package com.google.android.gms.measurement.internal;

import android.content.Context;
import android.content.pm.ApplicationInfo;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteException;
import android.net.Uri;
import android.os.Build;
import android.os.Bundle;
import android.provider.Settings;
import android.text.TextUtils;
import android.util.Pair;
import androidx.annotation.NonNull;
import androidx.annotation.WorkerThread;
import com.google.android.exoplayer2.text.ttml.b;
import com.google.android.gms.common.internal.a0;
import com.google.android.gms.common.p.c;
import com.google.android.gms.common.util.VisibleForTesting;
import com.google.android.gms.common.util.g;
import com.google.android.gms.internal.measurement.d4;
import com.google.android.gms.internal.measurement.db;
import com.google.android.gms.internal.measurement.f9;
import com.google.android.gms.internal.measurement.k9;
import com.google.android.gms.internal.measurement.p0;
import com.google.android.gms.internal.measurement.w9;
import com.google.android.gms.internal.measurement.zzbr;
import com.google.firebase.analytics.FirebaseAnalytics;
import com.ibm.icu.lang.c;
import com.lzy.okgo.model.HttpHeaders;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.net.MalformedURLException;
import java.net.URL;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;
import java.nio.channels.FileLock;
import java.nio.channels.OverlappingFileLockException;
import java.security.SecureRandom;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.TimeoutException;
import kotlin.time.DurationKt;
import kotlinx.coroutines.s0;

/* compiled from: com.google.android.gms:play-services-measurement@@17.2.0 */
public class l9 implements z5 {

    /* renamed from: a  reason: collision with root package name */
    private static volatile l9 f10974a;

    /* renamed from: b  reason: collision with root package name */
    private v4 f10975b;

    /* renamed from: c  reason: collision with root package name */
    private a4 f10976c;

    /* renamed from: d  reason: collision with root package name */
    private d f10977d;

    /* renamed from: e  reason: collision with root package name */
    private i4 f10978e;
    private g9 f;
    private x9 g;
    private final p9 h;
    private l7 i;
    private final b5 j;
    private boolean k;
    private boolean l;
    private boolean m;
    @VisibleForTesting
    private long n;
    private List<Runnable> o;
    private int p;
    private int q;
    private boolean r;
    private boolean s;
    private boolean t;
    private FileLock u;
    private FileChannel v;
    private List<Long> w;
    private List<Long> x;
    private long y;

    /* access modifiers changed from: package-private */
    /* compiled from: com.google.android.gms:play-services-measurement@@17.2.0 */
    public class a implements f {

        /* renamed from: a  reason: collision with root package name */
        zzbr.g f10979a;

        /* renamed from: b  reason: collision with root package name */
        List<Long> f10980b;

        /* renamed from: c  reason: collision with root package name */
        List<zzbr.c> f10981c;

        /* renamed from: d  reason: collision with root package name */
        private long f10982d;

        private a() {
        }

        private static long c(zzbr.c cVar) {
            return ((cVar.V() / 1000) / 60) / 60;
        }

        @Override // com.google.android.gms.measurement.internal.f
        public final void a(zzbr.g gVar) {
            a0.k(gVar);
            this.f10979a = gVar;
        }

        @Override // com.google.android.gms.measurement.internal.f
        public final boolean b(long j, zzbr.c cVar) {
            a0.k(cVar);
            if (this.f10981c == null) {
                this.f10981c = new ArrayList();
            }
            if (this.f10980b == null) {
                this.f10980b = new ArrayList();
            }
            if (this.f10981c.size() > 0 && c(this.f10981c.get(0)) != c(cVar)) {
                return false;
            }
            long h = this.f10982d + ((long) cVar.h());
            if (h >= ((long) Math.max(0, o.p.a(null).intValue()))) {
                return false;
            }
            this.f10982d = h;
            this.f10981c.add(cVar);
            this.f10980b.add(Long.valueOf(j));
            if (this.f10981c.size() >= Math.max(1, o.q.a(null).intValue())) {
                return false;
            }
            return true;
        }

        /* synthetic */ a(l9 l9Var, k9 k9Var) {
            this();
        }
    }

    private l9(q9 q9Var) {
        this(q9Var, null);
    }

    @VisibleForTesting
    @WorkerThread
    private final boolean D(int i2, FileChannel fileChannel) {
        j0();
        if (fileChannel == null || !fileChannel.isOpen()) {
            this.j.h().H().a("Bad channel to read from");
            return false;
        }
        ByteBuffer allocate = ByteBuffer.allocate(4);
        allocate.putInt(i2);
        allocate.flip();
        try {
            fileChannel.truncate(0L);
            fileChannel.write(allocate);
            fileChannel.force(true);
            if (fileChannel.size() != 4) {
                this.j.h().H().b("Error writing to channel. Bytes written", Long.valueOf(fileChannel.size()));
            }
            return true;
        } catch (IOException e2) {
            this.j.h().H().b("Failed to write to channel", e2);
            return false;
        }
    }

    private final boolean E(zzbr.c.a aVar, zzbr.c.a aVar2) {
        String str;
        a0.a("_e".equals(aVar.L()));
        Z();
        zzbr.e A = p9.A((zzbr.c) ((d4) aVar.o()), "_sc");
        String str2 = null;
        if (A == null) {
            str = null;
        } else {
            str = A.M();
        }
        Z();
        zzbr.e A2 = p9.A((zzbr.c) ((d4) aVar2.o()), "_pc");
        if (A2 != null) {
            str2 = A2.M();
        }
        if (str2 == null || !str2.equals(str)) {
            return false;
        }
        L(aVar, aVar2);
        return true;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:420:0x0cd3, code lost:
        if (r5 != r20) goto L_0x0cd5;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:422:0x0cd7, code lost:
        r1 = false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:424:0x0ceb, code lost:
        if (java.lang.Math.abs(r7.N() - r11.g) >= com.ibm.icu.impl.e.j) goto L_0x0cd5;
     */
    /* JADX WARNING: Removed duplicated region for block: B:119:0x0390  */
    /* JADX WARNING: Removed duplicated region for block: B:126:0x039c  */
    /* JADX WARNING: Removed duplicated region for block: B:132:0x03b9  */
    /* JADX WARNING: Removed duplicated region for block: B:145:0x045a  */
    /* JADX WARNING: Removed duplicated region for block: B:148:0x04bb  */
    /* JADX WARNING: Removed duplicated region for block: B:149:0x04bf  */
    /* JADX WARNING: Removed duplicated region for block: B:158:0x0525  */
    /* JADX WARNING: Removed duplicated region for block: B:167:0x0554 A[ADDED_TO_REGION] */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x055d  */
    /* JADX WARNING: Removed duplicated region for block: B:171:0x057c  */
    /* JADX WARNING: Removed duplicated region for block: B:209:0x0670  */
    /* JADX WARNING: Removed duplicated region for block: B:246:0x077b  */
    /* JADX WARNING: Removed duplicated region for block: B:252:0x0795  */
    /* JADX WARNING: Removed duplicated region for block: B:253:0x07af  */
    /* JADX WARNING: Removed duplicated region for block: B:378:0x0b34  */
    /* JADX WARNING: Removed duplicated region for block: B:379:0x0b47  */
    /* JADX WARNING: Removed duplicated region for block: B:381:0x0b4a  */
    /* JADX WARNING: Removed duplicated region for block: B:382:0x0b71  */
    /* JADX WARNING: Removed duplicated region for block: B:497:0x0f38  */
    /* JADX WARNING: Removed duplicated region for block: B:502:0x0f4c  */
    /* JADX WARNING: Removed duplicated region for block: B:512:0x0422 A[EDGE_INSN: B:512:0x0422->B:140:0x0422 ?: BREAK  , SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x0240  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x0247  */
    /* JADX WARNING: Removed duplicated region for block: B:84:0x0253  */
    @WorkerThread
    private final boolean F(String str, long j2) {
        Throwable th;
        Throwable th2;
        List<zzbr.c> list;
        boolean z;
        String str2;
        long j3;
        SecureRandom secureRandom;
        HashMap hashMap;
        int i2;
        boolean z2;
        int G;
        long j4;
        HashMap hashMap2;
        long j5;
        e5 j0;
        boolean z3;
        boolean z4;
        zzbr.c.a aVar;
        boolean z5;
        int i3;
        zzbr.g.a aVar2;
        int i4;
        int i5;
        String str3;
        int i6;
        boolean z6;
        zzbr.g.a aVar3;
        String str4;
        int i7;
        zzbr.e.a aVar4;
        boolean z7;
        String str5;
        String str6;
        String str7;
        String str8;
        String str9;
        boolean z8;
        char c2;
        String str10;
        SQLiteException sQLiteException;
        String str11;
        String[] strArr;
        String str12;
        String[] strArr2;
        l9 l9Var = this;
        String str13 = "_npa";
        W().w0();
        try {
            Cursor cursor = null;
            a aVar5 = new a(l9Var, null);
            d W = W();
            long j6 = l9Var.y;
            a0.k(aVar5);
            W.e();
            W.t();
            try {
                SQLiteDatabase y2 = W.y();
                String str14 = "";
                if (TextUtils.isEmpty(null)) {
                    int i8 = (j6 > -1 ? 1 : (j6 == -1 ? 0 : -1));
                    if (i8 != 0) {
                        try {
                            strArr2 = new String[]{String.valueOf(j6), String.valueOf(j2)};
                        } catch (SQLiteException e2) {
                            sQLiteException = e2;
                            str10 = null;
                        }
                    } else {
                        strArr2 = new String[]{String.valueOf(j2)};
                    }
                    if (i8 != 0) {
                        str14 = "rowid <= ? and ";
                    }
                    StringBuilder sb = new StringBuilder(str14.length() + 148);
                    sb.append("select app_id, metadata_fingerprint from raw_events where ");
                    sb.append(str14);
                    sb.append("app_id in (select app_id from apps where config_fetched_time >= ?) order by rowid limit 1;");
                    cursor = y2.rawQuery(sb.toString(), strArr2);
                    try {
                        if (!cursor.moveToFirst()) {
                            cursor.close();
                            list = aVar5.f10981c;
                            if (!(list != null || list.isEmpty())) {
                                zzbr.g.a T = ((zzbr.g.a) aVar5.f10979a.w()).T();
                                boolean C = l9Var.j.z().C(aVar5.f10979a.K2(), o.j0);
                                int i9 = -1;
                                zzbr.c.a aVar6 = null;
                                zzbr.c.a aVar7 = null;
                                int i10 = 0;
                                int i11 = -1;
                                boolean z9 = false;
                                long j7 = 0;
                                int i12 = 0;
                                while (true) {
                                    z = z9;
                                    str2 = "_e";
                                    if (i10 >= aVar5.f10981c.size()) {
                                        break;
                                    }
                                    zzbr.c.a aVar8 = (zzbr.c.a) aVar5.f10981c.get(i10).w();
                                    String str15 = "_err";
                                    if (S().D(aVar5.f10979a.K2(), aVar8.L())) {
                                        l9Var.j.h().K().c("Dropping blacklisted raw event. appId", w3.y(aVar5.f10979a.K2()), l9Var.j.J().z(aVar8.L()));
                                        if (!(S().K(aVar5.f10979a.K2()) || S().L(aVar5.f10979a.K2())) && !str15.equals(aVar8.L())) {
                                            l9Var.j.I().T(aVar5.f10979a.K2(), 11, "_ev", aVar8.L(), 0);
                                        }
                                        z5 = C;
                                        aVar = aVar6;
                                        i4 = i11;
                                        z9 = z;
                                        j7 = j7;
                                        i3 = i10;
                                        aVar2 = T;
                                    } else {
                                        z5 = C;
                                        boolean F = S().F(aVar5.f10979a.K2(), aVar8.L());
                                        if (!F) {
                                            Z();
                                            String L = aVar8.L();
                                            a0.g(L);
                                            i5 = i11;
                                            int hashCode = L.hashCode();
                                            aVar = aVar6;
                                            if (hashCode != 94660) {
                                                if (hashCode != 95025) {
                                                    if (hashCode == 95027 && L.equals("_ui")) {
                                                        c2 = 1;
                                                        if (!(c2 != 0 || c2 == 1 || c2 == 2)) {
                                                            str3 = "_et";
                                                            aVar3 = T;
                                                            str4 = str2;
                                                        }
                                                        str3 = "_et";
                                                        i6 = 0;
                                                        boolean z10 = false;
                                                        z6 = false;
                                                        while (true) {
                                                            aVar3 = T;
                                                            if (i6 >= aVar8.I()) {
                                                                break;
                                                            }
                                                            if ("_c".equals(aVar8.G(i6).A())) {
                                                                str7 = str2;
                                                                aVar8.B(i6, (zzbr.e) ((d4) ((zzbr.e.a) aVar8.G(i6).w()).C(1).o()));
                                                                str6 = str15;
                                                                z10 = true;
                                                            } else {
                                                                str7 = str2;
                                                                if ("_r".equals(aVar8.G(i6).A())) {
                                                                    str6 = str15;
                                                                    aVar8.B(i6, (zzbr.e) ((d4) ((zzbr.e.a) aVar8.G(i6).w()).C(1).o()));
                                                                    z6 = true;
                                                                } else {
                                                                    str6 = str15;
                                                                }
                                                            }
                                                            i6++;
                                                            T = aVar3;
                                                            str2 = str7;
                                                            str15 = str6;
                                                        }
                                                        str4 = str2;
                                                        String str16 = str15;
                                                        if (!z10 && F) {
                                                            l9Var.j.h().P().b("Marking event as conversion", l9Var.j.J().z(aVar8.L()));
                                                            aVar8.D(zzbr.e.S().D("_c").C(1));
                                                        }
                                                        if (!z6) {
                                                            l9Var.j.h().P().b("Marking event as real-time", l9Var.j.J().z(aVar8.L()));
                                                            aVar8.D(zzbr.e.S().D("_r").C(1));
                                                        }
                                                        if (W().D(k0(), aVar5.f10979a.K2(), false, false, false, false, true).f10789e > ((long) l9Var.j.z().o(aVar5.f10979a.K2()))) {
                                                            l(aVar8, "_r");
                                                        } else {
                                                            z = true;
                                                        }
                                                        if (s9.Y(aVar8.L()) && F && W().D(k0(), aVar5.f10979a.K2(), false, false, true, false, false).f10787c > ((long) l9Var.j.z().t(aVar5.f10979a.K2(), o.u))) {
                                                            l9Var.j.h().K().b("Too many conversions. Not logging as conversion. appId", w3.y(aVar5.f10979a.K2()));
                                                            i7 = 0;
                                                            int i13 = -1;
                                                            aVar4 = null;
                                                            z7 = false;
                                                            while (i7 < aVar8.I()) {
                                                                zzbr.e G2 = aVar8.G(i7);
                                                                if ("_c".equals(G2.A())) {
                                                                    aVar4 = (zzbr.e.a) G2.w();
                                                                    str5 = str16;
                                                                    i13 = i7;
                                                                } else {
                                                                    str5 = str16;
                                                                    if (str5.equals(G2.A())) {
                                                                        z7 = true;
                                                                    }
                                                                }
                                                                i7++;
                                                                str16 = str5;
                                                            }
                                                            if (!z7 && aVar4 != null) {
                                                                aVar8.J(i13);
                                                            } else if (aVar4 != null) {
                                                                aVar8.B(i13, (zzbr.e) ((d4) ((zzbr.e.a) ((d4.b) aVar4.clone())).D(str16).C(10).o()));
                                                            } else {
                                                                l9Var.j.h().H().b("Did not find conversion parameter. appId", w3.y(aVar5.f10979a.K2()));
                                                            }
                                                        }
                                                    }
                                                } else if (L.equals("_ug")) {
                                                    c2 = 2;
                                                    if (!(c2 != 0 || c2 == 1 || c2 == 2)) {
                                                    }
                                                    str3 = "_et";
                                                    i6 = 0;
                                                    boolean z102 = false;
                                                    z6 = false;
                                                    while (true) {
                                                        aVar3 = T;
                                                        if (i6 >= aVar8.I()) {
                                                        }
                                                        i6++;
                                                        T = aVar3;
                                                        str2 = str7;
                                                        str15 = str6;
                                                    }
                                                    str4 = str2;
                                                    String str162 = str15;
                                                    l9Var.j.h().P().b("Marking event as conversion", l9Var.j.J().z(aVar8.L()));
                                                    aVar8.D(zzbr.e.S().D("_c").C(1));
                                                    if (!z6) {
                                                    }
                                                    if (W().D(k0(), aVar5.f10979a.K2(), false, false, false, false, true).f10789e > ((long) l9Var.j.z().o(aVar5.f10979a.K2()))) {
                                                    }
                                                    l9Var.j.h().K().b("Too many conversions. Not logging as conversion. appId", w3.y(aVar5.f10979a.K2()));
                                                    i7 = 0;
                                                    int i132 = -1;
                                                    aVar4 = null;
                                                    z7 = false;
                                                    while (i7 < aVar8.I()) {
                                                    }
                                                    if (!z7) {
                                                    }
                                                    if (aVar4 != null) {
                                                    }
                                                }
                                            } else if (L.equals("_in")) {
                                                c2 = 0;
                                                if (!(c2 != 0 || c2 == 1 || c2 == 2)) {
                                                }
                                                str3 = "_et";
                                                i6 = 0;
                                                boolean z1022 = false;
                                                z6 = false;
                                                while (true) {
                                                    aVar3 = T;
                                                    if (i6 >= aVar8.I()) {
                                                    }
                                                    i6++;
                                                    T = aVar3;
                                                    str2 = str7;
                                                    str15 = str6;
                                                }
                                                str4 = str2;
                                                String str1622 = str15;
                                                l9Var.j.h().P().b("Marking event as conversion", l9Var.j.J().z(aVar8.L()));
                                                aVar8.D(zzbr.e.S().D("_c").C(1));
                                                if (!z6) {
                                                }
                                                if (W().D(k0(), aVar5.f10979a.K2(), false, false, false, false, true).f10789e > ((long) l9Var.j.z().o(aVar5.f10979a.K2()))) {
                                                }
                                                l9Var.j.h().K().b("Too many conversions. Not logging as conversion. appId", w3.y(aVar5.f10979a.K2()));
                                                i7 = 0;
                                                int i1322 = -1;
                                                aVar4 = null;
                                                z7 = false;
                                                while (i7 < aVar8.I()) {
                                                }
                                                if (!z7) {
                                                }
                                                if (aVar4 != null) {
                                                }
                                            }
                                            c2 = 65535;
                                            if (!(c2 != 0 || c2 == 1 || c2 == 2)) {
                                            }
                                            str3 = "_et";
                                            i6 = 0;
                                            boolean z10222 = false;
                                            z6 = false;
                                            while (true) {
                                                aVar3 = T;
                                                if (i6 >= aVar8.I()) {
                                                }
                                                i6++;
                                                T = aVar3;
                                                str2 = str7;
                                                str15 = str6;
                                            }
                                            str4 = str2;
                                            String str16222 = str15;
                                            l9Var.j.h().P().b("Marking event as conversion", l9Var.j.J().z(aVar8.L()));
                                            aVar8.D(zzbr.e.S().D("_c").C(1));
                                            if (!z6) {
                                            }
                                            if (W().D(k0(), aVar5.f10979a.K2(), false, false, false, false, true).f10789e > ((long) l9Var.j.z().o(aVar5.f10979a.K2()))) {
                                            }
                                            l9Var.j.h().K().b("Too many conversions. Not logging as conversion. appId", w3.y(aVar5.f10979a.K2()));
                                            i7 = 0;
                                            int i13222 = -1;
                                            aVar4 = null;
                                            z7 = false;
                                            while (i7 < aVar8.I()) {
                                            }
                                            if (!z7) {
                                            }
                                            if (aVar4 != null) {
                                            }
                                        } else {
                                            aVar = aVar6;
                                            i5 = i11;
                                            str3 = "_et";
                                            i6 = 0;
                                            boolean z102222 = false;
                                            z6 = false;
                                            while (true) {
                                                aVar3 = T;
                                                if (i6 >= aVar8.I()) {
                                                }
                                                i6++;
                                                T = aVar3;
                                                str2 = str7;
                                                str15 = str6;
                                            }
                                            str4 = str2;
                                            String str162222 = str15;
                                            l9Var.j.h().P().b("Marking event as conversion", l9Var.j.J().z(aVar8.L()));
                                            aVar8.D(zzbr.e.S().D("_c").C(1));
                                            if (!z6) {
                                            }
                                            if (W().D(k0(), aVar5.f10979a.K2(), false, false, false, false, true).f10789e > ((long) l9Var.j.z().o(aVar5.f10979a.K2()))) {
                                            }
                                            l9Var.j.h().K().b("Too many conversions. Not logging as conversion. appId", w3.y(aVar5.f10979a.K2()));
                                            i7 = 0;
                                            int i132222 = -1;
                                            aVar4 = null;
                                            z7 = false;
                                            while (i7 < aVar8.I()) {
                                            }
                                            if (!z7) {
                                            }
                                            if (aVar4 != null) {
                                            }
                                        }
                                        z9 = z;
                                        if (F) {
                                            ArrayList arrayList = new ArrayList(aVar8.H());
                                            int i14 = -1;
                                            int i15 = -1;
                                            for (int i16 = 0; i16 < arrayList.size(); i16++) {
                                                if ("value".equals(((zzbr.e) arrayList.get(i16)).A())) {
                                                    i14 = i16;
                                                } else if (FirebaseAnalytics.b.f12316e.equals(((zzbr.e) arrayList.get(i16)).A())) {
                                                    i15 = i16;
                                                }
                                            }
                                            if (i14 != -1) {
                                                if (((zzbr.e) arrayList.get(i14)).O() || ((zzbr.e) arrayList.get(i14)).Q()) {
                                                    if (i15 == -1) {
                                                        z8 = true;
                                                    } else {
                                                        String M = ((zzbr.e) arrayList.get(i15)).M();
                                                        if (M.length() == 3) {
                                                            int i17 = 0;
                                                            while (true) {
                                                                if (i17 >= M.length()) {
                                                                    z8 = false;
                                                                    break;
                                                                }
                                                                int codePointAt = M.codePointAt(i17);
                                                                if (!Character.isLetter(codePointAt)) {
                                                                    break;
                                                                }
                                                                i17 += Character.charCount(codePointAt);
                                                            }
                                                        }
                                                        z8 = true;
                                                    }
                                                    if (z8) {
                                                        l9Var.j.h().M().a("Value parameter discarded. You must also supply a 3-letter ISO_4217 currency code in the currency parameter.");
                                                        aVar8.J(i14);
                                                        l(aVar8, "_c");
                                                        k(aVar8, 19, FirebaseAnalytics.b.f12316e);
                                                    }
                                                    if (l9Var.j.z().C(aVar5.f10979a.K2(), o.i0)) {
                                                        str9 = str4;
                                                        if (str9.equals(aVar8.L())) {
                                                            Z();
                                                            if (p9.A((zzbr.c) ((d4) aVar8.o()), "_fr") == null) {
                                                                if (aVar7 != null && Math.abs(aVar7.N() - aVar8.N()) <= 1000) {
                                                                    zzbr.c.a aVar9 = (zzbr.c.a) ((d4.b) aVar7.clone());
                                                                    if (l9Var.E(aVar8, aVar9)) {
                                                                        aVar2 = aVar3;
                                                                        aVar2.B(i9, aVar9);
                                                                        i4 = i5;
                                                                        str8 = str3;
                                                                    }
                                                                }
                                                                aVar2 = aVar3;
                                                                aVar = aVar8;
                                                                i4 = i12;
                                                            } else {
                                                                aVar2 = aVar3;
                                                                i4 = i5;
                                                            }
                                                            str8 = str3;
                                                        } else {
                                                            aVar2 = aVar3;
                                                            if ("_vs".equals(aVar8.L())) {
                                                                Z();
                                                                str8 = str3;
                                                                if (p9.A((zzbr.c) ((d4) aVar8.o()), str8) == null) {
                                                                    if (aVar != null && Math.abs(aVar.N() - aVar8.N()) <= 1000) {
                                                                        zzbr.c.a aVar10 = (zzbr.c.a) ((d4.b) aVar.clone());
                                                                        if (l9Var.E(aVar10, aVar8)) {
                                                                            i4 = i5;
                                                                            aVar2.B(i4, aVar10);
                                                                        }
                                                                    }
                                                                    i4 = i5;
                                                                    aVar7 = aVar8;
                                                                    i9 = i12;
                                                                } else {
                                                                    i4 = i5;
                                                                }
                                                            } else {
                                                                i4 = i5;
                                                                str8 = str3;
                                                                if (l9Var.j.z().C(aVar5.f10979a.K2(), o.R0) && "_ab".equals(aVar8.L())) {
                                                                    Z();
                                                                    if (p9.A((zzbr.c) ((d4) aVar8.o()), str8) == null && aVar != null && Math.abs(aVar.N() - aVar8.N()) <= 4000) {
                                                                        zzbr.c.a aVar11 = (zzbr.c.a) ((d4.b) aVar.clone());
                                                                        l9Var.L(aVar11, aVar8);
                                                                        aVar2.B(i4, aVar11);
                                                                        aVar = null;
                                                                    }
                                                                }
                                                            }
                                                        }
                                                        aVar7 = null;
                                                        aVar = null;
                                                    } else {
                                                        i4 = i5;
                                                        str8 = str3;
                                                        aVar2 = aVar3;
                                                        str9 = str4;
                                                    }
                                                    if (!z5 && str9.equals(aVar8.L())) {
                                                        if (aVar8.I() == 0) {
                                                            l9Var.j.h().K().b("Engagement event does not contain any parameters. appId", w3.y(aVar5.f10979a.K2()));
                                                        } else {
                                                            Z();
                                                            Long l2 = (Long) p9.U((zzbr.c) ((d4) aVar8.o()), str8);
                                                            if (l2 == null) {
                                                                l9Var.j.h().K().b("Engagement event does not include duration. appId", w3.y(aVar5.f10979a.K2()));
                                                            } else {
                                                                j7 += l2.longValue();
                                                                i3 = i10;
                                                                aVar5.f10981c.set(i3, (zzbr.c) ((d4) aVar8.o()));
                                                                i12++;
                                                                aVar2.E(aVar8);
                                                            }
                                                        }
                                                    }
                                                    j7 = j7;
                                                    i3 = i10;
                                                    aVar5.f10981c.set(i3, (zzbr.c) ((d4) aVar8.o()));
                                                    i12++;
                                                    aVar2.E(aVar8);
                                                } else {
                                                    l9Var.j.h().M().a("Value must be specified with a numeric type.");
                                                    aVar8.J(i14);
                                                    l(aVar8, "_c");
                                                    k(aVar8, 18, "value");
                                                }
                                            }
                                            if (l9Var.j.z().C(aVar5.f10979a.K2(), o.i0)) {
                                            }
                                            if (aVar8.I() == 0) {
                                            }
                                            j7 = j7;
                                            i3 = i10;
                                            aVar5.f10981c.set(i3, (zzbr.c) ((d4) aVar8.o()));
                                            i12++;
                                            aVar2.E(aVar8);
                                        }
                                        if (l9Var.j.z().C(aVar5.f10979a.K2(), o.i0)) {
                                        }
                                        if (aVar8.I() == 0) {
                                        }
                                        j7 = j7;
                                        i3 = i10;
                                        aVar5.f10981c.set(i3, (zzbr.c) ((d4) aVar8.o()));
                                        i12++;
                                        aVar2.E(aVar8);
                                    }
                                    i10 = i3 + 1;
                                    i11 = i4;
                                    T = aVar2;
                                    str13 = str13;
                                    C = z5;
                                    aVar6 = aVar;
                                }
                                if (C) {
                                    int i18 = i12;
                                    j3 = j7;
                                    int i19 = 0;
                                    while (i19 < i18) {
                                        zzbr.c N = T.N(i19);
                                        if (str2.equals(N.T())) {
                                            Z();
                                            if (p9.A(N, "_fr") != null) {
                                                T.U(i19);
                                                i18--;
                                                i19--;
                                                i19++;
                                            }
                                        }
                                        Z();
                                        zzbr.e A = p9.A(N, "_et");
                                        if (A != null) {
                                            Long valueOf = A.O() ? Long.valueOf(A.P()) : null;
                                            if (valueOf != null && valueOf.longValue() > 0) {
                                                j3 += valueOf.longValue();
                                            }
                                        }
                                        i19++;
                                    }
                                } else {
                                    j3 = j7;
                                }
                                l9Var.o(T, j3, false);
                                if (l9Var.j.z().C(T.C0(), o.y0)) {
                                    Iterator<zzbr.c> it = T.L().iterator();
                                    while (true) {
                                        if (it.hasNext()) {
                                            if ("_s".equals(it.next().T())) {
                                                z4 = true;
                                                break;
                                            }
                                        } else {
                                            z4 = false;
                                            break;
                                        }
                                    }
                                    if (z4) {
                                        W().m0(T.C0(), "_se");
                                    }
                                    if (db.a() && l9Var.j.z().C(T.C0(), o.z0)) {
                                        if (!(p9.x(T, "_sid") >= 0)) {
                                            int x2 = p9.x(T, "_se");
                                            if (x2 >= 0) {
                                                T.f0(x2);
                                                l9Var.j.h().K().b("Session engagement user property is in the bundle without session ID. appId", w3.y(aVar5.f10979a.K2()));
                                            }
                                        }
                                    }
                                    l9Var.o(T, j3, true);
                                } else if (l9Var.j.z().C(T.C0(), o.B0)) {
                                    W().m0(T.C0(), "_se");
                                }
                                if (l9Var.j.z().C(T.C0(), o.k0)) {
                                    p9 Z = Z();
                                    Z.h().P().a("Checking account type status for ad personalization signals");
                                    if (Z.r().I(T.C0()) && (j0 = Z.q().j0(T.C0())) != null && j0.l() && Z.f().A()) {
                                        Z.h().O().a("Turning off ad personalization due to account type");
                                        zzbr.j jVar = (zzbr.j) ((d4) zzbr.j.W().D(str13).C(Z.f().y()).F(1).o());
                                        int i20 = 0;
                                        while (true) {
                                            if (i20 >= T.d0()) {
                                                z3 = false;
                                                break;
                                            } else if (str13.equals(T.b0(i20).O())) {
                                                T.C(i20, jVar);
                                                z3 = true;
                                                break;
                                            } else {
                                                i20++;
                                            }
                                        }
                                        if (!z3) {
                                            T.H(jVar);
                                        }
                                    }
                                }
                                if (l9Var.j.z().C(T.C0(), o.M0)) {
                                    n(T);
                                }
                                zzbr.g.a J0 = T.J0();
                                String C0 = T.C0();
                                List<zzbr.j> c0 = T.c0();
                                List<zzbr.c> L2 = T.L();
                                long i0 = T.i0();
                                a0.g(C0);
                                J0.W(X().x(C0, L2, c0, Long.valueOf(i0)));
                                if (l9Var.j.z().B(aVar5.f10979a.K2())) {
                                    try {
                                        HashMap hashMap3 = new HashMap();
                                        ArrayList arrayList2 = new ArrayList();
                                        SecureRandom z0 = l9Var.j.I().z0();
                                        int i21 = 0;
                                        while (i21 < T.M()) {
                                            zzbr.c.a aVar12 = (zzbr.c.a) T.N(i21).w();
                                            if (aVar12.L().equals("_ep")) {
                                                Z();
                                                String str17 = (String) p9.U((zzbr.c) ((d4) aVar12.o()), "_en");
                                                k kVar = (k) hashMap3.get(str17);
                                                if (kVar == null) {
                                                    kVar = W().E(aVar5.f10979a.K2(), str17);
                                                    hashMap3.put(str17, kVar);
                                                }
                                                if (kVar.i == null) {
                                                    if (kVar.j.longValue() > 1) {
                                                        Z();
                                                        p9.I(aVar12, "_sr", kVar.j);
                                                    }
                                                    Boolean bool = kVar.k;
                                                    if (bool != null && bool.booleanValue()) {
                                                        Z();
                                                        p9.I(aVar12, "_efs", 1L);
                                                    }
                                                    arrayList2.add((zzbr.c) ((d4) aVar12.o()));
                                                }
                                                T.B(i21, aVar12);
                                            } else {
                                                long J = S().J(aVar5.f10979a.K2());
                                                l9Var.j.I();
                                                long w2 = s9.w(aVar12.N(), J);
                                                zzbr.c cVar = (zzbr.c) ((d4) aVar12.o());
                                                Long l3 = 1L;
                                                if (!TextUtils.isEmpty("_dbg") && l3 != null) {
                                                    Iterator<zzbr.e> it2 = cVar.B().iterator();
                                                    while (true) {
                                                        if (!it2.hasNext()) {
                                                            break;
                                                        }
                                                        zzbr.e next = it2.next();
                                                        if (!"_dbg".equals(next.A())) {
                                                            it2 = it2;
                                                        } else if (l3.equals(Long.valueOf(next.P())) || (((l3 instanceof String) && l3.equals(next.M())) || ((l3 instanceof Double) && l3.equals(Double.valueOf(next.R()))))) {
                                                            z2 = true;
                                                        }
                                                    }
                                                    G = z2 ? S().G(aVar5.f10979a.K2(), aVar12.L()) : 1;
                                                    if (G > 0) {
                                                        l9Var.j.h().K().c("Sample rate must be positive. event, rate", aVar12.L(), Integer.valueOf(G));
                                                        arrayList2.add((zzbr.c) ((d4) aVar12.o()));
                                                        T.B(i21, aVar12);
                                                    } else {
                                                        k kVar2 = (k) hashMap3.get(aVar12.L());
                                                        if (kVar2 == null && (kVar2 = W().E(aVar5.f10979a.K2(), aVar12.L())) == null) {
                                                            j4 = w2;
                                                            l9Var.j.h().K().c("Event being bundled has no eventAggregate. appId, eventName", aVar5.f10979a.K2(), aVar12.L());
                                                            if (l9Var.j.z().C(aVar5.f10979a.K2(), o.x0)) {
                                                                kVar2 = new k(aVar5.f10979a.K2(), aVar12.L(), 1, 1, 1, aVar12.N(), 0, null, null, null, null);
                                                            } else {
                                                                kVar2 = new k(aVar5.f10979a.K2(), aVar12.L(), 1, 1, aVar12.N(), 0, null, null, null, null);
                                                            }
                                                        } else {
                                                            j4 = w2;
                                                        }
                                                        Z();
                                                        Long l4 = (Long) p9.U((zzbr.c) ((d4) aVar12.o()), "_eid");
                                                        Boolean valueOf2 = Boolean.valueOf(l4 != null);
                                                        if (G == 1) {
                                                            arrayList2.add((zzbr.c) ((d4) aVar12.o()));
                                                            if (valueOf2.booleanValue() && !(kVar2.i == null && kVar2.j == null && kVar2.k == null)) {
                                                                hashMap3.put(aVar12.L(), kVar2.c(null, null, null));
                                                            }
                                                            T.B(i21, aVar12);
                                                        } else {
                                                            if (z0.nextInt(G) == 0) {
                                                                Z();
                                                                long j8 = (long) G;
                                                                p9.I(aVar12, "_sr", Long.valueOf(j8));
                                                                arrayList2.add((zzbr.c) ((d4) aVar12.o()));
                                                                if (valueOf2.booleanValue()) {
                                                                    kVar2 = kVar2.c(null, Long.valueOf(j8), null);
                                                                }
                                                                hashMap3.put(aVar12.L(), kVar2.b(aVar12.N(), j4));
                                                                hashMap = hashMap3;
                                                                secureRandom = z0;
                                                                i2 = i21;
                                                            } else {
                                                                secureRandom = z0;
                                                                if (l9Var.j.z().O(aVar5.f10979a.K2())) {
                                                                    Long l5 = kVar2.h;
                                                                    if (l5 != null) {
                                                                        j5 = l5.longValue();
                                                                        hashMap2 = hashMap3;
                                                                    } else {
                                                                        l9Var.j.I();
                                                                        hashMap2 = hashMap3;
                                                                        j5 = s9.w(aVar12.O(), J);
                                                                    }
                                                                } else {
                                                                    hashMap2 = hashMap3;
                                                                }
                                                                boolean z11 = true;
                                                                if (z11) {
                                                                    Z();
                                                                    p9.I(aVar12, "_efs", 1L);
                                                                    Z();
                                                                    long j9 = (long) G;
                                                                    p9.I(aVar12, "_sr", Long.valueOf(j9));
                                                                    arrayList2.add((zzbr.c) ((d4) aVar12.o()));
                                                                    if (valueOf2.booleanValue()) {
                                                                        kVar2 = kVar2.c(null, Long.valueOf(j9), Boolean.TRUE);
                                                                    }
                                                                    hashMap = hashMap2;
                                                                    hashMap.put(aVar12.L(), kVar2.b(aVar12.N(), j4));
                                                                } else {
                                                                    hashMap = hashMap2;
                                                                    if (valueOf2.booleanValue()) {
                                                                        hashMap.put(aVar12.L(), kVar2.c(l4, null, null));
                                                                    }
                                                                }
                                                                i2 = i21;
                                                            }
                                                            T.B(i2, aVar12);
                                                            z0 = secureRandom;
                                                            i21 = i2 + 1;
                                                            hashMap3 = hashMap;
                                                            l9Var = this;
                                                        }
                                                    }
                                                }
                                                z2 = false;
                                                if (z2) {
                                                }
                                                if (G > 0) {
                                                }
                                            }
                                            hashMap = hashMap3;
                                            secureRandom = z0;
                                            i2 = i21;
                                            z0 = secureRandom;
                                            i21 = i2 + 1;
                                            hashMap3 = hashMap;
                                            l9Var = this;
                                        }
                                        if (arrayList2.size() < T.M()) {
                                            T.T().I(arrayList2);
                                        }
                                        for (Map.Entry entry : hashMap3.entrySet()) {
                                            W().N((k) entry.getValue());
                                        }
                                    } catch (Throwable th3) {
                                        th = th3;
                                        W().A0();
                                        throw th;
                                    }
                                }
                                if (!this.j.z().C(T.C0(), o.M0)) {
                                    n(T);
                                }
                                String K2 = aVar5.f10979a.K2();
                                e5 j02 = W().j0(K2);
                                if (j02 == null) {
                                    this.j.h().H().b("Bundling raw events w/o app info. appId", w3.y(aVar5.f10979a.K2()));
                                } else if (T.M() > 0) {
                                    long R = j02.R();
                                    if (R != 0) {
                                        T.g0(R);
                                    } else {
                                        T.v0();
                                    }
                                    long P = j02.P();
                                    if (P != 0) {
                                        R = P;
                                    }
                                    if (R != 0) {
                                        T.Y(R);
                                    } else {
                                        T.r0();
                                    }
                                    j02.i0();
                                    T.n0((int) j02.f0());
                                    j02.a(T.i0());
                                    j02.q(T.m0());
                                    String j10 = j02.j();
                                    if (j10 != null) {
                                        T.B0(j10);
                                    } else {
                                        T.D0();
                                    }
                                    W().O(j02);
                                }
                                if (T.M() > 0) {
                                    this.j.v();
                                    p0.b x3 = S().x(aVar5.f10979a.K2());
                                    if (x3 != null && x3.E()) {
                                        T.y0(x3.F());
                                    } else if (TextUtils.isEmpty(aVar5.f10979a.l0())) {
                                        T.y0(-1);
                                    } else {
                                        this.j.h().K().b("Did not find measurement config or missing version info. appId", w3.y(aVar5.f10979a.K2()));
                                    }
                                    W().R((zzbr.g) ((d4) T.o()), z);
                                }
                                d W2 = W();
                                List<Long> list2 = aVar5.f10980b;
                                a0.k(list2);
                                W2.e();
                                W2.t();
                                StringBuilder sb2 = new StringBuilder("rowid in (");
                                for (int i22 = 0; i22 < list2.size(); i22++) {
                                    if (i22 != 0) {
                                        sb2.append(",");
                                    }
                                    sb2.append(list2.get(i22).longValue());
                                }
                                sb2.append(")");
                                int delete = W2.y().delete("raw_events", sb2.toString(), null);
                                if (delete != list2.size()) {
                                    W2.h().H().c("Deleted fewer rows from raw events table than expected", Integer.valueOf(delete), Integer.valueOf(list2.size()));
                                }
                                d W3 = W();
                                try {
                                    W3.y().execSQL("delete from raw_events_metadata where app_id=? and metadata_fingerprint not in (select distinct metadata_fingerprint from raw_events where app_id=?)", new String[]{K2, K2});
                                } catch (SQLiteException e3) {
                                    W3.h().H().c("Failed to remove unused event metadata. appId", w3.y(K2), e3);
                                }
                                W().x();
                                W().A0();
                                return true;
                            }
                            W().x();
                            W().A0();
                            return false;
                        }
                        str10 = cursor.getString(0);
                        try {
                            str11 = cursor.getString(1);
                            cursor.close();
                        } catch (SQLiteException e4) {
                            sQLiteException = e4;
                        }
                    } catch (SQLiteException e5) {
                        sQLiteException = e5;
                        str10 = null;
                        try {
                            W.h().H().c("Data loss. Error selecting raw event. appId", w3.y(str10), sQLiteException);
                            if (cursor != null) {
                            }
                            list = aVar5.f10981c;
                            if (!(list != null || list.isEmpty())) {
                            }
                        } catch (Throwable th4) {
                            th2 = th4;
                            if (cursor != null) {
                            }
                            throw th2;
                        }
                    }
                } else {
                    int i23 = (j6 > -1 ? 1 : (j6 == -1 ? 0 : -1));
                    String[] strArr3 = i23 != 0 ? new String[]{null, String.valueOf(j6)} : new String[]{null};
                    if (i23 != 0) {
                        str14 = " and rowid <= ?";
                    }
                    StringBuilder sb3 = new StringBuilder(str14.length() + 84);
                    sb3.append("select metadata_fingerprint from raw_events where app_id = ?");
                    sb3.append(str14);
                    sb3.append(" order by rowid limit 1;");
                    Cursor rawQuery = y2.rawQuery(sb3.toString(), strArr3);
                    if (!rawQuery.moveToFirst()) {
                        rawQuery.close();
                        list = aVar5.f10981c;
                        if (!(list != null || list.isEmpty())) {
                        }
                    } else {
                        str11 = rawQuery.getString(0);
                        rawQuery.close();
                        str10 = null;
                    }
                }
                Cursor query = y2.query("raw_events_metadata", new String[]{b.l}, "app_id = ? and metadata_fingerprint = ?", new String[]{str10, str11}, null, null, "rowid", "2");
                if (!query.moveToFirst()) {
                    W.h().H().b("Raw event metadata record is missing. appId", w3.y(str10));
                    query.close();
                } else {
                    try {
                        zzbr.g gVar = (zzbr.g) ((d4) ((zzbr.g.a) p9.B(zzbr.g.Q0(), query.getBlob(0))).o());
                        if (query.moveToNext()) {
                            W.h().K().b("Get multiple raw event metadata records, expected one. appId", w3.y(str10));
                        }
                        query.close();
                        aVar5.a(gVar);
                        if (j6 != -1) {
                            str12 = "app_id = ? and metadata_fingerprint = ? and rowid <= ?";
                            strArr = new String[]{str10, str11, String.valueOf(j6)};
                        } else {
                            str12 = "app_id = ? and metadata_fingerprint = ?";
                            strArr = new String[]{str10, str11};
                        }
                        Cursor query2 = y2.query("raw_events", new String[]{"rowid", "name", "timestamp", "data"}, str12, strArr, null, null, "rowid", null);
                        if (query2.moveToFirst()) {
                            while (true) {
                                long j11 = query2.getLong(0);
                                try {
                                    zzbr.c.a aVar13 = (zzbr.c.a) p9.B(zzbr.c.a0(), query2.getBlob(3));
                                    aVar13.F(query2.getString(1)).C(query2.getLong(2));
                                    if (!aVar5.b(j11, (zzbr.c) ((d4) aVar13.o()))) {
                                        query2.close();
                                        break;
                                    }
                                } catch (IOException e6) {
                                    W.h().H().c("Data loss. Failed to merge raw event. appId", w3.y(str10), e6);
                                }
                                if (!query2.moveToNext()) {
                                    query2.close();
                                    break;
                                }
                            }
                        } else {
                            W.h().K().b("Raw event data disappeared while in transaction. appId", w3.y(str10));
                            query2.close();
                        }
                    } catch (IOException e7) {
                        W.h().H().c("Data loss. Failed to merge raw event metadata. appId", w3.y(str10), e7);
                        query.close();
                    }
                }
            } catch (SQLiteException e8) {
                sQLiteException = e8;
                cursor = null;
                str10 = null;
                W.h().H().c("Data loss. Error selecting raw event. appId", w3.y(str10), sQLiteException);
                if (cursor != null) {
                    cursor.close();
                }
                list = aVar5.f10981c;
                if (!(list != null || list.isEmpty())) {
                }
            } catch (Throwable th5) {
                th2 = th5;
                cursor = null;
                if (cursor != null) {
                    cursor.close();
                }
                throw th2;
            }
            list = aVar5.f10981c;
            if (!(list != null || list.isEmpty())) {
            }
        } catch (Throwable th6) {
            th = th6;
            W().A0();
            throw th;
        }
    }

    @WorkerThread
    private final void G() {
        j0();
        if (this.r || this.s || this.t) {
            this.j.h().P().d("Not stopping services. fetch, network, upload", Boolean.valueOf(this.r), Boolean.valueOf(this.s), Boolean.valueOf(this.t));
            return;
        }
        this.j.h().P().a("Stopping uploading service(s)");
        List<Runnable> list = this.o;
        if (list != null) {
            for (Runnable runnable : list) {
                runnable.run();
            }
            this.o.clear();
        }
    }

    @VisibleForTesting
    @WorkerThread
    private final boolean H() {
        FileLock fileLock;
        j0();
        if (!this.j.z().r(o.L0) || (fileLock = this.u) == null || !fileLock.isValid()) {
            try {
                FileChannel channel = new RandomAccessFile(new File(this.j.i().getFilesDir(), "google_app_measurement.db"), "rw").getChannel();
                this.v = channel;
                FileLock tryLock = channel.tryLock();
                this.u = tryLock;
                if (tryLock != null) {
                    this.j.h().P().a("Storage concurrent access okay");
                    return true;
                }
                this.j.h().H().a("Storage concurrent data access panic");
                return false;
            } catch (FileNotFoundException e2) {
                this.j.h().H().b("Failed to acquire storage lock", e2);
                return false;
            } catch (IOException e3) {
                this.j.h().H().b("Failed to access storage lock file", e3);
                return false;
            } catch (OverlappingFileLockException e4) {
                this.j.h().K().b("Storage lock already acquired", e4);
                return false;
            }
        } else {
            this.j.h().P().a("Storage concurrent access okay");
            return true;
        }
    }

    @WorkerThread
    private final boolean I() {
        j0();
        c0();
        return this.l;
    }

    @WorkerThread
    private final Boolean K(e5 e5Var) {
        try {
            if (e5Var.V() != -2147483648L) {
                if (e5Var.V() == ((long) c.a(this.j.i()).e(e5Var.t(), 0).versionCode)) {
                    return Boolean.TRUE;
                }
            } else {
                String str = c.a(this.j.i()).e(e5Var.t(), 0).versionName;
                if (e5Var.T() != null && e5Var.T().equals(str)) {
                    return Boolean.TRUE;
                }
            }
            return Boolean.FALSE;
        } catch (PackageManager.NameNotFoundException unused) {
            return null;
        }
    }

    private final void L(zzbr.c.a aVar, zzbr.c.a aVar2) {
        a0.a("_e".equals(aVar.L()));
        Z();
        zzbr.e A = p9.A((zzbr.c) ((d4) aVar.o()), "_et");
        if (A.O() && A.P() > 0) {
            long P = A.P();
            Z();
            zzbr.e A2 = p9.A((zzbr.c) ((d4) aVar2.o()), "_et");
            if (A2 != null && A2.P() > 0) {
                P += A2.P();
            }
            Z();
            p9.I(aVar2, "_et", Long.valueOf(P));
            Z();
            p9.I(aVar, "_fr", 1L);
        }
    }

    /* JADX WARNING: Code restructure failed: missing block: B:214:0x07fe, code lost:
        r11 = true;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:219:0x0838, code lost:
        if (r10.f10789e < ((long) r27.j.z().o(r4.f10952a))) goto L_0x07fe;
     */
    /* JADX WARNING: Removed duplicated region for block: B:70:0x0268  */
    /* JADX WARNING: Removed duplicated region for block: B:74:0x029f  */
    @WorkerThread
    private final void M(zzan zzan, zzm zzm) {
        long j2;
        String str;
        k kVar;
        List<Integer> X;
        t9 o0;
        boolean z;
        long j3;
        t9 t9Var;
        e5 j0;
        a0.k(zzm);
        a0.g(zzm.f11237a);
        long nanoTime = System.nanoTime();
        j0();
        c0();
        String str2 = zzm.f11237a;
        if (Z().R(zzan, zzm)) {
            if (!zzm.N0) {
                T(zzm);
            } else if (S().D(str2, zzan.f11233a)) {
                this.j.h().K().c("Dropping blacklisted event. appId", w3.y(str2), this.j.J().z(zzan.f11233a));
                boolean z2 = S().K(str2) || S().L(str2);
                if (!z2 && !"_err".equals(zzan.f11233a)) {
                    this.j.I().T(str2, 11, "_ev", zzan.f11233a, 0);
                }
                if (z2 && (j0 = W().j0(str2)) != null) {
                    if (Math.abs(this.j.m().a() - Math.max(j0.h0(), j0.g0())) > o.G.a(null).longValue()) {
                        this.j.h().O().a("Fetching config for blacklisted app");
                        r(j0);
                    }
                }
            } else {
                if (this.j.h().D(2)) {
                    this.j.h().P().b("Logging event", this.j.J().y(zzan));
                }
                W().w0();
                try {
                    T(zzm);
                    if ("_iap".equals(zzan.f11233a) || FirebaseAnalytics.a.g.equals(zzan.f11233a)) {
                        String u1 = zzan.f11234b.u1(FirebaseAnalytics.b.f12316e);
                        if (FirebaseAnalytics.a.g.equals(zzan.f11233a)) {
                            double doubleValue = zzan.f11234b.s1("value").doubleValue() * 1000000.0d;
                            if (doubleValue == 0.0d) {
                                doubleValue = ((double) zzan.f11234b.m1("value").longValue()) * 1000000.0d;
                            }
                            if (doubleValue > 9.223372036854776E18d || doubleValue < -9.223372036854776E18d) {
                                this.j.h().K().c("Data lost. Currency value is too big. appId", w3.y(str2), Double.valueOf(doubleValue));
                                j2 = nanoTime;
                                z = false;
                                if (!z) {
                                    W().x();
                                    W().A0();
                                    return;
                                }
                            } else {
                                j3 = Math.round(doubleValue);
                            }
                        } else {
                            j3 = zzan.f11234b.m1("value").longValue();
                        }
                        if (!TextUtils.isEmpty(u1)) {
                            String upperCase = u1.toUpperCase(Locale.US);
                            if (upperCase.matches("[A-Z]{3}")) {
                                String concat = upperCase.length() != 0 ? "_ltv_".concat(upperCase) : new String("_ltv_");
                                t9 o02 = W().o0(str2, concat);
                                if (o02 != null) {
                                    Object obj = o02.f11133e;
                                    if (obj instanceof Long) {
                                        j2 = nanoTime;
                                        t9Var = new t9(str2, zzan.I0, concat, this.j.m().a(), Long.valueOf(((Long) obj).longValue() + j3));
                                        if (!W().T(t9Var)) {
                                            this.j.h().H().d("Too many unique user properties are set. Ignoring user property. appId", w3.y(str2), this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                                            this.j.I().T(str2, 9, null, null, 0);
                                        }
                                        z = true;
                                        if (!z) {
                                        }
                                    }
                                }
                                j2 = nanoTime;
                                d W = W();
                                int t2 = this.j.z().t(str2, o.L) - 1;
                                a0.g(str2);
                                W.e();
                                W.t();
                                try {
                                    W.y().execSQL("delete from user_attributes where app_id=? and name in (select name from user_attributes where app_id=? and name like '_ltv_%' order by set_timestamp desc limit ?,10);", new String[]{str2, str2, String.valueOf(t2)});
                                } catch (SQLiteException e2) {
                                    W.h().H().c("Error pruning currencies. appId", w3.y(str2), e2);
                                }
                                t9Var = new t9(str2, zzan.I0, concat, this.j.m().a(), Long.valueOf(j3));
                                if (!W().T(t9Var)) {
                                }
                                z = true;
                                if (!z) {
                                }
                            }
                        }
                        j2 = nanoTime;
                        z = true;
                        if (!z) {
                        }
                    } else {
                        j2 = nanoTime;
                    }
                    boolean Y = s9.Y(zzan.f11233a);
                    boolean equals = "_err".equals(zzan.f11233a);
                    c D = W().D(k0(), str2, true, Y, false, equals, false);
                    long intValue = D.f10786b - ((long) o.r.a(null).intValue());
                    if (intValue > 0) {
                        if (intValue % 1000 == 1) {
                            this.j.h().H().c("Data loss. Too many events logged. appId, count", w3.y(str2), Long.valueOf(D.f10786b));
                        }
                        W().x();
                        return;
                    }
                    if (Y) {
                        long intValue2 = D.f10785a - ((long) o.t.a(null).intValue());
                        if (intValue2 > 0) {
                            if (intValue2 % 1000 == 1) {
                                this.j.h().H().c("Data loss. Too many public events logged. appId, count", w3.y(str2), Long.valueOf(D.f10785a));
                            }
                            this.j.I().T(str2, 16, "_ev", zzan.f11233a, 0);
                            W().x();
                            W().A0();
                            return;
                        }
                    }
                    if (equals) {
                        long max = D.f10788d - ((long) Math.max(0, Math.min((int) DurationKt.NANOS_IN_MILLIS, this.j.z().t(zzm.f11237a, o.s))));
                        if (max > 0) {
                            if (max == 1) {
                                this.j.h().H().c("Too many error events logged. appId, count", w3.y(str2), Long.valueOf(D.f10788d));
                            }
                            W().x();
                            W().A0();
                            return;
                        }
                    }
                    Bundle d1 = zzan.f11234b.d1();
                    this.j.I().L(d1, "_o", zzan.I0);
                    if (this.j.I().v0(str2)) {
                        this.j.I().L(d1, "_dbg", 1L);
                        this.j.I().L(d1, "_r", 1L);
                    }
                    if ("_s".equals(zzan.f11233a) && this.j.z().Q(zzm.f11237a) && (o0 = W().o0(zzm.f11237a, "_sno")) != null && (o0.f11133e instanceof Long)) {
                        this.j.I().L(d1, "_sno", o0.f11133e);
                    }
                    if (!"_s".equals(zzan.f11233a) || !this.j.z().C(zzm.f11237a, o.e0) || this.j.z().Q(zzm.f11237a)) {
                        str = null;
                    } else {
                        str = null;
                        O(new zzkj("_sno", 0, null), zzm);
                    }
                    long n0 = W().n0(str2);
                    if (n0 > 0) {
                        this.j.h().K().c("Data lost. Too many events stored on disk, deleted. appId", w3.y(str2), Long.valueOf(n0));
                    }
                    String str3 = "_r";
                    l lVar = new l(this.j, zzan.I0, str2, zzan.f11233a, zzan.J0, 0, d1);
                    k E = W().E(str2, lVar.f10953b);
                    if (E != null) {
                        lVar = lVar.a(this.j, E.f);
                        kVar = E.a(lVar.f10955d);
                    } else if (W().x0(str2) < 500 || !Y) {
                        kVar = new k(str2, lVar.f10953b, 0, 0, lVar.f10955d, 0, null, null, null, null);
                    } else {
                        this.j.h().H().d("Too many event names used, ignoring event. appId, name, supported count", w3.y(str2), this.j.J().z(lVar.f10953b), 500);
                        this.j.I().T(str2, 8, null, null, 0);
                        W().A0();
                        return;
                    }
                    W().N(kVar);
                    j0();
                    c0();
                    a0.k(lVar);
                    a0.k(zzm);
                    a0.g(lVar.f10952a);
                    a0.a(lVar.f10952a.equals(zzm.f11237a));
                    zzbr.g.a J = zzbr.g.Q0().A(1).J("android");
                    if (!TextUtils.isEmpty(zzm.f11237a)) {
                        J.l0(zzm.f11237a);
                    }
                    if (!TextUtils.isEmpty(zzm.J0)) {
                        J.h0(zzm.J0);
                    }
                    if (!TextUtils.isEmpty(zzm.I0)) {
                        J.q0(zzm.I0);
                    }
                    long j4 = zzm.P0;
                    if (j4 != -2147483648L) {
                        J.s0((int) j4);
                    }
                    J.k0(zzm.K0);
                    if (!TextUtils.isEmpty(zzm.f11238b)) {
                        J.F0(zzm.f11238b);
                    }
                    if (this.j.z().r(o.r0)) {
                        if (TextUtils.isEmpty(J.I0()) && !TextUtils.isEmpty(zzm.X0)) {
                            J.N0(zzm.X0);
                        }
                    } else if (!TextUtils.isEmpty(zzm.X0)) {
                        J.N0(zzm.X0);
                    }
                    long j5 = zzm.L0;
                    if (j5 != 0) {
                        J.t0(j5);
                    }
                    J.E0(zzm.Z0);
                    if (this.j.z().C(zzm.f11237a, o.o0) && (X = Z().X()) != null) {
                        J.Z(X);
                    }
                    Pair<String, Boolean> w2 = this.j.C().w(zzm.f11237a);
                    if (w2 == null || TextUtils.isEmpty((CharSequence) w2.first)) {
                        if (!this.j.S().u(this.j.i()) && zzm.V0) {
                            String string = Settings.Secure.getString(this.j.i().getContentResolver(), "android_id");
                            if (string == null) {
                                this.j.h().K().b("null secure ID. appId", w3.y(J.C0()));
                                string = "null";
                            } else if (string.isEmpty()) {
                                this.j.h().K().b("empty secure ID. appId", w3.y(J.C0()));
                            }
                            J.K0(string);
                        }
                    } else if (zzm.U0) {
                        J.u0((String) w2.first);
                        Object obj2 = w2.second;
                        if (obj2 != null) {
                            J.K(((Boolean) obj2).booleanValue());
                        }
                    }
                    this.j.S().p();
                    zzbr.g.a X2 = J.X(Build.MODEL);
                    this.j.S().p();
                    X2.R(Build.VERSION.RELEASE).j0((int) this.j.S().w()).a0(this.j.S().x()).A0(zzm.R0);
                    if (this.j.p() && ga.X()) {
                        J.C0();
                        if (!TextUtils.isEmpty(str)) {
                            J.M0(str);
                        }
                    }
                    e5 j02 = W().j0(zzm.f11237a);
                    if (j02 == null) {
                        j02 = new e5(this.j, zzm.f11237a);
                        j02.c(this.j.I().C0());
                        j02.F(zzm.Q0);
                        j02.r(zzm.f11238b);
                        j02.C(this.j.C().z(zzm.f11237a));
                        j02.H(0);
                        j02.a(0);
                        j02.q(0);
                        j02.I(zzm.I0);
                        j02.u(zzm.P0);
                        j02.L(zzm.J0);
                        j02.y(zzm.K0);
                        j02.B(zzm.L0);
                        j02.e(zzm.N0);
                        j02.c0(zzm.R0);
                        j02.E(zzm.Z0);
                        W().O(j02);
                    }
                    if (!TextUtils.isEmpty(j02.x())) {
                        J.z0(j02.x());
                    }
                    if (!TextUtils.isEmpty(j02.M())) {
                        J.H0(j02.M());
                    }
                    List<t9> I = W().I(zzm.f11237a);
                    for (int i2 = 0; i2 < I.size(); i2++) {
                        zzbr.j.a C = zzbr.j.W().D(I.get(i2).f11131c).C(I.get(i2).f11132d);
                        Z().K(C, I.get(i2).f11133e);
                        J.G(C);
                    }
                    try {
                        long A = W().A((zzbr.g) ((d4) J.o()));
                        d W2 = W();
                        zzam zzam = lVar.f;
                        if (zzam != null) {
                            Iterator<String> it = zzam.iterator();
                            while (true) {
                                if (!it.hasNext()) {
                                    boolean F = S().F(lVar.f10952a, lVar.f10953b);
                                    c D2 = W().D(k0(), lVar.f10952a, false, false, false, false, false);
                                    if (F) {
                                    }
                                } else if (str3.equals(it.next())) {
                                    break;
                                } else {
                                    str3 = str3;
                                }
                            }
                        }
                        boolean z3 = false;
                        if (W2.S(lVar, A, z3)) {
                            this.n = 0;
                        }
                    } catch (IOException e3) {
                        this.j.h().H().c("Data loss. Failed to insert raw event metadata. appId", w3.y(J.C0()), e3);
                    }
                    W().x();
                    if (this.j.h().D(2)) {
                        this.j.h().P().b("Event recorded", this.j.J().w(lVar));
                    }
                    W().A0();
                    m0();
                    this.j.h().P().b("Background event processing time, ms", Long.valueOf(((System.nanoTime() - j2) + 500000) / 1000000));
                } finally {
                    W().A0();
                }
            }
        }
    }

    private static void N(h9 h9Var) {
        if (h9Var == null) {
            throw new IllegalStateException("Upload Component not created");
        } else if (!h9Var.s()) {
            String valueOf = String.valueOf(h9Var.getClass());
            StringBuilder sb = new StringBuilder(valueOf.length() + 27);
            sb.append("Component not initialized: ");
            sb.append(valueOf);
            throw new IllegalStateException(sb.toString());
        }
    }

    @VisibleForTesting
    @WorkerThread
    private final int a(FileChannel fileChannel) {
        j0();
        if (fileChannel == null || !fileChannel.isOpen()) {
            this.j.h().H().a("Bad channel to read from");
            return 0;
        }
        ByteBuffer allocate = ByteBuffer.allocate(4);
        try {
            fileChannel.position(0L);
            int read = fileChannel.read(allocate);
            if (read != 4) {
                if (read != -1) {
                    this.j.h().K().b("Unexpected data length. Bytes read", Integer.valueOf(read));
                }
                return 0;
            }
            allocate.flip();
            return allocate.getInt();
        } catch (IOException e2) {
            this.j.h().H().b("Failed to read from channel", e2);
            return 0;
        }
    }

    /* JADX WARNING: Removed duplicated region for block: B:10:0x0046  */
    /* JADX WARNING: Removed duplicated region for block: B:13:0x0058  */
    /* JADX WARNING: Removed duplicated region for block: B:38:0x00dc  */
    /* JADX WARNING: Removed duplicated region for block: B:46:0x0100  */
    /* JADX WARNING: Removed duplicated region for block: B:49:0x010e  */
    /* JADX WARNING: Removed duplicated region for block: B:57:0x0138  */
    /* JADX WARNING: Removed duplicated region for block: B:60:0x0146  */
    /* JADX WARNING: Removed duplicated region for block: B:63:0x0154  */
    /* JADX WARNING: Removed duplicated region for block: B:76:0x018f  */
    private final e5 c(zzm zzm, e5 e5Var, String str) {
        boolean z;
        long j2;
        boolean z2 = true;
        if (e5Var == null) {
            e5Var = new e5(this.j, zzm.f11237a);
            e5Var.c(this.j.I().C0());
            e5Var.C(str);
        } else if (!str.equals(e5Var.J())) {
            e5Var.C(str);
            e5Var.c(this.j.I().C0());
        } else {
            z = false;
            if (!TextUtils.equals(zzm.f11238b, e5Var.A())) {
                e5Var.r(zzm.f11238b);
                z = true;
            }
            if (!TextUtils.equals(zzm.X0, e5Var.D())) {
                e5Var.v(zzm.X0);
                z = true;
            }
            if (w9.a() && this.j.z().C(e5Var.t(), o.N0) && !TextUtils.equals(zzm.b1, e5Var.G())) {
                e5Var.z(zzm.b1);
                z = true;
            }
            if (!TextUtils.isEmpty(zzm.Q0) && !zzm.Q0.equals(e5Var.M())) {
                e5Var.F(zzm.Q0);
                z = true;
            }
            long j3 = zzm.K0;
            if (!(j3 == 0 || j3 == e5Var.Z())) {
                e5Var.y(zzm.K0);
                z = true;
            }
            if (!TextUtils.isEmpty(zzm.I0) && !zzm.I0.equals(e5Var.T())) {
                e5Var.I(zzm.I0);
                z = true;
            }
            if (zzm.P0 != e5Var.V()) {
                e5Var.u(zzm.P0);
                z = true;
            }
            String str2 = zzm.J0;
            if (str2 != null && !str2.equals(e5Var.X())) {
                e5Var.L(zzm.J0);
                z = true;
            }
            if (zzm.L0 != e5Var.b0()) {
                e5Var.B(zzm.L0);
                z = true;
            }
            if (zzm.N0 != e5Var.e0()) {
                e5Var.e(zzm.N0);
                z = true;
            }
            if (!TextUtils.isEmpty(zzm.M0) && !zzm.M0.equals(e5Var.i())) {
                e5Var.O(zzm.M0);
                z = true;
            }
            if (zzm.R0 != e5Var.k()) {
                e5Var.c0(zzm.R0);
                z = true;
            }
            if (zzm.U0 != e5Var.l()) {
                e5Var.s(zzm.U0);
                z = true;
            }
            if (zzm.V0 != e5Var.m()) {
                e5Var.w(zzm.V0);
                z = true;
            }
            if (this.j.z().C(zzm.f11237a, o.k0) && zzm.Y0 != e5Var.n()) {
                e5Var.b(zzm.Y0);
                z = true;
            }
            j2 = zzm.Z0;
            if (j2 != 0 || j2 == e5Var.d0()) {
                z2 = z;
            } else {
                e5Var.E(zzm.Z0);
            }
            if (z2) {
                W().O(e5Var);
            }
            return e5Var;
        }
        z = true;
        if (!TextUtils.equals(zzm.f11238b, e5Var.A())) {
        }
        if (!TextUtils.equals(zzm.X0, e5Var.D())) {
        }
        e5Var.z(zzm.b1);
        z = true;
        e5Var.F(zzm.Q0);
        z = true;
        long j32 = zzm.K0;
        e5Var.y(zzm.K0);
        z = true;
        e5Var.I(zzm.I0);
        z = true;
        if (zzm.P0 != e5Var.V()) {
        }
        String str22 = zzm.J0;
        e5Var.L(zzm.J0);
        z = true;
        if (zzm.L0 != e5Var.b0()) {
        }
        if (zzm.N0 != e5Var.e0()) {
        }
        e5Var.O(zzm.M0);
        z = true;
        if (zzm.R0 != e5Var.k()) {
        }
        if (zzm.U0 != e5Var.l()) {
        }
        if (zzm.V0 != e5Var.m()) {
        }
        e5Var.b(zzm.Y0);
        z = true;
        j2 = zzm.Z0;
        if (j2 != 0) {
        }
        z2 = z;
        if (z2) {
        }
        return e5Var;
    }

    public static l9 d(Context context) {
        a0.k(context);
        a0.k(context.getApplicationContext());
        if (f10974a == null) {
            synchronized (l9.class) {
                if (f10974a == null) {
                    f10974a = new l9(new q9(context));
                }
            }
        }
        return f10974a;
    }

    private final zzm e(Context context, String str, String str2, boolean z, boolean z2, boolean z3, long j2, String str3, String str4) {
        String str5;
        String str6;
        int i2;
        PackageManager packageManager = context.getPackageManager();
        if (packageManager == null) {
            this.j.h().H().a("PackageManager is null, can not log app install information");
            return null;
        }
        try {
            str5 = packageManager.getInstallerPackageName(str);
        } catch (IllegalArgumentException unused) {
            this.j.h().H().b("Error retrieving installer package name. appId", w3.y(str));
            str5 = "Unknown";
        }
        if (str5 == null) {
            str5 = "manual_install";
        } else if ("com.android.vending".equals(str5)) {
            str5 = "";
        }
        try {
            PackageInfo e2 = c.a(context).e(str, 0);
            if (e2 != null) {
                CharSequence d2 = c.a(context).d(str);
                if (!TextUtils.isEmpty(d2)) {
                    d2.toString();
                }
                str6 = e2.versionName;
                i2 = e2.versionCode;
            } else {
                str6 = "Unknown";
                i2 = Integer.MIN_VALUE;
            }
            this.j.v();
            return new zzm(str, str2, str6, (long) i2, str5, this.j.z().D(), this.j.I().x(context, str), (String) null, z, false, "", 0L, this.j.z().K(str) ? j2 : 0, 0, z2, z3, false, str3, (Boolean) null, 0L, (List<String>) null, (!w9.a() || !this.j.z().C(str, o.N0)) ? null : str4);
        } catch (PackageManager.NameNotFoundException unused2) {
            this.j.h().H().c("Error retrieving newly installed package info. appId, appName", w3.y(str), "Unknown");
            return null;
        }
    }

    @WorkerThread
    private final zzm f(String str) {
        e5 j0 = W().j0(str);
        if (j0 == null || TextUtils.isEmpty(j0.T())) {
            this.j.h().O().b("No app data available; dropping", str);
            return null;
        }
        Boolean K = K(j0);
        if (K == null || K.booleanValue()) {
            return new zzm(str, j0.A(), j0.T(), j0.V(), j0.X(), j0.Z(), j0.b0(), (String) null, j0.e0(), false, j0.M(), j0.k(), 0L, 0, j0.l(), j0.m(), false, j0.D(), j0.n(), j0.d0(), j0.o(), (!w9.a() || !this.j.z().C(str, o.N0)) ? null : j0.G());
        }
        this.j.h().H().b("App version does not match; dropping. appId", w3.y(str));
        return null;
    }

    private final i4 h0() {
        i4 i4Var = this.f10978e;
        if (i4Var != null) {
            return i4Var;
        }
        throw new IllegalStateException("Network broadcast receiver not created");
    }

    private final g9 i0() {
        N(this.f);
        return this.f;
    }

    @WorkerThread
    private final void j0() {
        this.j.b().e();
    }

    @VisibleForTesting
    private static void k(zzbr.c.a aVar, int i2, String str) {
        List<zzbr.e> H = aVar.H();
        for (int i3 = 0; i3 < H.size(); i3++) {
            if ("_err".equals(H.get(i3).A())) {
                return;
            }
        }
        aVar.E((zzbr.e) ((d4) zzbr.e.S().D("_err").C(Long.valueOf((long) i2).longValue()).o())).E((zzbr.e) ((d4) zzbr.e.S().D("_ev").F(str).o()));
    }

    private final long k0() {
        long a2 = this.j.m().a();
        k4 C = this.j.C();
        C.p();
        C.e();
        long a3 = C.j.a();
        if (a3 == 0) {
            a3 = 1 + ((long) C.k().z0().nextInt(86400000));
            C.j.b(a3);
        }
        return ((((a2 + a3) / 1000) / 60) / 60) / 24;
    }

    @VisibleForTesting
    private static void l(zzbr.c.a aVar, @NonNull String str) {
        List<zzbr.e> H = aVar.H();
        for (int i2 = 0; i2 < H.size(); i2++) {
            if (str.equals(H.get(i2).A())) {
                aVar.J(i2);
                return;
            }
        }
    }

    private final boolean l0() {
        j0();
        c0();
        return W().F0() || !TextUtils.isEmpty(W().z());
    }

    /* JADX WARNING: Removed duplicated region for block: B:53:0x01a1  */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x01bf  */
    @WorkerThread
    private final void m0() {
        long j2;
        long j3;
        j0();
        c0();
        if (I() || this.j.z().r(o.n0)) {
            if (this.n > 0) {
                long abs = 3600000 - Math.abs(this.j.m().b() - this.n);
                if (abs > 0) {
                    this.j.h().P().b("Upload has been suspended. Will update scheduling later in approximately ms", Long.valueOf(abs));
                    h0().c();
                    i0().y();
                    return;
                }
                this.n = 0;
            }
            if (!this.j.u() || !l0()) {
                this.j.h().P().a("Nothing to upload or uploading impossible");
                h0().c();
                i0().y();
                return;
            }
            long a2 = this.j.m().a();
            long max = Math.max(0L, o.H.a(null).longValue());
            boolean z = W().G0() || W().B0();
            if (z) {
                String V = this.j.z().V();
                if (TextUtils.isEmpty(V) || ".none.".equals(V)) {
                    j2 = Math.max(0L, o.B.a(null).longValue());
                } else {
                    j2 = Math.max(0L, o.C.a(null).longValue());
                }
            } else {
                j2 = Math.max(0L, o.A.a(null).longValue());
            }
            long a3 = this.j.C().f.a();
            long a4 = this.j.C().g.a();
            long max2 = Math.max(W().D0(), W().E0());
            if (max2 != 0) {
                long abs2 = a2 - Math.abs(max2 - a2);
                long abs3 = a2 - Math.abs(a3 - a2);
                long abs4 = a2 - Math.abs(a4 - a2);
                long max3 = Math.max(abs3, abs4);
                j3 = abs2 + max;
                if (z && max3 > 0) {
                    j3 = Math.min(abs2, max3) + j2;
                }
                if (!Z().Q(max3, j2)) {
                    j3 = max3 + j2;
                }
                if (abs4 != 0 && abs4 >= abs2) {
                    int i2 = 0;
                    while (true) {
                        if (i2 >= Math.min(20, Math.max(0, o.J.a(null).intValue()))) {
                            break;
                        }
                        j3 += Math.max(0L, o.I.a(null).longValue()) * (1 << i2);
                        if (j3 > abs4) {
                            break;
                        }
                        i2++;
                    }
                }
                if (j3 != 0) {
                    this.j.h().P().a("Next upload time is 0");
                    h0().c();
                    i0().y();
                    return;
                } else if (!U().A()) {
                    this.j.h().P().a("No network");
                    h0().b();
                    i0().y();
                    return;
                } else {
                    long a5 = this.j.C().h.a();
                    long max4 = Math.max(0L, o.y.a(null).longValue());
                    if (!Z().Q(a5, max4)) {
                        j3 = Math.max(j3, a5 + max4);
                    }
                    h0().c();
                    long a6 = j3 - this.j.m().a();
                    if (a6 <= 0) {
                        a6 = Math.max(0L, o.D.a(null).longValue());
                        this.j.C().f.b(this.j.m().a());
                    }
                    this.j.h().P().b("Upload scheduled in approximately ms", Long.valueOf(a6));
                    i0().x(a6);
                    return;
                }
            }
            j3 = 0;
            if (j3 != 0) {
            }
        }
    }

    private static void n(zzbr.g.a aVar) {
        aVar.O(Long.MAX_VALUE).V(Long.MIN_VALUE);
        for (int i2 = 0; i2 < aVar.M(); i2++) {
            zzbr.c N = aVar.N(i2);
            if (N.V() < aVar.i0()) {
                aVar.O(N.V());
            }
            if (N.V() > aVar.m0()) {
                aVar.V(N.V());
            }
        }
    }

    @VisibleForTesting
    private final void o(zzbr.g.a aVar, long j2, boolean z) {
        t9 t9Var;
        String str = z ? "_se" : "_lte";
        t9 o0 = W().o0(aVar.C0(), str);
        if (o0 == null || o0.f11133e == null) {
            t9Var = new t9(aVar.C0(), s0.f22117c, str, this.j.m().a(), Long.valueOf(j2));
        } else {
            t9Var = new t9(aVar.C0(), s0.f22117c, str, this.j.m().a(), Long.valueOf(((Long) o0.f11133e).longValue() + j2));
        }
        zzbr.j jVar = (zzbr.j) ((d4) zzbr.j.W().D(str).C(this.j.m().a()).F(((Long) t9Var.f11133e).longValue()).o());
        boolean z2 = false;
        int x2 = p9.x(aVar, str);
        if (x2 >= 0) {
            aVar.C(x2, jVar);
            z2 = true;
        }
        if (!z2) {
            aVar.H(jVar);
        }
        if (j2 > 0) {
            W().T(t9Var);
            this.j.h().O().c("Updated engagement user property. scope, value", z ? "session-scoped" : "lifetime", t9Var.f11133e);
        }
    }

    @WorkerThread
    private final void r(e5 e5Var) {
        j0();
        if (!TextUtils.isEmpty(e5Var.A()) || !TextUtils.isEmpty(e5Var.D())) {
            ga z = this.j.z();
            Uri.Builder builder = new Uri.Builder();
            String A = e5Var.A();
            if (TextUtils.isEmpty(A)) {
                A = e5Var.D();
            }
            b.b.a aVar = null;
            Uri.Builder encodedAuthority = builder.scheme(o.l.a(null)).encodedAuthority(o.m.a(null));
            String valueOf = String.valueOf(A);
            encodedAuthority.path(valueOf.length() != 0 ? "config/app/".concat(valueOf) : new String("config/app/")).appendQueryParameter("app_instance_id", e5Var.x()).appendQueryParameter("platform", "android").appendQueryParameter("gmp_version", String.valueOf(z.D()));
            String uri = builder.build().toString();
            try {
                URL url = new URL(uri);
                this.j.h().P().b("Fetching remote configuration", e5Var.t());
                p0.b x2 = S().x(e5Var.t());
                String C = S().C(e5Var.t());
                if (x2 != null && !TextUtils.isEmpty(C)) {
                    aVar = new b.b.a();
                    aVar.put(HttpHeaders.HEAD_KEY_IF_MODIFIED_SINCE, C);
                }
                this.r = true;
                a4 U = U();
                String t2 = e5Var.t();
                m9 m9Var = new m9(this);
                U.e();
                U.t();
                a0.k(url);
                a0.k(m9Var);
                U.b().D(new f4(U, t2, url, null, aVar, m9Var));
            } catch (MalformedURLException unused) {
                this.j.h().H().c("Failed to parse config URL. Not fetching. appId", w3.y(e5Var.t()), uri);
            }
        } else {
            B(e5Var.t(), c.p.Y2, null, null, null);
        }
    }

    /* access modifiers changed from: private */
    @WorkerThread
    public final void u(q9 q9Var) {
        this.j.b().e();
        d dVar = new d(this);
        dVar.u();
        this.f10977d = dVar;
        this.j.z().q(this.f10975b);
        x9 x9Var = new x9(this);
        x9Var.u();
        this.g = x9Var;
        l7 l7Var = new l7(this);
        l7Var.u();
        this.i = l7Var;
        g9 g9Var = new g9(this);
        g9Var.u();
        this.f = g9Var;
        this.f10978e = new i4(this);
        if (this.p != this.q) {
            this.j.h().H().c("Not all upload components initialized", Integer.valueOf(this.p), Integer.valueOf(this.q));
        }
        this.k = true;
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void A(Runnable runnable) {
        j0();
        if (this.o == null) {
            this.o = new ArrayList();
        }
        this.o.add(runnable);
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:53:0x013a  */
    /* JADX WARNING: Removed duplicated region for block: B:54:0x014a  */
    @VisibleForTesting
    @WorkerThread
    public final void B(String str, int i2, Throwable th, byte[] bArr, Map<String, List<String>> map) {
        j0();
        c0();
        a0.g(str);
        if (bArr == null) {
            try {
                bArr = new byte[0];
            } catch (Throwable th2) {
                this.r = false;
                G();
                throw th2;
            }
        }
        this.j.h().P().b("onConfigFetched. Response size", Integer.valueOf(bArr.length));
        W().w0();
        try {
            e5 j0 = W().j0(str);
            boolean z = true;
            boolean z2 = (i2 == 200 || i2 == 204 || i2 == 304) && th == null;
            if (j0 == null) {
                this.j.h().K().b("App does not exist in onConfigFetched. appId", w3.y(str));
            } else {
                if (!z2) {
                    if (i2 != 404) {
                        j0.N(this.j.m().a());
                        W().O(j0);
                        this.j.h().P().c("Fetching config failed. code, error", Integer.valueOf(i2), th);
                        S().E(str);
                        this.j.C().g.b(this.j.m().a());
                        if (i2 != 503) {
                            if (i2 != 429) {
                                z = false;
                            }
                        }
                        if (z) {
                            this.j.C().h.b(this.j.m().a());
                        }
                        m0();
                    }
                }
                List<String> list = map != null ? map.get(HttpHeaders.HEAD_KEY_LAST_MODIFIED) : null;
                String str2 = (list == null || list.size() <= 0) ? null : list.get(0);
                if (i2 != 404) {
                    if (i2 != 304) {
                        if (!S().B(str, bArr, str2)) {
                            W().A0();
                            this.r = false;
                            G();
                            return;
                        }
                        j0.K(this.j.m().a());
                        W().O(j0);
                        if (i2 != 404) {
                            this.j.h().M().b("Config not found. Using empty config. appId", str);
                        } else {
                            this.j.h().P().c("Successfully fetched config. Got network response. code, size", Integer.valueOf(i2), Integer.valueOf(bArr.length));
                        }
                        if (U().A() || !l0()) {
                            m0();
                        } else {
                            d0();
                        }
                    }
                }
                if (S().x(str) == null && !S().B(str, null, null)) {
                    W().A0();
                    this.r = false;
                    G();
                    return;
                }
                j0.K(this.j.m().a());
                W().O(j0);
                if (i2 != 404) {
                }
                if (U().A()) {
                }
                m0();
            }
            W().x();
            W().A0();
            this.r = false;
            G();
        } catch (Throwable th3) {
            W().A0();
            throw th3;
        }
    }

    /* access modifiers changed from: package-private */
    public final void C(boolean z) {
        m0();
    }

    public final ga J() {
        return this.j.z();
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void O(zzkj zzkj, zzm zzm) {
        j0();
        c0();
        if (TextUtils.isEmpty(zzm.f11238b) && TextUtils.isEmpty(zzm.X0)) {
            return;
        }
        if (!zzm.N0) {
            T(zzm);
        } else if (!this.j.z().C(zzm.f11237a, o.k0)) {
            this.j.h().O().b("Removing user property", this.j.J().C(zzkj.f11236b));
            W().w0();
            try {
                T(zzm);
                W().m0(zzm.f11237a, zzkj.f11236b);
                W().x();
                this.j.h().O().b("User property removed", this.j.J().C(zzkj.f11236b));
            } finally {
                W().A0();
            }
        } else if (!"_npa".equals(zzkj.f11236b) || zzm.Y0 == null) {
            this.j.h().O().b("Removing user property", this.j.J().C(zzkj.f11236b));
            W().w0();
            try {
                T(zzm);
                W().m0(zzm.f11237a, zzkj.f11236b);
                W().x();
                this.j.h().O().b("User property removed", this.j.J().C(zzkj.f11236b));
            } finally {
                W().A0();
            }
        } else {
            this.j.h().O().a("Falling back to manifest metadata value for ad personalization");
            w(new zzkj("_npa", this.j.m().a(), Long.valueOf(zzm.Y0.booleanValue() ? 1 : 0), s0.f22117c), zzm);
        }
    }

    /* access modifiers changed from: package-private */
    /* JADX WARNING: Removed duplicated region for block: B:133:0x03d7  */
    /* JADX WARNING: Removed duplicated region for block: B:79:0x022c  */
    @WorkerThread
    public final void P(zzm zzm) {
        String str;
        int i2;
        String str2;
        k kVar;
        long j2;
        long j3;
        PackageInfo packageInfo;
        String str3;
        ApplicationInfo applicationInfo;
        boolean z;
        boolean z2;
        t9 o0;
        j0();
        c0();
        a0.k(zzm);
        a0.g(zzm.f11237a);
        if (!TextUtils.isEmpty(zzm.f11238b) || !TextUtils.isEmpty(zzm.X0)) {
            e5 j0 = W().j0(zzm.f11237a);
            if (j0 != null && TextUtils.isEmpty(j0.A()) && !TextUtils.isEmpty(zzm.f11238b)) {
                j0.K(0);
                W().O(j0);
                S().H(zzm.f11237a);
            }
            if (!zzm.N0) {
                T(zzm);
                return;
            }
            long j4 = zzm.S0;
            if (j4 == 0) {
                j4 = this.j.m().a();
            }
            if (this.j.z().C(zzm.f11237a, o.k0)) {
                this.j.S().z();
            }
            int i3 = zzm.T0;
            if (!(i3 == 0 || i3 == 1)) {
                this.j.h().K().c("Incorrect app type, assuming installed app. appId, appType", w3.y(zzm.f11237a), Integer.valueOf(i3));
                i3 = 0;
            }
            W().w0();
            try {
                if (!this.j.z().C(zzm.f11237a, o.k0) || ((o0 = W().o0(zzm.f11237a, "_npa")) != null && !s0.f22117c.equals(o0.f11130b))) {
                    str = "_sysu";
                    i2 = 1;
                } else if (zzm.Y0 != null) {
                    str = "_sysu";
                    i2 = 1;
                    zzkj zzkj = new zzkj("_npa", j4, Long.valueOf(zzm.Y0.booleanValue() ? 1 : 0), s0.f22117c);
                    if (o0 == null || !o0.f11133e.equals(zzkj.J0)) {
                        w(zzkj, zzm);
                    }
                } else {
                    str = "_sysu";
                    i2 = 1;
                    if (o0 != null) {
                        O(new zzkj("_npa", j4, null, s0.f22117c), zzm);
                    }
                }
                e5 j02 = W().j0(zzm.f11237a);
                if (j02 != null) {
                    this.j.I();
                    if (s9.d0(zzm.f11238b, j02.A(), zzm.X0, j02.D())) {
                        this.j.h().K().b("New GMP App Id passed in. Removing cached database data. appId", w3.y(j02.t()));
                        d W = W();
                        String t2 = j02.t();
                        W.t();
                        W.e();
                        a0.g(t2);
                        try {
                            SQLiteDatabase y2 = W.y();
                            String[] strArr = new String[i2];
                            strArr[0] = t2;
                            int delete = y2.delete("events", "app_id=?", strArr) + 0 + y2.delete("user_attributes", "app_id=?", strArr) + y2.delete("conditional_properties", "app_id=?", strArr) + y2.delete("apps", "app_id=?", strArr) + y2.delete("raw_events", "app_id=?", strArr) + y2.delete("raw_events_metadata", "app_id=?", strArr) + y2.delete("event_filters", "app_id=?", strArr) + y2.delete("property_filters", "app_id=?", strArr) + y2.delete("audience_filter_values", "app_id=?", strArr);
                            if (delete > 0) {
                                W.h().P().c("Deleted application data. app, records", t2, Integer.valueOf(delete));
                            }
                        } catch (SQLiteException e2) {
                            W.h().H().c("Error deleting application data. appId, error", w3.y(t2), e2);
                        }
                        j02 = null;
                    }
                }
                if (j02 != null) {
                    if (j02.V() != -2147483648L) {
                        str2 = "_sys";
                        if (j02.V() != zzm.P0) {
                            z2 = true;
                            if (z2 || ((j02.V() == -2147483648L || j02.T() == null || j02.T().equals(zzm.I0)) ? false : true)) {
                                Bundle bundle = new Bundle();
                                bundle.putString("_pv", j02.T());
                                p(new zzan("_au", new zzam(bundle), s0.f22117c, j4), zzm);
                            }
                        }
                    } else {
                        str2 = "_sys";
                    }
                    z2 = false;
                    if (z2 || ((j02.V() == -2147483648L || j02.T() == null || j02.T().equals(zzm.I0)) ? false : true)) {
                    }
                } else {
                    str2 = "_sys";
                }
                T(zzm);
                if (i3 == 0) {
                    kVar = W().E(zzm.f11237a, "_f");
                } else {
                    kVar = i3 == 1 ? W().E(zzm.f11237a, "_v") : null;
                }
                if (kVar == null) {
                    long j5 = ((j4 / 3600000) + 1) * 3600000;
                    if (i3 == 0) {
                        w(new zzkj("_fot", j4, Long.valueOf(j5), s0.f22117c), zzm);
                        if (this.j.z().M(zzm.f11238b)) {
                            j0();
                            this.j.F().b(zzm.f11237a);
                        }
                        j0();
                        c0();
                        Bundle bundle2 = new Bundle();
                        bundle2.putLong("_c", 1);
                        bundle2.putLong("_r", 1);
                        bundle2.putLong("_uwa", 0);
                        bundle2.putLong("_pfo", 0);
                        bundle2.putLong(str2, 0);
                        bundle2.putLong(str, 0);
                        if (this.j.z().T(zzm.f11237a)) {
                            j3 = 1;
                            bundle2.putLong("_et", 1);
                        } else {
                            j3 = 1;
                        }
                        if (zzm.W0) {
                            bundle2.putLong("_dac", j3);
                        }
                        d W2 = W();
                        String str4 = zzm.f11237a;
                        a0.g(str4);
                        W2.e();
                        W2.t();
                        long z0 = W2.z0(str4, "first_open_count");
                        if (this.j.i().getPackageManager() == null) {
                            this.j.h().H().b("PackageManager is null, first open report might be inaccurate. appId", w3.y(zzm.f11237a));
                        } else {
                            try {
                                packageInfo = com.google.android.gms.common.p.c.a(this.j.i()).e(zzm.f11237a, 0);
                            } catch (PackageManager.NameNotFoundException e3) {
                                this.j.h().H().c("Package info is null, first open report might be inaccurate. appId", w3.y(zzm.f11237a), e3);
                                packageInfo = null;
                            }
                            if (packageInfo != null) {
                                long j6 = packageInfo.firstInstallTime;
                                if (j6 != 0) {
                                    if (j6 != packageInfo.lastUpdateTime) {
                                        if (!this.j.z().r(o.T0)) {
                                            bundle2.putLong("_uwa", 1);
                                        } else if (z0 == 0) {
                                            bundle2.putLong("_uwa", 1);
                                        }
                                        z = false;
                                    } else {
                                        z = true;
                                    }
                                    str3 = str;
                                    w(new zzkj("_fi", j4, Long.valueOf(z ? 1 : 0), s0.f22117c), zzm);
                                    applicationInfo = com.google.android.gms.common.p.c.a(this.j.i()).c(zzm.f11237a, 0);
                                    if (applicationInfo != null) {
                                        if ((applicationInfo.flags & 1) != 0) {
                                            bundle2.putLong(str2, 1);
                                        }
                                        if ((applicationInfo.flags & 128) != 0) {
                                            bundle2.putLong(str3, 1);
                                        }
                                    }
                                }
                            }
                            str3 = str;
                            try {
                                applicationInfo = com.google.android.gms.common.p.c.a(this.j.i()).c(zzm.f11237a, 0);
                            } catch (PackageManager.NameNotFoundException e4) {
                                this.j.h().H().c("Application info is null, first open report might be inaccurate. appId", w3.y(zzm.f11237a), e4);
                                applicationInfo = null;
                            }
                            if (applicationInfo != null) {
                            }
                        }
                        if (z0 >= 0) {
                            bundle2.putLong("_pfo", z0);
                        }
                        p(new zzan("_f", new zzam(bundle2), s0.f22117c, j4), zzm);
                    } else if (i3 == 1) {
                        w(new zzkj("_fvt", j4, Long.valueOf(j5), s0.f22117c), zzm);
                        j0();
                        c0();
                        Bundle bundle3 = new Bundle();
                        bundle3.putLong("_c", 1);
                        bundle3.putLong("_r", 1);
                        if (this.j.z().T(zzm.f11237a)) {
                            j2 = 1;
                            bundle3.putLong("_et", 1);
                        } else {
                            j2 = 1;
                        }
                        if (zzm.W0) {
                            bundle3.putLong("_dac", j2);
                        }
                        p(new zzan("_v", new zzam(bundle3), s0.f22117c, j4), zzm);
                    }
                    if (!this.j.z().C(zzm.f11237a, o.j0)) {
                        Bundle bundle4 = new Bundle();
                        bundle4.putLong("_et", 1);
                        if (this.j.z().T(zzm.f11237a)) {
                            bundle4.putLong("_fr", 1);
                        }
                        p(new zzan("_e", new zzam(bundle4), s0.f22117c, j4), zzm);
                    }
                } else if (zzm.O0) {
                    p(new zzan("_cd", new zzam(new Bundle()), s0.f22117c, j4), zzm);
                }
                W().x();
            } finally {
                W().A0();
            }
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void Q(zzv zzv) {
        zzm f2 = f(zzv.f11239a);
        if (f2 != null) {
            R(zzv, f2);
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void R(zzv zzv, zzm zzm) {
        a0.k(zzv);
        a0.g(zzv.f11239a);
        a0.k(zzv.I0);
        a0.g(zzv.I0.f11236b);
        j0();
        c0();
        if (TextUtils.isEmpty(zzm.f11238b) && TextUtils.isEmpty(zzm.X0)) {
            return;
        }
        if (!zzm.N0) {
            T(zzm);
            return;
        }
        W().w0();
        try {
            T(zzm);
            zzv q0 = W().q0(zzv.f11239a, zzv.I0.f11236b);
            if (q0 != null) {
                this.j.h().O().c("Removing conditional user property", zzv.f11239a, this.j.J().C(zzv.I0.f11236b));
                W().s0(zzv.f11239a, zzv.I0.f11236b);
                if (q0.K0) {
                    W().m0(zzv.f11239a, zzv.I0.f11236b);
                }
                zzan zzan = zzv.Q0;
                if (zzan != null) {
                    Bundle bundle = null;
                    zzam zzam = zzan.f11234b;
                    if (zzam != null) {
                        bundle = zzam.d1();
                    }
                    s9 I = this.j.I();
                    String str = zzv.f11239a;
                    zzan zzan2 = zzv.Q0;
                    M(I.D(str, zzan2.f11233a, bundle, q0.f11240b, zzan2.J0, true, false), zzm);
                }
            } else {
                this.j.h().K().c("Conditional user property doesn't exist", w3.y(zzv.f11239a), this.j.J().C(zzv.I0.f11236b));
            }
            W().x();
        } finally {
            W().A0();
        }
    }

    public final v4 S() {
        N(this.f10975b);
        return this.f10975b;
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final e5 T(zzm zzm) {
        j0();
        c0();
        a0.k(zzm);
        a0.g(zzm.f11237a);
        e5 j0 = W().j0(zzm.f11237a);
        String z = this.j.C().z(zzm.f11237a);
        if (!k9.a() || !o.V0.a(null).booleanValue()) {
            return c(zzm, j0, z);
        }
        if (j0 == null) {
            j0 = new e5(this.j, zzm.f11237a);
            j0.c(this.j.I().C0());
            j0.C(z);
        } else if (!z.equals(j0.J())) {
            j0.C(z);
            j0.c(this.j.I().C0());
        }
        j0.r(zzm.f11238b);
        j0.v(zzm.X0);
        if (w9.a() && this.j.z().C(j0.t(), o.N0)) {
            j0.z(zzm.b1);
        }
        if (!TextUtils.isEmpty(zzm.Q0)) {
            j0.F(zzm.Q0);
        }
        long j2 = zzm.K0;
        if (j2 != 0) {
            j0.y(j2);
        }
        if (!TextUtils.isEmpty(zzm.I0)) {
            j0.I(zzm.I0);
        }
        j0.u(zzm.P0);
        String str = zzm.J0;
        if (str != null) {
            j0.L(str);
        }
        j0.B(zzm.L0);
        j0.e(zzm.N0);
        if (!TextUtils.isEmpty(zzm.M0)) {
            j0.O(zzm.M0);
        }
        j0.c0(zzm.R0);
        j0.s(zzm.U0);
        j0.w(zzm.V0);
        if (this.j.z().C(zzm.f11237a, o.k0)) {
            j0.b(zzm.Y0);
        }
        j0.E(zzm.Z0);
        if (j0.f()) {
            W().O(j0);
        }
        return j0;
    }

    public final a4 U() {
        N(this.f10976c);
        return this.f10976c;
    }

    /* access modifiers changed from: package-private */
    public final String V(zzm zzm) {
        try {
            return (String) this.j.b().x(new o9(this, zzm)).get(30000, TimeUnit.MILLISECONDS);
        } catch (InterruptedException | ExecutionException | TimeoutException e2) {
            this.j.h().H().c("Failed to get app instance id. appId", w3.y(zzm.f11237a), e2);
            return null;
        }
    }

    public final d W() {
        N(this.f10977d);
        return this.f10977d;
    }

    public final x9 X() {
        N(this.g);
        return this.g;
    }

    public final l7 Y() {
        N(this.i);
        return this.i;
    }

    public final p9 Z() {
        N(this.h);
        return this.h;
    }

    public final u3 a0() {
        return this.j.J();
    }

    @Override // com.google.android.gms.measurement.internal.z5
    public final y4 b() {
        return this.j.b();
    }

    public final s9 b0() {
        return this.j.I();
    }

    /* access modifiers changed from: package-private */
    public final void c0() {
        if (!this.k) {
            throw new IllegalStateException("UploadController is not initialized");
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void d0() {
        e5 j0;
        String str;
        j0();
        c0();
        this.t = true;
        try {
            this.j.v();
            Boolean b0 = this.j.R().b0();
            if (b0 == null) {
                this.j.h().K().a("Upload data called on the client side before use of service was decided");
            } else if (b0.booleanValue()) {
                this.j.h().H().a("Upload called in the client side when service should be used");
                this.t = false;
                G();
            } else if (this.n > 0) {
                m0();
                this.t = false;
                G();
            } else {
                j0();
                if (this.w != null) {
                    this.j.h().P().a("Uploading requested multiple times");
                    this.t = false;
                    G();
                } else if (!U().A()) {
                    this.j.h().P().a("Network not connected, ignoring upload request");
                    m0();
                    this.t = false;
                    G();
                } else {
                    long a2 = this.j.m().a();
                    F(null, a2 - ga.U());
                    long a3 = this.j.C().f.a();
                    if (a3 != 0) {
                        this.j.h().O().b("Uploading events. Elapsed time since last upload attempt (ms)", Long.valueOf(Math.abs(a2 - a3)));
                    }
                    String z = W().z();
                    if (!TextUtils.isEmpty(z)) {
                        if (this.y == -1) {
                            this.y = W().Y();
                        }
                        List<Pair<zzbr.g, Long>> J = W().J(z, this.j.z().t(z, o.n), Math.max(0, this.j.z().t(z, o.o)));
                        if (!J.isEmpty()) {
                            Iterator<Pair<zzbr.g, Long>> it = J.iterator();
                            while (true) {
                                if (!it.hasNext()) {
                                    str = null;
                                    break;
                                }
                                zzbr.g gVar = (zzbr.g) it.next().first;
                                if (!TextUtils.isEmpty(gVar.b0())) {
                                    str = gVar.b0();
                                    break;
                                }
                            }
                            if (str != null) {
                                int i2 = 0;
                                while (true) {
                                    if (i2 >= J.size()) {
                                        break;
                                    }
                                    zzbr.g gVar2 = (zzbr.g) J.get(i2).first;
                                    if (!(TextUtils.isEmpty(gVar2.b0()) || gVar2.b0().equals(str))) {
                                        J = J.subList(0, i2);
                                        break;
                                    }
                                    i2++;
                                }
                            }
                            zzbr.f.a E = zzbr.f.E();
                            int size = J.size();
                            ArrayList arrayList = new ArrayList(J.size());
                            boolean z2 = ga.X() && this.j.z().y(z);
                            for (int i3 = 0; i3 < size; i3++) {
                                zzbr.g.a aVar = (zzbr.g.a) ((zzbr.g) J.get(i3).first).w();
                                arrayList.add((Long) J.get(i3).second);
                                zzbr.g.a D = aVar.p0(this.j.z().D()).D(a2);
                                this.j.v();
                                D.S(false);
                                if (!z2) {
                                    aVar.L0();
                                }
                                if (this.j.z().C(z, o.q0)) {
                                    aVar.G0(Z().y(((zzbr.g) ((d4) aVar.o())).i()));
                                }
                                E.A(aVar);
                            }
                            String E2 = this.j.h().D(2) ? Z().E((zzbr.f) ((d4) E.o())) : null;
                            Z();
                            byte[] i4 = ((zzbr.f) ((d4) E.o())).i();
                            String a4 = o.x.a(null);
                            try {
                                URL url = new URL(a4);
                                a0.a(!arrayList.isEmpty());
                                if (this.w != null) {
                                    this.j.h().H().a("Set uploading progress before finishing the previous upload");
                                } else {
                                    this.w = new ArrayList(arrayList);
                                }
                                this.j.C().g.b(a2);
                                String str2 = "?";
                                if (size > 0) {
                                    str2 = E.B(0).K2();
                                }
                                this.j.h().P().d("Uploading data. app, uncompressed size, data", str2, Integer.valueOf(i4.length), E2);
                                this.s = true;
                                a4 U = U();
                                n9 n9Var = new n9(this, z);
                                U.e();
                                U.t();
                                a0.k(url);
                                a0.k(i4);
                                a0.k(n9Var);
                                U.b().D(new f4(U, z, url, i4, null, n9Var));
                            } catch (MalformedURLException unused) {
                                this.j.h().H().c("Failed to parse upload URL. Not uploading. appId", w3.y(z), a4);
                            }
                        }
                    } else {
                        this.y = -1;
                        String H = W().H(a2 - ga.U());
                        if (!TextUtils.isEmpty(H) && (j0 = W().j0(H)) != null) {
                            r(j0);
                        }
                    }
                    this.t = false;
                    G();
                }
            }
        } finally {
            this.t = false;
            G();
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void e0() {
        j0();
        c0();
        if (!this.m) {
            this.m = true;
            j0();
            c0();
            if ((this.j.z().r(o.n0) || I()) && H()) {
                int a2 = a(this.v);
                int G = this.j.T().G();
                j0();
                if (a2 > G) {
                    this.j.h().H().c("Panic: can't downgrade version. Previous, current version", Integer.valueOf(a2), Integer.valueOf(G));
                } else if (a2 < G) {
                    if (D(G, this.v)) {
                        this.j.h().P().c("Storage version upgraded. Previous, current version", Integer.valueOf(a2), Integer.valueOf(G));
                    } else {
                        this.j.h().H().c("Storage version upgrade failed. Previous, current version", Integer.valueOf(a2), Integer.valueOf(G));
                    }
                }
            }
        }
        if (!this.l && !this.j.z().r(o.n0)) {
            this.j.h().N().a("This instance being marked as an uploader");
            this.l = true;
            m0();
        }
    }

    /* access modifiers changed from: package-private */
    public final void f0() {
        this.q++;
    }

    /* access modifiers changed from: protected */
    @WorkerThread
    public final void g() {
        this.j.b().e();
        W().C0();
        if (this.j.C().f.a() == 0) {
            this.j.C().f.b(this.j.m().a());
        }
        m0();
    }

    /* access modifiers changed from: package-private */
    public final b5 g0() {
        return this.j;
    }

    @Override // com.google.android.gms.measurement.internal.z5
    public final w3 h() {
        return this.j.h();
    }

    @Override // com.google.android.gms.measurement.internal.z5
    public final Context i() {
        return this.j.i();
    }

    /* JADX INFO: finally extract failed */
    /* access modifiers changed from: package-private */
    @VisibleForTesting
    @WorkerThread
    public final void j(int i2, Throwable th, byte[] bArr, String str) {
        j0();
        c0();
        if (bArr == null) {
            try {
                bArr = new byte[0];
            } catch (Throwable th2) {
                this.s = false;
                G();
                throw th2;
            }
        }
        List<Long> list = this.w;
        this.w = null;
        boolean z = true;
        if ((i2 == 200 || i2 == 204) && th == null) {
            try {
                this.j.C().f.b(this.j.m().a());
                this.j.C().g.b(0);
                m0();
                this.j.h().P().c("Successful upload. Got network response. code, size", Integer.valueOf(i2), Integer.valueOf(bArr.length));
                W().w0();
                try {
                    for (Long l2 : list) {
                        try {
                            d W = W();
                            long longValue = l2.longValue();
                            W.e();
                            W.t();
                            try {
                                if (W.y().delete("queue", "rowid=?", new String[]{String.valueOf(longValue)}) != 1) {
                                    throw new SQLiteException("Deleted fewer rows from queue than expected");
                                }
                            } catch (SQLiteException e2) {
                                W.h().H().b("Failed to delete a bundle in a queue table", e2);
                                throw e2;
                            }
                        } catch (SQLiteException e3) {
                            List<Long> list2 = this.x;
                            if (list2 == null || !list2.contains(l2)) {
                                throw e3;
                            }
                        }
                    }
                    W().x();
                    W().A0();
                    this.x = null;
                    if (!U().A() || !l0()) {
                        this.y = -1;
                        m0();
                    } else {
                        d0();
                    }
                    this.n = 0;
                } catch (Throwable th3) {
                    W().A0();
                    throw th3;
                }
            } catch (SQLiteException e4) {
                this.j.h().H().b("Database error while trying to delete uploaded bundles", e4);
                this.n = this.j.m().b();
                this.j.h().P().b("Disable upload, time", Long.valueOf(this.n));
            }
        } else {
            this.j.h().P().c("Network upload failed. Will retry later. code, error", Integer.valueOf(i2), th);
            this.j.C().g.b(this.j.m().a());
            if (!(i2 == 503 || i2 == 429)) {
                z = false;
            }
            if (z) {
                this.j.C().h.b(this.j.m().a());
            }
            W().Q(list);
            m0();
        }
        this.s = false;
        G();
    }

    @Override // com.google.android.gms.measurement.internal.z5
    public final g m() {
        return this.j.m();
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void p(zzan zzan, zzm zzm) {
        List<zzv> list;
        List<zzv> list2;
        List<zzv> list3;
        List<String> list4;
        zzan zzan2 = zzan;
        a0.k(zzm);
        a0.g(zzm.f11237a);
        j0();
        c0();
        String str = zzm.f11237a;
        long j2 = zzan2.J0;
        if (Z().R(zzan2, zzm)) {
            if (!zzm.N0) {
                T(zzm);
                return;
            }
            if (this.j.z().C(str, o.v0) && (list4 = zzm.a1) != null) {
                if (list4.contains(zzan2.f11233a)) {
                    Bundle d1 = zzan2.f11234b.d1();
                    d1.putLong("ga_safelisted", 1);
                    zzan2 = new zzan(zzan2.f11233a, new zzam(d1), zzan2.I0, zzan2.J0);
                } else {
                    this.j.h().O().d("Dropping non-safelisted event. appId, event name, origin", str, zzan2.f11233a, zzan2.I0);
                    return;
                }
            }
            W().w0();
            try {
                d W = W();
                a0.g(str);
                W.e();
                W.t();
                int i2 = (j2 > 0 ? 1 : (j2 == 0 ? 0 : -1));
                if (i2 < 0) {
                    W.h().K().c("Invalid time querying timed out conditional properties", w3.y(str), Long.valueOf(j2));
                    list = Collections.emptyList();
                } else {
                    list = W.L("active=0 and app_id=? and abs(? - creation_timestamp) > trigger_timeout", new String[]{str, String.valueOf(j2)});
                }
                for (zzv zzv : list) {
                    if (zzv != null) {
                        this.j.h().O().d("User property timed out", zzv.f11239a, this.j.J().C(zzv.I0.f11236b), zzv.I0.e0());
                        if (zzv.M0 != null) {
                            M(new zzan(zzv.M0, j2), zzm);
                        }
                        W().s0(str, zzv.I0.f11236b);
                    }
                }
                d W2 = W();
                a0.g(str);
                W2.e();
                W2.t();
                if (i2 < 0) {
                    W2.h().K().c("Invalid time querying expired conditional properties", w3.y(str), Long.valueOf(j2));
                    list2 = Collections.emptyList();
                } else {
                    list2 = W2.L("active<>0 and app_id=? and abs(? - triggered_timestamp) > time_to_live", new String[]{str, String.valueOf(j2)});
                }
                ArrayList arrayList = new ArrayList(list2.size());
                for (zzv zzv2 : list2) {
                    if (zzv2 != null) {
                        this.j.h().O().d("User property expired", zzv2.f11239a, this.j.J().C(zzv2.I0.f11236b), zzv2.I0.e0());
                        W().m0(str, zzv2.I0.f11236b);
                        zzan zzan3 = zzv2.Q0;
                        if (zzan3 != null) {
                            arrayList.add(zzan3);
                        }
                        W().s0(str, zzv2.I0.f11236b);
                    }
                }
                int size = arrayList.size();
                int i3 = 0;
                while (i3 < size) {
                    Object obj = arrayList.get(i3);
                    i3++;
                    M(new zzan((zzan) obj, j2), zzm);
                }
                d W3 = W();
                String str2 = zzan2.f11233a;
                a0.g(str);
                a0.g(str2);
                W3.e();
                W3.t();
                if (i2 < 0) {
                    W3.h().K().d("Invalid time querying triggered conditional properties", w3.y(str), W3.g().z(str2), Long.valueOf(j2));
                    list3 = Collections.emptyList();
                } else {
                    list3 = W3.L("active=0 and app_id=? and trigger_event_name=? and abs(? - creation_timestamp) <= trigger_timeout", new String[]{str, str2, String.valueOf(j2)});
                }
                ArrayList arrayList2 = new ArrayList(list3.size());
                for (zzv zzv3 : list3) {
                    if (zzv3 != null) {
                        zzkj zzkj = zzv3.I0;
                        t9 t9Var = new t9(zzv3.f11239a, zzv3.f11240b, zzkj.f11236b, j2, zzkj.e0());
                        if (W().T(t9Var)) {
                            this.j.h().O().d("User property triggered", zzv3.f11239a, this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                        } else {
                            this.j.h().H().d("Too many active user properties, ignoring", w3.y(zzv3.f11239a), this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                        }
                        zzan zzan4 = zzv3.O0;
                        if (zzan4 != null) {
                            arrayList2.add(zzan4);
                        }
                        zzv3.I0 = new zzkj(t9Var);
                        zzv3.K0 = true;
                        W().U(zzv3);
                    }
                }
                M(zzan2, zzm);
                int size2 = arrayList2.size();
                int i4 = 0;
                while (i4 < size2) {
                    Object obj2 = arrayList2.get(i4);
                    i4++;
                    M(new zzan((zzan) obj2, j2), zzm);
                }
                W().x();
            } finally {
                W().A0();
            }
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void q(zzan zzan, String str) {
        e5 j0 = W().j0(str);
        if (j0 == null || TextUtils.isEmpty(j0.T())) {
            this.j.h().O().b("No app data available; dropping event", str);
            return;
        }
        Boolean K = K(j0);
        if (K == null) {
            if (!"_ui".equals(zzan.f11233a)) {
                this.j.h().K().b("Could not find package. appId", w3.y(str));
            }
        } else if (!K.booleanValue()) {
            this.j.h().H().b("App version does not match; dropping event. appId", w3.y(str));
            return;
        }
        p(zzan, new zzm(str, j0.A(), j0.T(), j0.V(), j0.X(), j0.Z(), j0.b0(), (String) null, j0.e0(), false, j0.M(), j0.k(), 0L, 0, j0.l(), j0.m(), false, j0.D(), j0.n(), j0.d0(), j0.o(), (!w9.a() || !this.j.z().C(j0.t(), o.N0)) ? null : j0.G()));
    }

    /* access modifiers changed from: package-private */
    public final void s(h9 h9Var) {
        this.p++;
    }

    @Override // com.google.android.gms.measurement.internal.z5
    public final fa v() {
        return this.j.v();
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void w(zzkj zzkj, zzm zzm) {
        k E;
        j0();
        c0();
        if (TextUtils.isEmpty(zzm.f11238b) && TextUtils.isEmpty(zzm.X0)) {
            return;
        }
        if (!zzm.N0) {
            T(zzm);
            return;
        }
        int o0 = this.j.I().o0(zzkj.f11236b);
        if (o0 != 0) {
            this.j.I();
            String G = s9.G(zzkj.f11236b, 24, true);
            String str = zzkj.f11236b;
            this.j.I().T(zzm.f11237a, o0, "_ev", G, str != null ? str.length() : 0);
            return;
        }
        int j0 = this.j.I().j0(zzkj.f11236b, zzkj.e0());
        if (j0 != 0) {
            this.j.I();
            String G2 = s9.G(zzkj.f11236b, 24, true);
            Object e0 = zzkj.e0();
            this.j.I().T(zzm.f11237a, j0, "_ev", G2, (e0 == null || (!(e0 instanceof String) && !(e0 instanceof CharSequence))) ? 0 : String.valueOf(e0).length());
            return;
        }
        Object p0 = this.j.I().p0(zzkj.f11236b, zzkj.e0());
        if (p0 != null) {
            if ("_sid".equals(zzkj.f11236b) && this.j.z().Q(zzm.f11237a)) {
                long j2 = zzkj.I0;
                String str2 = zzkj.M0;
                long j3 = 0;
                t9 o02 = W().o0(zzm.f11237a, "_sno");
                if (o02 != null) {
                    Object obj = o02.f11133e;
                    if (obj instanceof Long) {
                        j3 = ((Long) obj).longValue();
                        w(new zzkj("_sno", j2, Long.valueOf(j3 + 1), str2), zzm);
                    }
                }
                if (o02 != null) {
                    this.j.h().K().b("Retrieved last session number from database does not contain a valid (long) value", o02.f11133e);
                }
                if (this.j.z().C(zzm.f11237a, o.d0) && (E = W().E(zzm.f11237a, "_s")) != null) {
                    j3 = E.f10932c;
                    this.j.h().P().b("Backfill the session number. Last used session number", Long.valueOf(j3));
                }
                w(new zzkj("_sno", j2, Long.valueOf(j3 + 1), str2), zzm);
            }
            t9 t9Var = new t9(zzm.f11237a, zzkj.M0, zzkj.f11236b, zzkj.I0, p0);
            this.j.h().O().c("Setting user property", this.j.J().C(t9Var.f11131c), p0);
            W().w0();
            try {
                T(zzm);
                boolean T = W().T(t9Var);
                W().x();
                if (T) {
                    this.j.h().O().c("User property set", this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                } else {
                    this.j.h().H().c("Too many unique user properties are set. Ignoring user property", this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                    this.j.I().T(zzm.f11237a, 9, null, null, 0);
                }
            } finally {
                W().A0();
            }
        }
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    @WorkerThread
    public final void x(zzm zzm) {
        if (this.w != null) {
            ArrayList arrayList = new ArrayList();
            this.x = arrayList;
            arrayList.addAll(this.w);
        }
        d W = W();
        String str = zzm.f11237a;
        a0.g(str);
        W.e();
        W.t();
        try {
            SQLiteDatabase y2 = W.y();
            String[] strArr = {str};
            int delete = y2.delete("apps", "app_id=?", strArr) + 0 + y2.delete("events", "app_id=?", strArr) + y2.delete("user_attributes", "app_id=?", strArr) + y2.delete("conditional_properties", "app_id=?", strArr) + y2.delete("raw_events", "app_id=?", strArr) + y2.delete("raw_events_metadata", "app_id=?", strArr) + y2.delete("queue", "app_id=?", strArr) + y2.delete("audience_filter_values", "app_id=?", strArr) + y2.delete("main_event_params", "app_id=?", strArr);
            if (delete > 0) {
                W.h().P().c("Reset analytics data. app, records", str, Integer.valueOf(delete));
            }
        } catch (SQLiteException e2) {
            W.h().H().c("Error resetting analytics data. appId, error", w3.y(str), e2);
        }
        if (!f9.a() || !this.j.z().r(o.S0)) {
            zzm e3 = e(this.j.i(), zzm.f11237a, zzm.f11238b, zzm.N0, zzm.U0, zzm.V0, zzm.S0, zzm.X0, zzm.b1);
            if (zzm.N0) {
                P(e3);
            }
        } else if (zzm.N0) {
            P(zzm);
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void y(zzv zzv) {
        zzm f2 = f(zzv.f11239a);
        if (f2 != null) {
            z(zzv, f2);
        }
    }

    /* access modifiers changed from: package-private */
    @WorkerThread
    public final void z(zzv zzv, zzm zzm) {
        boolean z;
        a0.k(zzv);
        a0.g(zzv.f11239a);
        a0.k(zzv.f11240b);
        a0.k(zzv.I0);
        a0.g(zzv.I0.f11236b);
        j0();
        c0();
        if (TextUtils.isEmpty(zzm.f11238b) && TextUtils.isEmpty(zzm.X0)) {
            return;
        }
        if (!zzm.N0) {
            T(zzm);
            return;
        }
        zzv zzv2 = new zzv(zzv);
        boolean z2 = false;
        zzv2.K0 = false;
        W().w0();
        try {
            zzv q0 = W().q0(zzv2.f11239a, zzv2.I0.f11236b);
            if (q0 != null && !q0.f11240b.equals(zzv2.f11240b)) {
                this.j.h().K().d("Updating a conditional user property with different origin. name, origin, origin (from DB)", this.j.J().C(zzv2.I0.f11236b), zzv2.f11240b, q0.f11240b);
            }
            if (q0 != null && (z = q0.K0)) {
                zzv2.f11240b = q0.f11240b;
                zzv2.J0 = q0.J0;
                zzv2.N0 = q0.N0;
                zzv2.L0 = q0.L0;
                zzv2.O0 = q0.O0;
                zzv2.K0 = z;
                zzkj zzkj = zzv2.I0;
                zzv2.I0 = new zzkj(zzkj.f11236b, q0.I0.I0, zzkj.e0(), q0.I0.M0);
            } else if (TextUtils.isEmpty(zzv2.L0)) {
                zzkj zzkj2 = zzv2.I0;
                zzv2.I0 = new zzkj(zzkj2.f11236b, zzv2.J0, zzkj2.e0(), zzv2.I0.M0);
                zzv2.K0 = true;
                z2 = true;
            }
            if (zzv2.K0) {
                zzkj zzkj3 = zzv2.I0;
                t9 t9Var = new t9(zzv2.f11239a, zzv2.f11240b, zzkj3.f11236b, zzkj3.I0, zzkj3.e0());
                if (W().T(t9Var)) {
                    this.j.h().O().d("User property updated immediately", zzv2.f11239a, this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                } else {
                    this.j.h().H().d("(2)Too many active user properties, ignoring", w3.y(zzv2.f11239a), this.j.J().C(t9Var.f11131c), t9Var.f11133e);
                }
                if (z2 && zzv2.O0 != null) {
                    M(new zzan(zzv2.O0, zzv2.J0), zzm);
                }
            }
            if (W().U(zzv2)) {
                this.j.h().O().d("Conditional property added", zzv2.f11239a, this.j.J().C(zzv2.I0.f11236b), zzv2.I0.e0());
            } else {
                this.j.h().H().d("Too many conditional properties, ignoring", w3.y(zzv2.f11239a), this.j.J().C(zzv2.I0.f11236b), zzv2.I0.e0());
            }
            W().x();
        } finally {
            W().A0();
        }
    }

    private l9(q9 q9Var, b5 b5Var) {
        this.k = false;
        a0.k(q9Var);
        b5 a2 = b5.a(q9Var.f11076a, null);
        this.j = a2;
        this.y = -1;
        p9 p9Var = new p9(this);
        p9Var.u();
        this.h = p9Var;
        a4 a4Var = new a4(this);
        a4Var.u();
        this.f10976c = a4Var;
        v4 v4Var = new v4(this);
        v4Var.u();
        this.f10975b = v4Var;
        a2.b().A(new k9(this, q9Var));
    }
}
