package com.google.android.material.internal;

import android.annotation.TargetApi;
import android.content.Context;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.view.Gravity;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.RequiresApi;
import androidx.annotation.RestrictTo;
import androidx.appcompat.widget.LinearLayoutCompat;
import androidx.core.view.GravityCompat;
import com.google.android.material.R;

@RestrictTo({RestrictTo.Scope.LIBRARY_GROUP})
public class ForegroundLinearLayout extends LinearLayoutCompat {
    private final Rect I0;
    private int J0;
    protected boolean K0;
    boolean L0;
    @Nullable

    /* renamed from: a  reason: collision with root package name */
    private Drawable f11712a;

    /* renamed from: b  reason: collision with root package name */
    private final Rect f11713b;

    public ForegroundLinearLayout(@NonNull Context context) {
        this(context, null);
    }

    public void draw(@NonNull Canvas canvas) {
        super.draw(canvas);
        Drawable drawable = this.f11712a;
        if (drawable != null) {
            if (this.L0) {
                this.L0 = false;
                Rect rect = this.f11713b;
                Rect rect2 = this.I0;
                int right = getRight() - getLeft();
                int bottom = getBottom() - getTop();
                if (this.K0) {
                    rect.set(0, 0, right, bottom);
                } else {
                    rect.set(getPaddingLeft(), getPaddingTop(), right - getPaddingRight(), bottom - getPaddingBottom());
                }
                Gravity.apply(this.J0, drawable.getIntrinsicWidth(), drawable.getIntrinsicHeight(), rect, rect2);
                drawable.setBounds(rect2);
            }
            drawable.draw(canvas);
        }
    }

    @RequiresApi(21)
    @TargetApi(21)
    public void drawableHotspotChanged(float f, float f2) {
        super.drawableHotspotChanged(f, f2);
        Drawable drawable = this.f11712a;
        if (drawable != null) {
            drawable.setHotspot(f, f2);
        }
    }

    /* access modifiers changed from: protected */
    public void drawableStateChanged() {
        super.drawableStateChanged();
        Drawable drawable = this.f11712a;
        if (drawable != null && drawable.isStateful()) {
            this.f11712a.setState(getDrawableState());
        }
    }

    @Nullable
    public Drawable getForeground() {
        return this.f11712a;
    }

    public int getForegroundGravity() {
        return this.J0;
    }

    @RequiresApi(11)
    public void jumpDrawablesToCurrentState() {
        super.jumpDrawablesToCurrentState();
        Drawable drawable = this.f11712a;
        if (drawable != null) {
            drawable.jumpToCurrentState();
        }
    }

    /* access modifiers changed from: protected */
    @Override // androidx.appcompat.widget.LinearLayoutCompat
    public void onLayout(boolean z, int i, int i2, int i3, int i4) {
        super.onLayout(z, i, i2, i3, i4);
        this.L0 = z | this.L0;
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int i, int i2, int i3, int i4) {
        super.onSizeChanged(i, i2, i3, i4);
        this.L0 = true;
    }

    public void setForeground(@Nullable Drawable drawable) {
        Drawable drawable2 = this.f11712a;
        if (drawable2 != drawable) {
            if (drawable2 != null) {
                drawable2.setCallback(null);
                unscheduleDrawable(this.f11712a);
            }
            this.f11712a = drawable;
            if (drawable != null) {
                setWillNotDraw(false);
                drawable.setCallback(this);
                if (drawable.isStateful()) {
                    drawable.setState(getDrawableState());
                }
                if (this.J0 == 119) {
                    drawable.getPadding(new Rect());
                }
            } else {
                setWillNotDraw(true);
            }
            requestLayout();
            invalidate();
        }
    }

    public void setForegroundGravity(int i) {
        if (this.J0 != i) {
            if ((8388615 & i) == 0) {
                i |= GravityCompat.START;
            }
            if ((i & 112) == 0) {
                i |= 48;
            }
            this.J0 = i;
            if (i == 119 && this.f11712a != null) {
                this.f11712a.getPadding(new Rect());
            }
            requestLayout();
        }
    }

    /* access modifiers changed from: protected */
    public boolean verifyDrawable(Drawable drawable) {
        return super.verifyDrawable(drawable) || drawable == this.f11712a;
    }

    public ForegroundLinearLayout(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, 0);
    }

    public ForegroundLinearLayout(@NonNull Context context, @Nullable AttributeSet attributeSet, int i) {
        super(context, attributeSet, i);
        this.f11713b = new Rect();
        this.I0 = new Rect();
        this.J0 = 119;
        this.K0 = true;
        this.L0 = false;
        TypedArray j = m.j(context, attributeSet, R.styleable.ForegroundLinearLayout, i, 0, new int[0]);
        this.J0 = j.getInt(R.styleable.ForegroundLinearLayout_android_foregroundGravity, this.J0);
        Drawable drawable = j.getDrawable(R.styleable.ForegroundLinearLayout_android_foreground);
        if (drawable != null) {
            setForeground(drawable);
        }
        this.K0 = j.getBoolean(R.styleable.ForegroundLinearLayout_foregroundInsidePadding, true);
        j.recycle();
    }
}
