package com.google.android.material.slider;

import android.animation.Animator;
import android.animation.AnimatorListenerAdapter;
import android.animation.ValueAnimator;
import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.Resources;
import android.content.res.TypedArray;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.Region;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.RippleDrawable;
import android.os.Build;
import android.os.Bundle;
import android.os.Parcel;
import android.os.Parcelable;
import android.util.AttributeSet;
import android.util.Log;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewConfiguration;
import android.view.ViewGroup;
import android.view.ViewParent;
import android.view.accessibility.AccessibilityManager;
import android.widget.SeekBar;
import androidx.annotation.ColorInt;
import androidx.annotation.ColorRes;
import androidx.annotation.DimenRes;
import androidx.annotation.Dimension;
import androidx.annotation.IntRange;
import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.annotation.VisibleForTesting;
import androidx.core.view.ViewCompat;
import androidx.core.view.accessibility.AccessibilityNodeInfoCompat;
import com.google.android.material.R;
import com.google.android.material.internal.m;
import com.google.android.material.internal.t;
import com.google.android.material.internal.u;
import com.google.android.material.shape.MaterialShapeDrawable;
import com.google.android.material.slider.BaseSlider;
import com.google.android.material.slider.a;
import com.google.android.material.slider.b;
import java.math.BigDecimal;
import java.math.MathContext;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;

/* access modifiers changed from: package-private */
public abstract class BaseSlider<S extends BaseSlider<S, L, T>, L extends a<S>, T extends b<S>> extends View {
    private static final String I0 = "Value(%s) must be equal to valueFrom(%s) plus a multiple of stepSize(%s) when using stepSize(%s)";
    private static final String J0 = "valueFrom(%s) must be smaller than valueTo(%s)";
    private static final String K0 = "valueTo(%s) must be greater than valueFrom(%s)";
    private static final String L0 = "The stepSize(%s) must be 0, or a factor of the valueFrom(%s)-valueTo(%s) range";
    private static final String M0 = "Floating point value used for %s(%s). Using floats can have rounding errors which may result in incorrect values. Instead, consider using integers with a custom LabelFormatter to display the  value correctly.";
    private static final int N0 = 200;
    private static final int O0 = 63;
    private static final double P0 = 1.0E-4d;
    static final int Q0 = R.style.Widget_MaterialComponents_Slider;
    static final int R0 = 1;
    static final int S0 = 0;
    private static final long T0 = 83;
    private static final long U0 = 117;

    /* renamed from: a  reason: collision with root package name */
    private static final String f11916a = BaseSlider.class.getSimpleName();

    /* renamed from: b  reason: collision with root package name */
    private static final String f11917b = "Slider value(%s) must be greater or equal to valueFrom(%s), and lower or equal to valueTo(%s)";
    private float A1;
    private float B1;
    private ArrayList<Float> C1;
    private int D1;
    private int E1;
    private float F1;
    private float[] G1;
    private boolean H1;
    private int I1;
    private boolean J1;
    private boolean K1;
    private boolean L1;
    @NonNull
    private ColorStateList M1;
    @NonNull
    private ColorStateList N1;
    @NonNull
    private ColorStateList O1;
    @NonNull
    private ColorStateList P1;
    @NonNull
    private ColorStateList Q1;
    @NonNull
    private final MaterialShapeDrawable R1;
    private float S1;
    private int T1;
    @NonNull
    private final Paint V0;
    @NonNull
    private final Paint W0;
    @NonNull
    private final Paint X0;
    @NonNull
    private final Paint Y0;
    @NonNull
    private final Paint Z0;
    @NonNull
    private final Paint a1;
    @NonNull
    private final e b1;
    private final AccessibilityManager c1;
    private BaseSlider<S, L, T>.d d1;
    @NonNull
    private final f e1;
    @NonNull
    private final List<com.google.android.material.l.a> f1;
    @NonNull
    private final List<L> g1;
    @NonNull
    private final List<T> h1;
    private boolean i1;
    private ValueAnimator j1;
    private ValueAnimator k1;
    private final int l1;
    private int m1;
    private int n1;
    private int o1;
    private int p1;
    private int q1;
    private int r1;
    private int s1;
    private int t1;
    private int u1;
    private int v1;
    private float w1;
    private MotionEvent x1;
    private d y1;
    private boolean z1;

    /* access modifiers changed from: package-private */
    public static class SliderState extends View.BaseSavedState {
        public static final Parcelable.Creator<SliderState> CREATOR = new a();
        ArrayList<Float> I0;
        float J0;
        boolean K0;

        /* renamed from: a  reason: collision with root package name */
        float f11918a;

        /* renamed from: b  reason: collision with root package name */
        float f11919b;

        static class a implements Parcelable.Creator<SliderState> {
            a() {
            }

            @NonNull
            /* renamed from: a */
            public SliderState createFromParcel(@NonNull Parcel parcel) {
                return new SliderState(parcel, null);
            }

            @NonNull
            /* renamed from: b */
            public SliderState[] newArray(int i) {
                return new SliderState[i];
            }
        }

        /* synthetic */ SliderState(Parcel parcel, a aVar) {
            this(parcel);
        }

        public void writeToParcel(@NonNull Parcel parcel, int i) {
            super.writeToParcel(parcel, i);
            parcel.writeFloat(this.f11918a);
            parcel.writeFloat(this.f11919b);
            parcel.writeList(this.I0);
            parcel.writeFloat(this.J0);
            parcel.writeBooleanArray(new boolean[]{this.K0});
        }

        SliderState(Parcelable parcelable) {
            super(parcelable);
        }

        private SliderState(@NonNull Parcel parcel) {
            super(parcel);
            this.f11918a = parcel.readFloat();
            this.f11919b = parcel.readFloat();
            ArrayList<Float> arrayList = new ArrayList<>();
            this.I0 = arrayList;
            parcel.readList(arrayList, Float.class.getClassLoader());
            this.J0 = parcel.readFloat();
            this.K0 = parcel.createBooleanArray()[0];
        }
    }

    /* access modifiers changed from: package-private */
    public class a implements f {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ AttributeSet f11920a;

        /* renamed from: b  reason: collision with root package name */
        final /* synthetic */ int f11921b;

        a(AttributeSet attributeSet, int i) {
            this.f11920a = attributeSet;
            this.f11921b = i;
        }

        @Override // com.google.android.material.slider.BaseSlider.f
        public com.google.android.material.l.a a() {
            TypedArray j = m.j(BaseSlider.this.getContext(), this.f11920a, R.styleable.Slider, this.f11921b, BaseSlider.Q0, new int[0]);
            com.google.android.material.l.a X = BaseSlider.X(BaseSlider.this.getContext(), j);
            j.recycle();
            return X;
        }
    }

    /* access modifiers changed from: package-private */
    public class b implements ValueAnimator.AnimatorUpdateListener {
        b() {
        }

        public void onAnimationUpdate(ValueAnimator valueAnimator) {
            float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
            for (com.google.android.material.l.a aVar : BaseSlider.this.f1) {
                aVar.k1(floatValue);
            }
            ViewCompat.postInvalidateOnAnimation(BaseSlider.this);
        }
    }

    /* access modifiers changed from: package-private */
    public class c extends AnimatorListenerAdapter {
        c() {
        }

        public void onAnimationEnd(Animator animator) {
            super.onAnimationEnd(animator);
            for (com.google.android.material.l.a aVar : BaseSlider.this.f1) {
                u.g(BaseSlider.this).b(aVar);
            }
        }
    }

    /* access modifiers changed from: private */
    public static class e extends androidx.customview.a.a {
        private final BaseSlider<?, ?, ?> q;
        Rect r = new Rect();

        e(BaseSlider<?, ?, ?> baseSlider) {
            super(baseSlider);
            this.q = baseSlider;
        }

        @NonNull
        private String N(int i) {
            if (i == this.q.getValues().size() - 1) {
                return this.q.getContext().getString(R.string.material_slider_range_end);
            }
            return i == 0 ? this.q.getContext().getString(R.string.material_slider_range_start) : "";
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.a.a
        public boolean A(int i, int i2, Bundle bundle) {
            if (!this.q.isEnabled()) {
                return false;
            }
            if (i2 == 4096 || i2 == 8192) {
                float m = this.q.m(20);
                if (i2 == 8192) {
                    m = -m;
                }
                if (this.q.K()) {
                    m = -m;
                }
                if (!this.q.i0(i, androidx.core.f.a.b(this.q.getValues().get(i).floatValue() + m, this.q.getValueFrom(), this.q.getValueTo()))) {
                    return false;
                }
                this.q.l0();
                this.q.postInvalidate();
                t(i);
                return true;
            }
            if (i2 == 16908349 && bundle != null && bundle.containsKey(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_PROGRESS_VALUE)) {
                if (this.q.i0(i, bundle.getFloat(AccessibilityNodeInfoCompat.ACTION_ARGUMENT_PROGRESS_VALUE))) {
                    this.q.l0();
                    this.q.postInvalidate();
                    t(i);
                    return true;
                }
            }
            return false;
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.a.a
        public void E(int i, AccessibilityNodeInfoCompat accessibilityNodeInfoCompat) {
            accessibilityNodeInfoCompat.addAction(AccessibilityNodeInfoCompat.AccessibilityActionCompat.ACTION_SET_PROGRESS);
            List<Float> values = this.q.getValues();
            float floatValue = values.get(i).floatValue();
            float valueFrom = this.q.getValueFrom();
            float valueTo = this.q.getValueTo();
            if (this.q.isEnabled()) {
                if (floatValue > valueFrom) {
                    accessibilityNodeInfoCompat.addAction(8192);
                }
                if (floatValue < valueTo) {
                    accessibilityNodeInfoCompat.addAction(4096);
                }
            }
            accessibilityNodeInfoCompat.setRangeInfo(AccessibilityNodeInfoCompat.RangeInfoCompat.obtain(1, valueFrom, valueTo, floatValue));
            accessibilityNodeInfoCompat.setClassName(SeekBar.class.getName());
            StringBuilder sb = new StringBuilder();
            if (this.q.getContentDescription() != null) {
                sb.append(this.q.getContentDescription());
                sb.append(",");
            }
            if (values.size() > 1) {
                sb.append(N(i));
                sb.append(this.q.D(floatValue));
            }
            accessibilityNodeInfoCompat.setContentDescription(sb.toString());
            this.q.k0(i, this.r);
            accessibilityNodeInfoCompat.setBoundsInParent(this.r);
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.a.a
        public int p(float f, float f2) {
            for (int i = 0; i < this.q.getValues().size(); i++) {
                this.q.k0(i, this.r);
                if (this.r.contains((int) f, (int) f2)) {
                    return i;
                }
            }
            return -1;
        }

        /* access modifiers changed from: protected */
        @Override // androidx.customview.a.a
        public void q(List<Integer> list) {
            for (int i = 0; i < this.q.getValues().size(); i++) {
                list.add(Integer.valueOf(i));
            }
        }
    }

    /* access modifiers changed from: private */
    public interface f {
        com.google.android.material.l.a a();
    }

    public BaseSlider(@NonNull Context context) {
        this(context, null);
    }

    private void A() {
        if (this.i1) {
            this.i1 = false;
            ValueAnimator q = q(false);
            this.k1 = q;
            this.j1 = null;
            q.addListener(new c());
            this.k1.start();
        }
    }

    private void B(int i) {
        if (i == 1) {
            R(Integer.MAX_VALUE);
        } else if (i == 2) {
            R(Integer.MIN_VALUE);
        } else if (i == 17) {
            S(Integer.MAX_VALUE);
        } else if (i == 66) {
            S(Integer.MIN_VALUE);
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private String D(float f2) {
        if (H()) {
            return this.y1.a(f2);
        }
        return String.format(((float) ((int) f2)) == f2 ? "%.0f" : "%.2f", Float.valueOf(f2));
    }

    private static float E(ValueAnimator valueAnimator, float f2) {
        if (valueAnimator == null || !valueAnimator.isRunning()) {
            return f2;
        }
        float floatValue = ((Float) valueAnimator.getAnimatedValue()).floatValue();
        valueAnimator.cancel();
        return floatValue;
    }

    private float F(int i, float f2) {
        float f3 = 0.0f;
        if (this.F1 == 0.0f) {
            f3 = getMinSeparation();
        }
        if (this.T1 == 0) {
            f3 = t(f3);
        }
        if (K()) {
            f3 = -f3;
        }
        int i2 = i + 1;
        int i3 = i - 1;
        return androidx.core.f.a.b(f2, i3 < 0 ? this.A1 : this.C1.get(i3).floatValue() + f3, i2 >= this.C1.size() ? this.B1 : this.C1.get(i2).floatValue() - f3);
    }

    @ColorInt
    private int G(@NonNull ColorStateList colorStateList) {
        return colorStateList.getColorForState(getDrawableState(), colorStateList.getDefaultColor());
    }

    private void I() {
        this.V0.setStrokeWidth((float) this.q1);
        this.W0.setStrokeWidth((float) this.q1);
        this.Z0.setStrokeWidth(((float) this.q1) / 2.0f);
        this.a1.setStrokeWidth(((float) this.q1) / 2.0f);
    }

    private boolean J() {
        ViewParent parent = getParent();
        while (true) {
            boolean z = false;
            if (!(parent instanceof ViewGroup)) {
                return false;
            }
            ViewGroup viewGroup = (ViewGroup) parent;
            if (viewGroup.canScrollVertically(1) || viewGroup.canScrollVertically(-1)) {
                z = true;
            }
            if (z && viewGroup.shouldDelayChildPressedState()) {
                return true;
            }
            parent = parent.getParent();
        }
    }

    private void M(@NonNull Resources resources) {
        this.o1 = resources.getDimensionPixelSize(R.dimen.mtrl_slider_widget_height);
        int dimensionPixelOffset = resources.getDimensionPixelOffset(R.dimen.mtrl_slider_track_side_padding);
        this.m1 = dimensionPixelOffset;
        this.r1 = dimensionPixelOffset;
        this.n1 = resources.getDimensionPixelSize(R.dimen.mtrl_slider_thumb_radius);
        this.s1 = resources.getDimensionPixelOffset(R.dimen.mtrl_slider_track_top);
        this.v1 = resources.getDimensionPixelSize(R.dimen.mtrl_slider_label_padding);
    }

    private void N() {
        if (this.F1 > 0.0f) {
            n0();
            int min = Math.min((int) (((this.B1 - this.A1) / this.F1) + 1.0f), (this.I1 / (this.q1 * 2)) + 1);
            float[] fArr = this.G1;
            if (fArr == null || fArr.length != min * 2) {
                this.G1 = new float[(min * 2)];
            }
            float f2 = ((float) this.I1) / ((float) (min - 1));
            for (int i = 0; i < min * 2; i += 2) {
                float[] fArr2 = this.G1;
                fArr2[i] = ((float) this.r1) + (((float) (i / 2)) * f2);
                fArr2[i + 1] = (float) n();
            }
        }
    }

    private void O(@NonNull Canvas canvas, int i, int i2) {
        if (f0()) {
            int T = (int) (((float) this.r1) + (T(this.C1.get(this.E1).floatValue()) * ((float) i)));
            if (Build.VERSION.SDK_INT < 28) {
                int i3 = this.u1;
                canvas.clipRect((float) (T - i3), (float) (i2 - i3), (float) (T + i3), (float) (i3 + i2), Region.Op.UNION);
            }
            canvas.drawCircle((float) T, (float) i2, (float) this.u1, this.Y0);
        }
    }

    private void P(@NonNull Canvas canvas) {
        if (this.H1 && this.F1 > 0.0f) {
            float[] activeRange = getActiveRange();
            int Z = Z(this.G1, activeRange[0]);
            int Z2 = Z(this.G1, activeRange[1]);
            int i = Z * 2;
            canvas.drawPoints(this.G1, 0, i, this.Z0);
            int i2 = Z2 * 2;
            canvas.drawPoints(this.G1, i, i2 - i, this.a1);
            float[] fArr = this.G1;
            canvas.drawPoints(fArr, i2, fArr.length - i2, this.Z0);
        }
    }

    private void Q() {
        this.r1 = this.m1 + Math.max(this.t1 - this.n1, 0);
        if (ViewCompat.isLaidOut(this)) {
            m0(getWidth());
        }
    }

    private boolean R(int i) {
        int i2 = this.E1;
        int d2 = (int) androidx.core.f.a.d(((long) i2) + ((long) i), 0, (long) (this.C1.size() - 1));
        this.E1 = d2;
        if (d2 == i2) {
            return false;
        }
        if (this.D1 != -1) {
            this.D1 = d2;
        }
        l0();
        postInvalidate();
        return true;
    }

    private boolean S(int i) {
        if (K()) {
            i = i == Integer.MIN_VALUE ? Integer.MAX_VALUE : -i;
        }
        return R(i);
    }

    private float T(float f2) {
        float f3 = this.A1;
        float f4 = (f2 - f3) / (this.B1 - f3);
        return K() ? 1.0f - f4 : f4;
    }

    private Boolean U(int i, @NonNull KeyEvent keyEvent) {
        if (i != 61) {
            if (i != 66) {
                if (i != 81) {
                    if (i == 69) {
                        R(-1);
                        return Boolean.TRUE;
                    } else if (i != 70) {
                        switch (i) {
                            case 21:
                                S(-1);
                                return Boolean.TRUE;
                            case 22:
                                S(1);
                                return Boolean.TRUE;
                            case 23:
                                break;
                            default:
                                return null;
                        }
                    }
                }
                R(1);
                return Boolean.TRUE;
            }
            this.D1 = this.E1;
            postInvalidate();
            return Boolean.TRUE;
        } else if (keyEvent.hasNoModifiers()) {
            return Boolean.valueOf(R(1));
        } else {
            if (keyEvent.isShiftPressed()) {
                return Boolean.valueOf(R(-1));
            }
            return Boolean.FALSE;
        }
    }

    private void V() {
        for (T t : this.h1) {
            t.a(this);
        }
    }

    private void W() {
        for (T t : this.h1) {
            t.b(this);
        }
    }

    /* access modifiers changed from: private */
    @NonNull
    public static com.google.android.material.l.a X(@NonNull Context context, @NonNull TypedArray typedArray) {
        return com.google.android.material.l.a.U0(context, null, 0, typedArray.getResourceId(R.styleable.Slider_labelStyle, R.style.Widget_MaterialComponents_Tooltip));
    }

    private static int Z(float[] fArr, float f2) {
        return Math.round(f2 * ((float) ((fArr.length / 2) - 1)));
    }

    private void a0(Context context, AttributeSet attributeSet, int i) {
        int i2;
        int i3;
        TypedArray j = m.j(context, attributeSet, R.styleable.Slider, i, Q0, new int[0]);
        this.A1 = j.getFloat(R.styleable.Slider_android_valueFrom, 0.0f);
        this.B1 = j.getFloat(R.styleable.Slider_android_valueTo, 1.0f);
        setValues(Float.valueOf(this.A1));
        this.F1 = j.getFloat(R.styleable.Slider_android_stepSize, 0.0f);
        int i4 = R.styleable.Slider_trackColor;
        boolean hasValue = j.hasValue(i4);
        if (hasValue) {
            i2 = i4;
        } else {
            i2 = R.styleable.Slider_trackColorInactive;
        }
        if (!hasValue) {
            i4 = R.styleable.Slider_trackColorActive;
        }
        ColorStateList a2 = com.google.android.material.i.c.a(context, j, i2);
        if (a2 == null) {
            a2 = androidx.appcompat.a.a.a.c(context, R.color.material_slider_inactive_track_color);
        }
        setTrackInactiveTintList(a2);
        ColorStateList a3 = com.google.android.material.i.c.a(context, j, i4);
        if (a3 == null) {
            a3 = androidx.appcompat.a.a.a.c(context, R.color.material_slider_active_track_color);
        }
        setTrackActiveTintList(a3);
        this.R1.n0(com.google.android.material.i.c.a(context, j, R.styleable.Slider_thumbColor));
        int i5 = R.styleable.Slider_thumbStrokeColor;
        if (j.hasValue(i5)) {
            setThumbStrokeColor(com.google.android.material.i.c.a(context, j, i5));
        }
        setThumbStrokeWidth(j.getDimension(R.styleable.Slider_thumbStrokeWidth, 0.0f));
        ColorStateList a4 = com.google.android.material.i.c.a(context, j, R.styleable.Slider_haloColor);
        if (a4 == null) {
            a4 = androidx.appcompat.a.a.a.c(context, R.color.material_slider_halo_color);
        }
        setHaloTintList(a4);
        this.H1 = j.getBoolean(R.styleable.Slider_tickVisible, true);
        int i6 = R.styleable.Slider_tickColor;
        boolean hasValue2 = j.hasValue(i6);
        if (hasValue2) {
            i3 = i6;
        } else {
            i3 = R.styleable.Slider_tickColorInactive;
        }
        if (!hasValue2) {
            i6 = R.styleable.Slider_tickColorActive;
        }
        ColorStateList a5 = com.google.android.material.i.c.a(context, j, i3);
        if (a5 == null) {
            a5 = androidx.appcompat.a.a.a.c(context, R.color.material_slider_inactive_tick_marks_color);
        }
        setTickInactiveTintList(a5);
        ColorStateList a6 = com.google.android.material.i.c.a(context, j, i6);
        if (a6 == null) {
            a6 = androidx.appcompat.a.a.a.c(context, R.color.material_slider_active_tick_marks_color);
        }
        setTickActiveTintList(a6);
        setThumbRadius(j.getDimensionPixelSize(R.styleable.Slider_thumbRadius, 0));
        setHaloRadius(j.getDimensionPixelSize(R.styleable.Slider_haloRadius, 0));
        setThumbElevation(j.getDimension(R.styleable.Slider_thumbElevation, 0.0f));
        setTrackHeight(j.getDimensionPixelSize(R.styleable.Slider_trackHeight, 0));
        this.p1 = j.getInt(R.styleable.Slider_labelBehavior, 0);
        if (!j.getBoolean(R.styleable.Slider_android_enabled, true)) {
            setEnabled(false);
        }
        j.recycle();
    }

    private void d0(int i) {
        BaseSlider<S, L, T>.d dVar = this.d1;
        if (dVar == null) {
            this.d1 = new d(this, null);
        } else {
            removeCallbacks(dVar);
        }
        this.d1.a(i);
        postDelayed(this.d1, 200);
    }

    private void e0(com.google.android.material.l.a aVar, float f2) {
        aVar.l1(D(f2));
        int T = (this.r1 + ((int) (T(f2) * ((float) this.I1)))) - (aVar.getIntrinsicWidth() / 2);
        int n = n() - (this.v1 + this.t1);
        aVar.setBounds(T, n - aVar.getIntrinsicHeight(), aVar.getIntrinsicWidth() + T, n);
        Rect rect = new Rect(aVar.getBounds());
        com.google.android.material.internal.c.c(u.f(this), this, rect);
        aVar.setBounds(rect);
        u.g(this).a(aVar);
    }

    private boolean f0() {
        return this.J1 || Build.VERSION.SDK_INT < 21 || !(getBackground() instanceof RippleDrawable);
    }

    private boolean g0(float f2) {
        return i0(this.D1, f2);
    }

    private float[] getActiveRange() {
        float floatValue = ((Float) Collections.max(getValues())).floatValue();
        float floatValue2 = ((Float) Collections.min(getValues())).floatValue();
        if (this.C1.size() == 1) {
            floatValue2 = this.A1;
        }
        float T = T(floatValue2);
        float T2 = T(floatValue);
        if (K()) {
            return new float[]{T2, T};
        }
        return new float[]{T, T2};
    }

    private float getValueOfTouchPosition() {
        double h0 = h0(this.S1);
        if (K()) {
            h0 = 1.0d - h0;
        }
        float f2 = this.B1;
        float f3 = this.A1;
        return (float) ((h0 * ((double) (f2 - f3))) + ((double) f3));
    }

    private float getValueOfTouchPositionAbsolute() {
        float f2 = this.S1;
        if (K()) {
            f2 = 1.0f - f2;
        }
        float f3 = this.B1;
        float f4 = this.A1;
        return (f2 * (f3 - f4)) + f4;
    }

    private double h0(float f2) {
        float f3 = this.F1;
        if (f3 <= 0.0f) {
            return (double) f2;
        }
        int i = (int) ((this.B1 - this.A1) / f3);
        return ((double) Math.round(f2 * ((float) i))) / ((double) i);
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private boolean i0(int i, float f2) {
        if (((double) Math.abs(f2 - this.C1.get(i).floatValue())) < P0) {
            return false;
        }
        this.C1.set(i, Float.valueOf(F(i, f2)));
        this.E1 = i;
        u(i);
        return true;
    }

    private void j(com.google.android.material.l.a aVar) {
        aVar.j1(u.f(this));
    }

    private boolean j0() {
        return g0(getValueOfTouchPosition());
    }

    private Float k(int i) {
        float m = this.K1 ? m(20) : l();
        if (i == 21) {
            if (!K()) {
                m = -m;
            }
            return Float.valueOf(m);
        } else if (i == 22) {
            if (K()) {
                m = -m;
            }
            return Float.valueOf(m);
        } else if (i == 69) {
            return Float.valueOf(-m);
        } else {
            if (i == 70 || i == 81) {
                return Float.valueOf(m);
            }
            return null;
        }
    }

    private float l() {
        float f2 = this.F1;
        if (f2 == 0.0f) {
            return 1.0f;
        }
        return f2;
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private void l0() {
        if (!f0() && getMeasuredWidth() > 0) {
            Drawable background = getBackground();
            if (background instanceof RippleDrawable) {
                int T = (int) ((T(this.C1.get(this.E1).floatValue()) * ((float) this.I1)) + ((float) this.r1));
                int n = n();
                int i = this.u1;
                androidx.core.graphics.drawable.c.l(background, T - i, n - i, T + i, n + i);
            }
        }
    }

    /* access modifiers changed from: private */
    /* access modifiers changed from: public */
    private float m(int i) {
        float l = l();
        float f2 = (this.B1 - this.A1) / l;
        float f3 = (float) i;
        if (f2 <= f3) {
            return l;
        }
        return ((float) Math.round(f2 / f3)) * l;
    }

    private void m0(int i) {
        this.I1 = Math.max(i - (this.r1 * 2), 0);
        N();
    }

    private int n() {
        int i = this.s1;
        int i2 = 0;
        if (this.p1 == 1) {
            i2 = this.f1.get(0).getIntrinsicHeight();
        }
        return i + i2;
    }

    private void n0() {
        if (this.L1) {
            p0();
            q0();
            o0();
            r0();
            u0();
            this.L1 = false;
        }
    }

    private void o0() {
        if (this.F1 > 0.0f && !s0(this.B1)) {
            throw new IllegalStateException(String.format(L0, Float.toString(this.F1), Float.toString(this.A1), Float.toString(this.B1)));
        }
    }

    private void p0() {
        if (this.A1 >= this.B1) {
            throw new IllegalStateException(String.format(J0, Float.toString(this.A1), Float.toString(this.B1)));
        }
    }

    private ValueAnimator q(boolean z) {
        float f2 = 0.0f;
        float E = E(z ? this.k1 : this.j1, z ? 0.0f : 1.0f);
        if (z) {
            f2 = 1.0f;
        }
        ValueAnimator ofFloat = ValueAnimator.ofFloat(E, f2);
        ofFloat.setDuration(z ? T0 : U0);
        ofFloat.setInterpolator(z ? com.google.android.material.a.a.f11330e : com.google.android.material.a.a.f11328c);
        ofFloat.addUpdateListener(new b());
        return ofFloat;
    }

    private void q0() {
        if (this.B1 <= this.A1) {
            throw new IllegalStateException(String.format(K0, Float.toString(this.B1), Float.toString(this.A1)));
        }
    }

    private void r() {
        if (this.f1.size() > this.C1.size()) {
            List<com.google.android.material.l.a> subList = this.f1.subList(this.C1.size(), this.f1.size());
            for (com.google.android.material.l.a aVar : subList) {
                if (ViewCompat.isAttachedToWindow(this)) {
                    s(aVar);
                }
            }
            subList.clear();
        }
        while (this.f1.size() < this.C1.size()) {
            com.google.android.material.l.a a2 = this.e1.a();
            this.f1.add(a2);
            if (ViewCompat.isAttachedToWindow(this)) {
                j(a2);
            }
        }
        int i = 1;
        if (this.f1.size() == 1) {
            i = 0;
        }
        for (com.google.android.material.l.a aVar2 : this.f1) {
            aVar2.H0((float) i);
        }
    }

    private void r0() {
        Iterator<Float> it = this.C1.iterator();
        while (it.hasNext()) {
            Float next = it.next();
            if (next.floatValue() < this.A1 || next.floatValue() > this.B1) {
                throw new IllegalStateException(String.format(f11917b, Float.toString(next.floatValue()), Float.toString(this.A1), Float.toString(this.B1)));
            } else if (this.F1 > 0.0f && !s0(next.floatValue())) {
                throw new IllegalStateException(String.format(I0, Float.toString(next.floatValue()), Float.toString(this.A1), Float.toString(this.F1), Float.toString(this.F1)));
            }
        }
    }

    private void s(com.google.android.material.l.a aVar) {
        t g = u.g(this);
        if (g != null) {
            g.b(aVar);
            aVar.W0(u.f(this));
        }
    }

    private boolean s0(float f2) {
        double doubleValue = new BigDecimal(Float.toString(f2)).subtract(new BigDecimal(Float.toString(this.A1))).divide(new BigDecimal(Float.toString(this.F1)), MathContext.DECIMAL64).doubleValue();
        return Math.abs(((double) Math.round(doubleValue)) - doubleValue) < P0;
    }

    private void setValuesInternal(@NonNull ArrayList<Float> arrayList) {
        if (!arrayList.isEmpty()) {
            Collections.sort(arrayList);
            if (this.C1.size() != arrayList.size() || !this.C1.equals(arrayList)) {
                this.C1 = arrayList;
                this.L1 = true;
                this.E1 = 0;
                l0();
                r();
                v();
                postInvalidate();
                return;
            }
            return;
        }
        throw new IllegalArgumentException("At least one value must be set");
    }

    private float t(float f2) {
        if (f2 == 0.0f) {
            return 0.0f;
        }
        float f3 = (f2 - ((float) this.r1)) / ((float) this.I1);
        float f4 = this.A1;
        return (f3 * (f4 - this.B1)) + f4;
    }

    private float t0(float f2) {
        return (T(f2) * ((float) this.I1)) + ((float) this.r1);
    }

    private void u(int i) {
        for (L l : this.g1) {
            l.a(this, this.C1.get(i).floatValue(), true);
        }
        AccessibilityManager accessibilityManager = this.c1;
        if (accessibilityManager != null && accessibilityManager.isEnabled()) {
            d0(i);
        }
    }

    private void u0() {
        float f2 = this.F1;
        if (f2 != 0.0f) {
            if (((float) ((int) f2)) != f2) {
                Log.w(f11916a, String.format(M0, "stepSize", Float.valueOf(f2)));
            }
            float f3 = this.A1;
            if (((float) ((int) f3)) != f3) {
                Log.w(f11916a, String.format(M0, "valueFrom", Float.valueOf(f3)));
            }
            float f4 = this.B1;
            if (((float) ((int) f4)) != f4) {
                Log.w(f11916a, String.format(M0, "valueTo", Float.valueOf(f4)));
            }
        }
    }

    private void v() {
        for (L l : this.g1) {
            Iterator<Float> it = this.C1.iterator();
            while (it.hasNext()) {
                l.a(this, it.next().floatValue(), false);
            }
        }
    }

    private void w(@NonNull Canvas canvas, int i, int i2) {
        float[] activeRange = getActiveRange();
        int i3 = this.r1;
        float f2 = (float) i;
        float f3 = (float) i2;
        canvas.drawLine(((float) i3) + (activeRange[0] * f2), f3, ((float) i3) + (activeRange[1] * f2), f3, this.W0);
    }

    private void x(@NonNull Canvas canvas, int i, int i2) {
        float[] activeRange = getActiveRange();
        int i3 = this.r1;
        float f2 = (float) i;
        float f3 = ((float) i3) + (activeRange[1] * f2);
        if (f3 < ((float) (i3 + i))) {
            float f4 = (float) i2;
            canvas.drawLine(f3, f4, (float) (i3 + i), f4, this.V0);
        }
        int i4 = this.r1;
        float f5 = ((float) i4) + (activeRange[0] * f2);
        if (f5 > ((float) i4)) {
            float f6 = (float) i2;
            canvas.drawLine((float) i4, f6, f5, f6, this.V0);
        }
    }

    private void y(@NonNull Canvas canvas, int i, int i2) {
        if (!isEnabled()) {
            Iterator<Float> it = this.C1.iterator();
            while (it.hasNext()) {
                canvas.drawCircle(((float) this.r1) + (T(it.next().floatValue()) * ((float) i)), (float) i2, (float) this.t1, this.X0);
            }
        }
        Iterator<Float> it2 = this.C1.iterator();
        while (it2.hasNext()) {
            canvas.save();
            int T = this.r1 + ((int) (T(it2.next().floatValue()) * ((float) i)));
            int i3 = this.t1;
            canvas.translate((float) (T - i3), (float) (i2 - i3));
            this.R1.draw(canvas);
            canvas.restore();
        }
    }

    private void z() {
        if (this.p1 != 2) {
            if (!this.i1) {
                this.i1 = true;
                ValueAnimator q = q(true);
                this.j1 = q;
                this.k1 = null;
                q.start();
            }
            Iterator<com.google.android.material.l.a> it = this.f1.iterator();
            for (int i = 0; i < this.C1.size() && it.hasNext(); i++) {
                if (i != this.E1) {
                    e0(it.next(), this.C1.get(i).floatValue());
                }
            }
            if (it.hasNext()) {
                e0(it.next(), this.C1.get(this.E1).floatValue());
            } else {
                throw new IllegalStateException(String.format("Not enough labels(%d) to display all the values(%d)", Integer.valueOf(this.f1.size()), Integer.valueOf(this.C1.size())));
            }
        }
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public void C(boolean z) {
        this.J1 = z;
    }

    public boolean H() {
        return this.y1 != null;
    }

    /* access modifiers changed from: package-private */
    public final boolean K() {
        return ViewCompat.getLayoutDirection(this) == 1;
    }

    public boolean L() {
        return this.H1;
    }

    /* access modifiers changed from: protected */
    public boolean Y() {
        if (this.D1 != -1) {
            return true;
        }
        float valueOfTouchPositionAbsolute = getValueOfTouchPositionAbsolute();
        float t0 = t0(valueOfTouchPositionAbsolute);
        this.D1 = 0;
        float abs = Math.abs(this.C1.get(0).floatValue() - valueOfTouchPositionAbsolute);
        for (int i = 1; i < this.C1.size(); i++) {
            float abs2 = Math.abs(this.C1.get(i).floatValue() - valueOfTouchPositionAbsolute);
            float t02 = t0(this.C1.get(i).floatValue());
            if (Float.compare(abs2, abs) > 1) {
                break;
            }
            boolean z = !K() ? t02 - t0 < 0.0f : t02 - t0 > 0.0f;
            if (Float.compare(abs2, abs) < 0) {
                this.D1 = i;
            } else {
                if (Float.compare(abs2, abs) != 0) {
                    continue;
                } else if (Math.abs(t02 - t0) < ((float) this.l1)) {
                    this.D1 = -1;
                    return false;
                } else if (z) {
                    this.D1 = i;
                }
            }
            abs = abs2;
        }
        if (this.D1 != -1) {
            return true;
        }
        return false;
    }

    public void b0(@NonNull L l) {
        this.g1.remove(l);
    }

    public void c0(@NonNull T t) {
        this.h1.remove(t);
    }

    public boolean dispatchHoverEvent(@NonNull MotionEvent motionEvent) {
        return this.b1.i(motionEvent) || super.dispatchHoverEvent(motionEvent);
    }

    public boolean dispatchKeyEvent(@NonNull KeyEvent keyEvent) {
        return super.dispatchKeyEvent(keyEvent);
    }

    /* access modifiers changed from: protected */
    public void drawableStateChanged() {
        super.drawableStateChanged();
        this.V0.setColor(G(this.Q1));
        this.W0.setColor(G(this.P1));
        this.Z0.setColor(G(this.O1));
        this.a1.setColor(G(this.N1));
        for (com.google.android.material.l.a aVar : this.f1) {
            if (aVar.isStateful()) {
                aVar.setState(getDrawableState());
            }
        }
        if (this.R1.isStateful()) {
            this.R1.setState(getDrawableState());
        }
        this.Y0.setColor(G(this.M1));
        this.Y0.setAlpha(63);
    }

    @NonNull
    public CharSequence getAccessibilityClassName() {
        return SeekBar.class.getName();
    }

    /* access modifiers changed from: package-private */
    @VisibleForTesting
    public final int getAccessibilityFocusedVirtualViewId() {
        return this.b1.k();
    }

    public int getActiveThumbIndex() {
        return this.D1;
    }

    public int getFocusedThumbIndex() {
        return this.E1;
    }

    @Dimension
    public int getHaloRadius() {
        return this.u1;
    }

    @NonNull
    public ColorStateList getHaloTintList() {
        return this.M1;
    }

    public int getLabelBehavior() {
        return this.p1;
    }

    /* access modifiers changed from: protected */
    public float getMinSeparation() {
        return 0.0f;
    }

    public float getStepSize() {
        return this.F1;
    }

    public float getThumbElevation() {
        return this.R1.x();
    }

    @Dimension
    public int getThumbRadius() {
        return this.t1;
    }

    public ColorStateList getThumbStrokeColor() {
        return this.R1.M();
    }

    public float getThumbStrokeWidth() {
        return this.R1.P();
    }

    @NonNull
    public ColorStateList getThumbTintList() {
        return this.R1.y();
    }

    @NonNull
    public ColorStateList getTickActiveTintList() {
        return this.N1;
    }

    @NonNull
    public ColorStateList getTickInactiveTintList() {
        return this.O1;
    }

    @NonNull
    public ColorStateList getTickTintList() {
        if (this.O1.equals(this.N1)) {
            return this.N1;
        }
        throw new IllegalStateException("The inactive and active ticks are different colors. Use the getTickColorInactive() and getTickColorActive() methods instead.");
    }

    @NonNull
    public ColorStateList getTrackActiveTintList() {
        return this.P1;
    }

    @Dimension
    public int getTrackHeight() {
        return this.q1;
    }

    @NonNull
    public ColorStateList getTrackInactiveTintList() {
        return this.Q1;
    }

    @Dimension
    public int getTrackSidePadding() {
        return this.r1;
    }

    @NonNull
    public ColorStateList getTrackTintList() {
        if (this.Q1.equals(this.P1)) {
            return this.P1;
        }
        throw new IllegalStateException("The inactive and active parts of the track are different colors. Use the getInactiveTrackColor() and getActiveTrackColor() methods instead.");
    }

    @Dimension
    public int getTrackWidth() {
        return this.I1;
    }

    public float getValueFrom() {
        return this.A1;
    }

    public float getValueTo() {
        return this.B1;
    }

    /* access modifiers changed from: package-private */
    @NonNull
    public List<Float> getValues() {
        return new ArrayList(this.C1);
    }

    public void h(@Nullable L l) {
        this.g1.add(l);
    }

    public void i(@NonNull T t) {
        this.h1.add(t);
    }

    /* access modifiers changed from: package-private */
    public void k0(int i, Rect rect) {
        int T = this.r1 + ((int) (T(getValues().get(i).floatValue()) * ((float) this.I1)));
        int n = n();
        int i2 = this.t1;
        rect.set(T - i2, n - i2, T + i2, n + i2);
    }

    public void o() {
        this.g1.clear();
    }

    /* access modifiers changed from: protected */
    public void onAttachedToWindow() {
        super.onAttachedToWindow();
        for (com.google.android.material.l.a aVar : this.f1) {
            j(aVar);
        }
    }

    /* access modifiers changed from: protected */
    public void onDetachedFromWindow() {
        BaseSlider<S, L, T>.d dVar = this.d1;
        if (dVar != null) {
            removeCallbacks(dVar);
        }
        this.i1 = false;
        for (com.google.android.material.l.a aVar : this.f1) {
            s(aVar);
        }
        super.onDetachedFromWindow();
    }

    /* access modifiers changed from: protected */
    public void onDraw(@NonNull Canvas canvas) {
        if (this.L1) {
            n0();
            N();
        }
        super.onDraw(canvas);
        int n = n();
        x(canvas, this.I1, n);
        if (((Float) Collections.max(getValues())).floatValue() > this.A1) {
            w(canvas, this.I1, n);
        }
        P(canvas);
        if ((this.z1 || isFocused()) && isEnabled()) {
            O(canvas, this.I1, n);
            if (this.D1 != -1) {
                z();
            }
        }
        y(canvas, this.I1, n);
    }

    /* access modifiers changed from: protected */
    public void onFocusChanged(boolean z, int i, @Nullable Rect rect) {
        super.onFocusChanged(z, i, rect);
        if (!z) {
            this.D1 = -1;
            A();
            this.b1.b(this.E1);
            return;
        }
        B(i);
        this.b1.K(this.E1);
    }

    public boolean onKeyDown(int i, @NonNull KeyEvent keyEvent) {
        if (!isEnabled()) {
            return super.onKeyDown(i, keyEvent);
        }
        if (this.C1.size() == 1) {
            this.D1 = 0;
        }
        if (this.D1 == -1) {
            Boolean U = U(i, keyEvent);
            return U != null ? U.booleanValue() : super.onKeyDown(i, keyEvent);
        }
        this.K1 |= keyEvent.isLongPress();
        Float k = k(i);
        if (k != null) {
            if (g0(this.C1.get(this.D1).floatValue() + k.floatValue())) {
                l0();
                postInvalidate();
            }
            return true;
        }
        if (i != 23) {
            if (i != 61) {
                if (i != 66) {
                    return super.onKeyDown(i, keyEvent);
                }
            } else if (keyEvent.hasNoModifiers()) {
                return R(1);
            } else {
                if (keyEvent.isShiftPressed()) {
                    return R(-1);
                }
                return false;
            }
        }
        this.D1 = -1;
        A();
        postInvalidate();
        return true;
    }

    public boolean onKeyUp(int i, @NonNull KeyEvent keyEvent) {
        this.K1 = false;
        return super.onKeyUp(i, keyEvent);
    }

    /* access modifiers changed from: protected */
    public void onMeasure(int i, int i2) {
        int i3 = this.o1;
        int i4 = 0;
        if (this.p1 == 1) {
            i4 = this.f1.get(0).getIntrinsicHeight();
        }
        super.onMeasure(i, View.MeasureSpec.makeMeasureSpec(i3 + i4, 1073741824));
    }

    /* access modifiers changed from: protected */
    public void onRestoreInstanceState(Parcelable parcelable) {
        SliderState sliderState = (SliderState) parcelable;
        super.onRestoreInstanceState(sliderState.getSuperState());
        this.A1 = sliderState.f11918a;
        this.B1 = sliderState.f11919b;
        setValuesInternal(sliderState.I0);
        this.F1 = sliderState.J0;
        if (sliderState.K0) {
            requestFocus();
        }
        v();
    }

    /* access modifiers changed from: protected */
    public Parcelable onSaveInstanceState() {
        SliderState sliderState = new SliderState(super.onSaveInstanceState());
        sliderState.f11918a = this.A1;
        sliderState.f11919b = this.B1;
        sliderState.I0 = new ArrayList<>(this.C1);
        sliderState.J0 = this.F1;
        sliderState.K0 = hasFocus();
        return sliderState;
    }

    /* access modifiers changed from: protected */
    public void onSizeChanged(int i, int i2, int i3, int i4) {
        m0(i);
        l0();
    }

    public boolean onTouchEvent(@NonNull MotionEvent motionEvent) {
        if (!isEnabled()) {
            return false;
        }
        float x = motionEvent.getX();
        float f2 = (x - ((float) this.r1)) / ((float) this.I1);
        this.S1 = f2;
        float max = Math.max(0.0f, f2);
        this.S1 = max;
        this.S1 = Math.min(1.0f, max);
        int actionMasked = motionEvent.getActionMasked();
        if (actionMasked == 0) {
            this.w1 = x;
            if (!J()) {
                getParent().requestDisallowInterceptTouchEvent(true);
                if (Y()) {
                    requestFocus();
                    this.z1 = true;
                    j0();
                    l0();
                    invalidate();
                    V();
                }
            }
        } else if (actionMasked == 1) {
            this.z1 = false;
            MotionEvent motionEvent2 = this.x1;
            if (motionEvent2 != null && motionEvent2.getActionMasked() == 0 && Math.abs(this.x1.getX() - motionEvent.getX()) <= ((float) this.l1) && Math.abs(this.x1.getY() - motionEvent.getY()) <= ((float) this.l1) && Y()) {
                V();
            }
            if (this.D1 != -1) {
                j0();
                this.D1 = -1;
                W();
            }
            A();
            invalidate();
        } else if (actionMasked == 2) {
            if (!this.z1) {
                if (J() && Math.abs(x - this.w1) < ((float) this.l1)) {
                    return false;
                }
                getParent().requestDisallowInterceptTouchEvent(true);
                V();
            }
            if (Y()) {
                this.z1 = true;
                j0();
                l0();
                invalidate();
            }
        }
        setPressed(this.z1);
        this.x1 = MotionEvent.obtain(motionEvent);
        return true;
    }

    public void p() {
        this.h1.clear();
    }

    /* access modifiers changed from: protected */
    public void setActiveThumbIndex(int i) {
        this.D1 = i;
    }

    public void setEnabled(boolean z) {
        super.setEnabled(z);
        setLayerType(z ? 0 : 2, null);
    }

    public void setFocusedThumbIndex(int i) {
        if (i < 0 || i >= this.C1.size()) {
            throw new IllegalArgumentException("index out of range");
        }
        this.E1 = i;
        this.b1.K(i);
        postInvalidate();
    }

    public void setHaloRadius(@IntRange(from = 0) @Dimension int i) {
        if (i != this.u1) {
            this.u1 = i;
            Drawable background = getBackground();
            if (f0() || !(background instanceof RippleDrawable)) {
                postInvalidate();
            } else {
                com.google.android.material.e.a.b((RippleDrawable) background, this.u1);
            }
        }
    }

    public void setHaloRadiusResource(@DimenRes int i) {
        setHaloRadius(getResources().getDimensionPixelSize(i));
    }

    public void setHaloTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.M1)) {
            this.M1 = colorStateList;
            Drawable background = getBackground();
            if (f0() || !(background instanceof RippleDrawable)) {
                this.Y0.setColor(G(colorStateList));
                this.Y0.setAlpha(63);
                invalidate();
                return;
            }
            ((RippleDrawable) background).setColor(colorStateList);
        }
    }

    public void setLabelBehavior(int i) {
        if (this.p1 != i) {
            this.p1 = i;
            requestLayout();
        }
    }

    public void setLabelFormatter(@Nullable d dVar) {
        this.y1 = dVar;
    }

    /* access modifiers changed from: protected */
    public void setSeparationUnit(int i) {
        this.T1 = i;
    }

    public void setStepSize(float f2) {
        if (f2 < 0.0f) {
            throw new IllegalArgumentException(String.format(L0, Float.toString(f2), Float.toString(this.A1), Float.toString(this.B1)));
        } else if (this.F1 != f2) {
            this.F1 = f2;
            this.L1 = true;
            postInvalidate();
        }
    }

    public void setThumbElevation(float f2) {
        this.R1.m0(f2);
    }

    public void setThumbElevationResource(@DimenRes int i) {
        setThumbElevation(getResources().getDimension(i));
    }

    public void setThumbRadius(@IntRange(from = 0) @Dimension int i) {
        if (i != this.t1) {
            this.t1 = i;
            Q();
            this.R1.setShapeAppearanceModel(com.google.android.material.shape.m.a().q(0, (float) this.t1).m());
            MaterialShapeDrawable materialShapeDrawable = this.R1;
            int i2 = this.t1;
            materialShapeDrawable.setBounds(0, 0, i2 * 2, i2 * 2);
            postInvalidate();
        }
    }

    public void setThumbRadiusResource(@DimenRes int i) {
        setThumbRadius(getResources().getDimensionPixelSize(i));
    }

    public void setThumbStrokeColor(@Nullable ColorStateList colorStateList) {
        this.R1.E0(colorStateList);
        postInvalidate();
    }

    public void setThumbStrokeColorResource(@ColorRes int i) {
        if (i != 0) {
            setThumbStrokeColor(androidx.appcompat.a.a.a.c(getContext(), i));
        }
    }

    public void setThumbStrokeWidth(float f2) {
        this.R1.H0(f2);
        postInvalidate();
    }

    public void setThumbStrokeWidthResource(@DimenRes int i) {
        if (i != 0) {
            setThumbStrokeWidth(getResources().getDimension(i));
        }
    }

    public void setThumbTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.R1.y())) {
            this.R1.n0(colorStateList);
            invalidate();
        }
    }

    public void setTickActiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.N1)) {
            this.N1 = colorStateList;
            this.a1.setColor(G(colorStateList));
            invalidate();
        }
    }

    public void setTickInactiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.O1)) {
            this.O1 = colorStateList;
            this.Z0.setColor(G(colorStateList));
            invalidate();
        }
    }

    public void setTickTintList(@NonNull ColorStateList colorStateList) {
        setTickInactiveTintList(colorStateList);
        setTickActiveTintList(colorStateList);
    }

    public void setTickVisible(boolean z) {
        if (this.H1 != z) {
            this.H1 = z;
            postInvalidate();
        }
    }

    public void setTrackActiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.P1)) {
            this.P1 = colorStateList;
            this.W0.setColor(G(colorStateList));
            invalidate();
        }
    }

    public void setTrackHeight(@IntRange(from = 0) @Dimension int i) {
        if (this.q1 != i) {
            this.q1 = i;
            I();
            postInvalidate();
        }
    }

    public void setTrackInactiveTintList(@NonNull ColorStateList colorStateList) {
        if (!colorStateList.equals(this.Q1)) {
            this.Q1 = colorStateList;
            this.V0.setColor(G(colorStateList));
            invalidate();
        }
    }

    public void setTrackTintList(@NonNull ColorStateList colorStateList) {
        setTrackInactiveTintList(colorStateList);
        setTrackActiveTintList(colorStateList);
    }

    public void setValueFrom(float f2) {
        this.A1 = f2;
        this.L1 = true;
        postInvalidate();
    }

    public void setValueTo(float f2) {
        this.B1 = f2;
        this.L1 = true;
        postInvalidate();
    }

    /* access modifiers changed from: package-private */
    public void setValues(@NonNull Float... fArr) {
        ArrayList<Float> arrayList = new ArrayList<>();
        Collections.addAll(arrayList, fArr);
        setValuesInternal(arrayList);
    }

    /* access modifiers changed from: private */
    public class d implements Runnable {

        /* renamed from: a  reason: collision with root package name */
        int f11925a;

        private d() {
            this.f11925a = -1;
        }

        /* access modifiers changed from: package-private */
        public void a(int i) {
            this.f11925a = i;
        }

        public void run() {
            BaseSlider.this.b1.L(this.f11925a, 4);
        }

        /* synthetic */ d(BaseSlider baseSlider, a aVar) {
            this();
        }
    }

    public BaseSlider(@NonNull Context context, @Nullable AttributeSet attributeSet) {
        this(context, attributeSet, R.attr.sliderStyle);
    }

    public BaseSlider(@NonNull Context context, @Nullable AttributeSet attributeSet, int i) {
        super(com.google.android.material.theme.a.a.c(context, attributeSet, i, Q0), attributeSet, i);
        this.f1 = new ArrayList();
        this.g1 = new ArrayList();
        this.h1 = new ArrayList();
        this.i1 = false;
        this.z1 = false;
        this.C1 = new ArrayList<>();
        this.D1 = -1;
        this.E1 = -1;
        this.F1 = 0.0f;
        this.H1 = true;
        this.K1 = false;
        MaterialShapeDrawable materialShapeDrawable = new MaterialShapeDrawable();
        this.R1 = materialShapeDrawable;
        this.T1 = 0;
        Context context2 = getContext();
        Paint paint = new Paint();
        this.V0 = paint;
        paint.setStyle(Paint.Style.STROKE);
        paint.setStrokeCap(Paint.Cap.ROUND);
        Paint paint2 = new Paint();
        this.W0 = paint2;
        paint2.setStyle(Paint.Style.STROKE);
        paint2.setStrokeCap(Paint.Cap.ROUND);
        Paint paint3 = new Paint(1);
        this.X0 = paint3;
        paint3.setStyle(Paint.Style.FILL);
        paint3.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.CLEAR));
        Paint paint4 = new Paint(1);
        this.Y0 = paint4;
        paint4.setStyle(Paint.Style.FILL);
        Paint paint5 = new Paint();
        this.Z0 = paint5;
        paint5.setStyle(Paint.Style.STROKE);
        paint5.setStrokeCap(Paint.Cap.ROUND);
        Paint paint6 = new Paint();
        this.a1 = paint6;
        paint6.setStyle(Paint.Style.STROKE);
        paint6.setStrokeCap(Paint.Cap.ROUND);
        M(context2.getResources());
        this.e1 = new a(attributeSet, i);
        a0(context2, attributeSet, i);
        setFocusable(true);
        setClickable(true);
        materialShapeDrawable.w0(2);
        this.l1 = ViewConfiguration.get(context2).getScaledTouchSlop();
        e eVar = new e(this);
        this.b1 = eVar;
        ViewCompat.setAccessibilityDelegate(this, eVar);
        this.c1 = (AccessibilityManager) getContext().getSystemService("accessibility");
    }

    /* access modifiers changed from: package-private */
    public void setValues(@NonNull List<Float> list) {
        setValuesInternal(new ArrayList<>(list));
    }
}
