package com.ibm.icu.text;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public final class DisplayOptions {

    /* renamed from: a  reason: collision with root package name */
    private final GrammaticalCase f15180a;

    /* renamed from: b  reason: collision with root package name */
    private final NounClass f15181b;

    /* renamed from: c  reason: collision with root package name */
    private final PluralCategory f15182c;

    /* renamed from: d  reason: collision with root package name */
    private final Capitalization f15183d;

    /* renamed from: e  reason: collision with root package name */
    private final NameStyle f15184e;
    private final DisplayLength f;
    private final SubstituteHandling g;

    public enum Capitalization {
        UNDEFINED,
        BEGINNING_OF_SENTENCE,
        MIDDLE_OF_SENTENCE,
        STANDALONE,
        UI_LIST_OR_MENU;
        
        public static final List<Capitalization> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
    }

    public enum DisplayLength {
        UNDEFINED,
        LENGTH_FULL,
        LENGTH_SHORT;
        
        public static final List<DisplayLength> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
    }

    public enum GrammaticalCase {
        UNDEFINED("undefined"),
        ABLATIVE("ablative"),
        ACCUSATIVE("accusative"),
        COMITATIVE("comitative"),
        DATIVE("dative"),
        ERGATIVE("ergative"),
        GENITIVE("genitive"),
        INSTRUMENTAL("instrumental"),
        LOCATIVE("locative"),
        LOCATIVE_COPULATIVE("locative_copulative"),
        NOMINATIVE("nominative"),
        OBLIQUE("oblique"),
        PREPOSITIONAL("prepositional"),
        SOCIATIVE("sociative"),
        VOCATIVE("vocative");
        
        public static final List<GrammaticalCase> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
        private final String identifier;

        private GrammaticalCase(String str) {
            this.identifier = str;
        }

        public static final GrammaticalCase fromIdentifier(String str) {
            if (str == null) {
                return UNDEFINED;
            }
            for (GrammaticalCase grammaticalCase : VALUES) {
                if (str.equals(grammaticalCase.getIdentifier())) {
                    return grammaticalCase;
                }
            }
            return UNDEFINED;
        }

        public final String getIdentifier() {
            return this.identifier;
        }
    }

    public enum NameStyle {
        UNDEFINED,
        STANDARD_NAMES,
        DIALECT_NAMES;
        
        public static final List<NameStyle> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
    }

    public enum NounClass {
        UNDEFINED("undefined"),
        OTHER(PluralRules.KEYWORD_OTHER),
        NEUTER("neuter"),
        FEMININE("feminine"),
        MASCULINE("masculine"),
        ANIMATE("animate"),
        INANIMATE("inanimate"),
        PERSONAL("personal"),
        COMMON("common");
        
        public static final List<NounClass> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
        private final String identifier;

        private NounClass(String str) {
            this.identifier = str;
        }

        public static final NounClass fromIdentifier(String str) {
            if (str == null) {
                return UNDEFINED;
            }
            for (NounClass nounClass : VALUES) {
                if (str.equals(nounClass.getIdentifier())) {
                    return nounClass;
                }
            }
            return UNDEFINED;
        }

        public final String getIdentifier() {
            return this.identifier;
        }
    }

    public enum PluralCategory {
        UNDEFINED("undefined"),
        ZERO(PluralRules.KEYWORD_ZERO),
        ONE(PluralRules.KEYWORD_ONE),
        TWO(PluralRules.KEYWORD_TWO),
        FEW(PluralRules.KEYWORD_FEW),
        MANY(PluralRules.KEYWORD_MANY),
        OTHER(PluralRules.KEYWORD_OTHER);
        
        public static final List<PluralCategory> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
        private final String identifier;

        private PluralCategory(String str) {
            this.identifier = str;
        }

        public static final PluralCategory fromIdentifier(String str) {
            if (str == null) {
                return UNDEFINED;
            }
            for (PluralCategory pluralCategory : VALUES) {
                if (str.equals(pluralCategory.getIdentifier())) {
                    return pluralCategory;
                }
            }
            return UNDEFINED;
        }

        public final String getIdentifier() {
            return this.identifier;
        }
    }

    public enum SubstituteHandling {
        UNDEFINED,
        SUBSTITUTE,
        NO_SUBSTITUTE;
        
        public static final List<SubstituteHandling> VALUES = Collections.unmodifiableList(Arrays.asList(values()));
    }

    public static b h() {
        return new b();
    }

    public b i() {
        return new b();
    }

    public Capitalization j() {
        return this.f15183d;
    }

    public DisplayLength k() {
        return this.f;
    }

    public GrammaticalCase l() {
        return this.f15180a;
    }

    public NameStyle m() {
        return this.f15184e;
    }

    public NounClass n() {
        return this.f15181b;
    }

    public PluralCategory o() {
        return this.f15182c;
    }

    public SubstituteHandling p() {
        return this.g;
    }

    public static class b {

        /* renamed from: a  reason: collision with root package name */
        private GrammaticalCase f15192a;

        /* renamed from: b  reason: collision with root package name */
        private NounClass f15193b;

        /* renamed from: c  reason: collision with root package name */
        private PluralCategory f15194c;

        /* renamed from: d  reason: collision with root package name */
        private Capitalization f15195d;

        /* renamed from: e  reason: collision with root package name */
        private NameStyle f15196e;
        private DisplayLength f;
        private SubstituteHandling g;

        public DisplayOptions h() {
            return new DisplayOptions(this);
        }

        public b i(Capitalization capitalization) {
            this.f15195d = capitalization;
            return this;
        }

        public b j(DisplayLength displayLength) {
            this.f = displayLength;
            return this;
        }

        public b k(GrammaticalCase grammaticalCase) {
            this.f15192a = grammaticalCase;
            return this;
        }

        public b l(NameStyle nameStyle) {
            this.f15196e = nameStyle;
            return this;
        }

        public b m(NounClass nounClass) {
            this.f15193b = nounClass;
            return this;
        }

        public b n(PluralCategory pluralCategory) {
            this.f15194c = pluralCategory;
            return this;
        }

        public b o(SubstituteHandling substituteHandling) {
            this.g = substituteHandling;
            return this;
        }

        private b() {
            this.f15192a = GrammaticalCase.UNDEFINED;
            this.f15193b = NounClass.UNDEFINED;
            this.f15194c = PluralCategory.UNDEFINED;
            this.f15195d = Capitalization.UNDEFINED;
            this.f15196e = NameStyle.UNDEFINED;
            this.f = DisplayLength.UNDEFINED;
            this.g = SubstituteHandling.UNDEFINED;
        }

        private b(DisplayOptions displayOptions) {
            this.f15192a = displayOptions.f15180a;
            this.f15193b = displayOptions.f15181b;
            this.f15194c = displayOptions.f15182c;
            this.f15195d = displayOptions.f15183d;
            this.f15196e = displayOptions.f15184e;
            this.f = displayOptions.f;
            this.g = displayOptions.g;
        }
    }

    private DisplayOptions(b bVar) {
        this.f15180a = bVar.f15192a;
        this.f15181b = bVar.f15193b;
        this.f15182c = bVar.f15194c;
        this.f15183d = bVar.f15195d;
        this.f15184e = bVar.f15196e;
        this.f = bVar.f;
        this.g = bVar.g;
    }
}
