package com.ibm.icu.text;

import com.ibm.icu.impl.ICUResourceBundle;
import com.ibm.icu.impl.a0;
import com.ibm.icu.impl.j1;
import com.ibm.icu.impl.l1;
import com.ibm.icu.impl.number.j;
import com.ibm.icu.impl.number.l;
import com.ibm.icu.impl.number.y;
import com.ibm.icu.impl.o;
import com.ibm.icu.impl.q2;
import com.ibm.icu.impl.r;
import com.ibm.icu.number.NumberFormatter;
import com.ibm.icu.number.f;
import com.ibm.icu.number.g;
import com.ibm.icu.number.p;
import com.ibm.icu.text.ListFormatter;
import com.ibm.icu.util.Currency;
import com.ibm.icu.util.ICUUncheckedIOException;
import com.ibm.icu.util.MeasureUnit;
import com.ibm.icu.util.ULocale;
import com.ibm.icu.util.h0;
import com.ibm.icu.util.t;
import java.io.Externalizable;
import java.io.IOException;
import java.io.InvalidObjectException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.io.ObjectStreamException;
import java.math.RoundingMode;
import java.text.FieldPosition;
import java.text.ParsePosition;
import java.util.Arrays;
import java.util.Collection;
import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.MissingResourceException;
import java.util.concurrent.ConcurrentHashMap;

public class MeasureFormat extends UFormat {
    private static final int I0 = 0;
    private static final int J0 = 1;
    private static final int K0 = 2;
    static final int L0 = 1;
    static final int M0 = 2;
    static final int N0 = 3;
    private static final Map<ULocale, String> O0 = new ConcurrentHashMap();
    static final /* synthetic */ boolean P0 = false;

    /* renamed from: a  reason: collision with root package name */
    private static final j1<ULocale, c> f15240a = new j1<>();

    /* renamed from: b  reason: collision with root package name */
    private static final Map<MeasureUnit, Integer> f15241b;
    static final long serialVersionUID = -7182021401701778240L;
    private final transient FormatWidth Q0;
    private final transient PluralRules R0;
    private final transient c S0;
    private final transient NumberFormat T0;
    private final transient g U0;
    private transient b V0;
    private transient b W0;
    private transient b X0;

    /* JADX WARN: Init of enum WIDE can be incorrect */
    /* JADX WARN: Init of enum SHORT can be incorrect */
    /* JADX WARN: Init of enum NARROW can be incorrect */
    /* JADX WARN: Init of enum NUMERIC can be incorrect */
    /* JADX WARN: Init of enum DEFAULT_CURRENCY can be incorrect */
    public enum FormatWidth {
        WIDE(r3, r11, r11),
        SHORT(r10, r1, NumberFormatter.UnitWidth.ISO_CODE),
        NARROW(r3, r4, r1),
        NUMERIC(r3, r4, r1),
        DEFAULT_CURRENCY(r10, r11, r1);
        
        final NumberFormatter.UnitWidth currencyWidth;
        final ListFormatter.Width listWidth;
        final NumberFormatter.UnitWidth unitWidth;

        static {
            ListFormatter.Width width = ListFormatter.Width.WIDE;
            NumberFormatter.UnitWidth unitWidth2 = NumberFormatter.UnitWidth.FULL_NAME;
            ListFormatter.Width width2 = ListFormatter.Width.SHORT;
            NumberFormatter.UnitWidth unitWidth3 = NumberFormatter.UnitWidth.SHORT;
            ListFormatter.Width width3 = ListFormatter.Width.NARROW;
            NumberFormatter.UnitWidth unitWidth4 = NumberFormatter.UnitWidth.NARROW;
        }

        private FormatWidth(ListFormatter.Width width, NumberFormatter.UnitWidth unitWidth2, NumberFormatter.UnitWidth unitWidth3) {
            this.listWidth = width;
            this.unitWidth = unitWidth2;
            this.currencyWidth = unitWidth3;
        }
    }

    /* access modifiers changed from: package-private */
    public static class b {

        /* renamed from: a  reason: collision with root package name */
        int f15243a;

        /* renamed from: b  reason: collision with root package name */
        MeasureUnit f15244b;

        /* renamed from: c  reason: collision with root package name */
        MeasureUnit f15245c;

        /* renamed from: d  reason: collision with root package name */
        g f15246d;

        b() {
        }
    }

    /* access modifiers changed from: package-private */
    public static class c {

        /* renamed from: a  reason: collision with root package name */
        private String f15247a;

        /* renamed from: b  reason: collision with root package name */
        private String f15248b;

        /* renamed from: c  reason: collision with root package name */
        private String f15249c;

        public c(String str, String str2, String str3) {
            this.f15247a = str;
            this.f15248b = str2;
            this.f15249c = str3;
        }

        public String a() {
            return this.f15247a;
        }

        public String b() {
            return this.f15249c;
        }

        public String c() {
            return this.f15248b;
        }
    }

    static {
        HashMap hashMap = new HashMap();
        f15241b = hashMap;
        hashMap.put(MeasureUnit.HOUR, 0);
        hashMap.put(MeasureUnit.MINUTE, 1);
        hashMap.put(MeasureUnit.SECOND, 2);
    }

    MeasureFormat(ULocale uLocale, FormatWidth formatWidth) {
        this(uLocale, formatWidth, null, null, null);
    }

    private r d(t tVar) {
        MeasureUnit b2 = tVar.b();
        j jVar = new j(tVar.a());
        r rVar = new r();
        if (b2 instanceof Currency) {
            s(2, b2, null).D(jVar, rVar);
        } else {
            s(1, b2, null).D(jVar, rVar);
        }
        return rVar;
    }

    private r e(t tVar) {
        j jVar = new j(tVar.a());
        r rVar = new r();
        s(3, tVar.b(), null).D(jVar, rVar);
        return rVar;
    }

    private void f(Appendable appendable, FieldPosition fieldPosition, t... tVarArr) {
        Number[] x;
        if (tVarArr.length != 0) {
            if (tVarArr.length == 1) {
                r d2 = d(tVarArr[0]);
                com.ibm.icu.impl.t.f(d2, fieldPosition);
                q2.k(d2, appendable);
            } else if (this.Q0 != FormatWidth.NUMERIC || (x = x(tVarArr)) == null) {
                ListFormatter k = ListFormatter.k(getLocale(), ListFormatter.Type.UNITS, this.Q0.listWidth);
                if (fieldPosition != o.f14300a) {
                    h(k, appendable, fieldPosition, tVarArr);
                    return;
                }
                String[] strArr = new String[tVarArr.length];
                for (int i = 0; i < tVarArr.length; i++) {
                    if (i == tVarArr.length - 1) {
                        strArr[i] = d(tVarArr[i]).toString();
                    } else {
                        strArr[i] = e(tVarArr[i]).toString();
                    }
                }
                k.f(Arrays.asList(strArr), false).c(appendable);
            } else {
                m(x, appendable);
            }
        }
    }

    public static MeasureFormat getCurrencyFormat(ULocale uLocale) {
        return new e0(uLocale);
    }

    public static MeasureFormat getInstance(ULocale uLocale, FormatWidth formatWidth) {
        return getInstance(uLocale, formatWidth, NumberFormat.getInstance(uLocale));
    }

    @Deprecated
    public static String getRangeFormat(ULocale uLocale, FormatWidth formatWidth) {
        String str;
        String str2;
        if (uLocale.getLanguage().equals("fr")) {
            return getRangeFormat(ULocale.ROOT, formatWidth);
        }
        Map<ULocale, String> map = O0;
        String str3 = map.get(uLocale);
        if (str3 == null) {
            ICUResourceBundle iCUResourceBundle = (ICUResourceBundle) h0.j(a0.f13490d, uLocale);
            ULocale D = iCUResourceBundle.D();
            if (uLocale.equals(D) || (str2 = map.get(uLocale)) == null) {
                z0 f = z0.f(uLocale);
                try {
                    str = iCUResourceBundle.W0("NumberElements/" + f.j() + "/miscPatterns/range");
                } catch (MissingResourceException unused) {
                    str = iCUResourceBundle.W0("NumberElements/latn/patterns/range");
                }
                str3 = l1.a(str, new StringBuilder(), 2, 2);
                Map<ULocale, String> map2 = O0;
                map2.put(uLocale, str3);
                if (!uLocale.equals(D)) {
                    map2.put(D, str3);
                }
            } else {
                map.put(uLocale, str2);
                return str2;
            }
        }
        return str3;
    }

    private void h(ListFormatter listFormatter, Appendable appendable, FieldPosition fieldPosition, t... tVarArr) {
        r rVar;
        String[] strArr = new String[tVarArr.length];
        FieldPosition fieldPosition2 = new FieldPosition(fieldPosition.getFieldAttribute(), fieldPosition.getField());
        int i = -1;
        for (int i2 = 0; i2 < tVarArr.length; i2++) {
            if (i2 == tVarArr.length - 1) {
                rVar = d(tVarArr[i2]);
            } else {
                rVar = e(tVarArr[i2]);
            }
            if (i == -1) {
                com.ibm.icu.impl.t.f(rVar, fieldPosition2);
                if (fieldPosition2.getEndIndex() != 0) {
                    i = i2;
                }
            }
            strArr[i2] = rVar.toString();
        }
        ListFormatter.e f = listFormatter.f(Arrays.asList(strArr), true);
        int d2 = f.d(i);
        if (d2 != -1) {
            fieldPosition.setBeginIndex(fieldPosition2.getBeginIndex() + d2);
            fieldPosition.setEndIndex(fieldPosition2.getEndIndex() + d2);
        }
        f.c(appendable);
    }

    private void m(Number[] numberArr, Appendable appendable) {
        String str;
        Integer num;
        int i;
        char c2 = 0;
        if (numberArr[0] != null && numberArr[2] != null) {
            str = this.S0.b();
            if (numberArr[1] == null) {
                numberArr[1] = 0;
            }
            numberArr[1] = Double.valueOf(Math.floor(numberArr[1].doubleValue()));
            numberArr[0] = Double.valueOf(Math.floor(numberArr[0].doubleValue()));
        } else if (numberArr[0] != null && numberArr[1] != null) {
            str = this.S0.a();
            numberArr[0] = Double.valueOf(Math.floor(numberArr[0].doubleValue()));
        } else if (numberArr[1] == null || numberArr[2] == null) {
            throw new IllegalStateException();
        } else {
            str = this.S0.c();
            numberArr[1] = Double.valueOf(Math.floor(numberArr[1].doubleValue()));
        }
        g gVar = (g) this.U0.e(f.b(2));
        r rVar = new r();
        int i2 = 0;
        boolean z = false;
        while (i2 < str.length()) {
            char charAt = str.charAt(i2);
            if (charAt == 'H') {
                num = numberArr[c2];
            } else if (charAt == 'm') {
                num = numberArr[1];
            } else if (charAt != 's') {
                num = 0;
            } else {
                num = numberArr[2];
            }
            if (charAt == '\'') {
                i = i2 + 1;
                if (i >= str.length() || str.charAt(i) != charAt) {
                    z = !z;
                    i2++;
                    c2 = 0;
                } else {
                    rVar.f(charAt, null);
                }
            } else if (charAt == 'H' || charAt == 'm' || charAt == 's') {
                if (z) {
                    rVar.f(charAt, null);
                } else {
                    i = i2 + 1;
                    if (i >= str.length() || str.charAt(i) != charAt) {
                        rVar.d(this.U0.C(num), null);
                    } else {
                        rVar.d(gVar.C(num), null);
                    }
                }
                i2++;
                c2 = 0;
            } else {
                rVar.f(charAt, null);
                i2++;
                c2 = 0;
            }
            i2 = i;
            i2++;
            c2 = 0;
        }
        try {
            appendable.append(rVar);
        } catch (IOException e2) {
            throw new ICUUncheckedIOException(e2);
        }
    }

    /* access modifiers changed from: private */
    public static FormatWidth n(int i) {
        FormatWidth[] values = FormatWidth.values();
        if (i < 0 || i >= values.length) {
            return FormatWidth.SHORT;
        }
        return values[i];
    }

    private synchronized g s(int i, MeasureUnit measureUnit, MeasureUnit measureUnit2) {
        g gVar;
        b bVar = this.V0;
        if (bVar != null) {
            if (bVar.f15243a == i && bVar.f15244b == measureUnit && bVar.f15245c == measureUnit2) {
                return bVar.f15246d;
            }
            b bVar2 = this.W0;
            if (bVar2 != null) {
                if (bVar2.f15243a == i && bVar2.f15244b == measureUnit && bVar2.f15245c == measureUnit2) {
                    return bVar2.f15246d;
                }
                b bVar3 = this.X0;
                if (bVar3 != null && bVar3.f15243a == i && bVar3.f15244b == measureUnit && bVar3.f15245c == measureUnit2) {
                    return bVar3.f15246d;
                }
            }
        }
        if (i == 1) {
            gVar = (g) ((g) ((g) q().s(measureUnit)).i(measureUnit2)).u(this.Q0.unitWidth);
        } else if (i == 2) {
            gVar = (g) ((g) ((g) NumberFormatter.d(getLocale()).s(measureUnit)).i(measureUnit2)).u(this.Q0.currencyWidth);
        } else {
            gVar = (g) ((g) ((g) ((g) q().s(measureUnit)).i(measureUnit2)).u(this.Q0.unitWidth)).j(p.x().I(y.e(RoundingMode.DOWN)));
        }
        this.X0 = this.W0;
        this.W0 = this.V0;
        b bVar4 = new b();
        this.V0 = bVar4;
        bVar4.f15243a = i;
        bVar4.f15244b = measureUnit;
        bVar4.f15245c = measureUnit2;
        bVar4.f15246d = gVar;
        return gVar;
    }

    private static String t(ICUResourceBundle iCUResourceBundle, String str) {
        return iCUResourceBundle.Z0(String.format("durationUnits/%s", str)).y().replace("h", DateFormat.HOUR24);
    }

    private static c u(ULocale uLocale) {
        ICUResourceBundle iCUResourceBundle = (ICUResourceBundle) h0.j(a0.n, uLocale);
        return new c(t(iCUResourceBundle, "hm"), t(iCUResourceBundle, DateFormat.MINUTE_SECOND), t(iCUResourceBundle, "hms"));
    }

    private Object writeReplace() throws ObjectStreamException {
        return new a(getLocale(), this.Q0, p(), 0);
    }

    private static Number[] x(t[] tVarArr) {
        Integer num;
        int intValue;
        Number[] numberArr = new Number[3];
        int length = tVarArr.length;
        int i = -1;
        int i2 = 0;
        while (i2 < length) {
            t tVar = tVarArr[i2];
            if (tVar.a().doubleValue() < 0.0d || (num = f15241b.get(tVar.b())) == null || (intValue = num.intValue()) <= i) {
                return null;
            }
            numberArr[intValue] = tVar.a();
            i2++;
            i = intValue;
        }
        return numberArr;
    }

    /* access modifiers changed from: package-private */
    public MeasureFormat A(NumberFormat numberFormat) {
        return new MeasureFormat(getLocale(), this.Q0, numberFormat, this.R0, this.S0);
    }

    /* access modifiers changed from: package-private */
    public synchronized void c() {
        this.V0 = null;
        this.W0 = null;
        this.X0 = null;
    }

    public final boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (!(obj instanceof MeasureFormat)) {
            return false;
        }
        MeasureFormat measureFormat = (MeasureFormat) obj;
        if (getWidth() != measureFormat.getWidth() || !getLocale().equals(measureFormat.getLocale()) || !p().equals(measureFormat.p())) {
            return false;
        }
        return true;
    }

    public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        int length = stringBuffer.length();
        int i = 0;
        fieldPosition.setBeginIndex(0);
        fieldPosition.setEndIndex(0);
        if (obj instanceof Collection) {
            Collection collection = (Collection) obj;
            t[] tVarArr = new t[collection.size()];
            for (Object obj2 : collection) {
                if (obj2 instanceof t) {
                    tVarArr[i] = (t) obj2;
                    i++;
                } else {
                    throw new IllegalArgumentException(obj.toString());
                }
            }
            f(stringBuffer, fieldPosition, tVarArr);
        } else if (obj instanceof t[]) {
            f(stringBuffer, fieldPosition, (t[]) obj);
        } else if (obj instanceof t) {
            r d2 = d((t) obj);
            com.ibm.icu.impl.t.f(d2, fieldPosition);
            q2.k(d2, stringBuffer);
        } else {
            throw new IllegalArgumentException(obj.toString());
        }
        if (length > 0 && fieldPosition.getEndIndex() != 0) {
            fieldPosition.setBeginIndex(fieldPosition.getBeginIndex() + length);
            fieldPosition.setEndIndex(fieldPosition.getEndIndex() + length);
        }
        return stringBuffer;
    }

    public StringBuilder formatMeasurePerUnit(t tVar, MeasureUnit measureUnit, StringBuilder sb, FieldPosition fieldPosition) {
        j jVar = new j(tVar.a());
        r rVar = new r();
        s(1, tVar.b(), measureUnit).D(jVar, rVar);
        DecimalFormat.h(jVar, rVar, fieldPosition, sb.length());
        q2.k(rVar, sb);
        return sb;
    }

    public final String formatMeasures(t... tVarArr) {
        return formatMeasures(new StringBuilder(), o.f14300a, tVarArr).toString();
    }

    public final ULocale getLocale() {
        return getLocale(ULocale.VALID_LOCALE);
    }

    public NumberFormat getNumberFormat() {
        return (NumberFormat) this.T0.clone();
    }

    public String getUnitDisplayName(MeasureUnit measureUnit) {
        return l.r(getLocale(), measureUnit, this.Q0.unitWidth);
    }

    public FormatWidth getWidth() {
        FormatWidth formatWidth = this.Q0;
        return formatWidth == FormatWidth.DEFAULT_CURRENCY ? FormatWidth.WIDE : formatWidth;
    }

    public final int hashCode() {
        return (((getLocale().hashCode() * 31) + p().hashCode()) * 31) + getWidth().hashCode();
    }

    /* access modifiers changed from: package-private */
    public NumberFormat p() {
        return this.T0;
    }

    /* access modifiers changed from: package-private */
    public g q() {
        return this.U0;
    }

    /* access modifiers changed from: package-private */
    public Object v() {
        return new a(getLocale(), this.Q0, p(), 2);
    }

    /* access modifiers changed from: package-private */
    public Object y() {
        return new a(getLocale(), this.Q0, p(), 1);
    }

    /* access modifiers changed from: package-private */
    public MeasureFormat z(ULocale uLocale) {
        return getInstance(uLocale, getWidth());
    }

    private MeasureFormat(ULocale uLocale, FormatWidth formatWidth, NumberFormat numberFormat, PluralRules pluralRules, c cVar) {
        NumberFormat numberFormat2;
        j1<ULocale, c> j1Var;
        this.V0 = null;
        this.W0 = null;
        this.X0 = null;
        a(uLocale, uLocale);
        this.Q0 = formatWidth;
        this.R0 = pluralRules == null ? PluralRules.forLocale(uLocale) : pluralRules;
        if (numberFormat == null) {
            numberFormat2 = NumberFormat.getInstance(uLocale);
        } else {
            numberFormat2 = (NumberFormat) numberFormat.clone();
        }
        this.T0 = numberFormat2;
        if (cVar == null && formatWidth == FormatWidth.NUMERIC && (cVar = (j1Var = f15240a).get(uLocale)) == null) {
            cVar = u(uLocale);
            j1Var.put(uLocale, cVar);
        }
        this.S0 = cVar;
        if (numberFormat2 instanceof DecimalFormat) {
            this.U0 = (g) ((DecimalFormat) numberFormat2).toNumberFormatter().u(formatWidth.unitWidth);
            return;
        }
        throw new IllegalArgumentException();
    }

    public static MeasureFormat getCurrencyFormat(Locale locale) {
        return getCurrencyFormat(ULocale.forLocale(locale));
    }

    public static MeasureFormat getInstance(Locale locale, FormatWidth formatWidth) {
        return getInstance(ULocale.forLocale(locale), formatWidth);
    }

    public StringBuilder formatMeasures(StringBuilder sb, FieldPosition fieldPosition, t... tVarArr) {
        int length = sb.length();
        f(sb, fieldPosition, tVarArr);
        if (length > 0 && fieldPosition.getEndIndex() > 0) {
            fieldPosition.setBeginIndex(fieldPosition.getBeginIndex() + length);
            fieldPosition.setEndIndex(fieldPosition.getEndIndex() + length);
        }
        return sb;
    }

    public t parseObject(String str, ParsePosition parsePosition) {
        throw new UnsupportedOperationException();
    }

    public static MeasureFormat getCurrencyFormat() {
        return getCurrencyFormat(ULocale.getDefault(ULocale.Category.FORMAT));
    }

    public static MeasureFormat getInstance(ULocale uLocale, FormatWidth formatWidth, NumberFormat numberFormat) {
        return new MeasureFormat(uLocale, formatWidth, numberFormat, null, null);
    }

    public static MeasureFormat getInstance(Locale locale, FormatWidth formatWidth, NumberFormat numberFormat) {
        return getInstance(ULocale.forLocale(locale), formatWidth, numberFormat);
    }

    /* access modifiers changed from: package-private */
    public static class a implements Externalizable {
        private static final long serialVersionUID = -6033308329886716770L;
        private FormatWidth formatWidth;
        private HashMap<Object, Object> keyValues;
        private ULocale locale;
        private NumberFormat numberFormat;
        private int subClass;

        public a(ULocale uLocale, FormatWidth formatWidth2, NumberFormat numberFormat2, int i) {
            this.locale = uLocale;
            this.formatWidth = formatWidth2;
            this.numberFormat = numberFormat2;
            this.subClass = i;
            this.keyValues = new HashMap<>();
        }

        private TimeUnitFormat a() throws InvalidObjectException {
            int i;
            FormatWidth formatWidth2 = this.formatWidth;
            if (formatWidth2 == FormatWidth.WIDE) {
                i = 0;
            } else if (formatWidth2 == FormatWidth.SHORT) {
                i = 1;
            } else {
                throw new InvalidObjectException("Bad width: " + this.formatWidth);
            }
            TimeUnitFormat timeUnitFormat = new TimeUnitFormat(this.locale, i);
            timeUnitFormat.setNumberFormat(this.numberFormat);
            return timeUnitFormat;
        }

        private Object readResolve() throws ObjectStreamException {
            int i = this.subClass;
            if (i == 0) {
                return MeasureFormat.getInstance(this.locale, this.formatWidth, this.numberFormat);
            }
            if (i == 1) {
                return a();
            }
            if (i == 2) {
                return MeasureFormat.getCurrencyFormat(this.locale);
            }
            throw new InvalidObjectException("Unknown subclass: " + this.subClass);
        }

        @Override // java.io.Externalizable
        public void readExternal(ObjectInput objectInput) throws IOException, ClassNotFoundException {
            objectInput.readByte();
            this.locale = ULocale.forLanguageTag(objectInput.readUTF());
            this.formatWidth = MeasureFormat.n(objectInput.readByte() & 255);
            NumberFormat numberFormat2 = (NumberFormat) objectInput.readObject();
            this.numberFormat = numberFormat2;
            if (numberFormat2 != null) {
                this.subClass = objectInput.readByte() & 255;
                HashMap<Object, Object> hashMap = (HashMap) objectInput.readObject();
                this.keyValues = hashMap;
                if (hashMap == null) {
                    throw new InvalidObjectException("Missing optional values map.");
                }
                return;
            }
            throw new InvalidObjectException("Missing number format.");
        }

        @Override // java.io.Externalizable
        public void writeExternal(ObjectOutput objectOutput) throws IOException {
            objectOutput.writeByte(0);
            objectOutput.writeUTF(this.locale.toLanguageTag());
            objectOutput.writeByte(this.formatWidth.ordinal());
            objectOutput.writeObject(this.numberFormat);
            objectOutput.writeByte(this.subClass);
            objectOutput.writeObject(this.keyValues);
        }

        public a() {
        }
    }

    MeasureFormat(ULocale uLocale, FormatWidth formatWidth, NumberFormat numberFormat, PluralRules pluralRules) {
        this(uLocale, formatWidth, numberFormat, pluralRules, null);
        if (formatWidth == FormatWidth.NUMERIC) {
            throw new IllegalArgumentException("The format width 'numeric' is not allowed by this constructor");
        }
    }
}
