package com.ibm.icu.text;

import androidx.constraintlayout.core.motion.h.w;
import com.ibm.icu.impl.StandardPlural;
import com.ibm.icu.impl.a1;
import com.ibm.icu.impl.number.Padder;
import com.ibm.icu.util.ULocale;
import java.io.IOException;
import java.io.NotSerializableException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectStreamException;
import java.io.Serializable;
import java.math.BigDecimal;
import java.text.ParseException;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashSet;
import java.util.List;
import java.util.Locale;
import java.util.Set;
import java.util.regex.Pattern;
import kotlin.time.DurationKt;

public class PluralRules implements Serializable {
    public static final PluralRules DEFAULT;
    private static final e I0;
    private static final l J0;
    static final Pattern K0 = Pattern.compile("\\s*\\Q\\E@\\s*");
    public static final String KEYWORD_FEW = "few";
    public static final String KEYWORD_MANY = "many";
    public static final String KEYWORD_ONE = "one";
    public static final String KEYWORD_OTHER = "other";
    public static final String KEYWORD_TWO = "two";
    public static final String KEYWORD_ZERO = "zero";
    static final Pattern L0 = Pattern.compile("\\s*or\\s*");
    static final Pattern M0 = Pattern.compile("\\s*and\\s*");
    static final Pattern N0 = Pattern.compile("\\s*,\\s*");
    public static final double NO_UNIQUE_VALUE = -0.00123456777d;
    @Deprecated
    public static final com.ibm.icu.impl.number.h NO_UNIQUE_VALUE_DECIMAL_QUANTITY = new com.ibm.icu.impl.number.j(-0.00123456777d);
    static final Pattern O0 = Pattern.compile("\\s*\\Q..\\E\\s*");
    static final Pattern P0 = Pattern.compile("\\s*~\\s*");
    static final Pattern Q0 = Pattern.compile("\\s*;\\s*");

    /* renamed from: a  reason: collision with root package name */
    static final UnicodeSet f15318a = new UnicodeSet("[a-z]").freeze();

    /* renamed from: b  reason: collision with root package name */
    private static final String f15319b = ";  ";
    private static final long serialVersionUID = 1;
    private final transient Set<String> R0;
    private final transient com.ibm.icu.impl.number.d0.c S0;
    private final m rules;

    @Deprecated
    public static class FixedDecimal extends Number implements Comparable<FixedDecimal>, i {

        /* renamed from: a  reason: collision with root package name */
        static final long f15320a = 1000000000000000000L;

        /* renamed from: b  reason: collision with root package name */
        private static final long f15321b = 1000000000;
        private static final long serialVersionUID = -4756200506571685661L;
        private final int baseFactor;
        final long decimalDigits;
        final long decimalDigitsWithoutTrailingZeros;
        final int exponent;
        final boolean hasIntegerValue;
        final long integerValue;
        final boolean isNegative;
        final double source;
        final int visibleDecimalDigitCount;
        final int visibleDecimalDigitCountWithoutTrailingZeros;

        @Deprecated
        public FixedDecimal(double d2, int i, long j, int i2, int i3) {
            boolean z = true;
            boolean z2 = d2 < 0.0d;
            this.isNegative = z2;
            double d3 = z2 ? -d2 : d2;
            this.source = d3;
            this.visibleDecimalDigitCount = i;
            this.decimalDigits = j;
            long j2 = d2 > 1.0E18d ? f15320a : (long) d3;
            this.integerValue = j2;
            this.exponent = i2 == 0 ? i3 : i2;
            this.hasIntegerValue = d3 != ((double) j2) ? false : z;
            if (j == 0) {
                this.decimalDigitsWithoutTrailingZeros = 0;
                this.visibleDecimalDigitCountWithoutTrailingZeros = 0;
            } else {
                int i4 = i;
                while (j % 10 == 0) {
                    j /= 10;
                    i4--;
                }
                this.decimalDigitsWithoutTrailingZeros = j;
                this.visibleDecimalDigitCountWithoutTrailingZeros = i4;
            }
            this.baseFactor = (int) Math.pow(10.0d, (double) i);
        }

        private static int M(double d2, int i) {
            if (i == 0) {
                return 0;
            }
            if (d2 < 0.0d) {
                d2 = -d2;
            }
            int pow = (int) Math.pow(10.0d, (double) i);
            return (int) (Math.round(d2 * ((double) pow)) % ((long) pow));
        }

        @Deprecated
        public static FixedDecimal createWithExponent(double d2, int i, int i2) {
            return new FixedDecimal(d2, i, (long) M(d2, i), i2);
        }

        @Deprecated
        public static int decimals(double d2) {
            if (Double.isInfinite(d2) || Double.isNaN(d2)) {
                return 0;
            }
            if (d2 < 0.0d) {
                d2 = -d2;
            }
            if (d2 == Math.floor(d2)) {
                return 0;
            }
            if (d2 < 1.0E9d) {
                long j = ((long) (d2 * 1000000.0d)) % 1000000;
                int i = 10;
                for (int i2 = 6; i2 > 0; i2--) {
                    if (j % ((long) i) != 0) {
                        return i2;
                    }
                    i *= 10;
                }
                return 0;
            }
            String format = String.format(Locale.ENGLISH, "%1.15e", Double.valueOf(d2));
            int lastIndexOf = format.lastIndexOf(101);
            int i3 = lastIndexOf + 1;
            if (format.charAt(i3) == '+') {
                i3++;
            }
            int parseInt = (lastIndexOf - 2) - Integer.parseInt(format.substring(i3));
            if (parseInt < 0) {
                return 0;
            }
            int i4 = lastIndexOf - 1;
            while (parseInt > 0 && format.charAt(i4) == '0') {
                parseInt--;
                i4--;
            }
            return parseInt;
        }

        @Deprecated
        public static Operand getOperand(String str) {
            return Operand.valueOf(str);
        }

        private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
            throw new NotSerializableException();
        }

        private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
            throw new NotSerializableException();
        }

        @Deprecated
        public double doubleValue() {
            return (this.isNegative ? -this.source : this.source) * Math.pow(10.0d, (double) this.exponent);
        }

        @Deprecated
        public boolean equals(Object obj) {
            if (obj == null) {
                return false;
            }
            if (obj == this) {
                return true;
            }
            if (!(obj instanceof FixedDecimal)) {
                return false;
            }
            FixedDecimal fixedDecimal = (FixedDecimal) obj;
            if (this.source == fixedDecimal.source && this.visibleDecimalDigitCount == fixedDecimal.visibleDecimalDigitCount && this.decimalDigits == fixedDecimal.decimalDigits && this.exponent == fixedDecimal.exponent) {
                return true;
            }
            return false;
        }

        @Deprecated
        public float floatValue() {
            return (float) (this.source * Math.pow(10.0d, (double) this.exponent));
        }

        @Deprecated
        public int getBaseFactor() {
            return this.baseFactor;
        }

        @Deprecated
        public long getDecimalDigits() {
            return this.decimalDigits;
        }

        @Deprecated
        public long getDecimalDigitsWithoutTrailingZeros() {
            return this.decimalDigitsWithoutTrailingZeros;
        }

        @Deprecated
        public long getIntegerValue() {
            return this.integerValue;
        }

        @Override // com.ibm.icu.text.PluralRules.i
        @Deprecated
        public double getPluralOperand(Operand operand) {
            switch (b.f15328a[operand.ordinal()]) {
                case 1:
                    int i = this.exponent;
                    double d2 = this.source;
                    return i == 0 ? d2 : d2 * Math.pow(10.0d, (double) i);
                case 2:
                    return (double) intValue();
                case 3:
                    return (double) this.decimalDigits;
                case 4:
                    return (double) this.decimalDigitsWithoutTrailingZeros;
                case 5:
                    return (double) this.visibleDecimalDigitCount;
                case 6:
                    return (double) this.visibleDecimalDigitCountWithoutTrailingZeros;
                case 7:
                    return (double) this.exponent;
                case 8:
                    return (double) this.exponent;
                default:
                    return doubleValue();
            }
        }

        @Deprecated
        public double getSource() {
            return this.source;
        }

        @Deprecated
        public int getVisibleDecimalDigitCount() {
            return this.visibleDecimalDigitCount;
        }

        @Deprecated
        public int getVisibleDecimalDigitCountWithoutTrailingZeros() {
            return this.visibleDecimalDigitCountWithoutTrailingZeros;
        }

        @Deprecated
        public boolean hasIntegerValue() {
            return this.hasIntegerValue;
        }

        @Deprecated
        public int hashCode() {
            return (int) (this.decimalDigits + ((long) ((this.visibleDecimalDigitCount + ((int) (this.source * 37.0d))) * 37)));
        }

        @Deprecated
        public int intValue() {
            return (int) longValue();
        }

        @Override // com.ibm.icu.text.PluralRules.i
        @Deprecated
        public boolean isHasIntegerValue() {
            return this.hasIntegerValue;
        }

        @Override // com.ibm.icu.text.PluralRules.i
        @Deprecated
        public boolean isInfinite() {
            return Double.isInfinite(this.source);
        }

        @Override // com.ibm.icu.text.PluralRules.i
        @Deprecated
        public boolean isNaN() {
            return Double.isNaN(this.source);
        }

        @Deprecated
        public boolean isNegative() {
            return this.isNegative;
        }

        @Deprecated
        public long longValue() {
            int i = this.exponent;
            if (i == 0) {
                return this.integerValue;
            }
            return (long) (Math.pow(10.0d, (double) i) * ((double) this.integerValue));
        }

        @Deprecated
        public String toString() {
            Locale locale = Locale.ROOT;
            String format = String.format(locale, "%." + this.visibleDecimalDigitCount + "f", Double.valueOf(this.source));
            if (this.exponent == 0) {
                return format;
            }
            return format + "e" + this.exponent;
        }

        @Deprecated
        public int compareTo(FixedDecimal fixedDecimal) {
            if (this.exponent == fixedDecimal.exponent) {
                long j = this.integerValue;
                long j2 = fixedDecimal.integerValue;
                if (j == j2) {
                    double d2 = this.source;
                    double d3 = fixedDecimal.source;
                    if (d2 == d3) {
                        int i = this.visibleDecimalDigitCount;
                        int i2 = fixedDecimal.visibleDecimalDigitCount;
                        if (i == i2) {
                            int i3 = ((this.decimalDigits - fixedDecimal.decimalDigits) > 0 ? 1 : ((this.decimalDigits - fixedDecimal.decimalDigits) == 0 ? 0 : -1));
                            if (i3 == 0) {
                                return 0;
                            }
                            if (i3 < 0) {
                                return -1;
                            }
                            return 1;
                        } else if (i < i2) {
                            return -1;
                        } else {
                            return 1;
                        }
                    } else if (d2 < d3) {
                        return -1;
                    } else {
                        return 1;
                    }
                } else if (j < j2) {
                    return -1;
                } else {
                    return 1;
                }
            } else if (doubleValue() < fixedDecimal.doubleValue()) {
                return -1;
            } else {
                return 1;
            }
        }

        @Deprecated
        public FixedDecimal(double d2, int i, long j, int i2) {
            this(d2, i, j, i2, i2);
        }

        @Deprecated
        public FixedDecimal(double d2, int i, long j) {
            this(d2, i, j, 0);
        }

        @Deprecated
        public FixedDecimal(double d2, int i) {
            this(d2, i, (long) M(d2, i));
        }

        @Deprecated
        public FixedDecimal(double d2) {
            this(d2, decimals(d2));
        }

        @Deprecated
        public FixedDecimal(long j) {
            this((double) j, 0);
        }

        @Deprecated
        private FixedDecimal(FixedDecimal fixedDecimal) {
            this.source = fixedDecimal.source;
            this.visibleDecimalDigitCount = fixedDecimal.visibleDecimalDigitCount;
            this.visibleDecimalDigitCountWithoutTrailingZeros = fixedDecimal.visibleDecimalDigitCountWithoutTrailingZeros;
            this.decimalDigits = fixedDecimal.decimalDigits;
            this.decimalDigitsWithoutTrailingZeros = fixedDecimal.decimalDigitsWithoutTrailingZeros;
            this.integerValue = fixedDecimal.integerValue;
            this.hasIntegerValue = fixedDecimal.hasIntegerValue;
            this.isNegative = fixedDecimal.isNegative;
            this.exponent = fixedDecimal.exponent;
            this.baseFactor = fixedDecimal.baseFactor;
        }
    }

    public enum KeywordStatus {
        INVALID,
        SUPPRESSED,
        UNIQUE,
        BOUNDED,
        UNBOUNDED
    }

    @Deprecated
    public enum Operand {
        n,
        i,
        f,
        t,
        v,
        w,
        e,
        c,
        j
    }

    public enum PluralType {
        CARDINAL,
        ORDINAL
    }

    @Deprecated
    public enum SampleType {
        INTEGER,
        DECIMAL
    }

    /* access modifiers changed from: package-private */
    public static class a implements e {
        private static final long serialVersionUID = 9163464945387899416L;

        a() {
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean r(i iVar) {
            return true;
        }

        public String toString() {
            return "";
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean w(SampleType sampleType) {
            return false;
        }
    }

    /* access modifiers changed from: package-private */
    public static /* synthetic */ class b {

        /* renamed from: a  reason: collision with root package name */
        static final /* synthetic */ int[] f15328a;

        /* renamed from: b  reason: collision with root package name */
        static final /* synthetic */ int[] f15329b;

        /* JADX WARNING: Can't wrap try/catch for region: R(22:0|(2:1|2)|3|(2:5|6)|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|26) */
        /* JADX WARNING: Can't wrap try/catch for region: R(23:0|1|2|3|(2:5|6)|7|9|10|11|12|13|14|15|16|17|18|19|20|21|22|23|24|26) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:11:0x002e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:13:0x0038 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:15:0x0043 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:17:0x004e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0059 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x0064 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x006f */
        static {
            int[] iArr = new int[SampleType.values().length];
            f15329b = iArr;
            try {
                iArr[SampleType.INTEGER.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                f15329b[SampleType.DECIMAL.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            int[] iArr2 = new int[Operand.values().length];
            f15328a = iArr2;
            iArr2[Operand.n.ordinal()] = 1;
            f15328a[Operand.i.ordinal()] = 2;
            f15328a[Operand.f.ordinal()] = 3;
            f15328a[Operand.t.ordinal()] = 4;
            f15328a[Operand.v.ordinal()] = 5;
            f15328a[Operand.w.ordinal()] = 6;
            f15328a[Operand.e.ordinal()] = 7;
            try {
                f15328a[Operand.c.ordinal()] = 8;
            } catch (NoSuchFieldError unused3) {
            }
        }
    }

    /* access modifiers changed from: private */
    public static class c extends d {
        private static final long serialVersionUID = 7766999779862263523L;

        c(e eVar, e eVar2) {
            super(eVar, eVar2);
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean r(i iVar) {
            return this.f15330a.r(iVar) && this.f15331b.r(iVar);
        }

        public String toString() {
            return this.f15330a.toString() + " and " + this.f15331b.toString();
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean w(SampleType sampleType) {
            return this.f15330a.w(sampleType) || this.f15331b.w(sampleType);
        }
    }

    private static abstract class d implements e, Serializable {
        private static final long serialVersionUID = 1;

        /* renamed from: a  reason: collision with root package name */
        protected final e f15330a;

        /* renamed from: b  reason: collision with root package name */
        protected final e f15331b;

        protected d(e eVar, e eVar2) {
            this.f15330a = eVar;
            this.f15331b = eVar2;
        }
    }

    /* access modifiers changed from: private */
    public interface e extends Serializable {
        boolean r(i iVar);

        boolean w(SampleType sampleType);
    }

    @Deprecated
    public static class f {
        @Deprecated

        /* renamed from: a  reason: collision with root package name */
        public final SampleType f15332a;
        @Deprecated

        /* renamed from: b  reason: collision with root package name */
        public final Set<g> f15333b;
        @Deprecated

        /* renamed from: c  reason: collision with root package name */
        public final boolean f15334c;

        private f(SampleType sampleType, Set<g> set, boolean z) {
            this.f15332a = sampleType;
            this.f15333b = set;
            this.f15334c = z;
        }

        private static void d(SampleType sampleType, com.ibm.icu.impl.number.h hVar) {
            if ((sampleType == SampleType.INTEGER && hVar.getPluralOperand(Operand.v) != 0.0d) || (sampleType == SampleType.DECIMAL && hVar.getPluralOperand(Operand.v) == 0.0d && hVar.getPluralOperand(Operand.e) == 0.0d)) {
                throw new IllegalArgumentException("Ill-formed number range: " + hVar);
            }
        }

        static f g(String str) {
            SampleType sampleType;
            LinkedHashSet linkedHashSet = new LinkedHashSet();
            if (str.startsWith(w.b.f1677b)) {
                sampleType = SampleType.INTEGER;
            } else if (str.startsWith("decimal")) {
                sampleType = SampleType.DECIMAL;
            } else {
                throw new IllegalArgumentException("Samples must start with 'integer' or 'decimal'");
            }
            String[] split = PluralRules.N0.split(str.substring(7).trim(), 0);
            boolean z = true;
            boolean z2 = false;
            for (String str2 : split) {
                if (str2.equals("…") || str2.equals("...")) {
                    z = false;
                    z2 = true;
                } else if (!z2) {
                    String[] split2 = PluralRules.P0.split(str2, 0);
                    int length = split2.length;
                    if (length == 1) {
                        com.ibm.icu.impl.number.h q0 = com.ibm.icu.impl.number.j.q0(split2[0]);
                        d(sampleType, q0);
                        linkedHashSet.add(new g(q0, q0));
                    } else if (length == 2) {
                        com.ibm.icu.impl.number.h q02 = com.ibm.icu.impl.number.j.q0(split2[0]);
                        com.ibm.icu.impl.number.h q03 = com.ibm.icu.impl.number.j.q0(split2[1]);
                        d(sampleType, q02);
                        d(sampleType, q03);
                        linkedHashSet.add(new g(q02, q03));
                    } else {
                        throw new IllegalArgumentException("Ill-formed number range: " + str2);
                    }
                } else {
                    throw new IllegalArgumentException("Can only have … at the end of samples: " + str2);
                }
            }
            return new f(sampleType, Collections.unmodifiableSet(linkedHashSet), z);
        }

        @Deprecated
        public Collection<com.ibm.icu.impl.number.h> a(Collection<com.ibm.icu.impl.number.h> collection) {
            c(null, collection);
            return collection;
        }

        @Deprecated
        public Collection<Double> b(Collection<Double> collection) {
            c(collection, null);
            return collection;
        }

        @Deprecated
        public void c(Collection<Double> collection, Collection<com.ibm.icu.impl.number.h> collection2) {
            if (!(collection == null && collection2 == null)) {
                if (collection == null || collection2 == null) {
                    boolean z = collection != null;
                    for (g gVar : this.f15333b) {
                        com.ibm.icu.impl.number.h hVar = gVar.f15335a;
                        com.ibm.icu.impl.number.h hVar2 = gVar.f15336b;
                        int D = hVar.D();
                        int a2 = hVar.a();
                        BigDecimal movePointRight = BigDecimal.ONE.movePointRight(D + a2);
                        com.ibm.icu.impl.number.h createCopy = hVar.createCopy();
                        while (createCopy.n() <= hVar2.n()) {
                            if (z) {
                                double n = createCopy.n();
                                if (n != Math.floor(n) && createCopy.getPluralOperand(Operand.v) > 0.0d) {
                                    collection.add(Double.valueOf(n));
                                }
                            } else {
                                collection2.add(createCopy);
                            }
                            com.ibm.icu.impl.number.j jVar = new com.ibm.icu.impl.number.j(createCopy.H().add(movePointRight));
                            jVar.l(-D);
                            jVar.J(-a2);
                            jVar.G(a2);
                            createCopy = jVar;
                        }
                    }
                }
            }
        }

        @Deprecated
        public Set<g> e() {
            return this.f15333b;
        }

        @Deprecated
        public void f(Set<com.ibm.icu.impl.number.h> set) {
            for (g gVar : this.f15333b) {
                set.add(gVar.f15335a);
                set.add(gVar.f15336b);
            }
        }

        @Deprecated
        public String toString() {
            StringBuilder sb = new StringBuilder("@");
            sb.append(this.f15332a.toString().toLowerCase(Locale.ENGLISH));
            boolean z = true;
            for (g gVar : this.f15333b) {
                if (z) {
                    z = false;
                } else {
                    sb.append(",");
                }
                sb.append(' ');
                sb.append(gVar);
            }
            if (!this.f15334c) {
                sb.append(", …");
            }
            return sb.toString();
        }
    }

    @Deprecated
    public static class g {
        @Deprecated

        /* renamed from: a  reason: collision with root package name */
        public final com.ibm.icu.impl.number.h f15335a;
        @Deprecated

        /* renamed from: b  reason: collision with root package name */
        public final com.ibm.icu.impl.number.h f15336b;

        @Deprecated
        public g(com.ibm.icu.impl.number.h hVar, com.ibm.icu.impl.number.h hVar2) {
            Operand operand = Operand.v;
            if (hVar.getPluralOperand(operand) == hVar2.getPluralOperand(operand)) {
                this.f15335a = hVar;
                this.f15336b = hVar2;
                return;
            }
            throw new IllegalArgumentException("Ranges must have the same number of visible decimals: " + hVar + "~" + hVar2);
        }

        @Deprecated
        public String toString() {
            String str;
            StringBuilder sb = new StringBuilder();
            sb.append(this.f15335a.p());
            if (this.f15336b == this.f15335a) {
                str = "";
            } else {
                str = "~" + this.f15336b.p();
            }
            sb.append(str);
            return sb.toString();
        }
    }

    @Deprecated
    public static abstract class h {
        @Deprecated
        protected h() {
        }

        @Deprecated
        public static a1 d() {
            return a1.f13497a;
        }

        @Deprecated
        public final PluralRules a(ULocale uLocale) {
            return b(uLocale, PluralType.CARDINAL);
        }

        @Deprecated
        public abstract PluralRules b(ULocale uLocale, PluralType pluralType);

        @Deprecated
        public abstract ULocale[] c();

        @Deprecated
        public abstract ULocale e(ULocale uLocale, boolean[] zArr);

        @Deprecated
        public abstract boolean f(ULocale uLocale);
    }

    @Deprecated
    public interface i {
        @Deprecated
        double getPluralOperand(Operand operand);

        @Deprecated
        boolean isHasIntegerValue();

        @Deprecated
        boolean isInfinite();

        @Deprecated
        boolean isNaN();
    }

    /* access modifiers changed from: private */
    public static class j extends d {
        private static final long serialVersionUID = 1405488568664762222L;

        j(e eVar, e eVar2) {
            super(eVar, eVar2);
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean r(i iVar) {
            return this.f15330a.r(iVar) || this.f15331b.r(iVar);
        }

        public String toString() {
            return this.f15330a.toString() + " or " + this.f15331b.toString();
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean w(SampleType sampleType) {
            return this.f15330a.w(sampleType) && this.f15331b.w(sampleType);
        }
    }

    /* access modifiers changed from: private */
    public static class k implements e, Serializable {
        private static final long serialVersionUID = 1;
        private final boolean inRange;
        private final boolean integersOnly;
        private final double lowerBound;
        private final int mod;
        private final Operand operand;
        private final long[] range_list;
        private final double upperBound;

        k(int i, boolean z, Operand operand2, boolean z2, double d2, double d3, long[] jArr) {
            this.mod = i;
            this.inRange = z;
            this.integersOnly = z2;
            this.lowerBound = d2;
            this.upperBound = d3;
            this.range_list = jArr;
            this.operand = operand2;
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean r(i iVar) {
            double pluralOperand = iVar.getPluralOperand(this.operand);
            if ((this.integersOnly && pluralOperand - ((double) ((long) pluralOperand)) != 0.0d) || (this.operand == Operand.j && iVar.getPluralOperand(Operand.v) != 0.0d)) {
                return !this.inRange;
            }
            int i = this.mod;
            if (i != 0) {
                pluralOperand %= (double) i;
            }
            boolean z = pluralOperand >= this.lowerBound && pluralOperand <= this.upperBound;
            if (z && this.range_list != null) {
                z = false;
                int i2 = 0;
                while (!z) {
                    long[] jArr = this.range_list;
                    if (i2 >= jArr.length) {
                        break;
                    }
                    z = pluralOperand >= ((double) jArr[i2]) && pluralOperand <= ((double) jArr[i2 + 1]);
                    i2 += 2;
                }
            }
            if (this.inRange == z) {
                return true;
            }
            return false;
        }

        /* JADX WARNING: Code restructure failed: missing block: B:10:0x002d, code lost:
            if (r10.inRange != false) goto L_0x0044;
         */
        /* JADX WARNING: Code restructure failed: missing block: B:15:0x0038, code lost:
            if (r10.inRange != false) goto L_0x0044;
         */
        /* JADX WARNING: Removed duplicated region for block: B:22:0x004b  */
        /* JADX WARNING: Removed duplicated region for block: B:30:0x0065  */
        public String toString() {
            StringBuilder sb = new StringBuilder();
            sb.append(this.operand);
            if (this.mod != 0) {
                sb.append(" % ");
                sb.append(this.mod);
            }
            String str = " = ";
            if (this.lowerBound != this.upperBound) {
                if (!this.integersOnly) {
                    str = this.inRange ? " within " : " not within ";
                }
                sb.append(str);
                if (this.range_list == null) {
                    int i = 0;
                    while (true) {
                        long[] jArr = this.range_list;
                        if (i >= jArr.length) {
                            break;
                        }
                        PluralRules.d(sb, (double) jArr[i], (double) jArr[i + 1], i != 0);
                        i += 2;
                    }
                } else {
                    PluralRules.d(sb, this.lowerBound, this.upperBound, false);
                }
                return sb.toString();
            }
            str = " != ";
            sb.append(str);
            if (this.range_list == null) {
            }
            return sb.toString();
        }

        @Override // com.ibm.icu.text.PluralRules.e
        public boolean w(SampleType sampleType) {
            Operand operand2;
            double d2 = this.lowerBound;
            boolean z = d2 == this.upperBound && d2 == 0.0d;
            Operand operand3 = this.operand;
            boolean z2 = (operand3 == Operand.v || operand3 == Operand.w || operand3 == Operand.f || operand3 == Operand.t) && this.inRange != z;
            int i = b.f15329b[sampleType.ordinal()];
            if (i != 1) {
                if (i != 2) {
                    return false;
                }
                if ((!z2 || (operand2 = this.operand) == Operand.n || operand2 == Operand.j) && ((this.integersOnly || this.lowerBound == this.upperBound) && this.mod == 0 && this.inRange)) {
                    return true;
                }
                return false;
            } else if (z2) {
                return true;
            } else {
                Operand operand4 = this.operand;
                if ((operand4 == Operand.n || operand4 == Operand.i || operand4 == Operand.j) && this.mod == 0 && this.inRange) {
                    return true;
                }
                return false;
            }
        }
    }

    /* access modifiers changed from: private */
    public static class l implements Serializable {
        private static final long serialVersionUID = 1;
        private final e constraint;
        private final f decimalSamples;
        private final f integerSamples;
        private final String keyword;

        public l(String str, e eVar, f fVar, f fVar2) {
            this.keyword = str;
            this.constraint = eVar;
            this.integerSamples = fVar;
            this.decimalSamples = fVar2;
        }

        public l c(e eVar) {
            return new l(this.keyword, new c(this.constraint, eVar), this.integerSamples, this.decimalSamples);
        }

        public boolean d(i iVar) {
            return this.constraint.r(iVar);
        }

        public String e() {
            return this.constraint.toString();
        }

        public String f() {
            return this.keyword;
        }

        public l g(e eVar) {
            return new l(this.keyword, new j(this.constraint, eVar), this.integerSamples, this.decimalSamples);
        }

        public int hashCode() {
            return this.keyword.hashCode() ^ this.constraint.hashCode();
        }

        public String toString() {
            String str;
            StringBuilder sb = new StringBuilder();
            sb.append(this.keyword);
            sb.append(": ");
            sb.append(this.constraint.toString());
            String str2 = "";
            if (this.integerSamples == null) {
                str = str2;
            } else {
                str = Padder.f14124a + this.integerSamples.toString();
            }
            sb.append(str);
            if (this.decimalSamples != null) {
                str2 = Padder.f14124a + this.decimalSamples.toString();
            }
            sb.append(str2);
            return sb.toString();
        }

        public boolean w(SampleType sampleType) {
            return this.constraint.w(sampleType);
        }
    }

    /* access modifiers changed from: package-private */
    public static class n {

        /* renamed from: a  reason: collision with root package name */
        static final UnicodeSet f15337a = new UnicodeSet(9, 10, 12, 13, 32, 32).freeze();

        /* renamed from: b  reason: collision with root package name */
        static final UnicodeSet f15338b = new UnicodeSet(33, 33, 37, 37, 44, 44, 46, 46, 61, 61).freeze();

        n() {
        }

        static String[] a(String str) {
            ArrayList arrayList = new ArrayList();
            int i = -1;
            for (int i2 = 0; i2 < str.length(); i2++) {
                char charAt = str.charAt(i2);
                if (f15337a.r(charAt)) {
                    if (i >= 0) {
                        arrayList.add(str.substring(i, i2));
                    }
                } else if (f15338b.r(charAt)) {
                    if (i >= 0) {
                        arrayList.add(str.substring(i, i2));
                    }
                    arrayList.add(str.substring(i2, i2 + 1));
                } else {
                    if (i < 0) {
                        i = i2;
                    }
                }
                i = -1;
            }
            if (i >= 0) {
                arrayList.add(str.substring(i));
            }
            return (String[]) arrayList.toArray(new String[arrayList.size()]);
        }
    }

    static {
        a aVar = new a();
        I0 = aVar;
        l lVar = new l(KEYWORD_OTHER, aVar, null, null);
        J0 = lVar;
        DEFAULT = new PluralRules(new m(null).c(lVar), com.ibm.icu.impl.number.d0.c.f14233b);
    }

    private PluralRules(m mVar, com.ibm.icu.impl.number.d0.c cVar) {
        this.rules = mVar;
        this.R0 = Collections.unmodifiableSet(mVar.g());
        this.S0 = cVar;
    }

    private boolean c(Set<i> set, Set<i> set2, double d2) {
        FixedDecimal fixedDecimal = new FixedDecimal(d2);
        if (set.contains(fixedDecimal) || set2.contains(fixedDecimal)) {
            return false;
        }
        set2.add(fixedDecimal);
        return true;
    }

    public static PluralRules createRules(String str) {
        try {
            return parseDescription(str);
        } catch (Exception unused) {
            return null;
        }
    }

    /* access modifiers changed from: private */
    public static void d(StringBuilder sb, double d2, double d3, boolean z) {
        if (z) {
            sb.append(",");
        }
        if (d2 == d3) {
            sb.append(f(d2));
            return;
        }
        sb.append(f(d2) + ".." + f(d3));
    }

    private boolean e(String str, com.ibm.icu.impl.number.h hVar, int i2, Set<com.ibm.icu.impl.number.h> set) {
        if (!select(hVar).equals(str)) {
            return true;
        }
        set.add(hVar);
        return i2 + -1 >= 0;
    }

    private static String f(double d2) {
        long j2 = (long) d2;
        return d2 == ((double) j2) ? String.valueOf(j2) : String.valueOf(d2);
    }

    public static PluralRules forLocale(ULocale uLocale) {
        return h.d().b(uLocale, PluralType.CARDINAL);
    }

    public static ULocale[] getAvailableULocales() {
        return h.d().c();
    }

    public static ULocale getFunctionalEquivalent(ULocale uLocale, boolean[] zArr) {
        return h.d().e(uLocale, zArr);
    }

    private static boolean h(String str) {
        return f15318a.T0(str);
    }

    private static String i(String[] strArr, int i2, String str) throws ParseException {
        if (i2 < strArr.length) {
            return strArr[i2];
        }
        throw new ParseException("missing token at end of '" + str + "'", -1);
    }

    /* JADX WARNING: Removed duplicated region for block: B:138:0x021c A[SYNTHETIC] */
    /* JADX WARNING: Removed duplicated region for block: B:50:0x00db  */
    /* JADX WARNING: Removed duplicated region for block: B:55:0x00ef  */
    /* JADX WARNING: Removed duplicated region for block: B:59:0x0111  */
    /* JADX WARNING: Removed duplicated region for block: B:78:0x0171  */
    /* JADX WARNING: Removed duplicated region for block: B:82:0x0179  */
    private static e j(String str) throws ParseException {
        j jVar;
        j jVar2;
        String[] strArr;
        int i2;
        int i3;
        String[] strArr2;
        int i4;
        int i5;
        boolean z;
        boolean z2;
        String str2;
        int i6;
        boolean z3;
        boolean z4;
        String str3;
        long parseLong;
        boolean z5;
        long j2;
        long[] jArr;
        int i7;
        String i8;
        int i9 = 0;
        String[] split = L0.split(str, 0);
        int i10 = 0;
        j jVar3 = null;
        while (i10 < split.length) {
            String[] split2 = M0.split(split[i10], i9);
            int i11 = 0;
            c cVar = null;
            while (i11 < split2.length) {
                e eVar = I0;
                String trim = split2[i11].trim();
                String[] a2 = n.a(trim);
                String str4 = a2[i9];
                try {
                    Operand operand = FixedDecimal.getOperand(str4);
                    if (1 < a2.length) {
                        String str5 = a2[1];
                        if ("mod".equals(str5) || "%".equals(str5)) {
                            int parseInt = Integer.parseInt(a2[2]);
                            str5 = i(a2, 3, trim);
                            i5 = parseInt;
                            i4 = 4;
                        } else {
                            i5 = 0;
                            i4 = 2;
                        }
                        if ("not".equals(str5)) {
                            i7 = i4 + 1;
                            i8 = i(a2, i4, trim);
                            if ("=".equals(i8)) {
                                throw m(i8, trim);
                            }
                        } else if ("!".equals(str5)) {
                            i7 = i4 + 1;
                            i8 = i(a2, i4, trim);
                            if (!"=".equals(i8)) {
                                throw m(i8, trim);
                            }
                        } else {
                            z = true;
                            if (!"is".equals(str5) || "in".equals(str5) || "=".equals(str5)) {
                                z3 = "is".equals(str5);
                                if (z3 || z) {
                                    i6 = i4 + 1;
                                    str2 = i(a2, i4, trim);
                                    z2 = true;
                                } else {
                                    throw m(str5, trim);
                                }
                            } else if ("within".equals(str5)) {
                                str2 = i(a2, i4, trim);
                                z2 = false;
                                i6 = i4 + 1;
                                z3 = false;
                            } else {
                                throw m(str5, trim);
                            }
                            if ("not".equals(str2)) {
                                z4 = z;
                            } else if (z3 || z) {
                                z4 = !z;
                                str2 = i(a2, i6, trim);
                                i6++;
                            } else {
                                throw m(str2, trim);
                            }
                            ArrayList arrayList = new ArrayList();
                            i2 = i10;
                            jVar = jVar3;
                            strArr2 = split2;
                            i3 = i11;
                            str3 = str2;
                            double d2 = 9.223372036854776E18d;
                            double d3 = -9.223372036854776E18d;
                            while (true) {
                                parseLong = Long.parseLong(str3);
                                strArr = split;
                                String str6 = str3;
                                if (i6 >= a2.length) {
                                    int i12 = i6 + 1;
                                    String i13 = i(a2, i6, trim);
                                    jVar2 = cVar;
                                    if (i13.equals(".")) {
                                        int i14 = i12 + 1;
                                        String i15 = i(a2, i12, trim);
                                        if (i15.equals(".")) {
                                            int i16 = i14 + 1;
                                            String i17 = i(a2, i14, trim);
                                            long parseLong2 = Long.parseLong(i17);
                                            if (i16 < a2.length) {
                                                i6 = i16 + 1;
                                                String i18 = i(a2, i16, trim);
                                                if (i18.equals(",")) {
                                                    z5 = z3;
                                                    str6 = i18;
                                                    j2 = parseLong2;
                                                } else {
                                                    throw m(i18, trim);
                                                }
                                            } else {
                                                i6 = i16;
                                                z5 = z3;
                                                j2 = parseLong2;
                                                str6 = i17;
                                            }
                                            if (parseLong > j2) {
                                                throw m(parseLong + "~" + j2, trim);
                                            } else if (i5 == 0 || j2 < ((long) i5)) {
                                                arrayList.add(Long.valueOf(parseLong));
                                                arrayList.add(Long.valueOf(j2));
                                                d2 = Math.min(d2, (double) parseLong);
                                                d3 = Math.max(d3, (double) j2);
                                                if (i6 < a2.length) {
                                                    str3 = i(a2, i6, trim);
                                                    i6++;
                                                    z3 = z5;
                                                    split = strArr;
                                                    cVar = jVar2;
                                                } else if (!str6.equals(",")) {
                                                    if (arrayList.size() == 2) {
                                                        jArr = null;
                                                    } else {
                                                        int size = arrayList.size();
                                                        long[] jArr2 = new long[size];
                                                        for (int i19 = 0; i19 < size; i19++) {
                                                            jArr2[i19] = ((Long) arrayList.get(i19)).longValue();
                                                        }
                                                        jArr = jArr2;
                                                    }
                                                    if (d2 == d3 || !z5 || z4) {
                                                        eVar = new k(i5, z4, operand, z2, d2, d3, jArr);
                                                    } else {
                                                        throw m("is not <range>", trim);
                                                    }
                                                } else {
                                                    throw m(str6, trim);
                                                }
                                            } else {
                                                throw m(j2 + ">mod=" + i5, trim);
                                            }
                                        } else {
                                            throw m(i15, trim);
                                        }
                                    } else if (i13.equals(",")) {
                                        z5 = z3;
                                        str6 = i13;
                                        i6 = i12;
                                    } else {
                                        throw m(i13, trim);
                                    }
                                } else {
                                    jVar2 = cVar;
                                    z5 = z3;
                                }
                                j2 = parseLong;
                                if (parseLong > j2) {
                                }
                            }
                        }
                        i4 = i7;
                        str5 = i8;
                        z = false;
                        if (!"is".equals(str5)) {
                        }
                        z3 = "is".equals(str5);
                        if (z3) {
                        }
                        i6 = i4 + 1;
                        str2 = i(a2, i4, trim);
                        z2 = true;
                        if ("not".equals(str2)) {
                        }
                        ArrayList arrayList2 = new ArrayList();
                        i2 = i10;
                        jVar = jVar3;
                        strArr2 = split2;
                        i3 = i11;
                        str3 = str2;
                        double d22 = 9.223372036854776E18d;
                        double d32 = -9.223372036854776E18d;
                        while (true) {
                            parseLong = Long.parseLong(str3);
                            strArr = split;
                            String str62 = str3;
                            if (i6 >= a2.length) {
                            }
                            j2 = parseLong;
                            if (parseLong > j2) {
                            }
                            str3 = i(a2, i6, trim);
                            i6++;
                            z3 = z5;
                            split = strArr;
                            cVar = jVar2;
                        }
                    } else {
                        strArr = split;
                        i2 = i10;
                        jVar = jVar3;
                        strArr2 = split2;
                        i3 = i11;
                        jVar2 = cVar;
                    }
                    if (jVar2 == null) {
                        cVar = eVar;
                    } else {
                        cVar = new c(jVar2, eVar);
                    }
                    i11 = i3 + 1;
                    jVar3 = jVar;
                    split2 = strArr2;
                    i10 = i2;
                    split = strArr;
                    i9 = 0;
                } catch (Exception unused) {
                    throw m(str4, trim);
                }
            }
            if (jVar3 == null) {
                jVar3 = cVar;
            } else {
                jVar3 = new j(jVar3, cVar);
            }
            i10++;
            split = split;
            i9 = 0;
        }
        return jVar3;
    }

    /* access modifiers changed from: private */
    public static l k(String str) throws ParseException {
        f fVar;
        e eVar;
        if (str.length() == 0) {
            return J0;
        }
        String lowerCase = str.toLowerCase(Locale.ENGLISH);
        int indexOf = lowerCase.indexOf(58);
        if (indexOf != -1) {
            String trim = lowerCase.substring(0, indexOf).trim();
            if (h(trim)) {
                boolean z = true;
                String trim2 = lowerCase.substring(indexOf + 1).trim();
                String[] split = K0.split(trim2, 0);
                int length = split.length;
                f fVar2 = null;
                if (length == 1) {
                    fVar = null;
                } else if (length == 2) {
                    fVar = f.g(split[1]);
                    if (fVar.f15332a != SampleType.DECIMAL) {
                        fVar2 = fVar;
                        fVar = null;
                    }
                } else if (length == 3) {
                    fVar2 = f.g(split[1]);
                    f g2 = f.g(split[2]);
                    if (fVar2.f15332a == SampleType.INTEGER && g2.f15332a == SampleType.DECIMAL) {
                        fVar = g2;
                    } else {
                        throw new IllegalArgumentException("Must have @integer then @decimal in " + trim2);
                    }
                } else {
                    throw new IllegalArgumentException("Too many samples in " + trim2);
                }
                boolean equals = trim.equals(KEYWORD_OTHER);
                if (split[0].length() != 0) {
                    z = false;
                }
                if (equals == z) {
                    if (equals) {
                        eVar = I0;
                    } else {
                        eVar = j(split[0]);
                    }
                    return new l(trim, eVar, fVar2, fVar);
                }
                throw new IllegalArgumentException("The keyword 'other' must have no constraints, just samples.");
            }
            throw new ParseException("keyword '" + trim + " is not valid", 0);
        }
        throw new ParseException("missing ':' in rule description '" + lowerCase + "'", 0);
    }

    private static m l(String str) throws ParseException {
        String[] split;
        m mVar = new m(null);
        if (str.endsWith(com.alipay.sdk.util.g.f6031b)) {
            str = str.substring(0, str.length() - 1);
        }
        for (String str2 : Q0.split(str, 0)) {
            l k2 = k(str2.trim());
            mVar.hasExplicitBoundingInfo |= (k2.integerSamples == null && k2.decimalSamples == null) ? false : true;
            mVar.c(k2);
        }
        return mVar.e();
    }

    private static ParseException m(String str, String str2) {
        return new ParseException("unexpected token '" + str + "' in '" + str2 + "'", -1);
    }

    @Deprecated
    public static PluralRules newInternal(String str, com.ibm.icu.impl.number.d0.c cVar) throws ParseException {
        String trim = str.trim();
        if (trim.length() == 0) {
            return DEFAULT;
        }
        return new PluralRules(l(trim), cVar);
    }

    public static PluralRules parseDescription(String str) throws ParseException {
        return newInternal(str, null);
    }

    private void readObject(ObjectInputStream objectInputStream) throws IOException, ClassNotFoundException {
        throw new NotSerializableException();
    }

    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        throw new NotSerializableException();
    }

    private Object writeReplace() throws ObjectStreamException {
        return new b1(toString());
    }

    @Deprecated
    public int compareTo(PluralRules pluralRules) {
        return toString().compareTo(pluralRules.toString());
    }

    @Deprecated
    public boolean computeLimited(String str, SampleType sampleType) {
        return this.rules.d(str, sampleType);
    }

    public boolean equals(Object obj) {
        return (obj instanceof PluralRules) && equals((PluralRules) obj);
    }

    /* access modifiers changed from: package-private */
    public Boolean g(String str) {
        return Boolean.valueOf(this.rules.i(str, SampleType.INTEGER));
    }

    @Deprecated
    public Collection<com.ibm.icu.impl.number.h> getAllKeywordDecimalQuantityValues(String str) {
        return getAllKeywordValues(str, SampleType.INTEGER);
    }

    public Collection<Double> getAllKeywordValues(String str) {
        Collection<com.ibm.icu.impl.number.h> allKeywordDecimalQuantityValues = getAllKeywordDecimalQuantityValues(str);
        if (allKeywordDecimalQuantityValues == null) {
            return null;
        }
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        for (com.ibm.icu.impl.number.h hVar : allKeywordDecimalQuantityValues) {
            linkedHashSet.add(Double.valueOf(hVar.n()));
        }
        return linkedHashSet;
    }

    @Deprecated
    public Collection<com.ibm.icu.impl.number.h> getDecimalQuantitySamples(String str) {
        return getDecimalQuantitySamples(str, SampleType.INTEGER);
    }

    @Deprecated
    public f getDecimalSamples(String str, SampleType sampleType) {
        return this.rules.f(str, sampleType);
    }

    public KeywordStatus getKeywordStatus(String str, int i2, Set<com.ibm.icu.impl.number.h> set, com.ibm.icu.util.w<com.ibm.icu.impl.number.h> wVar) {
        return getKeywordStatus(str, i2, set, wVar, SampleType.INTEGER);
    }

    public Set<String> getKeywords() {
        return this.R0;
    }

    @Deprecated
    public String getRules(String str) {
        return this.rules.h(str);
    }

    public Collection<Double> getSamples(String str) {
        return getSamples(str, SampleType.INTEGER);
    }

    @Deprecated
    public com.ibm.icu.impl.number.h getUniqueKeywordDecimalQuantityValue(String str) {
        Collection<com.ibm.icu.impl.number.h> allKeywordDecimalQuantityValues = getAllKeywordDecimalQuantityValues(str);
        if (allKeywordDecimalQuantityValues == null || allKeywordDecimalQuantityValues.size() != 1) {
            return NO_UNIQUE_VALUE_DECIMAL_QUANTITY;
        }
        return allKeywordDecimalQuantityValues.iterator().next();
    }

    public double getUniqueKeywordValue(String str) {
        com.ibm.icu.impl.number.h uniqueKeywordDecimalQuantityValue = getUniqueKeywordDecimalQuantityValue(str);
        if (uniqueKeywordDecimalQuantityValue.equals(NO_UNIQUE_VALUE_DECIMAL_QUANTITY)) {
            return -0.00123456777d;
        }
        return uniqueKeywordDecimalQuantityValue.n();
    }

    public int hashCode() {
        return this.rules.hashCode();
    }

    @Deprecated
    public boolean isLimited(String str, SampleType sampleType) {
        return this.rules.i(str, sampleType);
    }

    @Deprecated
    public boolean matches(FixedDecimal fixedDecimal, String str) {
        return this.rules.k(fixedDecimal, str);
    }

    public String select(double d2) {
        return this.rules.j(new FixedDecimal(d2));
    }

    public String toString() {
        return this.rules.toString();
    }

    public static PluralRules forLocale(Locale locale) {
        return forLocale(ULocale.forLocale(locale));
    }

    public boolean equals(PluralRules pluralRules) {
        return pluralRules != null && toString().equals(pluralRules.toString());
    }

    @Deprecated
    public Collection<com.ibm.icu.impl.number.h> getDecimalQuantitySamples(String str, SampleType sampleType) {
        if (!this.R0.contains(str)) {
            return null;
        }
        Set<com.ibm.icu.impl.number.h> linkedHashSet = new LinkedHashSet<>();
        if (this.rules.hasExplicitBoundingInfo) {
            f f2 = this.rules.f(str, sampleType);
            if (f2 == null) {
                return Collections.unmodifiableSet(linkedHashSet);
            }
            return Collections.unmodifiableCollection(f2.a(linkedHashSet));
        }
        int i2 = isLimited(str, sampleType) ? Integer.MAX_VALUE : 20;
        int i3 = b.f15329b[sampleType.ordinal()];
        int i4 = 0;
        if (i3 == 1) {
            while (i4 < 200 && e(str, new com.ibm.icu.impl.number.j(i4), i2, linkedHashSet)) {
                i4++;
            }
            e(str, new com.ibm.icu.impl.number.j((int) DurationKt.NANOS_IN_MILLIS), i2, linkedHashSet);
        } else if (i3 == 2) {
            while (i4 < 2000) {
                com.ibm.icu.impl.number.j jVar = new com.ibm.icu.impl.number.j(i4);
                jVar.J(-1);
                if (!e(str, jVar, i2, linkedHashSet)) {
                    break;
                }
                i4++;
            }
            e(str, com.ibm.icu.impl.number.j.q0("1000000.0"), i2, linkedHashSet);
        }
        if (linkedHashSet.size() == 0) {
            return null;
        }
        return Collections.unmodifiableSet(linkedHashSet);
    }

    @Deprecated
    public KeywordStatus getKeywordStatus(String str, int i2, Set<com.ibm.icu.impl.number.h> set, com.ibm.icu.util.w<com.ibm.icu.impl.number.h> wVar, SampleType sampleType) {
        if (wVar != null) {
            wVar.f16195a = null;
        }
        if (!this.R0.contains(str)) {
            return KeywordStatus.INVALID;
        }
        if (!isLimited(str, sampleType)) {
            return KeywordStatus.UNBOUNDED;
        }
        Collection<com.ibm.icu.impl.number.h> decimalQuantitySamples = getDecimalQuantitySamples(str, sampleType);
        int size = decimalQuantitySamples.size();
        if (set == null) {
            set = Collections.emptySet();
        }
        if (size <= set.size()) {
            ArrayList arrayList = new ArrayList(decimalQuantitySamples);
            for (com.ibm.icu.impl.number.h hVar : set) {
                arrayList.remove(new com.ibm.icu.impl.number.j(hVar.H().subtract(new BigDecimal(i2))));
            }
            if (arrayList.size() == 0) {
                return KeywordStatus.SUPPRESSED;
            }
            if (wVar != null && arrayList.size() == 1) {
                wVar.f16195a = (T) arrayList.iterator().next();
            }
            return size == 1 ? KeywordStatus.UNIQUE : KeywordStatus.BOUNDED;
        } else if (size != 1) {
            return KeywordStatus.BOUNDED;
        } else {
            if (wVar != null) {
                wVar.f16195a = (T) decimalQuantitySamples.iterator().next();
            }
            return KeywordStatus.UNIQUE;
        }
    }

    @Deprecated
    public Collection<Double> getSamples(String str, SampleType sampleType) {
        Collection<com.ibm.icu.impl.number.h> decimalQuantitySamples = getDecimalQuantitySamples(str, sampleType);
        if (decimalQuantitySamples == null) {
            return null;
        }
        LinkedHashSet linkedHashSet = new LinkedHashSet();
        for (com.ibm.icu.impl.number.h hVar : decimalQuantitySamples) {
            linkedHashSet.add(Double.valueOf(hVar.n()));
        }
        return linkedHashSet;
    }

    public String select(com.ibm.icu.number.c cVar) {
        return this.rules.j(cVar.c());
    }

    /* access modifiers changed from: private */
    public static class m implements Serializable {
        private static final long serialVersionUID = 1;
        private boolean hasExplicitBoundingInfo;
        private final List<l> rules;

        private m() {
            this.hasExplicitBoundingInfo = false;
            this.rules = new ArrayList();
        }

        private l l(i iVar) {
            for (l lVar : this.rules) {
                if (lVar.d(iVar)) {
                    return lVar;
                }
            }
            return null;
        }

        public m c(l lVar) {
            String f = lVar.f();
            for (l lVar2 : this.rules) {
                if (f.equals(lVar2.f())) {
                    throw new IllegalArgumentException("Duplicate keyword: " + f);
                }
            }
            this.rules.add(lVar);
            return this;
        }

        public boolean d(String str, SampleType sampleType) {
            boolean z = false;
            for (l lVar : this.rules) {
                if (str.equals(lVar.f())) {
                    if (!lVar.w(sampleType)) {
                        return false;
                    }
                    z = true;
                }
            }
            return z;
        }

        public m e() throws ParseException {
            Iterator<l> it = this.rules.iterator();
            l lVar = null;
            while (it.hasNext()) {
                l next = it.next();
                if (PluralRules.KEYWORD_OTHER.equals(next.f())) {
                    it.remove();
                    lVar = next;
                }
            }
            if (lVar == null) {
                lVar = PluralRules.k("other:");
            }
            this.rules.add(lVar);
            return this;
        }

        public f f(String str, SampleType sampleType) {
            for (l lVar : this.rules) {
                if (lVar.f().equals(str)) {
                    return sampleType == SampleType.INTEGER ? lVar.integerSamples : lVar.decimalSamples;
                }
            }
            return null;
        }

        public Set<String> g() {
            LinkedHashSet linkedHashSet = new LinkedHashSet();
            for (l lVar : this.rules) {
                linkedHashSet.add(lVar.f());
            }
            return linkedHashSet;
        }

        public String h(String str) {
            for (l lVar : this.rules) {
                if (lVar.f().equals(str)) {
                    return lVar.e();
                }
            }
            return null;
        }

        public boolean i(String str, SampleType sampleType) {
            if (!this.hasExplicitBoundingInfo) {
                return d(str, sampleType);
            }
            f f = f(str, sampleType);
            if (f == null) {
                return true;
            }
            return f.f15334c;
        }

        public String j(i iVar) {
            return (iVar.isInfinite() || iVar.isNaN()) ? PluralRules.KEYWORD_OTHER : l(iVar).f();
        }

        public boolean k(i iVar, String str) {
            for (l lVar : this.rules) {
                if (lVar.f().equals(str) && lVar.d(iVar)) {
                    return true;
                }
            }
            return false;
        }

        public String toString() {
            StringBuilder sb = new StringBuilder();
            for (l lVar : this.rules) {
                if (sb.length() != 0) {
                    sb.append(PluralRules.f15319b);
                }
                sb.append(lVar);
            }
            return sb.toString();
        }

        /* synthetic */ m(a aVar) {
            this();
        }
    }

    public static PluralRules forLocale(ULocale uLocale, PluralType pluralType) {
        return h.d().b(uLocale, pluralType);
    }

    public String select(com.ibm.icu.number.d dVar) {
        if (this.S0 != null) {
            return this.S0.i(StandardPlural.fromString(select(dVar.d())), StandardPlural.fromString(select(dVar.g()))).getKeyword();
        }
        throw new UnsupportedOperationException("Plural ranges are unavailable on this instance");
    }

    public static PluralRules forLocale(Locale locale, PluralType pluralType) {
        return forLocale(ULocale.forLocale(locale), pluralType);
    }

    @Deprecated
    public Collection<com.ibm.icu.impl.number.h> getAllKeywordValues(String str, SampleType sampleType) {
        if (!isLimited(str, sampleType)) {
            return null;
        }
        return getDecimalQuantitySamples(str, sampleType);
    }

    @Deprecated
    public String select(double d2, int i2, long j2) {
        return this.rules.j(new FixedDecimal(d2, i2, j2));
    }

    @Deprecated
    public String select(i iVar) {
        return this.rules.j(iVar);
    }
}
