package com.ibm.icu.text;

import com.alipay.sdk.util.g;
import com.ibm.icu.impl.ICUResourceBundle;
import com.ibm.icu.impl.TZDBTimeZoneNames;
import com.ibm.icu.impl.TimeZoneGenericNames;
import com.ibm.icu.impl.TimeZoneNamesImpl;
import com.ibm.icu.impl.a0;
import com.ibm.icu.impl.m1;
import com.ibm.icu.impl.r1;
import com.ibm.icu.impl.s2;
import com.ibm.icu.impl.units.e;
import com.ibm.icu.impl.y0;
import com.ibm.icu.impl.z0;
import com.ibm.icu.text.DateFormat;
import com.ibm.icu.text.TimeZoneNames;
import com.ibm.icu.util.Calendar;
import com.ibm.icu.util.TimeZone;
import com.ibm.icu.util.ULocale;
import com.ibm.icu.util.h0;
import com.ibm.icu.util.n;
import com.ibm.icu.util.w;
import com.niming.weipa.model.PayType;
import java.io.IOException;
import java.io.InvalidObjectException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.ObjectStreamField;
import java.io.Serializable;
import java.text.AttributedCharacterIterator;
import java.text.AttributedString;
import java.text.FieldPosition;
import java.text.ParseException;
import java.text.ParsePosition;
import java.util.ArrayList;
import java.util.BitSet;
import java.util.Collection;
import java.util.Date;
import java.util.EnumSet;
import java.util.Iterator;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.Objects;

public class TimeZoneFormat extends UFormat implements n<TimeZoneFormat>, Serializable {
    private static final String I0 = "Etc/GMT";
    private static final String[] J0 = {L0, "UTC", "UT"};
    private static final String K0 = "GMT{0}";
    private static final String L0 = "GMT";
    private static final String[] M0 = {"0", "1", "2", "3", PayType.TYPE_YUER, PayType.TYPE_DAICONG, "6", "7", "8", "9"};
    private static final char N0 = ':';
    private static final String O0 = "0123456789";
    private static final String P0 = "Z";
    private static final String Q0 = "Etc/Unknown";
    private static final String R0 = "unk";
    private static final String S0 = "Unknown";
    private static final GMTOffsetPatternType[] T0 = {GMTOffsetPatternType.POSITIVE_HMS, GMTOffsetPatternType.NEGATIVE_HMS, GMTOffsetPatternType.POSITIVE_HM, GMTOffsetPatternType.NEGATIVE_HM, GMTOffsetPatternType.POSITIVE_H, GMTOffsetPatternType.NEGATIVE_H};
    private static final int U0 = 3600000;
    private static final int V0 = 60000;
    private static final int W0 = 1000;
    private static final int X0 = 86400000;
    private static final int Y0 = 23;
    private static final int Z0 = 59;

    /* renamed from: a  reason: collision with root package name */
    private static final int f15426a = 128;
    private static final int a1 = 59;

    /* renamed from: b  reason: collision with root package name */
    private static final int f15427b = 256;
    private static final int b1 = Integer.MAX_VALUE;
    private static d c1 = new d(null);
    private static final EnumSet<TimeZoneNames.NameType> d1 = EnumSet.of(TimeZoneNames.NameType.LONG_STANDARD, TimeZoneNames.NameType.LONG_DAYLIGHT, TimeZoneNames.NameType.SHORT_STANDARD, TimeZoneNames.NameType.SHORT_DAYLIGHT, TimeZoneNames.NameType.EXEMPLAR_LOCATION);
    private static final EnumSet<TimeZoneGenericNames.GenericNameType> e1 = EnumSet.of(TimeZoneGenericNames.GenericNameType.LOCATION, TimeZoneGenericNames.GenericNameType.LONG, TimeZoneGenericNames.GenericNameType.SHORT);
    private static volatile r1<String> f1 = null;
    private static volatile r1<String> g1 = null;
    static final /* synthetic */ boolean h1 = false;
    private static final ObjectStreamField[] serialPersistentFields = {new ObjectStreamField("_locale", ULocale.class), new ObjectStreamField("_tznames", TimeZoneNames.class), new ObjectStreamField("_gmtPattern", String.class), new ObjectStreamField("_gmtOffsetPatterns", String[].class), new ObjectStreamField("_gmtOffsetDigits", String[].class), new ObjectStreamField("_gmtZeroFormat", String.class), new ObjectStreamField("_parseAllStyles", Boolean.TYPE)};
    private static final long serialVersionUID = 2281246852693575022L;
    private String[] _gmtOffsetDigits;
    private String[] _gmtOffsetPatterns;
    private String _gmtPattern;
    private String _gmtZeroFormat = L0;
    private ULocale _locale;
    private boolean _parseAllStyles;
    private boolean _parseTZDBNames;
    private TimeZoneNames _tznames;
    private volatile transient TimeZoneGenericNames i1;
    private transient String j1;
    private transient String k1;
    private transient Object[][] l1;
    private transient boolean m1;
    private transient String n1;
    private volatile transient boolean o1;
    private volatile transient TimeZoneNames p1;

    public enum GMTOffsetPatternType {
        POSITIVE_HM("+H:mm", DateFormat.HOUR24_MINUTE, true),
        POSITIVE_HMS("+H:mm:ss", DateFormat.HOUR24_MINUTE_SECOND, true),
        NEGATIVE_HM("-H:mm", DateFormat.HOUR24_MINUTE, false),
        NEGATIVE_HMS("-H:mm:ss", DateFormat.HOUR24_MINUTE_SECOND, false),
        POSITIVE_H("+H", DateFormat.HOUR24, true),
        NEGATIVE_H("-H", DateFormat.HOUR24, false);
        
        private String _defaultPattern;
        private boolean _isPositive;
        private String _required;

        private GMTOffsetPatternType(String str, String str2, boolean z) {
            this._defaultPattern = str;
            this._required = str2;
            this._isPositive = z;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String h() {
            return this._defaultPattern;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private boolean i() {
            return this._isPositive;
        }

        /* access modifiers changed from: private */
        /* access modifiers changed from: public */
        private String j() {
            return this._required;
        }
    }

    public enum ParseOption {
        ALL_STYLES,
        TZ_DATABASE_ABBREVIATIONS
    }

    public enum Style {
        GENERIC_LOCATION(1),
        GENERIC_LONG(2),
        GENERIC_SHORT(4),
        SPECIFIC_LONG(8),
        SPECIFIC_SHORT(16),
        LOCALIZED_GMT(32),
        LOCALIZED_GMT_SHORT(64),
        ISO_BASIC_SHORT(128),
        ISO_BASIC_LOCAL_SHORT(256),
        ISO_BASIC_FIXED(128),
        ISO_BASIC_LOCAL_FIXED(256),
        ISO_BASIC_FULL(128),
        ISO_BASIC_LOCAL_FULL(256),
        ISO_EXTENDED_FIXED(128),
        ISO_EXTENDED_LOCAL_FIXED(256),
        ISO_EXTENDED_FULL(128),
        ISO_EXTENDED_LOCAL_FULL(256),
        ZONE_ID(512),
        ZONE_ID_SHORT(1024),
        EXEMPLAR_LOCATION(2048);
        
        final int flag;

        private Style(int i) {
            this.flag = i;
        }
    }

    public enum TimeType {
        UNKNOWN,
        STANDARD,
        DAYLIGHT
    }

    /* access modifiers changed from: package-private */
    public static /* synthetic */ class a {

        /* renamed from: a  reason: collision with root package name */
        static final /* synthetic */ int[] f15432a;

        /* renamed from: b  reason: collision with root package name */
        static final /* synthetic */ int[] f15433b;

        /* JADX WARNING: Can't wrap try/catch for region: R(48:0|(2:1|2)|3|(2:5|6)|7|(2:9|10)|11|(2:13|14)|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|(3:55|56|58)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(49:0|(2:1|2)|3|(2:5|6)|7|9|10|11|(2:13|14)|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|(3:55|56|58)) */
        /* JADX WARNING: Can't wrap try/catch for region: R(52:0|(2:1|2)|3|5|6|7|9|10|11|(2:13|14)|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|55|56|58) */
        /* JADX WARNING: Can't wrap try/catch for region: R(54:0|1|2|3|5|6|7|9|10|11|13|14|15|17|18|19|20|21|22|23|24|25|26|27|28|29|30|31|32|33|34|35|36|37|38|39|40|41|42|43|44|45|46|47|48|49|50|51|52|53|54|55|56|58) */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:19:0x0044 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:21:0x004e */
        /* JADX WARNING: Missing exception handler attribute for start block: B:23:0x0058 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:25:0x0062 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:27:0x006d */
        /* JADX WARNING: Missing exception handler attribute for start block: B:29:0x0078 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:31:0x0083 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:33:0x008f */
        /* JADX WARNING: Missing exception handler attribute for start block: B:35:0x009b */
        /* JADX WARNING: Missing exception handler attribute for start block: B:37:0x00a7 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:39:0x00b3 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:41:0x00bf */
        /* JADX WARNING: Missing exception handler attribute for start block: B:43:0x00cb */
        /* JADX WARNING: Missing exception handler attribute for start block: B:45:0x00d7 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:47:0x00e3 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:49:0x00ef */
        /* JADX WARNING: Missing exception handler attribute for start block: B:51:0x00fb */
        /* JADX WARNING: Missing exception handler attribute for start block: B:53:0x0107 */
        /* JADX WARNING: Missing exception handler attribute for start block: B:55:0x0113 */
        static {
            int[] iArr = new int[TimeZoneNames.NameType.values().length];
            f15433b = iArr;
            try {
                iArr[TimeZoneNames.NameType.LONG_STANDARD.ordinal()] = 1;
            } catch (NoSuchFieldError unused) {
            }
            try {
                f15433b[TimeZoneNames.NameType.SHORT_STANDARD.ordinal()] = 2;
            } catch (NoSuchFieldError unused2) {
            }
            try {
                f15433b[TimeZoneNames.NameType.LONG_DAYLIGHT.ordinal()] = 3;
            } catch (NoSuchFieldError unused3) {
            }
            try {
                f15433b[TimeZoneNames.NameType.SHORT_DAYLIGHT.ordinal()] = 4;
            } catch (NoSuchFieldError unused4) {
            }
            int[] iArr2 = new int[Style.values().length];
            f15432a = iArr2;
            iArr2[Style.GENERIC_LOCATION.ordinal()] = 1;
            f15432a[Style.GENERIC_LONG.ordinal()] = 2;
            f15432a[Style.GENERIC_SHORT.ordinal()] = 3;
            f15432a[Style.SPECIFIC_LONG.ordinal()] = 4;
            f15432a[Style.SPECIFIC_SHORT.ordinal()] = 5;
            f15432a[Style.ZONE_ID.ordinal()] = 6;
            f15432a[Style.ZONE_ID_SHORT.ordinal()] = 7;
            f15432a[Style.EXEMPLAR_LOCATION.ordinal()] = 8;
            f15432a[Style.LOCALIZED_GMT.ordinal()] = 9;
            f15432a[Style.LOCALIZED_GMT_SHORT.ordinal()] = 10;
            f15432a[Style.ISO_BASIC_SHORT.ordinal()] = 11;
            f15432a[Style.ISO_BASIC_LOCAL_SHORT.ordinal()] = 12;
            f15432a[Style.ISO_BASIC_FIXED.ordinal()] = 13;
            f15432a[Style.ISO_BASIC_LOCAL_FIXED.ordinal()] = 14;
            f15432a[Style.ISO_BASIC_FULL.ordinal()] = 15;
            f15432a[Style.ISO_BASIC_LOCAL_FULL.ordinal()] = 16;
            f15432a[Style.ISO_EXTENDED_FIXED.ordinal()] = 17;
            f15432a[Style.ISO_EXTENDED_LOCAL_FIXED.ordinal()] = 18;
            f15432a[Style.ISO_EXTENDED_FULL.ordinal()] = 19;
            try {
                f15432a[Style.ISO_EXTENDED_LOCAL_FULL.ordinal()] = 20;
            } catch (NoSuchFieldError unused5) {
            }
        }
    }

    /* access modifiers changed from: private */
    public static class b {

        /* renamed from: a  reason: collision with root package name */
        final char f15434a;

        /* renamed from: b  reason: collision with root package name */
        final int f15435b;

        b(char c2, int i) {
            this.f15434a = c2;
            this.f15435b = i;
        }

        static boolean c(char c2, int i) {
            return i == 1 || i == 2;
        }

        /* access modifiers changed from: package-private */
        public char a() {
            return this.f15434a;
        }

        /* access modifiers changed from: package-private */
        public int b() {
            return this.f15435b;
        }
    }

    /* access modifiers changed from: private */
    public enum c {
        H,
        HM,
        HMS
    }

    /* access modifiers changed from: private */
    public static class d extends m1<ULocale, TimeZoneFormat, ULocale> {
        private d() {
        }

        /* access modifiers changed from: protected */
        /* renamed from: c */
        public TimeZoneFormat a(ULocale uLocale, ULocale uLocale2) {
            TimeZoneFormat timeZoneFormat = new TimeZoneFormat(uLocale2);
            timeZoneFormat.freeze();
            return timeZoneFormat;
        }

        /* synthetic */ d(a aVar) {
            this();
        }
    }

    protected TimeZoneFormat(ULocale uLocale) {
        String str;
        String str2;
        this._locale = uLocale;
        this._tznames = TimeZoneNames.getInstance(uLocale);
        String str3 = null;
        try {
            ICUResourceBundle iCUResourceBundle = (ICUResourceBundle) h0.j(a0.m, uLocale);
            try {
                str2 = iCUResourceBundle.W0("zoneStrings/gmtFormat");
            } catch (MissingResourceException unused) {
                str2 = null;
            }
            try {
                str3 = iCUResourceBundle.W0("zoneStrings/hourFormat");
            } catch (MissingResourceException unused2) {
            }
            try {
                this._gmtZeroFormat = iCUResourceBundle.W0("zoneStrings/gmtZeroFormat");
            } catch (MissingResourceException unused3) {
            }
            str = str3;
            str3 = str2;
        } catch (MissingResourceException unused4) {
            str = null;
        }
        x(str3 == null ? K0 : str3);
        String[] strArr = new String[GMTOffsetPatternType.values().length];
        if (str != null) {
            String[] split = str.split(g.f6031b, 2);
            strArr[GMTOffsetPatternType.POSITIVE_H.ordinal()] = P(split[0]);
            strArr[GMTOffsetPatternType.POSITIVE_HM.ordinal()] = split[0];
            strArr[GMTOffsetPatternType.POSITIVE_HMS.ordinal()] = d(split[0]);
            strArr[GMTOffsetPatternType.NEGATIVE_H.ordinal()] = P(split[1]);
            strArr[GMTOffsetPatternType.NEGATIVE_HM.ordinal()] = split[1];
            strArr[GMTOffsetPatternType.NEGATIVE_HMS.ordinal()] = d(split[1]);
        } else {
            GMTOffsetPatternType[] values = GMTOffsetPatternType.values();
            for (GMTOffsetPatternType gMTOffsetPatternType : values) {
                strArr[gMTOffsetPatternType.ordinal()] = gMTOffsetPatternType.h();
            }
        }
        v(strArr);
        this._gmtOffsetDigits = M0;
        z0 f = z0.f(uLocale);
        if (!f.l()) {
            this._gmtOffsetDigits = O(f.c());
        }
    }

    private static int A(String str, ParsePosition parsePosition, char c2, c cVar, c cVar2) {
        int i;
        int i2;
        int indexOf;
        int index = parsePosition.getIndex();
        int[] iArr = {0, 0, 0};
        int[] iArr2 = {0, -1, -1};
        int i3 = index;
        int i4 = 0;
        while (true) {
            i = 1;
            if (i3 >= str.length() || i4 > cVar2.ordinal()) {
                break;
            }
            char charAt = str.charAt(i3);
            if (charAt != c2) {
                if (iArr2[i4] == -1 || (indexOf = O0.indexOf(charAt)) < 0) {
                    break;
                }
                iArr[i4] = (iArr[i4] * 10) + indexOf;
                iArr2[i4] = iArr2[i4] + 1;
                if (iArr2[i4] < 2) {
                    i3++;
                }
            } else if (i4 == 0) {
                if (iArr2[0] == 0) {
                    break;
                }
            } else if (iArr2[i4] != -1) {
                break;
            } else {
                iArr2[i4] = 0;
                i3++;
            }
            i4++;
            i3++;
        }
        c cVar3 = null;
        if (iArr2[0] == 0) {
            i2 = 0;
            i = 0;
        } else if (iArr[0] > 23) {
            i2 = (iArr[0] / 10) * 3600000;
            cVar3 = c.H;
        } else {
            int i5 = iArr[0] * 3600000;
            int i6 = iArr2[0];
            c cVar4 = c.H;
            if (iArr2[1] == 2 && iArr[1] <= 59) {
                i5 += iArr[1] * 60000;
                i6 += iArr2[1] + 1;
                cVar4 = c.HM;
                if (iArr2[2] == 2 && iArr[2] <= 59) {
                    int i7 = (iArr[2] * 1000) + i5;
                    i = i6 + iArr2[2] + 1;
                    cVar3 = c.HMS;
                    i2 = i7;
                }
            }
            i2 = i5;
            i = i6;
            cVar3 = cVar4;
        }
        if (cVar3 == null || cVar3.ordinal() < cVar.ordinal()) {
            parsePosition.setErrorIndex(index);
            return 0;
        }
        parsePosition.setIndex(index + i);
        return i2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:23:0x0082  */
    /* JADX WARNING: Removed duplicated region for block: B:25:0x0085  */
    private int B(String str, int i, char c2, int[] iArr) {
        int i2;
        int i3;
        int i4;
        int length = str.length();
        int[] iArr2 = {0};
        int E = E(str, i, 1, 2, 0, 23, iArr2);
        if (iArr2[0] == 0) {
            i3 = i;
        } else {
            int i5 = i + iArr2[0];
            int i6 = i5 + 1;
            if (i6 >= length || str.charAt(i5) != c2) {
                i3 = i5;
            } else {
                i2 = E(str, i6, 2, 2, 0, 59, iArr2);
                if (iArr2[0] == 0) {
                    i3 = i5;
                } else {
                    int i7 = i5 + iArr2[0] + 1;
                    int i8 = i7 + 1;
                    if (i8 >= length || str.charAt(i7) != c2) {
                        i3 = i7;
                    } else {
                        i4 = E(str, i8, 2, 2, 0, 59, iArr2);
                        if (iArr2[0] == 0) {
                            i3 = i7;
                        } else {
                            i3 = i7 + iArr2[0] + 1;
                        }
                        if (i3 == i) {
                            iArr[0] = 0;
                            return 0;
                        }
                        iArr[0] = i3 - i;
                        return (E * 3600000) + (i2 * 60000) + (i4 * 1000);
                    }
                }
                i4 = 0;
                if (i3 == i) {
                }
            }
        }
        i4 = 0;
        i2 = 0;
        if (i3 == i) {
        }
    }

    private String C(String str, ParsePosition parsePosition) {
        int index = parsePosition.getIndex();
        Collection<TimeZoneNames.e> find = this._tznames.find(str, index, EnumSet.of(TimeZoneNames.NameType.EXEMPLAR_LOCATION));
        String str2 = null;
        if (find != null) {
            int i = -1;
            TimeZoneNames.e eVar = null;
            for (TimeZoneNames.e eVar2 : find) {
                if (eVar2.a() + index > i) {
                    i = eVar2.a() + index;
                    eVar = eVar2;
                }
            }
            if (eVar != null) {
                str2 = u(eVar.d(), eVar.b());
                parsePosition.setIndex(i);
            }
        }
        if (str2 == null) {
            parsePosition.setErrorIndex(index);
        }
        return str2;
    }

    private int D(String str, int i, int[] iArr) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        int i8;
        String[] strArr = J0;
        int length = strArr.length;
        int i9 = 0;
        while (true) {
            if (i9 >= length) {
                i2 = 0;
                break;
            }
            String str2 = strArr[i9];
            i2 = str2.length();
            if (str.regionMatches(true, i, str2, 0, i2)) {
                break;
            }
            i9++;
        }
        if (i2 != 0 && (i6 = (i5 = i2 + i) + 1) < str.length()) {
            char charAt = str.charAt(i5);
            if (charAt == '+') {
                i7 = 1;
            } else if (charAt == '-') {
                i7 = -1;
            }
            int[] iArr2 = {0};
            int B = B(str, i6, N0, iArr2);
            if (iArr2[0] == str.length() - i6) {
                i3 = B * i7;
                i8 = iArr2[0];
            } else {
                int[] iArr3 = {0};
                int z = z(str, i6, iArr3);
                if (iArr2[0] > iArr3[0]) {
                    i3 = B * i7;
                    i8 = iArr2[0];
                } else {
                    i3 = z * i7;
                    i8 = iArr3[0];
                }
            }
            i4 = (i6 + i8) - i;
            iArr[0] = i4;
            return i3;
        }
        i4 = 0;
        i3 = 0;
        iArr[0] = i4;
        return i3;
    }

    private int E(String str, int i, int i2, int i3, int i4, int i5, int[] iArr) {
        int i6;
        iArr[0] = 0;
        int[] iArr2 = {0};
        int i7 = i;
        int i8 = 0;
        int i9 = 0;
        while (i7 < str.length() && i8 < i3 && (r5 = M(str, i7, iArr2)) >= 0 && (i6 = (i9 * 10) + r5) <= i5) {
            i8++;
            i7 += iArr2[0];
            i9 = i6;
        }
        if (i8 < i2 || i9 < i4) {
            return -1;
        }
        iArr[0] = i7 - i;
        return i9;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:25:0x0089, code lost:
        if (r18.i() != false) goto L_0x0093;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:27:0x0093, code lost:
        r15 = 1;
     */
    private int F(String str, int i, boolean z, int[] iArr) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int i7;
        if (iArr != null && iArr.length >= 1) {
            iArr[0] = 0;
        }
        int[] iArr2 = {0, 0, 0};
        GMTOffsetPatternType[] gMTOffsetPatternTypeArr = T0;
        int length = gMTOffsetPatternTypeArr.length;
        int i8 = 0;
        int i9 = 0;
        while (true) {
            i2 = -1;
            if (i9 >= length) {
                i3 = i8;
                i4 = 1;
                i5 = 0;
                i6 = 0;
                i7 = 0;
                break;
            }
            GMTOffsetPatternType gMTOffsetPatternType = gMTOffsetPatternTypeArr[i9];
            i8 = G(str, i, this.l1[gMTOffsetPatternType.ordinal()], false, iArr2);
            if (i8 > 0) {
                int i10 = gMTOffsetPatternType.i() ? 1 : -1;
                i3 = i8;
                i4 = i10;
                i5 = iArr2[0];
                i6 = iArr2[1];
                i7 = iArr2[2];
            } else {
                i9++;
            }
        }
        if (i3 > 0 && this.m1) {
            GMTOffsetPatternType[] gMTOffsetPatternTypeArr2 = T0;
            int length2 = gMTOffsetPatternTypeArr2.length;
            int i11 = 0;
            int i12 = 0;
            while (true) {
                if (i12 >= length2) {
                    break;
                }
                GMTOffsetPatternType gMTOffsetPatternType2 = gMTOffsetPatternTypeArr2[i12];
                i11 = G(str, i, this.l1[gMTOffsetPatternType2.ordinal()], true, iArr2);
                if (i11 <= 0) {
                    i12++;
                    length2 = length2;
                    gMTOffsetPatternTypeArr2 = gMTOffsetPatternTypeArr2;
                }
            }
            if (i11 > i3) {
                i5 = iArr2[0];
                i6 = iArr2[1];
                i7 = iArr2[2];
                i3 = i11;
                i4 = i2;
            }
        }
        if (iArr != null && iArr.length >= 1) {
            iArr[0] = i3;
        }
        if (i3 > 0) {
            return ((((i5 * 60) + i6) * 60) + i7) * 1000 * i4;
        }
        return 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:22:0x0065  */
    /* JADX WARNING: Removed duplicated region for block: B:45:0x0063 A[EDGE_INSN: B:45:0x0063->B:21:0x0063 ?: BREAK  , SYNTHETIC] */
    private int G(String str, int i, Object[] objArr, boolean z, int[] iArr) {
        boolean z2;
        int i2;
        int i3;
        iArr[2] = 0;
        iArr[1] = 0;
        iArr[0] = 0;
        int[] iArr2 = {0};
        int i4 = i;
        int i5 = 0;
        int i6 = 0;
        int i7 = 0;
        int i8 = 0;
        while (true) {
            if (i5 >= objArr.length) {
                z2 = false;
                break;
            } else if (objArr[i5] instanceof String) {
                String str2 = (String) objArr[i5];
                int length = str2.length();
                if (i5 == 0 && i4 < str.length()) {
                    if (!y0.e(str.codePointAt(i4))) {
                        int i9 = 0;
                        while (length > 0) {
                            int codePointAt = str2.codePointAt(i9);
                            if (!y0.e(codePointAt)) {
                                break;
                            }
                            int charCount = Character.charCount(codePointAt);
                            length -= charCount;
                            i9 += charCount;
                        }
                        i2 = length;
                        i3 = i9;
                        if (str.regionMatches(true, i4, str2, i3, i2)) {
                            break;
                        }
                        i4 += i2;
                        i5++;
                    }
                }
                i2 = length;
                i3 = 0;
                if (str.regionMatches(true, i4, str2, i3, i2)) {
                }
            } else {
                char a2 = ((b) objArr[i5]).a();
                if (a2 == 'H') {
                    i6 = E(str, i4, 1, z ? 1 : 2, 0, 23, iArr2);
                } else if (a2 == 'm') {
                    i7 = E(str, i4, 2, 2, 0, 59, iArr2);
                } else if (a2 == 's') {
                    i8 = E(str, i4, 2, 2, 0, 59, iArr2);
                }
                if (iArr2[0] == 0) {
                    break;
                }
                i4 += iArr2[0];
                i5++;
            }
        }
        z2 = true;
        if (z2) {
            return 0;
        }
        iArr[0] = i6;
        iArr[1] = i7;
        iArr[2] = i8;
        return i4 - i;
    }

    private static int H(String str, ParsePosition parsePosition, boolean z, w<Boolean> wVar) {
        if (wVar != null) {
            wVar.f16195a = (T) Boolean.FALSE;
        }
        int index = parsePosition.getIndex();
        if (index >= str.length()) {
            parsePosition.setErrorIndex(index);
            return 0;
        }
        char charAt = str.charAt(index);
        int i = 1;
        if (Character.toUpperCase(charAt) == P0.charAt(0)) {
            parsePosition.setIndex(index + 1);
            return 0;
        }
        if (charAt != '+') {
            if (charAt == '-') {
                i = -1;
            } else {
                parsePosition.setErrorIndex(index);
                return 0;
            }
        }
        int i2 = index + 1;
        ParsePosition parsePosition2 = new ParsePosition(i2);
        c cVar = c.H;
        c cVar2 = c.HMS;
        int A = A(str, parsePosition2, N0, cVar, cVar2);
        if (parsePosition2.getErrorIndex() == -1 && !z && parsePosition2.getIndex() - index <= 3) {
            ParsePosition parsePosition3 = new ParsePosition(i2);
            int y = y(str, parsePosition3, cVar, cVar2, false);
            if (parsePosition3.getErrorIndex() == -1 && parsePosition3.getIndex() > parsePosition2.getIndex()) {
                parsePosition2.setIndex(parsePosition3.getIndex());
                A = y;
            }
        }
        if (parsePosition2.getErrorIndex() != -1) {
            parsePosition.setErrorIndex(index);
            return 0;
        }
        parsePosition.setIndex(parsePosition2.getIndex());
        if (wVar != null) {
            wVar.f16195a = (T) Boolean.TRUE;
        }
        return i * A;
    }

    private int I(String str, ParsePosition parsePosition, boolean z, w<Boolean> wVar) {
        int index = parsePosition.getIndex();
        int[] iArr = {0};
        if (wVar != null) {
            wVar.f16195a = (T) Boolean.FALSE;
        }
        int J = J(str, index, z, iArr);
        if (iArr[0] > 0) {
            if (wVar != null) {
                wVar.f16195a = (T) Boolean.TRUE;
            }
            parsePosition.setIndex(index + iArr[0]);
            return J;
        }
        int D = D(str, index, iArr);
        if (iArr[0] > 0) {
            if (wVar != null) {
                wVar.f16195a = (T) Boolean.TRUE;
            }
            parsePosition.setIndex(index + iArr[0]);
            return D;
        }
        String str2 = this._gmtZeroFormat;
        if (str.regionMatches(true, index, str2, 0, str2.length())) {
            parsePosition.setIndex(index + this._gmtZeroFormat.length());
            return 0;
        }
        String[] strArr = J0;
        for (String str3 : strArr) {
            if (str.regionMatches(true, index, str3, 0, str3.length())) {
                parsePosition.setIndex(index + str3.length());
                return 0;
            }
        }
        parsePosition.setErrorIndex(index);
        return 0;
    }

    /* JADX WARNING: Removed duplicated region for block: B:14:0x004c  */
    /* JADX WARNING: Removed duplicated region for block: B:15:0x004f  */
    private int J(String str, int i, boolean z, int[] iArr) {
        int i2;
        int i3;
        int length = this.j1.length();
        boolean z2 = true;
        if (length <= 0 || str.regionMatches(true, i, this.j1, 0, length)) {
            i3 = i + length;
            int[] iArr2 = new int[1];
            i2 = F(str, i3, false, iArr2);
            if (iArr2[0] != 0) {
                i3 += iArr2[0];
                int length2 = this.k1.length();
                if (length2 <= 0 || str.regionMatches(true, i3, this.k1, 0, length2)) {
                    i3 += length2;
                    iArr[0] = !z2 ? i3 - i : 0;
                    return i2;
                }
            }
        } else {
            i3 = i;
            i2 = 0;
        }
        z2 = false;
        iArr[0] = !z2 ? i3 - i : 0;
        return i2;
    }

    private static Object[] K(String str, String str2) {
        boolean z;
        StringBuilder sb = new StringBuilder();
        ArrayList arrayList = new ArrayList();
        BitSet bitSet = new BitSet(str2.length());
        boolean z2 = true;
        int i = 0;
        boolean z3 = false;
        boolean z4 = false;
        char c2 = 0;
        int i2 = 1;
        while (true) {
            if (i >= str.length()) {
                z = false;
                break;
            }
            char charAt = str.charAt(i);
            if (charAt == '\'') {
                if (z4) {
                    sb.append(z0.f14782a);
                    z4 = false;
                } else if (c2 != 0) {
                    if (!b.c(c2, i2)) {
                        break;
                    }
                    arrayList.add(new b(c2, i2));
                    z4 = true;
                    c2 = 0;
                } else {
                    z4 = true;
                }
                z3 = !z3;
                i++;
            } else {
                if (z3) {
                    sb.append(charAt);
                } else {
                    int indexOf = str2.indexOf(charAt);
                    if (indexOf < 0) {
                        if (c2 != 0) {
                            if (!b.c(c2, i2)) {
                                break;
                            }
                            arrayList.add(new b(c2, i2));
                            c2 = 0;
                        }
                        sb.append(charAt);
                    } else if (charAt == c2) {
                        i2++;
                    } else {
                        if (c2 != 0) {
                            if (!b.c(c2, i2)) {
                                break;
                            }
                            arrayList.add(new b(c2, i2));
                        } else if (sb.length() > 0) {
                            arrayList.add(sb.toString());
                            sb.setLength(0);
                        }
                        bitSet.set(indexOf);
                        c2 = charAt;
                        z4 = false;
                        i2 = 1;
                        i++;
                    }
                }
                z4 = false;
                i++;
            }
        }
        z = true;
        if (!z) {
            if (c2 != 0) {
                if (b.c(c2, i2)) {
                    arrayList.add(new b(c2, i2));
                }
                if (z2 && bitSet.cardinality() == str2.length()) {
                    return arrayList.toArray(new Object[arrayList.size()]);
                }
                throw new IllegalStateException("Bad localized GMT offset pattern: " + str);
            } else if (sb.length() > 0) {
                arrayList.add(sb.toString());
                sb.setLength(0);
            }
        }
        z2 = z;
        if (z2) {
        }
        throw new IllegalStateException("Bad localized GMT offset pattern: " + str);
    }

    private static String L(String str, ParsePosition parsePosition) {
        if (g1 == null) {
            synchronized (TimeZoneFormat.class) {
                if (g1 == null) {
                    r1<String> r1Var = new r1<>(true);
                    for (String str2 : TimeZone.getAvailableIDs(TimeZone.SystemTimeZoneType.CANONICAL, null, null)) {
                        String q = s2.q(str2);
                        if (q != null) {
                            r1Var.k(q, str2);
                        }
                    }
                    r1Var.k(R0, "Etc/Unknown");
                    g1 = r1Var;
                }
            }
        }
        r1.e eVar = new r1.e();
        Iterator<String> i = g1.i(str, parsePosition.getIndex(), eVar);
        if (i != null) {
            String next = i.next();
            parsePosition.setIndex(parsePosition.getIndex() + eVar.f14362a);
            return next;
        }
        parsePosition.setErrorIndex(parsePosition.getIndex());
        return null;
    }

    private int M(String str, int i, int[] iArr) {
        iArr[0] = 0;
        int i2 = -1;
        if (i < str.length()) {
            int codePointAt = Character.codePointAt(str, i);
            int i3 = 0;
            while (true) {
                String[] strArr = this._gmtOffsetDigits;
                if (i3 >= strArr.length) {
                    break;
                } else if (codePointAt == strArr[i3].codePointAt(0)) {
                    i2 = i3;
                    break;
                } else {
                    i3++;
                }
            }
            if (i2 < 0) {
                i2 = com.ibm.icu.lang.c.j(codePointAt);
            }
            if (i2 >= 0) {
                iArr[0] = Character.charCount(codePointAt);
            }
        }
        return i2;
    }

    private static String N(String str, ParsePosition parsePosition) {
        if (f1 == null) {
            synchronized (TimeZoneFormat.class) {
                if (f1 == null) {
                    r1<String> r1Var = new r1<>(true);
                    String[] availableIDs = TimeZone.getAvailableIDs();
                    for (String str2 : availableIDs) {
                        r1Var.k(str2, str2);
                    }
                    f1 = r1Var;
                }
            }
        }
        r1.e eVar = new r1.e();
        Iterator<String> i = f1.i(str, parsePosition.getIndex(), eVar);
        if (i != null) {
            String next = i.next();
            parsePosition.setIndex(parsePosition.getIndex() + eVar.f14362a);
            return next;
        }
        parsePosition.setErrorIndex(parsePosition.getIndex());
        return null;
    }

    private static String[] O(String str) {
        int i = 0;
        int codePointCount = str.codePointCount(0, str.length());
        String[] strArr = new String[codePointCount];
        int i2 = 0;
        while (i < codePointCount) {
            int charCount = Character.charCount(str.codePointAt(i2)) + i2;
            strArr[i] = str.substring(i2, charCount);
            i++;
            i2 = charCount;
        }
        return strArr;
    }

    private static String P(String str) {
        int indexOf = str.indexOf("mm");
        if (indexOf >= 0) {
            int lastIndexOf = str.substring(0, indexOf).lastIndexOf("HH");
            if (lastIndexOf >= 0) {
                return str.substring(0, lastIndexOf + 2);
            }
            int lastIndexOf2 = str.substring(0, indexOf).lastIndexOf(DateFormat.HOUR24);
            if (lastIndexOf2 >= 0) {
                return str.substring(0, lastIndexOf2 + 1);
            }
            throw new RuntimeException("Bad time zone hour pattern data");
        }
        throw new RuntimeException("Bad time zone hour pattern data");
    }

    private static String R(String str) {
        if (str.indexOf(39) < 0) {
            return str;
        }
        StringBuilder sb = new StringBuilder();
        boolean z = false;
        for (int i = 0; i < str.length(); i++) {
            char charAt = str.charAt(i);
            if (charAt != '\'') {
                sb.append(charAt);
            } else if (z) {
                sb.append(charAt);
            } else {
                z = true;
            }
            z = false;
        }
        return sb.toString();
    }

    private void b(StringBuilder sb, int i, int i2) {
        int i3 = i >= 10 ? 2 : 1;
        for (int i4 = 0; i4 < i2 - i3; i4++) {
            sb.append(this._gmtOffsetDigits[0]);
        }
        if (i3 == 2) {
            sb.append(this._gmtOffsetDigits[i / 10]);
        }
        sb.append(this._gmtOffsetDigits[i % 10]);
    }

    private void c() {
        this.m1 = false;
        Object[][] objArr = this.l1;
        for (Object[] objArr2 : objArr) {
            boolean z = false;
            for (Object obj : objArr2) {
                if (obj instanceof b) {
                    b bVar = (b) obj;
                    if (z) {
                        this.m1 = true;
                    } else if (bVar.a() == 'H') {
                        z = true;
                    }
                } else if (z) {
                    break;
                }
            }
        }
    }

    private static String d(String str) {
        int indexOf = str.indexOf("mm");
        if (indexOf >= 0) {
            int lastIndexOf = str.substring(0, indexOf).lastIndexOf(DateFormat.HOUR24);
            String substring = lastIndexOf >= 0 ? str.substring(lastIndexOf + 1, indexOf) : ":";
            StringBuilder sb = new StringBuilder();
            int i = indexOf + 2;
            sb.append(str.substring(0, i));
            sb.append(substring);
            sb.append("ss");
            sb.append(str.substring(i));
            return sb.toString();
        }
        throw new RuntimeException("Bad time zone hour pattern data");
    }

    private String e(TimeZone timeZone) {
        String exemplarLocationName = getTimeZoneNames().getExemplarLocationName(s2.e(timeZone));
        if (exemplarLocationName != null) {
            return exemplarLocationName;
        }
        String exemplarLocationName2 = getTimeZoneNames().getExemplarLocationName("Etc/Unknown");
        return exemplarLocationName2 == null ? S0 : exemplarLocationName2;
    }

    private String f(int i, boolean z, boolean z2, boolean z3, boolean z4) {
        Character ch;
        int i2 = i < 0 ? -i : i;
        if (z2) {
            if (i2 < 1000) {
                return P0;
            }
            if (z4 && i2 < 60000) {
                return P0;
            }
        }
        c cVar = z3 ? c.H : c.HM;
        c cVar2 = z4 ? c.HM : c.HMS;
        if (z) {
            ch = null;
        } else {
            ch = Character.valueOf(N0);
        }
        if (i2 < 86400000) {
            int i3 = i2 % 3600000;
            int[] iArr = {i2 / 3600000, i3 / 60000, (i3 % 60000) / 1000};
            int ordinal = cVar2.ordinal();
            while (ordinal > cVar.ordinal() && iArr[ordinal] == 0) {
                ordinal--;
            }
            StringBuilder sb = new StringBuilder();
            char c2 = '+';
            if (i < 0) {
                int i4 = 0;
                while (true) {
                    if (i4 > ordinal) {
                        break;
                    } else if (iArr[i4] != 0) {
                        c2 = '-';
                        break;
                    } else {
                        i4++;
                    }
                }
            }
            sb.append(c2);
            for (int i5 = 0; i5 <= ordinal; i5++) {
                if (!(ch == null || i5 == 0)) {
                    sb.append(ch);
                }
                if (iArr[i5] < 10) {
                    sb.append('0');
                }
                sb.append(iArr[i5]);
            }
            return sb.toString();
        }
        throw new IllegalArgumentException("Offset out of range :" + i);
    }

    public static TimeZoneFormat getInstance(ULocale uLocale) {
        Objects.requireNonNull(uLocale, "locale is null");
        return (TimeZoneFormat) c1.b(uLocale, uLocale);
    }

    private String h(int i, boolean z) {
        boolean z2;
        Object[] objArr;
        if (i == 0) {
            return this._gmtZeroFormat;
        }
        StringBuilder sb = new StringBuilder();
        if (i < 0) {
            i = -i;
            z2 = false;
        } else {
            z2 = true;
        }
        int i2 = i / 3600000;
        int i3 = i % 3600000;
        int i4 = i3 / 60000;
        int i5 = i3 % 60000;
        int i6 = i5 / 1000;
        if (i2 > 23 || i4 > 59 || i6 > 59) {
            throw new IllegalArgumentException("Offset out of range :" + i5);
        }
        if (z2) {
            if (i6 != 0) {
                objArr = this.l1[GMTOffsetPatternType.POSITIVE_HMS.ordinal()];
            } else if (i4 != 0 || !z) {
                objArr = this.l1[GMTOffsetPatternType.POSITIVE_HM.ordinal()];
            } else {
                objArr = this.l1[GMTOffsetPatternType.POSITIVE_H.ordinal()];
            }
        } else if (i6 != 0) {
            objArr = this.l1[GMTOffsetPatternType.NEGATIVE_HMS.ordinal()];
        } else if (i4 != 0 || !z) {
            objArr = this.l1[GMTOffsetPatternType.NEGATIVE_HM.ordinal()];
        } else {
            objArr = this.l1[GMTOffsetPatternType.NEGATIVE_H.ordinal()];
        }
        sb.append(this.j1);
        for (Object obj : objArr) {
            if (obj instanceof String) {
                sb.append((String) obj);
            } else if (obj instanceof b) {
                char a2 = ((b) obj).a();
                int i7 = 2;
                if (a2 == 'H') {
                    if (z) {
                        i7 = 1;
                    }
                    b(sb, i2, i7);
                } else if (a2 == 'm') {
                    b(sb, i4, 2);
                } else if (a2 == 's') {
                    b(sb, i6, 2);
                }
            }
        }
        sb.append(this.k1);
        return sb.toString();
    }

    private String m(TimeZone timeZone, TimeZoneNames.NameType nameType, TimeZoneNames.NameType nameType2, long j, w<TimeType> wVar) {
        String str;
        boolean inDaylightTime = timeZone.inDaylightTime(new Date(j));
        if (inDaylightTime) {
            str = getTimeZoneNames().getDisplayName(s2.e(timeZone), nameType2, j);
        } else {
            str = getTimeZoneNames().getDisplayName(s2.e(timeZone), nameType, j);
        }
        if (!(str == null || wVar == null)) {
            wVar.f16195a = inDaylightTime ? (T) TimeType.DAYLIGHT : (T) TimeType.STANDARD;
        }
        return str;
    }

    private TimeZoneNames n() {
        if (this.p1 == null) {
            synchronized (this) {
                if (this.p1 == null) {
                    this.p1 = new TZDBTimeZoneNames(this._locale);
                }
            }
        }
        return this.p1;
    }

    private synchronized String p() {
        if (this.n1 == null) {
            String country = this._locale.getCountry();
            this.n1 = country;
            if (country.length() == 0) {
                String country2 = ULocale.addLikelySubtags(this._locale).getCountry();
                this.n1 = country2;
                if (country2.length() == 0) {
                    this.n1 = e.c.i;
                }
            }
        }
        return this.n1;
    }

    private TimeType q(TimeZoneNames.NameType nameType) {
        int i = a.f15433b[nameType.ordinal()];
        if (i == 1 || i == 2) {
            return TimeType.STANDARD;
        }
        if (i == 3 || i == 4) {
            return TimeType.DAYLIGHT;
        }
        return TimeType.UNKNOWN;
    }

    private void readObject(ObjectInputStream objectInputStream) throws ClassNotFoundException, IOException {
        ObjectInputStream.GetField readFields = objectInputStream.readFields();
        ULocale uLocale = (ULocale) readFields.get("_locale", (Object) null);
        this._locale = uLocale;
        if (uLocale != null) {
            TimeZoneNames timeZoneNames = (TimeZoneNames) readFields.get("_tznames", (Object) null);
            this._tznames = timeZoneNames;
            if (timeZoneNames != null) {
                String str = (String) readFields.get("_gmtPattern", (Object) null);
                this._gmtPattern = str;
                if (str != null) {
                    String[] strArr = (String[]) readFields.get("_gmtOffsetPatterns", (Object) null);
                    if (strArr == null) {
                        throw new InvalidObjectException("Missing field: gmtOffsetPatterns");
                    } else if (strArr.length >= 4) {
                        this._gmtOffsetPatterns = new String[6];
                        if (strArr.length == 4) {
                            for (int i = 0; i < 4; i++) {
                                this._gmtOffsetPatterns[i] = strArr[i];
                            }
                            this._gmtOffsetPatterns[GMTOffsetPatternType.POSITIVE_H.ordinal()] = P(this._gmtOffsetPatterns[GMTOffsetPatternType.POSITIVE_HM.ordinal()]);
                            this._gmtOffsetPatterns[GMTOffsetPatternType.NEGATIVE_H.ordinal()] = P(this._gmtOffsetPatterns[GMTOffsetPatternType.NEGATIVE_HM.ordinal()]);
                        } else {
                            this._gmtOffsetPatterns = strArr;
                        }
                        String[] strArr2 = (String[]) readFields.get("_gmtOffsetDigits", (Object) null);
                        this._gmtOffsetDigits = strArr2;
                        if (strArr2 == null) {
                            throw new InvalidObjectException("Missing field: gmtOffsetDigits");
                        } else if (strArr2.length == 10) {
                            String str2 = (String) readFields.get("_gmtZeroFormat", (Object) null);
                            this._gmtZeroFormat = str2;
                            if (str2 != null) {
                                this._parseAllStyles = readFields.get("_parseAllStyles", false);
                                if (!readFields.defaulted("_parseAllStyles")) {
                                    if (this._tznames instanceof TimeZoneNamesImpl) {
                                        this._tznames = TimeZoneNames.getInstance(this._locale);
                                        this.i1 = null;
                                    } else {
                                        this.i1 = new TimeZoneGenericNames(this._locale, this._tznames);
                                    }
                                    x(this._gmtPattern);
                                    v(this._gmtOffsetPatterns);
                                    return;
                                }
                                throw new InvalidObjectException("Missing field: parseAllStyles");
                            }
                            throw new InvalidObjectException("Missing field: gmtZeroFormat");
                        } else {
                            throw new InvalidObjectException("Incompatible field: gmtOffsetDigits");
                        }
                    } else {
                        throw new InvalidObjectException("Incompatible field: gmtOffsetPatterns");
                    }
                } else {
                    throw new InvalidObjectException("Missing field: gmtPattern");
                }
            } else {
                throw new InvalidObjectException("Missing field: tznames");
            }
        } else {
            throw new InvalidObjectException("Missing field: locale");
        }
    }

    private TimeZone s(int i) {
        if (i == 0) {
            return TimeZone.getTimeZone(I0);
        }
        return s2.l(i);
    }

    private TimeZoneGenericNames t() {
        if (this.i1 == null) {
            synchronized (this) {
                if (this.i1 == null) {
                    this.i1 = TimeZoneGenericNames.getInstance(this._locale);
                }
            }
        }
        return this.i1;
    }

    private String u(String str, String str2) {
        if (str != null || (str = this._tznames.getReferenceZoneID(str2, p())) != null) {
            return str;
        }
        throw new IllegalArgumentException("Invalid mzID: " + str2);
    }

    private void v(String[] strArr) {
        int length = GMTOffsetPatternType.values().length;
        if (strArr.length >= length) {
            Object[][] objArr = new Object[length][];
            GMTOffsetPatternType[] values = GMTOffsetPatternType.values();
            for (GMTOffsetPatternType gMTOffsetPatternType : values) {
                int ordinal = gMTOffsetPatternType.ordinal();
                objArr[ordinal] = K(strArr[ordinal], gMTOffsetPatternType.j());
            }
            String[] strArr2 = new String[length];
            this._gmtOffsetPatterns = strArr2;
            System.arraycopy(strArr, 0, strArr2, 0, length);
            this.l1 = objArr;
            c();
            return;
        }
        throw new IllegalArgumentException("Insufficient number of elements in gmtOffsetPatterns");
    }

    private void writeObject(ObjectOutputStream objectOutputStream) throws IOException {
        ObjectOutputStream.PutField putFields = objectOutputStream.putFields();
        putFields.put("_locale", this._locale);
        putFields.put("_tznames", this._tznames);
        putFields.put("_gmtPattern", this._gmtPattern);
        putFields.put("_gmtOffsetPatterns", this._gmtOffsetPatterns);
        putFields.put("_gmtOffsetDigits", this._gmtOffsetDigits);
        putFields.put("_gmtZeroFormat", this._gmtZeroFormat);
        putFields.put("_parseAllStyles", this._parseAllStyles);
        objectOutputStream.writeFields();
    }

    private void x(String str) {
        int indexOf = str.indexOf("{0}");
        if (indexOf >= 0) {
            this._gmtPattern = str;
            this.j1 = R(str.substring(0, indexOf));
            this.k1 = R(str.substring(indexOf + 3));
            return;
        }
        throw new IllegalArgumentException("Bad localized GMT pattern: " + str);
    }

    private static int y(String str, ParsePosition parsePosition, c cVar, c cVar2, boolean z) {
        int i;
        int i2;
        int i3;
        int i4;
        int i5;
        int index = parsePosition.getIndex();
        boolean z2 = true;
        int ordinal = ((cVar.ordinal() + 1) * 2) - (!z ? 1 : 0);
        int ordinal2 = (cVar2.ordinal() + 1) * 2;
        int[] iArr = new int[ordinal2];
        int i6 = index;
        int i7 = 0;
        while (i7 < ordinal2 && i6 < str.length()) {
            int indexOf = O0.indexOf(str.charAt(i6));
            if (indexOf < 0) {
                break;
            }
            iArr[i7] = indexOf;
            i7++;
            i6++;
        }
        if (z && (i7 & 1) != 0) {
            i7--;
        }
        if (i7 < ordinal) {
            parsePosition.setErrorIndex(index);
            return 0;
        }
        while (true) {
            if (i7 >= ordinal) {
                switch (i7) {
                    case 1:
                        i2 = iArr[0];
                        i = 0;
                        i3 = 0;
                        break;
                    case 2:
                        i2 = (iArr[0] * 10) + iArr[1];
                        i = 0;
                        i3 = 0;
                        break;
                    case 3:
                        i2 = iArr[0];
                        i5 = iArr[1] * 10;
                        i4 = iArr[2];
                        i3 = i5 + i4;
                        i = 0;
                        break;
                    case 4:
                        i2 = iArr[1] + (iArr[0] * 10);
                        i5 = iArr[2] * 10;
                        i4 = iArr[3];
                        i3 = i5 + i4;
                        i = 0;
                        break;
                    case 5:
                        i2 = iArr[0];
                        i3 = (iArr[1] * 10) + iArr[2];
                        i = iArr[4] + (iArr[3] * 10);
                        break;
                    case 6:
                        i2 = (iArr[0] * 10) + iArr[1];
                        i3 = (iArr[2] * 10) + iArr[3];
                        i = (iArr[4] * 10) + iArr[5];
                        break;
                    default:
                        i = 0;
                        i2 = 0;
                        i3 = 0;
                        break;
                }
                if (i2 > 23 || i3 > 59 || i > 59) {
                    i7 -= z ? 2 : 1;
                }
            } else {
                i = 0;
                z2 = false;
                i2 = 0;
                i3 = 0;
            }
        }
        if (!z2) {
            parsePosition.setErrorIndex(index);
            return 0;
        }
        parsePosition.setIndex(index + i7);
        return ((((i2 * 60) + i3) * 60) + i) * 1000;
    }

    private int z(String str, int i, int[] iArr) {
        int i2;
        int i3;
        int i4;
        int i5;
        int i6;
        int[] iArr2 = new int[6];
        int[] iArr3 = new int[6];
        int[] iArr4 = {0};
        int i7 = i;
        int i8 = 0;
        for (int i9 = 0; i9 < 6; i9++) {
            iArr2[i9] = M(str, i7, iArr4);
            if (iArr2[i9] < 0) {
                break;
            }
            i7 += iArr4[0];
            iArr3[i9] = i7 - i;
            i8++;
        }
        if (i8 == 0) {
            iArr[0] = 0;
            return 0;
        }
        while (i8 > 0) {
            switch (i8) {
                case 1:
                    i3 = iArr2[0];
                    i2 = 0;
                    i4 = 0;
                    break;
                case 2:
                    i3 = (iArr2[0] * 10) + iArr2[1];
                    i2 = 0;
                    i4 = 0;
                    break;
                case 3:
                    i3 = iArr2[0];
                    i6 = iArr2[1] * 10;
                    i5 = iArr2[2];
                    i4 = i6 + i5;
                    i2 = 0;
                    break;
                case 4:
                    i3 = iArr2[1] + (iArr2[0] * 10);
                    i6 = iArr2[2] * 10;
                    i5 = iArr2[3];
                    i4 = i6 + i5;
                    i2 = 0;
                    break;
                case 5:
                    i3 = iArr2[0];
                    i4 = iArr2[2] + (iArr2[1] * 10);
                    i2 = iArr2[4] + (iArr2[3] * 10);
                    break;
                case 6:
                    i3 = (iArr2[0] * 10) + iArr2[1];
                    i4 = (iArr2[2] * 10) + iArr2[3];
                    i2 = (iArr2[4] * 10) + iArr2[5];
                    break;
                default:
                    i2 = 0;
                    i4 = 0;
                    i3 = 0;
                    break;
            }
            if (i3 > 23 || i4 > 59 || i2 > 59) {
                i8--;
            } else {
                int i10 = (i3 * 3600000) + (i4 * 60000) + (i2 * 1000);
                iArr[0] = iArr3[i8 - 1];
                return i10;
            }
        }
        return 0;
    }

    public final String format(Style style, TimeZone timeZone, long j) {
        return format(style, timeZone, j, null);
    }

    public final String formatOffsetISO8601Basic(int i, boolean z, boolean z2, boolean z3) {
        return f(i, true, z, z2, z3);
    }

    public final String formatOffsetISO8601Extended(int i, boolean z, boolean z2, boolean z3) {
        return f(i, false, z, z2, z3);
    }

    public String formatOffsetLocalizedGMT(int i) {
        return h(i, false);
    }

    public String formatOffsetShortLocalizedGMT(int i) {
        return h(i, true);
    }

    public AttributedCharacterIterator formatToCharacterIterator(Object obj) {
        AttributedString attributedString = new AttributedString(format(obj, new StringBuffer(), new FieldPosition(0)).toString());
        DateFormat.Field field = DateFormat.Field.TIME_ZONE;
        attributedString.addAttribute(field, field);
        return attributedString.getIterator();
    }

    public EnumSet<ParseOption> getDefaultParseOptions() {
        boolean z = this._parseAllStyles;
        if (z && this._parseTZDBNames) {
            return EnumSet.of(ParseOption.ALL_STYLES, ParseOption.TZ_DATABASE_ABBREVIATIONS);
        }
        if (z) {
            return EnumSet.of(ParseOption.ALL_STYLES);
        }
        if (this._parseTZDBNames) {
            return EnumSet.of(ParseOption.TZ_DATABASE_ABBREVIATIONS);
        }
        return EnumSet.noneOf(ParseOption.class);
    }

    public String getGMTOffsetDigits() {
        StringBuilder sb = new StringBuilder(this._gmtOffsetDigits.length);
        for (String str : this._gmtOffsetDigits) {
            sb.append(str);
        }
        return sb.toString();
    }

    public String getGMTOffsetPattern(GMTOffsetPatternType gMTOffsetPatternType) {
        return this._gmtOffsetPatterns[gMTOffsetPatternType.ordinal()];
    }

    public String getGMTPattern() {
        return this._gmtPattern;
    }

    public String getGMTZeroFormat() {
        return this._gmtZeroFormat;
    }

    public TimeZoneNames getTimeZoneNames() {
        return this._tznames;
    }

    @Override // com.ibm.icu.util.n
    public boolean isFrozen() {
        return this.o1;
    }

    /* JADX WARNING: Removed duplicated region for block: B:167:0x038d  */
    /* JADX WARNING: Removed duplicated region for block: B:168:0x0398  */
    /* JADX WARNING: Removed duplicated region for block: B:170:0x03a0  */
    /* JADX WARNING: Removed duplicated region for block: B:227:0x04da  */
    /* JADX WARNING: Removed duplicated region for block: B:229:0x04e3  */
    /* JADX WARNING: Removed duplicated region for block: B:234:0x04f4  */
    public TimeZone parse(Style style, String str, ParsePosition parsePosition, EnumSet<ParseOption> enumSet, w<TimeType> wVar) {
        int i;
        int i2;
        int i3;
        boolean z;
        EnumSet<ParseOption> enumSet2;
        boolean z2;
        int i4;
        T t;
        String str2;
        TimeZone timeZone;
        String str3;
        TimeZoneGenericNames.c findBestMatch;
        String str4;
        Collection<TimeZoneNames.e> find;
        TimeType timeType;
        TimeZoneNames.e eVar;
        int i5;
        EnumSet<TimeZoneGenericNames.GenericNameType> enumSet3;
        EnumSet<TimeZoneNames.NameType> enumSet4;
        Collection<TimeZoneNames.e> find2;
        int i6;
        w<TimeType> wVar2 = wVar;
        if (wVar2 == null) {
            wVar2 = new w<>(TimeType.UNKNOWN);
        } else {
            wVar2.f16195a = (T) TimeType.UNKNOWN;
        }
        int index = parsePosition.getIndex();
        int length = str.length();
        Style style2 = Style.SPECIFIC_LONG;
        boolean z3 = style == style2 || style == Style.GENERIC_LONG || style == Style.GENERIC_LOCATION;
        boolean z4 = style == Style.SPECIFIC_SHORT || style == Style.GENERIC_SHORT;
        ParsePosition parsePosition2 = new ParsePosition(index);
        if (z3 || z4) {
            w<Boolean> wVar3 = new w<>(Boolean.FALSE);
            i = I(str, parsePosition2, z4, wVar3);
            if (parsePosition2.getErrorIndex() != -1) {
                i2 = -1;
                i = Integer.MAX_VALUE;
            } else if (parsePosition2.getIndex() == length || wVar3.f16195a.booleanValue()) {
                parsePosition.setIndex(parsePosition2.getIndex());
                return s(i);
            } else {
                i2 = parsePosition2.getIndex();
            }
            i3 = Style.LOCALIZED_GMT_SHORT.flag | Style.LOCALIZED_GMT.flag | 0;
        } else {
            i3 = 0;
            i2 = -1;
            i = Integer.MAX_VALUE;
        }
        if (enumSet == null) {
            z = getDefaultParseOptions().contains(ParseOption.TZ_DATABASE_ABBREVIATIONS);
        } else {
            z = enumSet.contains(ParseOption.TZ_DATABASE_ABBREVIATIONS);
        }
        int[] iArr = a.f15432a;
        switch (iArr[style.ordinal()]) {
            case 1:
            case 2:
            case 3:
                int i7 = iArr[style.ordinal()];
                if (i7 == 1) {
                    enumSet3 = EnumSet.of(TimeZoneGenericNames.GenericNameType.LOCATION);
                } else if (i7 == 2) {
                    enumSet3 = EnumSet.of(TimeZoneGenericNames.GenericNameType.LONG, TimeZoneGenericNames.GenericNameType.LOCATION);
                } else if (i7 != 3) {
                    enumSet3 = null;
                } else {
                    enumSet3 = EnumSet.of(TimeZoneGenericNames.GenericNameType.SHORT, TimeZoneGenericNames.GenericNameType.LOCATION);
                }
                TimeZoneGenericNames.c findBestMatch2 = t().findBestMatch(str, index, enumSet3);
                if (findBestMatch2 != null && findBestMatch2.a() + index > i2) {
                    wVar2.f16195a = (T) findBestMatch2.c();
                    parsePosition.setIndex(index + findBestMatch2.a());
                    return TimeZone.getTimeZone(findBestMatch2.d());
                }
            case 4:
            case 5:
                if (style == style2) {
                    enumSet4 = EnumSet.of(TimeZoneNames.NameType.LONG_STANDARD, TimeZoneNames.NameType.LONG_DAYLIGHT);
                } else {
                    enumSet4 = EnumSet.of(TimeZoneNames.NameType.SHORT_STANDARD, TimeZoneNames.NameType.SHORT_DAYLIGHT);
                }
                Collection<TimeZoneNames.e> find3 = this._tznames.find(str, index, enumSet4);
                if (find3 != null) {
                    TimeZoneNames.e eVar2 = null;
                    for (TimeZoneNames.e eVar3 : find3) {
                        if (index + eVar3.a() > i2) {
                            i2 = eVar3.a() + index;
                            eVar2 = eVar3;
                        }
                    }
                    if (eVar2 != null) {
                        wVar2.f16195a = (T) q(eVar2.c());
                        parsePosition.setIndex(i2);
                        return TimeZone.getTimeZone(u(eVar2.d(), eVar2.b()));
                    }
                }
                if (z && style == Style.SPECIFIC_SHORT && (find2 = n().find(str, index, enumSet4)) != null) {
                    TimeZoneNames.e eVar4 = null;
                    for (TimeZoneNames.e eVar5 : find2) {
                        if (eVar5.a() + index > i2) {
                            i2 = eVar5.a() + index;
                            eVar4 = eVar5;
                        }
                    }
                    if (eVar4 != null) {
                        wVar2.f16195a = (T) q(eVar4.c());
                        parsePosition.setIndex(i2);
                        return TimeZone.getTimeZone(u(eVar4.d(), eVar4.b()));
                    }
                }
                break;
            case 6:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                String N = N(str, parsePosition2);
                if (parsePosition2.getErrorIndex() == -1) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return TimeZone.getTimeZone(N);
                }
                break;
            case 7:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                String L = L(str, parsePosition2);
                if (parsePosition2.getErrorIndex() == -1) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return TimeZone.getTimeZone(L);
                }
                break;
            case 8:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                String C = C(str, parsePosition2);
                if (parsePosition2.getErrorIndex() == -1) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return TimeZone.getTimeZone(C);
                }
                break;
            case 9:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                int parseOffsetLocalizedGMT = parseOffsetLocalizedGMT(str, parsePosition2);
                if (parsePosition2.getErrorIndex() != -1) {
                    i6 = Style.LOCALIZED_GMT_SHORT.flag;
                    i3 |= i6;
                    break;
                } else {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(parseOffsetLocalizedGMT);
                }
            case 10:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                int parseOffsetShortLocalizedGMT = parseOffsetShortLocalizedGMT(str, parsePosition2);
                if (parsePosition2.getErrorIndex() != -1) {
                    i6 = Style.LOCALIZED_GMT.flag;
                    i3 |= i6;
                    break;
                } else {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(parseOffsetShortLocalizedGMT);
                }
            case 11:
            case 13:
            case 15:
            case 17:
            case 19:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                int parseOffsetISO8601 = parseOffsetISO8601(str, parsePosition2);
                if (parsePosition2.getErrorIndex() == -1) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(parseOffsetISO8601);
                }
                break;
            case 12:
            case 14:
            case 16:
            case 18:
            case 20:
                parsePosition2.setIndex(index);
                parsePosition2.setErrorIndex(-1);
                w wVar4 = new w(Boolean.FALSE);
                int H = H(str, parsePosition2, false, wVar4);
                if (parsePosition2.getErrorIndex() == -1 && wVar4.f16195a.booleanValue()) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(H);
                }
        }
        int i8 = style.flag | i3;
        if (i2 > index) {
            parsePosition.setIndex(i2);
            return s(i);
        }
        TimeType timeType2 = TimeType.UNKNOWN;
        if (i2 < length && ((i8 & 128) == 0 || (i8 & 256) == 0)) {
            parsePosition2.setIndex(index);
            parsePosition2.setErrorIndex(-1);
            w wVar5 = new w(Boolean.FALSE);
            int H2 = H(str, parsePosition2, false, wVar5);
            if (parsePosition2.getErrorIndex() == -1) {
                if (parsePosition2.getIndex() == length || wVar5.f16195a.booleanValue()) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(H2);
                } else if (i2 < parsePosition2.getIndex()) {
                    i2 = parsePosition2.getIndex();
                    i = H2;
                }
            }
        }
        if (i2 < length && (Style.LOCALIZED_GMT.flag & i8) == 0) {
            parsePosition2.setIndex(index);
            parsePosition2.setErrorIndex(-1);
            w<Boolean> wVar6 = new w<>(Boolean.FALSE);
            int I = I(str, parsePosition2, false, wVar6);
            if (parsePosition2.getErrorIndex() == -1) {
                if (parsePosition2.getIndex() == length || wVar6.f16195a.booleanValue()) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(I);
                } else if (i2 < parsePosition2.getIndex()) {
                    i2 = parsePosition2.getIndex();
                    i = I;
                }
            }
        }
        if (i2 < length && (Style.LOCALIZED_GMT_SHORT.flag & i8) == 0) {
            parsePosition2.setIndex(index);
            parsePosition2.setErrorIndex(-1);
            w<Boolean> wVar7 = new w<>(Boolean.FALSE);
            int I2 = I(str, parsePosition2, true, wVar7);
            if (parsePosition2.getErrorIndex() == -1) {
                if (parsePosition2.getIndex() == length || wVar7.f16195a.booleanValue()) {
                    parsePosition.setIndex(parsePosition2.getIndex());
                    return s(I2);
                } else if (i2 < parsePosition2.getIndex()) {
                    i2 = parsePosition2.getIndex();
                    enumSet2 = enumSet;
                    i = I2;
                    if (enumSet2 != null) {
                        z2 = getDefaultParseOptions().contains(ParseOption.ALL_STYLES);
                    } else {
                        z2 = enumSet2.contains(ParseOption.ALL_STYLES);
                    }
                    if (!z2) {
                        if (i2 < length) {
                            Collection<TimeZoneNames.e> find4 = this._tznames.find(str, index, d1);
                            if (find4 != null) {
                                eVar = null;
                                i5 = -1;
                                for (TimeZoneNames.e eVar6 : find4) {
                                    if (index + eVar6.a() > i5) {
                                        i5 = index + eVar6.a();
                                        eVar = eVar6;
                                    }
                                    timeType2 = timeType2;
                                }
                                timeType = timeType2;
                            } else {
                                timeType = timeType2;
                                eVar = null;
                                i5 = -1;
                            }
                            if (i2 < i5) {
                                str3 = u(eVar.d(), eVar.b());
                                t = q(eVar.c());
                                i2 = i5;
                                i = Integer.MAX_VALUE;
                                if (z || i2 >= length || (Style.SPECIFIC_SHORT.flag & i8) != 0 || (find = n().find(str, index, d1)) == null) {
                                    str4 = str3;
                                } else {
                                    TimeZoneNames.e eVar7 = null;
                                    int i9 = -1;
                                    for (TimeZoneNames.e eVar8 : find) {
                                        if (index + eVar8.a() > i9) {
                                            i9 = eVar8.a() + index;
                                            eVar7 = eVar8;
                                        }
                                        str3 = str3;
                                    }
                                    str4 = str3;
                                    if (i2 < i9) {
                                        str2 = u(eVar7.d(), eVar7.b());
                                        t = q(eVar7.c());
                                        i2 = i9;
                                        i = Integer.MAX_VALUE;
                                        if (i2 < length && (findBestMatch = t().findBestMatch(str, index, e1)) != null && i2 < findBestMatch.a() + index) {
                                            i2 = index + findBestMatch.a();
                                            str2 = findBestMatch.d();
                                            t = findBestMatch.c();
                                            i = Integer.MAX_VALUE;
                                        }
                                        if (i2 < length && (Style.ZONE_ID.flag & i8) == 0) {
                                            parsePosition2.setIndex(index);
                                            parsePosition2.setErrorIndex(-1);
                                            String N2 = N(str, parsePosition2);
                                            if (parsePosition2.getErrorIndex() == -1 && i2 < parsePosition2.getIndex()) {
                                                int index2 = parsePosition2.getIndex();
                                                t = (T) TimeType.UNKNOWN;
                                                i2 = index2;
                                                str2 = N2;
                                                i = Integer.MAX_VALUE;
                                            }
                                        }
                                        if (i2 < length && (i8 & Style.ZONE_ID_SHORT.flag) == 0) {
                                            parsePosition2.setIndex(index);
                                            parsePosition2.setErrorIndex(-1);
                                            String L2 = L(str, parsePosition2);
                                            if (parsePosition2.getErrorIndex() == -1 && i2 < parsePosition2.getIndex()) {
                                                i2 = parsePosition2.getIndex();
                                                t = (T) TimeType.UNKNOWN;
                                                i4 = Integer.MAX_VALUE;
                                                str2 = L2;
                                            }
                                        }
                                        i4 = i;
                                    }
                                }
                                str2 = str4;
                                i2 = index + findBestMatch.a();
                                str2 = findBestMatch.d();
                                t = findBestMatch.c();
                                i = Integer.MAX_VALUE;
                                parsePosition2.setIndex(index);
                                parsePosition2.setErrorIndex(-1);
                                String N22 = N(str, parsePosition2);
                                int index22 = parsePosition2.getIndex();
                                t = (T) TimeType.UNKNOWN;
                                i2 = index22;
                                str2 = N22;
                                i = Integer.MAX_VALUE;
                                parsePosition2.setIndex(index);
                                parsePosition2.setErrorIndex(-1);
                                String L22 = L(str, parsePosition2);
                                i2 = parsePosition2.getIndex();
                                t = (T) TimeType.UNKNOWN;
                                i4 = Integer.MAX_VALUE;
                                str2 = L22;
                            }
                        } else {
                            timeType = timeType2;
                        }
                        t = timeType;
                        str3 = null;
                        if (z) {
                        }
                        str4 = str3;
                        str2 = str4;
                        i2 = index + findBestMatch.a();
                        str2 = findBestMatch.d();
                        t = findBestMatch.c();
                        i = Integer.MAX_VALUE;
                        parsePosition2.setIndex(index);
                        parsePosition2.setErrorIndex(-1);
                        String N222 = N(str, parsePosition2);
                        int index222 = parsePosition2.getIndex();
                        t = (T) TimeType.UNKNOWN;
                        i2 = index222;
                        str2 = N222;
                        i = Integer.MAX_VALUE;
                        parsePosition2.setIndex(index);
                        parsePosition2.setErrorIndex(-1);
                        String L222 = L(str, parsePosition2);
                        i2 = parsePosition2.getIndex();
                        t = (T) TimeType.UNKNOWN;
                        i4 = Integer.MAX_VALUE;
                        str2 = L222;
                    } else {
                        t = (T) timeType2;
                        i4 = i;
                        str2 = null;
                    }
                    if (i2 <= index) {
                        if (str2 != null) {
                            timeZone = TimeZone.getTimeZone(str2);
                        } else {
                            timeZone = s(i4);
                        }
                        wVar2.f16195a = t;
                        parsePosition.setIndex(i2);
                        return timeZone;
                    }
                    parsePosition.setErrorIndex(index);
                    return null;
                }
            }
        }
        enumSet2 = enumSet;
        if (enumSet2 != null) {
        }
        if (!z2) {
        }
        if (i2 <= index) {
        }
    }

    public Object parseObject(String str, ParsePosition parsePosition) {
        return parse(str, parsePosition);
    }

    public final int parseOffsetISO8601(String str, ParsePosition parsePosition) {
        return H(str, parsePosition, false, null);
    }

    public int parseOffsetLocalizedGMT(String str, ParsePosition parsePosition) {
        return I(str, parsePosition, false, null);
    }

    public int parseOffsetShortLocalizedGMT(String str, ParsePosition parsePosition) {
        return I(str, parsePosition, true, null);
    }

    public TimeZoneFormat setDefaultParseOptions(EnumSet<ParseOption> enumSet) {
        this._parseAllStyles = enumSet.contains(ParseOption.ALL_STYLES);
        this._parseTZDBNames = enumSet.contains(ParseOption.TZ_DATABASE_ABBREVIATIONS);
        return this;
    }

    public TimeZoneFormat setGMTOffsetDigits(String str) {
        if (!isFrozen()) {
            Objects.requireNonNull(str, "Null GMT offset digits");
            String[] O = O(str);
            if (O.length == 10) {
                this._gmtOffsetDigits = O;
                return this;
            }
            throw new IllegalArgumentException("Length of digits must be 10");
        }
        throw new UnsupportedOperationException("Attempt to modify frozen object");
    }

    public TimeZoneFormat setGMTOffsetPattern(GMTOffsetPatternType gMTOffsetPatternType, String str) {
        if (!isFrozen()) {
            Objects.requireNonNull(str, "Null GMT offset pattern");
            Object[] K = K(str, gMTOffsetPatternType.j());
            this._gmtOffsetPatterns[gMTOffsetPatternType.ordinal()] = str;
            this.l1[gMTOffsetPatternType.ordinal()] = K;
            c();
            return this;
        }
        throw new UnsupportedOperationException("Attempt to modify frozen object");
    }

    public TimeZoneFormat setGMTPattern(String str) {
        if (!isFrozen()) {
            x(str);
            return this;
        }
        throw new UnsupportedOperationException("Attempt to modify frozen object");
    }

    public TimeZoneFormat setGMTZeroFormat(String str) {
        if (!isFrozen()) {
            Objects.requireNonNull(str, "Null GMT zero format");
            if (str.length() != 0) {
                this._gmtZeroFormat = str;
                return this;
            }
            throw new IllegalArgumentException("Empty GMT zero format");
        }
        throw new UnsupportedOperationException("Attempt to modify frozen object");
    }

    public TimeZoneFormat setTimeZoneNames(TimeZoneNames timeZoneNames) {
        if (!isFrozen()) {
            this._tznames = timeZoneNames;
            this.i1 = new TimeZoneGenericNames(this._locale, this._tznames);
            return this;
        }
        throw new UnsupportedOperationException("Attempt to modify frozen object");
    }

    @Override // com.ibm.icu.util.n
    public TimeZoneFormat cloneAsThawed() {
        TimeZoneFormat timeZoneFormat = (TimeZoneFormat) super.clone();
        timeZoneFormat.o1 = false;
        return timeZoneFormat;
    }

    public String format(Style style, TimeZone timeZone, long j, w<TimeType> wVar) {
        boolean z;
        String str;
        if (wVar != null) {
            wVar.f16195a = (T) TimeType.UNKNOWN;
        }
        int[] iArr = a.f15432a;
        switch (iArr[style.ordinal()]) {
            case 1:
                str = t().getGenericLocationName(s2.e(timeZone));
                z = false;
                break;
            case 2:
                str = t().getDisplayName(timeZone, TimeZoneGenericNames.GenericNameType.LONG, j);
                z = false;
                break;
            case 3:
                str = t().getDisplayName(timeZone, TimeZoneGenericNames.GenericNameType.SHORT, j);
                z = false;
                break;
            case 4:
                str = m(timeZone, TimeZoneNames.NameType.LONG_STANDARD, TimeZoneNames.NameType.LONG_DAYLIGHT, j, wVar);
                z = false;
                break;
            case 5:
                str = m(timeZone, TimeZoneNames.NameType.SHORT_STANDARD, TimeZoneNames.NameType.SHORT_DAYLIGHT, j, wVar);
                z = false;
                break;
            case 6:
                str = timeZone.getID();
                z = true;
                break;
            case 7:
                str = s2.p(timeZone);
                if (str == null) {
                    str = R0;
                }
                z = true;
                break;
            case 8:
                str = e(timeZone);
                z = true;
                break;
            default:
                str = null;
                z = false;
                break;
        }
        if (str == null && !z) {
            int[] iArr2 = {0, 0};
            timeZone.getOffset(j, false, iArr2);
            int i = iArr2[0] + iArr2[1];
            switch (iArr[style.ordinal()]) {
                case 1:
                case 2:
                case 4:
                case 9:
                    str = formatOffsetLocalizedGMT(i);
                    break;
                case 3:
                case 5:
                case 10:
                    str = formatOffsetShortLocalizedGMT(i);
                    break;
                case 11:
                    str = formatOffsetISO8601Basic(i, true, true, true);
                    break;
                case 12:
                    str = formatOffsetISO8601Basic(i, false, true, true);
                    break;
                case 13:
                    str = formatOffsetISO8601Basic(i, true, false, true);
                    break;
                case 14:
                    str = formatOffsetISO8601Basic(i, false, false, true);
                    break;
                case 15:
                    str = formatOffsetISO8601Basic(i, true, false, false);
                    break;
                case 16:
                    str = formatOffsetISO8601Basic(i, false, false, false);
                    break;
                case 17:
                    str = formatOffsetISO8601Extended(i, true, false, true);
                    break;
                case 18:
                    str = formatOffsetISO8601Extended(i, false, false, true);
                    break;
                case 19:
                    str = formatOffsetISO8601Extended(i, true, false, false);
                    break;
                case 20:
                    str = formatOffsetISO8601Extended(i, false, false, false);
                    break;
            }
            if (wVar != null) {
                wVar.f16195a = iArr2[1] != 0 ? (T) TimeType.DAYLIGHT : (T) TimeType.STANDARD;
            }
        }
        return str;
    }

    @Override // com.ibm.icu.util.n
    public TimeZoneFormat freeze() {
        this.o1 = true;
        return this;
    }

    public static TimeZoneFormat getInstance(Locale locale) {
        return getInstance(ULocale.forLocale(locale));
    }

    public StringBuffer format(Object obj, StringBuffer stringBuffer, FieldPosition fieldPosition) {
        TimeZone timeZone;
        long currentTimeMillis = System.currentTimeMillis();
        if (obj instanceof TimeZone) {
            timeZone = (TimeZone) obj;
        } else if (obj instanceof Calendar) {
            Calendar calendar = (Calendar) obj;
            TimeZone timeZone2 = calendar.getTimeZone();
            long timeInMillis = calendar.getTimeInMillis();
            timeZone = timeZone2;
            currentTimeMillis = timeInMillis;
        } else {
            throw new IllegalArgumentException("Cannot format given Object (" + obj.getClass().getName() + ") as a time zone");
        }
        String formatOffsetLocalizedGMT = formatOffsetLocalizedGMT(timeZone.getOffset(currentTimeMillis));
        stringBuffer.append(formatOffsetLocalizedGMT);
        if (fieldPosition.getFieldAttribute() == DateFormat.Field.TIME_ZONE || fieldPosition.getField() == 17) {
            fieldPosition.setBeginIndex(0);
            fieldPosition.setEndIndex(formatOffsetLocalizedGMT.length());
        }
        return stringBuffer;
    }

    public TimeZone parse(Style style, String str, ParsePosition parsePosition, w<TimeType> wVar) {
        return parse(style, str, parsePosition, null, wVar);
    }

    public final TimeZone parse(String str, ParsePosition parsePosition) {
        return parse(Style.GENERIC_LOCATION, str, parsePosition, EnumSet.of(ParseOption.ALL_STYLES), null);
    }

    public final TimeZone parse(String str) throws ParseException {
        ParsePosition parsePosition = new ParsePosition(0);
        TimeZone parse = parse(str, parsePosition);
        if (parsePosition.getErrorIndex() < 0) {
            return parse;
        }
        throw new ParseException("Unparseable time zone: \"" + str + "\"", 0);
    }
}
