package com.lzy.okgo.request.base;

import android.text.TextUtils;
import com.lzy.okgo.c.a;
import com.lzy.okgo.c.c;
import com.lzy.okgo.c.d;
import com.lzy.okgo.cache.CacheMode;
import com.lzy.okgo.e.b;
import com.lzy.okgo.model.HttpHeaders;
import com.lzy.okgo.model.HttpMethod;
import com.lzy.okgo.model.HttpParams;
import com.lzy.okgo.request.base.Request;
import com.lzy.okgo.request.base.b;
import java.io.IOException;
import java.io.Serializable;
import java.util.List;
import java.util.Map;
import okhttp3.f0;
import okhttp3.h0;
import okhttp3.i0;
import okhttp3.j;
import okhttp3.j0;

public abstract class Request<T, R extends Request> implements Serializable {
    private static final long serialVersionUID = -7174118653689916252L;
    protected transient h0 I0;
    protected transient c<T> J0;
    protected transient com.lzy.okgo.d.c<T> K0;
    protected transient b<T> L0;
    protected transient com.lzy.okgo.cache.a.b<T> M0;
    protected transient b.c N0;

    /* renamed from: a  reason: collision with root package name */
    protected transient f0 f17313a;

    /* renamed from: b  reason: collision with root package name */
    protected transient Object f17314b;
    protected String baseUrl;
    protected String cacheKey;
    protected CacheMode cacheMode;
    protected long cacheTime;
    protected HttpHeaders headers = new HttpHeaders();
    protected HttpParams params = new HttpParams();
    protected int retryCount;
    protected String url;

    public Request(String str) {
        this.url = str;
        this.baseUrl = str;
        com.lzy.okgo.b p = com.lzy.okgo.b.p();
        String acceptLanguage = HttpHeaders.getAcceptLanguage();
        if (!TextUtils.isEmpty(acceptLanguage)) {
            headers(HttpHeaders.HEAD_KEY_ACCEPT_LANGUAGE, acceptLanguage);
        }
        String userAgent = HttpHeaders.getUserAgent();
        if (!TextUtils.isEmpty(userAgent)) {
            headers(HttpHeaders.HEAD_KEY_USER_AGENT, userAgent);
        }
        if (p.l() != null) {
            params(p.l());
        }
        if (p.k() != null) {
            headers(p.k());
        }
        this.retryCount = p.r();
        this.cacheMode = p.i();
        this.cacheTime = p.j();
    }

    public c<T> adapt() {
        c<T> cVar = this.J0;
        return cVar == null ? new com.lzy.okgo.c.b(this) : cVar;
    }

    public R addUrlParams(String str, List<String> list) {
        this.params.putUrlParams(str, list);
        return this;
    }

    public R cacheKey(String str) {
        com.lzy.okgo.h.c.b(str, "cacheKey == null");
        this.cacheKey = str;
        return this;
    }

    public R cacheMode(CacheMode cacheMode2) {
        this.cacheMode = cacheMode2;
        return this;
    }

    public R cachePolicy(com.lzy.okgo.cache.a.b<T> bVar) {
        com.lzy.okgo.h.c.b(bVar, "cachePolicy == null");
        this.M0 = bVar;
        return this;
    }

    public R cacheTime(long j) {
        if (j <= -1) {
            j = -1;
        }
        this.cacheTime = j;
        return this;
    }

    public R call(c<T> cVar) {
        com.lzy.okgo.h.c.b(cVar, "call == null");
        this.J0 = cVar;
        return this;
    }

    public R client(f0 f0Var) {
        com.lzy.okgo.h.c.b(f0Var, "OkHttpClient == null");
        this.f17313a = f0Var;
        return this;
    }

    public R converter(com.lzy.okgo.e.b<T> bVar) {
        com.lzy.okgo.h.c.b(bVar, "converter == null");
        this.L0 = bVar;
        return this;
    }

    public j0 execute() throws IOException {
        return getRawCall().execute();
    }

    public abstract h0 generateRequest(i0 i0Var);

    /* access modifiers changed from: protected */
    public abstract i0 generateRequestBody();

    public String getBaseUrl() {
        return this.baseUrl;
    }

    public String getCacheKey() {
        return this.cacheKey;
    }

    public CacheMode getCacheMode() {
        return this.cacheMode;
    }

    public com.lzy.okgo.cache.a.b<T> getCachePolicy() {
        return this.M0;
    }

    public long getCacheTime() {
        return this.cacheTime;
    }

    public com.lzy.okgo.e.b<T> getConverter() {
        if (this.L0 == null) {
            this.L0 = this.K0;
        }
        com.lzy.okgo.h.c.b(this.L0, "converter == null, do you forget to call Request#converter(Converter<T>) ?");
        return this.L0;
    }

    public HttpParams.FileWrapper getFileParam(String str) {
        List<HttpParams.FileWrapper> list = this.params.fileParamsMap.get(str);
        if (list == null || list.size() <= 0) {
            return null;
        }
        return list.get(0);
    }

    public HttpHeaders getHeaders() {
        return this.headers;
    }

    public abstract HttpMethod getMethod();

    public HttpParams getParams() {
        return this.params;
    }

    public j getRawCall() {
        i0 generateRequestBody = generateRequestBody();
        if (generateRequestBody != null) {
            b bVar = new b(generateRequestBody, this.K0);
            bVar.o(this.N0);
            this.I0 = generateRequest(bVar);
        } else {
            this.I0 = generateRequest(null);
        }
        if (this.f17313a == null) {
            this.f17313a = com.lzy.okgo.b.p().q();
        }
        return this.f17313a.a(this.I0);
    }

    public h0 getRequest() {
        return this.I0;
    }

    public int getRetryCount() {
        return this.retryCount;
    }

    public Object getTag() {
        return this.f17314b;
    }

    public String getUrl() {
        return this.url;
    }

    public String getUrlParam(String str) {
        List<String> list = this.params.urlParamsMap.get(str);
        if (list == null || list.size() <= 0) {
            return null;
        }
        return list.get(0);
    }

    public R headers(HttpHeaders httpHeaders) {
        this.headers.put(httpHeaders);
        return this;
    }

    public R params(HttpParams httpParams) {
        this.params.put(httpParams);
        return this;
    }

    public R removeAllHeaders() {
        this.headers.clear();
        return this;
    }

    public R removeAllParams() {
        this.params.clear();
        return this;
    }

    public R removeHeader(String str) {
        this.headers.remove(str);
        return this;
    }

    public R removeParam(String str) {
        this.params.remove(str);
        return this;
    }

    public R retryCount(int i) {
        if (i >= 0) {
            this.retryCount = i;
            return this;
        }
        throw new IllegalArgumentException("retryCount must > 0");
    }

    public void setCallback(com.lzy.okgo.d.c<T> cVar) {
        this.K0 = cVar;
    }

    public R tag(Object obj) {
        this.f17314b = obj;
        return this;
    }

    public R uploadInterceptor(b.c cVar) {
        this.N0 = cVar;
        return this;
    }

    public void execute(com.lzy.okgo.d.c<T> cVar) {
        com.lzy.okgo.h.c.b(cVar, "callback == null");
        this.K0 = cVar;
        adapt().k(cVar);
    }

    public R headers(String str, String str2) {
        this.headers.put(str, str2);
        return this;
    }

    public R params(Map<String, String> map, boolean... zArr) {
        this.params.put(map, zArr);
        return this;
    }

    public <E> E adapt(d<T, E> dVar) {
        c<T> cVar = this.J0;
        if (cVar == null) {
            cVar = new com.lzy.okgo.c.b<>(this);
        }
        return dVar.a(cVar, null);
    }

    public R params(String str, String str2, boolean... zArr) {
        this.params.put(str, str2, zArr);
        return this;
    }

    public R params(String str, int i, boolean... zArr) {
        this.params.put(str, i, zArr);
        return this;
    }

    public R params(String str, float f, boolean... zArr) {
        this.params.put(str, f, zArr);
        return this;
    }

    public <E> E adapt(a aVar, d<T, E> dVar) {
        c<T> cVar = this.J0;
        if (cVar == null) {
            cVar = new com.lzy.okgo.c.b<>(this);
        }
        return dVar.a(cVar, aVar);
    }

    public R params(String str, double d2, boolean... zArr) {
        this.params.put(str, d2, zArr);
        return this;
    }

    public R params(String str, long j, boolean... zArr) {
        this.params.put(str, j, zArr);
        return this;
    }

    public R params(String str, char c2, boolean... zArr) {
        this.params.put(str, c2, zArr);
        return this;
    }

    public R params(String str, boolean z, boolean... zArr) {
        this.params.put(str, z, zArr);
        return this;
    }
}
