package com.noober.background;

import android.content.Context;
import android.content.res.ColorStateList;
import android.content.res.TypedArray;
import android.graphics.drawable.AnimationDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.GradientDrawable;
import android.graphics.drawable.LayerDrawable;
import android.graphics.drawable.RippleDrawable;
import android.graphics.drawable.StateListDrawable;
import android.os.Build;
import android.text.TextUtils;
import android.util.AttributeSet;
import android.util.Log;
import android.view.InflateException;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.TextView;
import androidx.annotation.Nullable;
import com.noober.background.drawable.DrawableFactory;
import com.noober.background.drawable.TextViewFactory;
import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashMap;
import java.util.Map;

public class BackgroundFactory implements LayoutInflater.Factory2 {
    private static final Object[] mConstructorArgs = new Object[2];
    private static final HashMap<String, HashMap<String, Method>> methodMap = new HashMap<>();
    private static final Map<String, Constructor<? extends View>> sConstructorMap = new b.b.a();
    private static final Class<?>[] sConstructorSignature = {Context.class, AttributeSet.class};
    private LayoutInflater.Factory mViewCreateFactory;
    private LayoutInflater.Factory2 mViewCreateFactory2;

    /* access modifiers changed from: package-private */
    public class a implements View.OnClickListener {

        /* renamed from: a  reason: collision with root package name */
        final /* synthetic */ Method f20763a;

        /* renamed from: b  reason: collision with root package name */
        final /* synthetic */ Context f20764b;

        a(Method method, Context context) {
            this.f20763a = method;
            this.f20764b = context;
        }

        public void onClick(View view) {
            try {
                this.f20763a.invoke(this.f20764b, new Object[0]);
            } catch (IllegalAccessException e2) {
                e2.printStackTrace();
            } catch (InvocationTargetException e3) {
                e3.printStackTrace();
            }
        }
    }

    private static View createView(Context context, String str, String str2) throws InflateException {
        String str3;
        Map<String, Constructor<? extends View>> map = sConstructorMap;
        Constructor<? extends View> constructor = map.get(str);
        if (constructor == null) {
            try {
                ClassLoader classLoader = context.getClassLoader();
                if (str2 != null) {
                    str3 = str2 + str;
                } else {
                    str3 = str;
                }
                constructor = classLoader.loadClass(str3).asSubclass(View.class).getConstructor(sConstructorSignature);
                map.put(str, constructor);
            } catch (Exception unused) {
                Log.w("BackgroundLibrary", "cannot create 【" + str + "】 : ");
                return null;
            }
        }
        constructor.setAccessible(true);
        return (View) constructor.newInstance(mConstructorArgs);
    }

    private static View createViewFromTag(Context context, String str, AttributeSet attributeSet) {
        if (TextUtils.isEmpty(str)) {
            return null;
        }
        if (str.equals("view")) {
            str = attributeSet.getAttributeValue(null, "class");
        }
        try {
            Object[] objArr = mConstructorArgs;
            objArr[0] = context;
            objArr[1] = attributeSet;
            if (-1 == str.indexOf(46)) {
                View createView = "View".equals(str) ? createView(context, str, "android.view.") : null;
                if (createView == null) {
                    createView = createView(context, str, "android.widget.");
                }
                if (createView == null) {
                    createView = createView(context, str, "android.webkit.");
                }
                objArr[0] = null;
                objArr[1] = null;
                return createView;
            }
            View createView2 = createView(context, str, null);
            objArr[0] = null;
            objArr[1] = null;
            return createView2;
        } catch (Exception unused) {
            Log.w("BackgroundLibrary", "cannot create 【" + str + "】 : ");
            Object[] objArr2 = mConstructorArgs;
            objArr2[0] = null;
            objArr2[1] = null;
            return null;
        } catch (Throwable th) {
            Object[] objArr3 = mConstructorArgs;
            objArr3[0] = null;
            objArr3[1] = null;
            throw th;
        }
    }

    private static Method findDeclaredMethod(Class cls, String str) {
        Method method = null;
        try {
            method = cls.getDeclaredMethod(str, new Class[0]);
            method.setAccessible(true);
            return method;
        } catch (NoSuchMethodException unused) {
            return cls.getSuperclass() != null ? findDeclaredMethod(cls.getSuperclass(), str) : method;
        }
    }

    private static Method findMethod(Class cls, String str) {
        try {
            return cls.getMethod(str, new Class[0]);
        } catch (NoSuchMethodException unused) {
            return findDeclaredMethod(cls, str);
        }
    }

    private static Method getMethod(Class cls, String str) {
        Method method;
        HashMap<String, HashMap<String, Method>> hashMap = methodMap;
        HashMap<String, Method> hashMap2 = hashMap.get(cls.getCanonicalName());
        if (hashMap2 != null) {
            method = hashMap.get(cls.getCanonicalName()).get(str);
        } else {
            hashMap2 = new HashMap<>();
            hashMap.put(cls.getCanonicalName(), hashMap2);
            method = null;
        }
        if (method == null && (method = findMethod(cls, str)) != null) {
            hashMap2.put(str, method);
        }
        return method;
    }

    private static boolean hasGradientState(TypedArray typedArray) {
        return typedArray.hasValue(R.styleable.background_bl_checkable_gradient_startColor) || typedArray.hasValue(R.styleable.background_bl_checked_gradient_startColor) || typedArray.hasValue(R.styleable.background_bl_enabled_gradient_startColor) || typedArray.hasValue(R.styleable.background_bl_selected_gradient_startColor) || typedArray.hasValue(R.styleable.background_bl_pressed_gradient_startColor) || typedArray.hasValue(R.styleable.background_bl_focused_gradient_startColor);
    }

    private static boolean hasStatus(int i, int i2) {
        return (i & i2) == i2;
    }

    /* JADX WARNING: Removed duplicated region for block: B:24:0x0066  */
    /* JADX WARNING: Removed duplicated region for block: B:33:0x0084  */
    /* JADX WARNING: Removed duplicated region for block: B:34:0x0088  */
    private static void setBackground(Drawable drawable, View view, TypedArray typedArray) {
        LayerDrawable layerDrawable;
        int i;
        int i2 = R.styleable.background_bl_stroke_width;
        float f = 0.0f;
        if (typedArray.hasValue(i2)) {
            int i3 = R.styleable.background_bl_stroke_position;
            if (typedArray.hasValue(i3)) {
                float dimension = typedArray.getDimension(i2, 0.0f);
                int i4 = typedArray.getInt(i3, 0);
                float f2 = hasStatus(i4, 2) ? 0.0f : -dimension;
                float f3 = hasStatus(i4, 4) ? 0.0f : -dimension;
                float f4 = hasStatus(i4, 8) ? 0.0f : -dimension;
                float f5 = hasStatus(i4, 16) ? 0.0f : -dimension;
                LayerDrawable layerDrawable2 = new LayerDrawable(new Drawable[]{drawable});
                layerDrawable2.setLayerInset(0, (int) f2, (int) f3, (int) f4, (int) f5);
                layerDrawable = layerDrawable2;
                i = R.styleable.background_bl_shape_alpha;
                if (typedArray.hasValue(i)) {
                    float f6 = typedArray.getFloat(i, 0.0f);
                    if (f6 >= 1.0f) {
                        f = 255.0f;
                    } else if (f6 > 0.0f) {
                        f = f6 * 255.0f;
                    }
                    layerDrawable.setAlpha((int) f);
                }
                if (Build.VERSION.SDK_INT < 16) {
                    view.setBackground(layerDrawable);
                    return;
                } else {
                    view.setBackgroundDrawable(layerDrawable);
                    return;
                }
            }
        }
        layerDrawable = drawable;
        i = R.styleable.background_bl_shape_alpha;
        if (typedArray.hasValue(i)) {
        }
        if (Build.VERSION.SDK_INT < 16) {
        }
    }

    private static void setDrawable(Drawable drawable, View view, TypedArray typedArray, TypedArray typedArray2) {
        if (view instanceof TextView) {
            int i = R.styleable.bl_other_bl_position;
            if (!typedArray.hasValue(i)) {
                setBackground(drawable, view, typedArray2);
            } else if (typedArray.getInt(i, 0) == 1) {
                drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
                ((TextView) view).setCompoundDrawables(drawable, null, null, null);
            } else if (typedArray.getInt(i, 0) == 2) {
                drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
                ((TextView) view).setCompoundDrawables(null, drawable, null, null);
            } else if (typedArray.getInt(i, 0) == 4) {
                drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
                ((TextView) view).setCompoundDrawables(null, null, drawable, null);
            } else if (typedArray.getInt(i, 0) == 8) {
                drawable.setBounds(0, 0, drawable.getMinimumWidth(), drawable.getMinimumHeight());
                ((TextView) view).setCompoundDrawables(null, null, null, drawable);
            }
        } else {
            setBackground(drawable, view, typedArray2);
        }
    }

    @Nullable
    public static View setViewBackground(Context context, AttributeSet attributeSet, View view) {
        return setViewBackground(null, context, attributeSet, view);
    }

    public View onCreateView(String str, Context context, AttributeSet attributeSet) {
        View view = null;
        if (str.startsWith("com.noober.background.view")) {
            return null;
        }
        LayoutInflater.Factory2 factory2 = this.mViewCreateFactory2;
        if (factory2 != null) {
            View onCreateView = factory2.onCreateView(str, context, attributeSet);
            view = onCreateView == null ? this.mViewCreateFactory2.onCreateView(null, str, context, attributeSet) : onCreateView;
        } else {
            LayoutInflater.Factory factory = this.mViewCreateFactory;
            if (factory != null) {
                view = factory.onCreateView(str, context, attributeSet);
            }
        }
        return setViewBackground(str, context, attributeSet, view);
    }

    public void setInterceptFactory(LayoutInflater.Factory factory) {
        this.mViewCreateFactory = factory;
    }

    public void setInterceptFactory2(LayoutInflater.Factory2 factory2) {
        this.mViewCreateFactory2 = factory2;
    }

    /* JADX WARNING: Code restructure failed: missing block: B:131:0x0290, code lost:
        r0 = th;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:132:0x0291, code lost:
        r18 = r15;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:133:0x0294, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:134:0x0295, code lost:
        r18 = r15;
        r13 = r23;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:30:0x00af, code lost:
        r0 = e;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:31:0x00b0, code lost:
        r13 = r23;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Removed duplicated region for block: B:109:0x01f5 A[Catch:{ Exception -> 0x028b }] */
    /* JADX WARNING: Removed duplicated region for block: B:120:0x0247 A[Catch:{ Exception -> 0x028b }] */
    /* JADX WARNING: Removed duplicated region for block: B:127:0x0287  */
    /* JADX WARNING: Removed duplicated region for block: B:131:0x0290 A[ExcHandler: all (th java.lang.Throwable), Splitter:B:4:0x004f] */
    /* JADX WARNING: Removed duplicated region for block: B:139:0x02bc  */
    /* JADX WARNING: Removed duplicated region for block: B:144:0x02e1  */
    /* JADX WARNING: Removed duplicated region for block: B:94:0x01b6 A[Catch:{ Exception -> 0x028b }] */
    /* JADX WARNING: Removed duplicated region for block: B:99:0x01cb A[Catch:{ Exception -> 0x028b }] */
    @Nullable
    private static View setViewBackground(String str, Context context, AttributeSet attributeSet, View view) {
        TypedArray typedArray;
        View view2;
        Exception e2;
        int i;
        StateListDrawable stateListDrawable;
        GradientDrawable gradientDrawable;
        int i2;
        StateListDrawable stateGradientDrawable;
        TypedArray obtainStyledAttributes = context.obtainStyledAttributes(attributeSet, R.styleable.background);
        TypedArray obtainStyledAttributes2 = context.obtainStyledAttributes(attributeSet, R.styleable.background_press);
        TypedArray obtainStyledAttributes3 = context.obtainStyledAttributes(attributeSet, R.styleable.background_selector);
        TypedArray obtainStyledAttributes4 = context.obtainStyledAttributes(attributeSet, R.styleable.text_selector);
        TypedArray obtainStyledAttributes5 = context.obtainStyledAttributes(attributeSet, R.styleable.background_button_drawable);
        TypedArray obtainStyledAttributes6 = context.obtainStyledAttributes(attributeSet, R.styleable.bl_other);
        TypedArray obtainStyledAttributes7 = context.obtainStyledAttributes(attributeSet, R.styleable.bl_anim);
        TypedArray obtainStyledAttributes8 = context.obtainStyledAttributes(attributeSet, R.styleable.background_multi_selector);
        TypedArray obtainStyledAttributes9 = context.obtainStyledAttributes(attributeSet, R.styleable.background_multi_selector_text);
        TypedArray obtainStyledAttributes10 = context.obtainStyledAttributes(attributeSet, R.styleable.bl_text);
        int i3 = Build.VERSION.SDK_INT;
        TypedArray obtainStyledAttributes11 = i3 < 21 ? context.obtainStyledAttributes(attributeSet, R.styleable.background_selector_pre_21) : null;
        try {
            if (obtainStyledAttributes.getIndexCount() == 0) {
                if (obtainStyledAttributes3.getIndexCount() == 0 && obtainStyledAttributes2.getIndexCount() == 0 && obtainStyledAttributes4.getIndexCount() == 0 && obtainStyledAttributes5.getIndexCount() == 0 && obtainStyledAttributes7.getIndexCount() == 0 && obtainStyledAttributes8.getIndexCount() == 0 && obtainStyledAttributes9.getIndexCount() == 0 && obtainStyledAttributes10.getIndexCount() == 0 && obtainStyledAttributes6.getIndexCount() == 0) {
                    obtainStyledAttributes.recycle();
                    obtainStyledAttributes2.recycle();
                    obtainStyledAttributes3.recycle();
                    obtainStyledAttributes4.recycle();
                    obtainStyledAttributes5.recycle();
                    obtainStyledAttributes6.recycle();
                    obtainStyledAttributes7.recycle();
                    obtainStyledAttributes8.recycle();
                    obtainStyledAttributes9.recycle();
                    obtainStyledAttributes10.recycle();
                    if (obtainStyledAttributes11 != null) {
                        obtainStyledAttributes11.recycle();
                    }
                    return view;
                }
            }
            view2 = view == null ? createViewFromTag(context, str, attributeSet) : view;
            if (view2 == null) {
                obtainStyledAttributes.recycle();
                obtainStyledAttributes2.recycle();
                obtainStyledAttributes3.recycle();
                obtainStyledAttributes4.recycle();
                obtainStyledAttributes5.recycle();
                obtainStyledAttributes6.recycle();
                obtainStyledAttributes7.recycle();
                obtainStyledAttributes8.recycle();
                obtainStyledAttributes9.recycle();
                obtainStyledAttributes10.recycle();
                if (obtainStyledAttributes11 != null) {
                    obtainStyledAttributes11.recycle();
                }
                return null;
            }
            if (obtainStyledAttributes3.getIndexCount() > 0) {
                if (obtainStyledAttributes8.getIndexCount() > 0) {
                    throw new IllegalArgumentException("Background_selector and background_multi_selector cannot be used simultaneously");
                }
            }
            if (obtainStyledAttributes4.getIndexCount() > 0) {
                if (obtainStyledAttributes9.getIndexCount() > 0) {
                    throw new IllegalArgumentException("text_selector and background_multi_selector_text cannot be used simultaneously");
                }
            }
            if (obtainStyledAttributes5.getIndexCount() <= 0 || !(view2 instanceof CompoundButton)) {
                i = i3;
                if (obtainStyledAttributes3.getIndexCount() > 0) {
                    stateGradientDrawable = DrawableFactory.getSelectorDrawable(obtainStyledAttributes, obtainStyledAttributes3);
                    setDrawable(stateGradientDrawable, view2, obtainStyledAttributes6, obtainStyledAttributes);
                } else if (obtainStyledAttributes2.getIndexCount() > 0) {
                    GradientDrawable drawable = DrawableFactory.getDrawable(obtainStyledAttributes);
                    StateListDrawable pressDrawable = DrawableFactory.getPressDrawable(drawable, obtainStyledAttributes, obtainStyledAttributes2);
                    setDrawable(pressDrawable, view2, obtainStyledAttributes6, obtainStyledAttributes);
                    typedArray = obtainStyledAttributes11;
                    stateListDrawable = pressDrawable;
                    gradientDrawable = drawable;
                    if (!(view2 instanceof TextView) && obtainStyledAttributes4.getIndexCount() > 0) {
                        ((TextView) view2).setTextColor(DrawableFactory.getTextSelectorColor(obtainStyledAttributes4));
                    } else if (!(view2 instanceof TextView) && obtainStyledAttributes9.getIndexCount() > 0) {
                        ((TextView) view2).setTextColor(DrawableFactory.getMultiTextColorSelectorColorCreator(context, obtainStyledAttributes9));
                    } else if ((view2 instanceof TextView) && obtainStyledAttributes10.getIndexCount() > 0) {
                        TextViewFactory.setTextGradientColor(context, attributeSet, (TextView) view2);
                    }
                    if (obtainStyledAttributes.getBoolean(R.styleable.background_bl_ripple_enable, false)) {
                        int i4 = R.styleable.background_bl_ripple_color;
                        if (obtainStyledAttributes.hasValue(i4)) {
                            int color = obtainStyledAttributes.getColor(i4, 0);
                            if (i >= 21) {
                                if (stateListDrawable == null) {
                                    stateListDrawable = gradientDrawable;
                                }
                                setBackground(new RippleDrawable(ColorStateList.valueOf(color), stateListDrawable, stateListDrawable), view2, obtainStyledAttributes);
                            } else if (stateListDrawable == null) {
                                StateListDrawable stateListDrawable2 = new StateListDrawable();
                                GradientDrawable drawable2 = DrawableFactory.getDrawable(obtainStyledAttributes);
                                drawable2.setColor(color);
                                stateListDrawable2.addState(new int[]{-16842919}, gradientDrawable);
                                stateListDrawable2.addState(new int[]{16842919}, drawable2);
                                setDrawable(stateListDrawable2, view2, obtainStyledAttributes6, obtainStyledAttributes);
                            }
                        }
                    }
                    i2 = R.styleable.bl_other_bl_function;
                    if (obtainStyledAttributes6.hasValue(i2)) {
                        String string = obtainStyledAttributes6.getString(i2);
                        if (!TextUtils.isEmpty(string)) {
                            Context context2 = view2.getContext();
                            Method method = getMethod(context2.getClass(), string);
                            if (method != null) {
                                view2.setOnClickListener(new a(method, context2));
                            }
                        }
                    }
                    obtainStyledAttributes.recycle();
                    obtainStyledAttributes2.recycle();
                    obtainStyledAttributes3.recycle();
                    obtainStyledAttributes4.recycle();
                    obtainStyledAttributes5.recycle();
                    obtainStyledAttributes6.recycle();
                    obtainStyledAttributes7.recycle();
                    obtainStyledAttributes8.recycle();
                    obtainStyledAttributes9.recycle();
                    obtainStyledAttributes10.recycle();
                    if (typedArray != null) {
                        typedArray.recycle();
                    }
                    return view2;
                } else if (obtainStyledAttributes8.getIndexCount() > 0) {
                    stateGradientDrawable = DrawableFactory.getMultiSelectorDrawable(context, obtainStyledAttributes8, obtainStyledAttributes);
                    setBackground(stateGradientDrawable, view2, obtainStyledAttributes);
                } else if (obtainStyledAttributes.getIndexCount() > 0) {
                    if (obtainStyledAttributes11 != null && obtainStyledAttributes11.getIndexCount() > 0) {
                        stateGradientDrawable = DrawableFactory.getSelectorPre21Drawable(obtainStyledAttributes);
                        setDrawable(stateGradientDrawable, view2, obtainStyledAttributes6, obtainStyledAttributes);
                    } else if (hasGradientState(obtainStyledAttributes)) {
                        stateGradientDrawable = DrawableFactory.getStateGradientDrawable(obtainStyledAttributes);
                        setDrawable(stateGradientDrawable, view2, obtainStyledAttributes6, obtainStyledAttributes);
                    } else {
                        gradientDrawable = DrawableFactory.getDrawable(obtainStyledAttributes);
                        setDrawable(gradientDrawable, view2, obtainStyledAttributes6, obtainStyledAttributes);
                        typedArray = obtainStyledAttributes11;
                        stateListDrawable = null;
                        if (!(view2 instanceof TextView)) {
                        }
                        if (!(view2 instanceof TextView)) {
                        }
                        TextViewFactory.setTextGradientColor(context, attributeSet, (TextView) view2);
                        if (obtainStyledAttributes.getBoolean(R.styleable.background_bl_ripple_enable, false)) {
                        }
                        i2 = R.styleable.bl_other_bl_function;
                        if (obtainStyledAttributes6.hasValue(i2)) {
                        }
                        obtainStyledAttributes.recycle();
                        obtainStyledAttributes2.recycle();
                        obtainStyledAttributes3.recycle();
                        obtainStyledAttributes4.recycle();
                        obtainStyledAttributes5.recycle();
                        obtainStyledAttributes6.recycle();
                        obtainStyledAttributes7.recycle();
                        obtainStyledAttributes8.recycle();
                        obtainStyledAttributes9.recycle();
                        obtainStyledAttributes10.recycle();
                        if (typedArray != null) {
                        }
                        return view2;
                    }
                } else if (obtainStyledAttributes7.getIndexCount() > 0) {
                    AnimationDrawable animationDrawable = DrawableFactory.getAnimationDrawable(obtainStyledAttributes7);
                    setBackground(animationDrawable, view2, obtainStyledAttributes);
                    typedArray = obtainStyledAttributes11;
                    try {
                        if (obtainStyledAttributes7.getBoolean(R.styleable.bl_anim_bl_anim_auto_start, false)) {
                            animationDrawable.start();
                        }
                        gradientDrawable = null;
                        stateListDrawable = null;
                        if (!(view2 instanceof TextView)) {
                        }
                        if (!(view2 instanceof TextView)) {
                        }
                        TextViewFactory.setTextGradientColor(context, attributeSet, (TextView) view2);
                        if (obtainStyledAttributes.getBoolean(R.styleable.background_bl_ripple_enable, false)) {
                        }
                        i2 = R.styleable.bl_other_bl_function;
                        if (obtainStyledAttributes6.hasValue(i2)) {
                        }
                        obtainStyledAttributes.recycle();
                        obtainStyledAttributes2.recycle();
                        obtainStyledAttributes3.recycle();
                        obtainStyledAttributes4.recycle();
                        obtainStyledAttributes5.recycle();
                        obtainStyledAttributes6.recycle();
                        obtainStyledAttributes7.recycle();
                        obtainStyledAttributes8.recycle();
                        obtainStyledAttributes9.recycle();
                        obtainStyledAttributes10.recycle();
                        if (typedArray != null) {
                        }
                        return view2;
                    } catch (Exception e3) {
                        e2 = e3;
                        try {
                            e2.printStackTrace();
                            obtainStyledAttributes.recycle();
                            obtainStyledAttributes2.recycle();
                            obtainStyledAttributes3.recycle();
                            obtainStyledAttributes4.recycle();
                            obtainStyledAttributes5.recycle();
                            obtainStyledAttributes6.recycle();
                            obtainStyledAttributes7.recycle();
                            obtainStyledAttributes8.recycle();
                            obtainStyledAttributes9.recycle();
                            obtainStyledAttributes10.recycle();
                            if (typedArray != null) {
                                typedArray.recycle();
                            }
                            return view2;
                        } catch (Throwable th) {
                            Throwable th2 = th;
                            obtainStyledAttributes.recycle();
                            obtainStyledAttributes2.recycle();
                            obtainStyledAttributes3.recycle();
                            obtainStyledAttributes4.recycle();
                            obtainStyledAttributes5.recycle();
                            obtainStyledAttributes6.recycle();
                            obtainStyledAttributes7.recycle();
                            obtainStyledAttributes8.recycle();
                            obtainStyledAttributes9.recycle();
                            obtainStyledAttributes10.recycle();
                            if (typedArray != null) {
                                typedArray.recycle();
                            }
                            throw th2;
                        }
                    }
                }
                stateListDrawable = stateGradientDrawable;
                typedArray = obtainStyledAttributes11;
                gradientDrawable = null;
                if (!(view2 instanceof TextView)) {
                }
                if (!(view2 instanceof TextView)) {
                }
                TextViewFactory.setTextGradientColor(context, attributeSet, (TextView) view2);
                if (obtainStyledAttributes.getBoolean(R.styleable.background_bl_ripple_enable, false)) {
                }
                i2 = R.styleable.bl_other_bl_function;
                if (obtainStyledAttributes6.hasValue(i2)) {
                }
                obtainStyledAttributes.recycle();
                obtainStyledAttributes2.recycle();
                obtainStyledAttributes3.recycle();
                obtainStyledAttributes4.recycle();
                obtainStyledAttributes5.recycle();
                obtainStyledAttributes6.recycle();
                obtainStyledAttributes7.recycle();
                obtainStyledAttributes8.recycle();
                obtainStyledAttributes9.recycle();
                obtainStyledAttributes10.recycle();
                if (typedArray != null) {
                }
                return view2;
            }
            i = i3;
            ((CompoundButton) view2).setButtonDrawable(DrawableFactory.getButtonDrawable(obtainStyledAttributes, obtainStyledAttributes5));
            typedArray = obtainStyledAttributes11;
            gradientDrawable = null;
            stateListDrawable = null;
            if (!(view2 instanceof TextView)) {
            }
            if (!(view2 instanceof TextView)) {
            }
            TextViewFactory.setTextGradientColor(context, attributeSet, (TextView) view2);
            if (obtainStyledAttributes.getBoolean(R.styleable.background_bl_ripple_enable, false)) {
            }
            i2 = R.styleable.bl_other_bl_function;
            if (obtainStyledAttributes6.hasValue(i2)) {
            }
            obtainStyledAttributes.recycle();
            obtainStyledAttributes2.recycle();
            obtainStyledAttributes3.recycle();
            obtainStyledAttributes4.recycle();
            obtainStyledAttributes5.recycle();
            obtainStyledAttributes6.recycle();
            obtainStyledAttributes7.recycle();
            obtainStyledAttributes8.recycle();
            obtainStyledAttributes9.recycle();
            obtainStyledAttributes10.recycle();
            if (typedArray != null) {
            }
            return view2;
        } catch (Exception e4) {
            e2 = e4;
            typedArray = obtainStyledAttributes11;
            e2.printStackTrace();
            obtainStyledAttributes.recycle();
            obtainStyledAttributes2.recycle();
            obtainStyledAttributes3.recycle();
            obtainStyledAttributes4.recycle();
            obtainStyledAttributes5.recycle();
            obtainStyledAttributes6.recycle();
            obtainStyledAttributes7.recycle();
            obtainStyledAttributes8.recycle();
            obtainStyledAttributes9.recycle();
            obtainStyledAttributes10.recycle();
            if (typedArray != null) {
            }
            return view2;
        } catch (Throwable th3) {
        }
    }

    public View onCreateView(View view, String str, Context context, AttributeSet attributeSet) {
        return onCreateView(str, context, attributeSet);
    }
}
