package com.readystatesoftware.chuck.internal.data;

import android.net.Uri;
import com.ibm.icu.impl.number.Padder;
import com.liulishuo.filedownloader.model.FileDownloadModel;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Locale;
import nl.qbusict.cupboard.annotation.Index;
import okhttp3.a0;
import tv.danmaku.ijk.media.player.IjkMediaPlayer;

public class HttpTransaction {
    public static final String[] PARTIAL_PROJECTION = {FileDownloadModel.I0, "requestDate", "tookMs", "method", "host", FileDownloadModel.K0, "scheme", "requestContentLength", "responseCode", IjkMediaPlayer.f.m, "responseContentLength"};
    private static final SimpleDateFormat TIME_ONLY_FMT = new SimpleDateFormat("HH:mm:ss", Locale.US);
    private Long _id;
    private String error;
    private String host;
    private String method;
    private String path;
    private String protocol;
    private String requestBody;
    private boolean requestBodyIsPlainText = true;
    private Long requestContentLength;
    private String requestContentType;
    @Index
    private Date requestDate;
    private String requestHeaders;
    private String responseBody;
    private boolean responseBodyIsPlainText = true;
    private Integer responseCode;
    private Long responseContentLength;
    private String responseContentType;
    private Date responseDate;
    private String responseHeaders;
    private String responseMessage;
    private String scheme;
    private Long tookMs;
    private String url;

    public enum Status {
        Requested,
        Complete,
        Failed
    }

    /* access modifiers changed from: package-private */
    public class a extends com.google.gson.u.a<List<b>> {
        a() {
        }
    }

    /* access modifiers changed from: package-private */
    public class b extends com.google.gson.u.a<List<b>> {
        b() {
        }
    }

    static /* synthetic */ class c {

        /* renamed from: a  reason: collision with root package name */
        static final /* synthetic */ int[] f20823a;

        /* JADX WARNING: Can't wrap try/catch for region: R(6:0|1|2|3|4|6) */
        /* JADX WARNING: Code restructure failed: missing block: B:7:?, code lost:
            return;
         */
        /* JADX WARNING: Failed to process nested try/catch */
        /* JADX WARNING: Missing exception handler attribute for start block: B:3:0x0012 */
        static {
            int[] iArr = new int[Status.values().length];
            f20823a = iArr;
            iArr[Status.Failed.ordinal()] = 1;
            f20823a[Status.Requested.ordinal()] = 2;
        }
    }

    private String formatBody(String str, String str2) {
        if (str2 == null || !str2.toLowerCase().contains("json")) {
            return (str2 == null || !str2.toLowerCase().contains("xml")) ? str : com.readystatesoftware.chuck.internal.support.b.d(str);
        }
        return com.readystatesoftware.chuck.internal.support.b.c(str);
    }

    private String formatBytes(long j) {
        return com.readystatesoftware.chuck.internal.support.b.a(j, true);
    }

    private List<b> toHttpHeaderList(a0 a0Var) {
        ArrayList arrayList = new ArrayList();
        int m = a0Var.m();
        for (int i = 0; i < m; i++) {
            arrayList.add(new b(a0Var.h(i), a0Var.o(i)));
        }
        return arrayList;
    }

    public String getDurationString() {
        if (this.tookMs == null) {
            return null;
        }
        return this.tookMs.longValue() + " ms";
    }

    public String getError() {
        return this.error;
    }

    public String getFormattedRequestBody() {
        return formatBody(this.requestBody, this.requestContentType);
    }

    public String getFormattedResponseBody() {
        return formatBody(this.responseBody, this.responseContentType);
    }

    public String getHost() {
        return this.host;
    }

    public Long getId() {
        return this._id;
    }

    public String getMethod() {
        return this.method;
    }

    public String getNotificationText() {
        int i = c.f20823a[getStatus().ordinal()];
        if (i == 1) {
            return " ! ! !  " + this.path;
        } else if (i != 2) {
            return String.valueOf(this.responseCode) + Padder.f14124a + this.path;
        } else {
            return " . . .  " + this.path;
        }
    }

    public String getPath() {
        return this.path;
    }

    public String getProtocol() {
        return this.protocol;
    }

    public String getRequestBody() {
        return this.requestBody;
    }

    public Long getRequestContentLength() {
        return this.requestContentLength;
    }

    public String getRequestContentType() {
        return this.requestContentType;
    }

    public Date getRequestDate() {
        return this.requestDate;
    }

    public String getRequestDateString() {
        Date date = this.requestDate;
        if (date != null) {
            return date.toString();
        }
        return null;
    }

    public List<b> getRequestHeaders() {
        return (List) com.readystatesoftware.chuck.internal.support.c.a().o(this.requestHeaders, new a().h());
    }

    public String getRequestHeadersString(boolean z) {
        return com.readystatesoftware.chuck.internal.support.b.b(getRequestHeaders(), z);
    }

    public String getRequestSizeString() {
        Long l = this.requestContentLength;
        return formatBytes(l != null ? l.longValue() : 0);
    }

    public String getRequestStartTimeString() {
        Date date = this.requestDate;
        if (date != null) {
            return TIME_ONLY_FMT.format(date);
        }
        return null;
    }

    public String getResponseBody() {
        return this.responseBody;
    }

    public Integer getResponseCode() {
        return this.responseCode;
    }

    public Long getResponseContentLength() {
        return this.responseContentLength;
    }

    public String getResponseContentType() {
        return this.responseContentType;
    }

    public Date getResponseDate() {
        return this.responseDate;
    }

    public String getResponseDateString() {
        Date date = this.responseDate;
        if (date != null) {
            return date.toString();
        }
        return null;
    }

    public List<b> getResponseHeaders() {
        return (List) com.readystatesoftware.chuck.internal.support.c.a().o(this.responseHeaders, new b().h());
    }

    public String getResponseHeadersString(boolean z) {
        return com.readystatesoftware.chuck.internal.support.b.b(getResponseHeaders(), z);
    }

    public String getResponseMessage() {
        return this.responseMessage;
    }

    public String getResponseSizeString() {
        Long l = this.responseContentLength;
        if (l != null) {
            return formatBytes(l.longValue());
        }
        return null;
    }

    public String getResponseSummaryText() {
        int i = c.f20823a[getStatus().ordinal()];
        if (i == 1) {
            return this.error;
        }
        if (i == 2) {
            return null;
        }
        return String.valueOf(this.responseCode) + Padder.f14124a + this.responseMessage;
    }

    public String getScheme() {
        return this.scheme;
    }

    public Status getStatus() {
        if (this.error != null) {
            return Status.Failed;
        }
        if (this.responseCode == null) {
            return Status.Requested;
        }
        return Status.Complete;
    }

    public Long getTookMs() {
        return this.tookMs;
    }

    public String getTotalSizeString() {
        Long l = this.requestContentLength;
        long j = 0;
        long longValue = l != null ? l.longValue() : 0;
        Long l2 = this.responseContentLength;
        if (l2 != null) {
            j = l2.longValue();
        }
        return formatBytes(longValue + j);
    }

    public String getUrl() {
        return this.url;
    }

    public boolean isSsl() {
        return this.scheme.toLowerCase().equals(c.a.b.c.b.f4999a);
    }

    public boolean requestBodyIsPlainText() {
        return this.requestBodyIsPlainText;
    }

    public boolean responseBodyIsPlainText() {
        return this.responseBodyIsPlainText;
    }

    public void setError(String str) {
        this.error = str;
    }

    public void setId(long j) {
        this._id = Long.valueOf(j);
    }

    public void setMethod(String str) {
        this.method = str;
    }

    public void setProtocol(String str) {
        this.protocol = str;
    }

    public void setRequestBody(String str) {
        this.requestBody = str;
    }

    public void setRequestBodyIsPlainText(boolean z) {
        this.requestBodyIsPlainText = z;
    }

    public void setRequestContentLength(Long l) {
        this.requestContentLength = l;
    }

    public void setRequestContentType(String str) {
        this.requestContentType = str;
    }

    public void setRequestDate(Date date) {
        this.requestDate = date;
    }

    public void setRequestHeaders(a0 a0Var) {
        setRequestHeaders(toHttpHeaderList(a0Var));
    }

    public void setResponseBody(String str) {
        this.responseBody = str;
    }

    public void setResponseBodyIsPlainText(boolean z) {
        this.responseBodyIsPlainText = z;
    }

    public void setResponseCode(Integer num) {
        this.responseCode = num;
    }

    public void setResponseContentLength(Long l) {
        this.responseContentLength = l;
    }

    public void setResponseContentType(String str) {
        this.responseContentType = str;
    }

    public void setResponseDate(Date date) {
        this.responseDate = date;
    }

    public void setResponseHeaders(a0 a0Var) {
        setResponseHeaders(toHttpHeaderList(a0Var));
    }

    public void setResponseMessage(String str) {
        this.responseMessage = str;
    }

    public void setTookMs(Long l) {
        this.tookMs = l;
    }

    public void setUrl(String str) {
        String str2;
        this.url = str;
        Uri parse = Uri.parse(str);
        this.host = parse.getHost();
        StringBuilder sb = new StringBuilder();
        sb.append(parse.getPath());
        if (parse.getQuery() != null) {
            str2 = "?" + parse.getQuery();
        } else {
            str2 = "";
        }
        sb.append(str2);
        this.path = sb.toString();
        this.scheme = parse.getScheme();
    }

    public void setRequestHeaders(List<b> list) {
        this.requestHeaders = com.readystatesoftware.chuck.internal.support.c.a().z(list);
    }

    public void setResponseHeaders(List<b> list) {
        this.responseHeaders = com.readystatesoftware.chuck.internal.support.c.a().z(list);
    }
}
